""" Cisco_IOS_XR_l2vpn_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR l2vpn package operational data.

This module contains definitions
for the following management objects\:
  l2vpn\-forwarding\: Show L2VPN forwarding
  l2vpnv2\: l2vpnv2
  l2vpn\: l2vpn
  generic\-interface\-list\-v2\: generic interface list v2

Copyright (c) 2013\-2016 by Cisco Systems, Inc.
All rights reserved.

"""


import re
import collections

from enum import Enum

from ydk.types import Empty, YList, YLeafList, DELETE, Decimal64, FixedBitsDict

from ydk.errors import YPYError, YPYModelError



class EvpnMainInterfaceEnum(Enum):
    """
    EvpnMainInterfaceEnum

    Evpn main interface

    .. data:: evpn_main_interface_ac = 1

    	EVPN main interface type AC

    .. data:: evpn_main_interface_nve = 2

    	EVPN main interface type NVE

    .. data:: evpn_main_interface_ac_vfi = 3

    	EVPN main interface type AC VFI

    .. data:: evpn_main_interface_ac_pw = 4

    	EVPN main interface type AC PW

    """

    evpn_main_interface_ac = 1

    evpn_main_interface_nve = 2

    evpn_main_interface_ac_vfi = 3

    evpn_main_interface_ac_pw = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['EvpnMainInterfaceEnum']


class IccpSmPortStateEnum(Enum):
    """
    IccpSmPortStateEnum

    ICCP\-based service multi\-homing port state

    .. data:: unknown = 0

    	Unknown

    .. data:: unconfigured = 1

    	Unconfigured

    .. data:: unsynchronized = 2

    	Unsynchronized

    .. data:: operational = 3

    	Operational

    .. data:: failed = 4

    	Failed

    .. data:: reverting = 5

    	Reverting

    """

    unknown = 0

    unconfigured = 1

    unsynchronized = 2

    operational = 3

    failed = 4

    reverting = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['IccpSmPortStateEnum']


class IccpSmStateEnum(Enum):
    """
    IccpSmStateEnum

    ICCP\-based service multi\-homing group state

    .. data:: unresolved = 0

    	Unresolved

    .. data:: provisioned = 1

    	Provisioned

    .. data:: connecting = 2

    	Connecting

    .. data:: connected = 3

    	Connected

    .. data:: synchronizing = 4

    	Synchronizing

    .. data:: synchronized = 5

    	Synchronized

    """

    unresolved = 0

    provisioned = 1

    connecting = 2

    connected = 3

    synchronizing = 4

    synchronized = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['IccpSmStateEnum']


class IflistRepStatusEnum(Enum):
    """
    IflistRepStatusEnum

    Interface list replication status

    .. data:: invalid = 0

    	Invalid

    .. data:: pending = 1

    	Pending

    .. data:: done = 2

    	Done

    .. data:: not_supported = 3

    	Not supported

    .. data:: failed = 4

    	Failed

    """

    invalid = 0

    pending = 1

    done = 2

    not_supported = 3

    failed = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['IflistRepStatusEnum']


class L2FibFeatureEnum(Enum):
    """
    L2FibFeatureEnum

    L2fib feature

    .. data:: l2fib_feature_dhcp_snooping = 0

    	l2fib feature dhcp snooping

    .. data:: l2fib_feature_igmp_snooping = 1

    	l2fib feature igmp snooping

    .. data:: l2fib_feature_mld_snooping = 2

    	l2fib feature mld snooping

    .. data:: l2fib_feature_max = 3

    	l2fib feature max

    """

    l2fib_feature_dhcp_snooping = 0

    l2fib_feature_igmp_snooping = 1

    l2fib_feature_mld_snooping = 2

    l2fib_feature_max = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibFeatureEnum']


class L2FibG8032ApsPortStatusEnum(Enum):
    """
    L2FibG8032ApsPortStatusEnum

    APS port status

    .. data:: l2fib_aps_port_state_unknown = 0

    	APS port state unknown

    .. data:: l2fib_aps_port_state_unbound = 1

    	APS port state unbound

    .. data:: l2fib_aps_port_state_bound = 2

    	APS port state bound

    """

    l2fib_aps_port_state_unknown = 0

    l2fib_aps_port_state_unbound = 1

    l2fib_aps_port_state_bound = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibG8032ApsPortStatusEnum']


class L2FibG8032RplEnum(Enum):
    """
    L2FibG8032RplEnum

    RPL types in g8032 ring

    .. data:: rpl_unknown = 0

    	No RPL info

    .. data:: port0_owner = 1

    	Port 0 owner

    .. data:: port0_neighbor = 2

    	Port 0 neighbor

    .. data:: port0_next_neighbor = 3

    	Port 0 next neighbor

    .. data:: port1_owner = 4

    	Port 1 owner

    .. data:: port1_neighbor = 5

    	Port 1 neighbor

    .. data:: port1_next_neighbor = 6

    	Port 1 next neighbor

    """

    rpl_unknown = 0

    port0_owner = 1

    port0_neighbor = 2

    port0_next_neighbor = 3

    port1_owner = 4

    port1_neighbor = 5

    port1_next_neighbor = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibG8032RplEnum']


class L2FibGroupStateEnum(Enum):
    """
    L2FibGroupStateEnum

    group state

    .. data:: up = 0

    	Group State Up

    .. data:: down = 1

    	Group State Down

    """

    up = 0

    down = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibGroupStateEnum']


class L2FibIpAddrEnum(Enum):
    """
    L2FibIpAddrEnum

    L2fib ip addr

    .. data:: v4 = 4

    	v4

    .. data:: v6 = 6

    	v6

    """

    v4 = 4

    v6 = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibIpAddrEnum']


class L2FibL2TpSessionEnum(Enum):
    """
    L2FibL2TpSessionEnum

    L2TPv2 and L2TPv3 session type

    .. data:: l2tpv3 = 0

    	L2TPv3 session

    .. data:: l2tpv2 = 1

    	L2TPv2 session

    """

    l2tpv3 = 0

    l2tpv2 = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibL2TpSessionEnum']


class L2FibLoadBalEnum(Enum):
    """
    L2FibLoadBalEnum

    L2fib load bal

    .. data:: flow_undef = 0

    	Load Balance Flow Undefined

    .. data:: src_dst_mac = 1

    	Load Balance Flow src-dst-mac

    .. data:: src_dst_ip = 2

    	Load Balance Flow src-dst-ip

    .. data:: vc = 3

    	Load Balance VC based

    """

    flow_undef = 0

    src_dst_mac = 1

    src_dst_ip = 2

    vc = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibLoadBalEnum']


class L2FibMainIfInstanceStateEnum(Enum):
    """
    L2FibMainIfInstanceStateEnum

    State of a main port instance

    .. data:: forwarding = 0

    	Forwarding state

    .. data:: blocked = 1

    	Blocked state

    .. data:: mac_learning = 2

    	Mac learning state

    .. data:: nack = 3

    	Nack state

    .. data:: forwarning_not_useful = 4

    	Forwarding not useful state

    .. data:: blocked_not_useful = 5

    	Blocked not useful state

    .. data:: mac_learning_not_useful = 6

    	Mac Learning not useful state

    .. data:: blocked_data_only = 7

    	Blocked data only state

    .. data:: multicast_pe2ce_blocked = 8

    	Multicast PE to CE blocked state

    .. data:: multicast_blocked = 9

    	Multicast blocked state

    .. data:: port_state_unknown = 10

    	Port state unknown

    """

    forwarding = 0

    blocked = 1

    mac_learning = 2

    nack = 3

    forwarning_not_useful = 4

    blocked_not_useful = 5

    mac_learning_not_useful = 6

    blocked_data_only = 7

    multicast_pe2ce_blocked = 8

    multicast_blocked = 9

    port_state_unknown = 10


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibMainIfInstanceStateEnum']


class L2FibPwIdEnum(Enum):
    """
    L2FibPwIdEnum

    Pseudowire ID type

    .. data:: default = 0

    	Default value - not set

    .. data:: manual = 1

    	Manual pseudowire ID

    .. data:: vpls = 2

    	VPLS pseudowire ID

    .. data:: vpws = 3

    	VPWS pseudowire ID

    .. data:: vpls_ldp = 4

    	VPLS with LDP signaling pseudowire ID

    .. data:: l2fib_pw_id_type_pwr = 5

    	PW-routing ID

    .. data:: l2fib_pw_id_type_evpn = 6

    	EVPN pseudowire ID

    """

    default = 0

    manual = 1

    vpls = 2

    vpws = 3

    vpls_ldp = 4

    l2fib_pw_id_type_pwr = 5

    l2fib_pw_id_type_evpn = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibPwIdEnum']


class L2FibPwRedundancyRoleEnum(Enum):
    """
    L2FibPwRedundancyRoleEnum

    Pseudowire redundancy role

    .. data:: primary = 0

    	Primary pseudowire

    .. data:: backup = 1

    	Backup pseudowire

    """

    primary = 0

    backup = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibPwRedundancyRoleEnum']


class L2FibStormControlRateUnitEnum(Enum):
    """
    L2FibStormControlRateUnitEnum

    Storm Control Rate Unit Type

    .. data:: pps = 0

    	Packets Per Second

    .. data:: kb_ps = 1

    	Kilobits Per Second

    """

    pps = 0

    kb_ps = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2FibStormControlRateUnitEnum']


class L2VpnAcEncapEnum(Enum):
    """
    L2VpnAcEncapEnum

    L2vpn ac encap

    .. data:: unknown_encap = 0

    	unknown encap

    .. data:: vlan = 1

    	vlan

    .. data:: qinq = 2

    	qinq

    .. data:: qin_any = 3

    	qin any

    .. data:: ethernet = 4

    	ethernet

    .. data:: atm_aal0 = 5

    	atm aal0

    .. data:: atm_aal5 = 6

    	atm aal5

    .. data:: atm_vp = 7

    	atm vp

    .. data:: atm_port = 8

    	atm port

    .. data:: hdlc = 9

    	hdlc

    .. data:: fr_dlci = 10

    	fr dlci

    .. data:: fr_dlci_local = 11

    	fr dlci local

    .. data:: ppp = 12

    	ppp

    .. data:: tdm_sa_to_p_e1 = 13

    	tdm sa to p e1

    .. data:: tdm_sa_to_p_t1 = 14

    	tdm sa to p t1

    .. data:: tdm_sa_to_p_e3 = 15

    	tdm sa to p e3

    .. data:: tdm_sa_to_p_t3 = 16

    	tdm sa to p t3

    .. data:: tdm_ce_so_psn = 17

    	tdm ce so psn

    .. data:: ip = 18

    	ip

    .. data:: vlan_encap = 19

    	vlan encap

    .. data:: dot1ad = 20

    	dot1ad

    .. data:: efp = 21

    	efp

    .. data:: bvi = 22

    	bvi

    .. data:: monitor_session = 23

    	monitor session

    .. data:: pseudowire_ether = 24

    	pseudowire ether

    .. data:: pseudowire_iw = 25

    	pseudowire iw

    .. data:: multi_segment_pseudowire = 26

    	multi segment pseudowire

    .. data:: pseudowire_l2_subinterface = 27

    	pseudowire l2 subinterface

    .. data:: virtual_network_interface = 28

    	virtual network interface

    .. data:: encap_types_max = 29

    	encap types max

    """

    unknown_encap = 0

    vlan = 1

    qinq = 2

    qin_any = 3

    ethernet = 4

    atm_aal0 = 5

    atm_aal5 = 6

    atm_vp = 7

    atm_port = 8

    hdlc = 9

    fr_dlci = 10

    fr_dlci_local = 11

    ppp = 12

    tdm_sa_to_p_e1 = 13

    tdm_sa_to_p_t1 = 14

    tdm_sa_to_p_e3 = 15

    tdm_sa_to_p_t3 = 16

    tdm_ce_so_psn = 17

    ip = 18

    vlan_encap = 19

    dot1ad = 20

    efp = 21

    bvi = 22

    monitor_session = 23

    pseudowire_ether = 24

    pseudowire_iw = 25

    multi_segment_pseudowire = 26

    pseudowire_l2_subinterface = 27

    virtual_network_interface = 28

    encap_types_max = 29


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAcEncapEnum']


class L2VpnAdLsdErrEnum(Enum):
    """
    L2VpnAdLsdErrEnum

    L2vpn ad lsd err

    .. data:: l2vpn_ad_lsd_err_type_none = 0

    	No Error

    .. data:: l2vpn_ad_lsd_err_type_rw_create_abort_lbl_alloc = 1

    	RW Creation aborted due to related Lbl Alloc

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_abort_rw_create = 2

    	Lbl Alloc disallowed due to related RW Creation

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_abort_lbl_alloc = 3

    	Lbl Alloc disallowed due to related Lbl Alloc

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_lbl_ctx_mismatch = 4

    	Lbl Ctx mismatch

    .. data:: l2vpn_ad_lsd_err_type_rw_create_fpi_size_mismatch = 5

    	FPI Size mismatch

    .. data:: l2vpn_ad_lsd_err_type_rw_create_fpi_version_mismatch = 6

    	FPI Version mismatch

    .. data:: l2vpn_ad_lsd_err_type_enospc = 7

    	Out of Label

    .. data:: l2vpn_ad_lsd_err_type_enomem = 8

    	No Memory

    .. data:: l2vpn_ad_lsd_err_type_undefined = 9

    	LABEL ERR

    """

    l2vpn_ad_lsd_err_type_none = 0

    l2vpn_ad_lsd_err_type_rw_create_abort_lbl_alloc = 1

    l2vpn_ad_lsd_err_type_lbl_alloc_abort_rw_create = 2

    l2vpn_ad_lsd_err_type_lbl_alloc_abort_lbl_alloc = 3

    l2vpn_ad_lsd_err_type_lbl_alloc_lbl_ctx_mismatch = 4

    l2vpn_ad_lsd_err_type_rw_create_fpi_size_mismatch = 5

    l2vpn_ad_lsd_err_type_rw_create_fpi_version_mismatch = 6

    l2vpn_ad_lsd_err_type_enospc = 7

    l2vpn_ad_lsd_err_type_enomem = 8

    l2vpn_ad_lsd_err_type_undefined = 9


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAdLsdErrEnum']


class L2VpnAdRdEnum(Enum):
    """
    L2VpnAdRdEnum

    L2vpn ad rd

    .. data:: l2vpn_ad_rd_none = 0

    	Route Distinguisher not set

    .. data:: l2vpn_ad_rd_auto = 1

    	Route Distinguisher auto-generated

    .. data:: l2vpn_ad_rd_as = 2

    	Route Distinguisher with 2 Byte AS number

    .. data:: l2vpn_ad_rd_4byte_as = 3

    	Route Distinguisher with 4 Byte AS number

    .. data:: l2vpn_ad_rd_v4_addr = 4

    	Route Distinguisher with IPv4 Address

    """

    l2vpn_ad_rd_none = 0

    l2vpn_ad_rd_auto = 1

    l2vpn_ad_rd_as = 2

    l2vpn_ad_rd_4byte_as = 3

    l2vpn_ad_rd_v4_addr = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAdRdEnum']


class L2VpnAdRtEnum(Enum):
    """
    L2VpnAdRtEnum

    L2vpn ad rt

    .. data:: l2vpn_ad_rt_none = 0

    	Route target not set

    .. data:: l2vpn_ad_rt_as = 1

    	Route Target with 2 Byte AS number

    .. data:: l2vpn_ad_rt_4byte_as = 2

    	Route Target with 4 Byte AS number

    .. data:: l2vpn_ad_rt_v4_addr = 3

    	Route Target with IPv4 Address

    .. data:: es_import = 1538

    	Ethernet Segment Route Target from BGP

    """

    l2vpn_ad_rt_none = 0

    l2vpn_ad_rt_as = 1

    l2vpn_ad_rt_4byte_as = 2

    l2vpn_ad_rt_v4_addr = 3

    es_import = 1538


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAdRtEnum']


class L2VpnAdSigMethodEnum(Enum):
    """
    L2VpnAdSigMethodEnum

    L2vpn ad sig method

    .. data:: l2vpn_ad_sig_method_none = 0

    	None

    .. data:: l2vpn_ad_sig_method_bgp = 1

    	BGP

    .. data:: l2vpn_ad_sig_method_ldp = 2

    	LDP

    """

    l2vpn_ad_sig_method_none = 0

    l2vpn_ad_sig_method_bgp = 1

    l2vpn_ad_sig_method_ldp = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAdSigMethodEnum']


class L2VpnAdVplsIdEnum(Enum):
    """
    L2VpnAdVplsIdEnum

    L2vpn ad vpls id

    .. data:: l2vpn_ad_vpls_id_none = 0

    	VPLS-ID not set

    .. data:: l2vpn_ad_vpls_id_auto = 1

    	Auto generated VPLS-ID

    .. data:: l2vpn_ad_vpls_id_as = 10

    	VPLS-ID with 2 Byte AS number

    .. data:: l2vpn_ad_vpls_id_v4_addr = 266

    	VPLS-ID with IPv4 Address

    """

    l2vpn_ad_vpls_id_none = 0

    l2vpn_ad_vpls_id_auto = 1

    l2vpn_ad_vpls_id_as = 10

    l2vpn_ad_vpls_id_v4_addr = 266


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAdVplsIdEnum']


class L2VpnAtmModeEnum(Enum):
    """
    L2VpnAtmModeEnum

    L2vpn atm mode

    .. data:: l2vpn_atm_port_mode = 0

    	ATM port mode

    .. data:: l2vpn_atm_vp_mode = 1

    	ATM Virtual Path mode

    .. data:: l2vpn_atm_vc_mode = 2

    	ATM Virtual Channel mode

    """

    l2vpn_atm_port_mode = 0

    l2vpn_atm_vp_mode = 1

    l2vpn_atm_vc_mode = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnAtmModeEnum']


class L2VpnBagAdEncapEnum(Enum):
    """
    L2VpnBagAdEncapEnum

    L2VPN AD Encapsulation

    .. data:: l2vpn_bag_ad_encap_not_specified = 0

    	Not Specified

    .. data:: l2vpn_bag_ad_encap_ether_vlan = 1

    	Ether VLAN

    .. data:: l2vpn_bag_ad_encap_ether = 2

    	Ethernet

    """

    l2vpn_bag_ad_encap_not_specified = 0

    l2vpn_bag_ad_encap_ether_vlan = 1

    l2vpn_bag_ad_encap_ether = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagAdEncapEnum']


class L2VpnBagMacAgingModeEnum(Enum):
    """
    L2VpnBagMacAgingModeEnum

    L2vpn bag mac aging mode

    .. data:: aging_none = 0

    	MAC Aging None

    .. data:: aging_absolute = 1

    	Mac Aging Absolute

    .. data:: aging_inactivity = 2

    	Mac Aging Inactivity

    """

    aging_none = 0

    aging_absolute = 1

    aging_inactivity = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagMacAgingModeEnum']


class L2VpnBagMacLimitActionEnum(Enum):
    """
    L2VpnBagMacLimitActionEnum

    L2vpn bag mac limit action

    .. data:: limit_none = 0

    	MAC Limit Action None

    .. data:: limit_flood = 1

    	MAC Limit Action Flood

    .. data:: limit_no_flood = 2

    	MAC Limit Action No Flood

    .. data:: limit_shutdown = 3

    	MAC Limit Action Shut

    .. data:: limit_no_config = 4

    	Mac Limit Action No Config

    """

    limit_none = 0

    limit_flood = 1

    limit_no_flood = 2

    limit_shutdown = 3

    limit_no_config = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagMacLimitActionEnum']


class L2VpnBagMacLimitNotifyEnum(Enum):
    """
    L2VpnBagMacLimitNotifyEnum

    L2vpn bag mac limit notify

    .. data:: mac_limit_notify_none = 0

    	MAC Limit Notify None

    .. data:: mac_limit_notify_syslog = 1

    	MAC Limit Notify Syslog

    .. data:: mac_limit_notify_trap = 2

    	MAC Limit Notify Trap

    .. data:: mac_limit_notify_syslog_trap = 3

    	MAC Limit Notify Syslog and Trap

    .. data:: mac_limit_notify_no_config = 4

    	MAC Limit Notify No Config

    """

    mac_limit_notify_none = 0

    mac_limit_notify_syslog = 1

    mac_limit_notify_trap = 2

    mac_limit_notify_syslog_trap = 3

    mac_limit_notify_no_config = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagMacLimitNotifyEnum']


class L2VpnBagMacSecureActionEnum(Enum):
    """
    L2VpnBagMacSecureActionEnum

    L2vpn bag mac secure action

    .. data:: not_set = 0

    	MAC Secure Action Not Set

    .. data:: restrict = 1

    	MAC Secure Action Restrict

    .. data:: none = 2

    	MAC Secure Action None

    .. data:: shutdown = 3

    	MAC Secure Action Shutdown

    """

    not_set = 0

    restrict = 1

    none = 2

    shutdown = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagMacSecureActionEnum']


class L2VpnBagMacWithdrawOptionEnum(Enum):
    """
    L2VpnBagMacWithdrawOptionEnum

    L2vpn bag mac withdraw option

    .. data:: mac_withdraw_option_state_up = 0

    	Mac withdraw on state up

    .. data:: mac_withdraw_option_state_down = 1

    	Mac withdraw on state down

    .. data:: mac_withdraw_option_optimize = 2

    	Optimized Mac withdraw

    """

    mac_withdraw_option_state_up = 0

    mac_withdraw_option_state_down = 1

    mac_withdraw_option_optimize = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagMacWithdrawOptionEnum']


class L2VpnBagStormControlRateUnitEnum(Enum):
    """
    L2VpnBagStormControlRateUnitEnum

    Storm Control Rate Unit Type

    .. data:: pps = 0

    	Packets Per Second

    .. data:: kb_ps = 1

    	Kilobits Per Second

    """

    pps = 0

    kb_ps = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBagStormControlRateUnitEnum']


class L2VpnBridgeCoupledStateEnum(Enum):
    """
    L2VpnBridgeCoupledStateEnum

    L2vpn bridge coupled state

    .. data:: disabled = 0

    	Coupled mode disabled

    .. data:: down = 2

    	Coupled state down

    .. data:: up = 3

    	Coupled state up

    """

    disabled = 0

    down = 2

    up = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBridgeCoupledStateEnum']


class L2VpnBridgeEnum(Enum):
    """
    L2VpnBridgeEnum

    L2vpn bridge

    .. data:: l2vpn_bridge_type_default = 0

    	Regular none PBB bridge

    .. data:: l2vpn_bridge_type_pbb_edge = 1

    	PBB edge bridge

    .. data:: l2vpn_bridge_type_pbb_core = 2

    	PBB core bridge

    """

    l2vpn_bridge_type_default = 0

    l2vpn_bridge_type_pbb_edge = 1

    l2vpn_bridge_type_pbb_core = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBridgeEnum']


class L2VpnBridgeStateEnum(Enum):
    """
    L2VpnBridgeStateEnum

    L2vpn bridge state

    .. data:: bridge_init = 0

    	Bridge Init State

    .. data:: bridge_up = 1

    	Bridge Up

    .. data:: bridge_down = 2

    	Bridge Down

    .. data:: bridge_admin_down = 3

    	Bridge Admin Down

    """

    bridge_init = 0

    bridge_up = 1

    bridge_down = 2

    bridge_admin_down = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnBridgeStateEnum']


class L2VpnEncapMethodEnum(Enum):
    """
    L2VpnEncapMethodEnum

    Encapsulation Method

    .. data:: l2vpn_pw_encaps_not_specified = 0

    	Not Specified

    .. data:: l2vpn_pw_encaps_l2tpv3 = 1

    	L2TPv3 encapsulation

    .. data:: l2vpn_pw_encaps_l2tpv2 = 2

    	L2TPv2 encapsulation

    .. data:: l2vpn_pw_encaps_mpls = 3

    	MPLS encapsulation

    .. data:: l2vpn_pw_encaps_unknown = 4

    	Unknown

    """

    l2vpn_pw_encaps_not_specified = 0

    l2vpn_pw_encaps_l2tpv3 = 1

    l2vpn_pw_encaps_l2tpv2 = 2

    l2vpn_pw_encaps_mpls = 3

    l2vpn_pw_encaps_unknown = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnEncapMethodEnum']


class L2VpnFrModeEnum(Enum):
    """
    L2VpnFrModeEnum

    L2vpn fr mode

    .. data:: l2vpn_fr_port_mode = 0

    	Frame Relay port mode

    .. data:: l2vpn_fr_dlci_mode = 1

    	Frame Relay DLCI mode

    """

    l2vpn_fr_port_mode = 0

    l2vpn_fr_dlci_mode = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnFrModeEnum']


class L2VpnG8032RplEnum(Enum):
    """
    L2VpnG8032RplEnum

    RPL types in g8032 ring

    .. data:: rpl_unknown = 0

    	No RPL info

    .. data:: port0_owner = 1

    	Port 0 owner

    .. data:: port0_neighbor = 2

    	Port 0 neighbor

    .. data:: port0_next_neighbor = 3

    	Port 0 next neighbor

    .. data:: port1_owner = 4

    	Port 1 owner

    .. data:: port1_neighbor = 5

    	Port 1 neighbor

    .. data:: port1_next_neighbor = 6

    	Port 1 next neighbor

    """

    rpl_unknown = 0

    port0_owner = 1

    port0_neighbor = 2

    port0_next_neighbor = 3

    port1_owner = 4

    port1_neighbor = 5

    port1_next_neighbor = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnG8032RplEnum']


class L2VpnG8032UncfgReasonEnum(Enum):
    """
    L2VpnG8032UncfgReasonEnum

    Unresolved reason for G8032 ring instance

    .. data:: reason_none = 0

    	No reason

    .. data:: ring_mp0_missing = 1

    	Main port0 missing

    .. data:: ring_mp1_missing = 2

    	Main port1 missing

    .. data:: inclusion_list_empty = 3

    	Inclusion list empty

    .. data:: aps0_missing = 4

    	APS port0 missing

    .. data:: aps0bp_notfound = 5

    	APS port0 not found as valid BP

    .. data:: aps0_no_ac_ctx = 6

    	APS port0 has no valid AC context

    .. data:: aps0_not_in_inclusion_list = 7

    	APS port0 not in inclusion list

    .. data:: aps0_mismatched = 8

    	APS port0 mismatched with main port

    .. data:: aps1_missing = 9

    	APS port1 missing

    .. data:: aps1bp_notfound = 10

    	APS port1 not found as valid BP

    .. data:: aps1_no_ac_ctx = 11

    	APS port1 has no valid AC context

    .. data:: aps1_not_in_inclusion_list = 12

    	APS port1 not in inclusion list

    .. data:: aps1_mismatched = 13

    	APS port1 mismatched with main port

    .. data:: aps_unprovisioned = 14

    	APS AC unrpvosioned

    """

    reason_none = 0

    ring_mp0_missing = 1

    ring_mp1_missing = 2

    inclusion_list_empty = 3

    aps0_missing = 4

    aps0bp_notfound = 5

    aps0_no_ac_ctx = 6

    aps0_not_in_inclusion_list = 7

    aps0_mismatched = 8

    aps1_missing = 9

    aps1bp_notfound = 10

    aps1_no_ac_ctx = 11

    aps1_not_in_inclusion_list = 12

    aps1_mismatched = 13

    aps_unprovisioned = 14


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnG8032UncfgReasonEnum']


class L2VpnIdMgrAppEnum(Enum):
    """
    L2VpnIdMgrAppEnum

    L2VPN ID Manager App Type

    .. data:: l2vpn_id_mgr_app_type_virtual_ac = 0

    	Virtual AC

    .. data:: l2vpn_id_mgr_app_type_ac = 1

    	AC

    .. data:: l2vpn_id_mgr_app_type_pw = 2

    	PW

    .. data:: l2vpn_id_mgr_app_type_bd = 3

    	BD

    .. data:: l2vpn_id_mgr_app_type_mp2mp = 4

    	MP2MP

    .. data:: l2vpn_id_mgr_app_type_rd = 5

    	RD

    .. data:: l2vpn_id_mgr_app_type_pbb = 6

    	PBB

    .. data:: l2vpn_id_mgr_app_type_if_list = 7

    	IFLIST

    .. data:: l2vpn_id_mgr_app_type_atom = 8

    	ATOM

    .. data:: l2vpn_id_mgr_app_type_global = 9

    	GLOBAL

    .. data:: l2vpn_id_mgr_app_type_p_tree = 10

    	PTREE

    .. data:: l2vpn_id_mgr_app_type_pw_group = 11

    	PWGROUP

    .. data:: l2vpn_id_mgr_app_type_evpn = 12

    	EVPN

    .. data:: l2vpn_id_mgr_app_type_evpn_lbl = 13

    	EVPN LBL

    .. data:: l2vpn_id_mgr_app_type_evpn_rd = 14

    	EVPN RD

    .. data:: l2vpn_id_mgr_app_type_count = 15

    	Count/Invalid

    """

    l2vpn_id_mgr_app_type_virtual_ac = 0

    l2vpn_id_mgr_app_type_ac = 1

    l2vpn_id_mgr_app_type_pw = 2

    l2vpn_id_mgr_app_type_bd = 3

    l2vpn_id_mgr_app_type_mp2mp = 4

    l2vpn_id_mgr_app_type_rd = 5

    l2vpn_id_mgr_app_type_pbb = 6

    l2vpn_id_mgr_app_type_if_list = 7

    l2vpn_id_mgr_app_type_atom = 8

    l2vpn_id_mgr_app_type_global = 9

    l2vpn_id_mgr_app_type_p_tree = 10

    l2vpn_id_mgr_app_type_pw_group = 11

    l2vpn_id_mgr_app_type_evpn = 12

    l2vpn_id_mgr_app_type_evpn_lbl = 13

    l2vpn_id_mgr_app_type_evpn_rd = 14

    l2vpn_id_mgr_app_type_count = 15


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnIdMgrAppEnum']


class L2VpnInterfaceEnum(Enum):
    """
    L2VpnInterfaceEnum

    L2vpn interface

    .. data:: l2vpn_intf_type_unknown = 0

    	Unknown

    .. data:: l2vpn_intf_type_ethernet = 1

    	Ethernet

    .. data:: l2vpn_intf_type_vlan = 2

    	Ethernet Vlan

    .. data:: l2vpn_intf_type_atm = 3

    	ATM

    .. data:: l2vpn_intf_type_frame_relay = 4

    	Frame Relay

    .. data:: l2vpn_intf_type_hdlc = 5

    	HDLC

    .. data:: l2vpn_intf_type_ppp = 6

    	PPP

    .. data:: l2vpn_intf_type_span = 7

    	SPAN

    .. data:: l2vpn_intf_type_bvi = 8

    	BVI

    .. data:: l2vpn_intf_type_cem = 9

    	CEM

    .. data:: l2vpn_intf_type_pw_ether = 10

    	PsuedowireEther

    .. data:: l2vpn_intf_type_pw_iw = 11

    	PsuedowireIW

    .. data:: l2vpn_intf_type_vni = 12

    	VXLAN

    """

    l2vpn_intf_type_unknown = 0

    l2vpn_intf_type_ethernet = 1

    l2vpn_intf_type_vlan = 2

    l2vpn_intf_type_atm = 3

    l2vpn_intf_type_frame_relay = 4

    l2vpn_intf_type_hdlc = 5

    l2vpn_intf_type_ppp = 6

    l2vpn_intf_type_span = 7

    l2vpn_intf_type_bvi = 8

    l2vpn_intf_type_cem = 9

    l2vpn_intf_type_pw_ether = 10

    l2vpn_intf_type_pw_iw = 11

    l2vpn_intf_type_vni = 12


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnInterfaceEnum']


class L2VpnInterworkingEnum(Enum):
    """
    L2VpnInterworkingEnum

    L2vpn interworking

    .. data:: l2vpn_iw_type_none = 0

    	None

    .. data:: l2vpn_iw_type_ethernet = 1

    	Ethernet

    .. data:: l2vpn_iw_type_ppp = 2

    	PPP

    .. data:: l2vpn_iw_type_ipv4 = 3

    	IPv4

    .. data:: l2vpn_iw_type_voluntary = 4

    	Voluntary

    .. data:: l2vpn_iw_type_frf8 = 5

    	FRF8

    """

    l2vpn_iw_type_none = 0

    l2vpn_iw_type_ethernet = 1

    l2vpn_iw_type_ppp = 2

    l2vpn_iw_type_ipv4 = 3

    l2vpn_iw_type_voluntary = 4

    l2vpn_iw_type_frf8 = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnInterworkingEnum']


class L2VpnIpcTransportModeEnum(Enum):
    """
    L2VpnIpcTransportModeEnum

    L2vpn ipc transport mode

    .. data:: unicast = 0

    	L2VPN Unicast IPC transport mode

    .. data:: broadcast = 1

    	L2VPN Broadcast IPC transport mode

    .. data:: unknown = 2

    	L2VPN Unknown IPC transport mode

    """

    unicast = 0

    broadcast = 1

    unknown = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnIpcTransportModeEnum']


class L2VpnL2TpTunnelStateEnum(Enum):
    """
    L2VpnL2TpTunnelStateEnum

    L2vpn l2tp tunnel state

    .. data:: l2vpn_l2tp_idle = 0

    	Idle

    .. data:: l2vpn_l2tp_wait_for_connecting = 1

    	Wait for connecting

    .. data:: l2vpn_l2tp_wait_for_connected = 2

    	Wait for connected

    .. data:: l2vpn_l2tp_in_coming_call = 3

    	Incoming call

    .. data:: l2vpn_l2tp_connected = 4

    	Connected

    .. data:: l2vpn_l2tp_disconnected = 5

    	Disconnected

    """

    l2vpn_l2tp_idle = 0

    l2vpn_l2tp_wait_for_connecting = 1

    l2vpn_l2tp_wait_for_connected = 2

    l2vpn_l2tp_in_coming_call = 3

    l2vpn_l2tp_connected = 4

    l2vpn_l2tp_disconnected = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnL2TpTunnelStateEnum']


class L2VpnLoadBalEnum(Enum):
    """
    L2VpnLoadBalEnum

    L2vpn load bal

    .. data:: not_supported = 0

    	Load Balance Flow Not Supported

    .. data:: source_dest_mac = 1

    	Load Balance Flow src-dst-mac

    .. data:: source_dest_ip = 2

    	Load Balance Flow src-dst-ip

    .. data:: undefined = 3

    	Load Balance Flow Undefined

    .. data:: pseudowire_label = 4

    	Load Balance PW Label based

    """

    not_supported = 0

    source_dest_mac = 1

    source_dest_ip = 2

    undefined = 3

    pseudowire_label = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnLoadBalEnum']


class L2VpnMainIfInstanceStateEnum(Enum):
    """
    L2VpnMainIfInstanceStateEnum

    State of a main port instance

    .. data:: forwarding = 0

    	Forwarding state

    .. data:: blocked = 1

    	Blocked state

    .. data:: mac_learning = 2

    	Mac learning state

    .. data:: nack = 3

    	Nack state

    .. data:: forwarning_not_useful = 4

    	Forwarding not useful state

    .. data:: blocked_not_useful = 5

    	Blocked not useful state

    .. data:: mac_learning_not_useful = 6

    	Mac Learning not useful state

    .. data:: blocked_data_only = 7

    	Blocked data only state

    .. data:: mcast_pe2_ce_blocked = 8

    	Mcast PE to CE blocked state

    .. data:: port_state_unknown = 9

    	Port state unknown

    """

    forwarding = 0

    blocked = 1

    mac_learning = 2

    nack = 3

    forwarning_not_useful = 4

    blocked_not_useful = 5

    mac_learning_not_useful = 6

    blocked_data_only = 7

    mcast_pe2_ce_blocked = 8

    port_state_unknown = 9


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnMainIfInstanceStateEnum']


class L2VpnMainIfProtectectedEnum(Enum):
    """
    L2VpnMainIfProtectectedEnum

    L2vpn main if protectected

    .. data:: erp_protected = 0

    	ERP Protected

    .. data:: mstp_protected = 1

    	MSTP Protected

    .. data:: no_protected = 2

    	No protection

    """

    erp_protected = 0

    mstp_protected = 1

    no_protected = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnMainIfProtectectedEnum']


class L2VpnMemoryStateEnum(Enum):
    """
    L2VpnMemoryStateEnum

    L2vpn memory state

    .. data:: memory_state_unknown = 0

    	Memory state Unknown

    .. data:: memory_state_normal = 1

    	Memory state Normal

    .. data:: memory_state_minor = 2

    	Memory state Minor

    .. data:: memory_state_severe = 3

    	Memory state Severe

    .. data:: memory_state_critical = 4

    	Memory state Critical

    .. data:: memory_state_invalid = 5

    	Memory state Invalid

    """

    memory_state_unknown = 0

    memory_state_normal = 1

    memory_state_minor = 2

    memory_state_severe = 3

    memory_state_critical = 4

    memory_state_invalid = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnMemoryStateEnum']


class L2VpnMirpLiteProtocolInfoEnum(Enum):
    """
    L2VpnMirpLiteProtocolInfoEnum

    L2vpn mirp lite protocol info

    .. data:: vlan0 = 0

    	MVRP PDU using Vlan0

    .. data:: none = 1

    	none

    """

    vlan0 = 0

    none = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnMirpLiteProtocolInfoEnum']


class L2VpnMirpLiteStatusEnum(Enum):
    """
    L2VpnMirpLiteStatusEnum

    L2vpn mirp lite status

    .. data:: enabled = 0

    	Supported, enabled

    .. data:: not_supported = 1

    	Not supported

    """

    enabled = 0

    not_supported = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnMirpLiteStatusEnum']


class L2VpnMstiStateEnum(Enum):
    """
    L2VpnMstiStateEnum

    L2VPN MSTI state

    .. data:: msti_bag_stp_port_state_forwarding = 0

    	msti bag stp port state forwarding

    .. data:: msti_bag_stp_port_state_blocked = 1

    	msti bag stp port state blocked

    .. data:: msti_bag_stp_port_state_mac_learning = 2

    	msti bag stp port state mac learning

    .. data:: msti_bag_stp_port_state_nack = 3

    	msti bag stp port state nack

    .. data:: msti_bag_stp_port_state_forwarding_not_useful = 4

    	msti bag stp port state forwarding not useful

    .. data:: msti_bag_stp_port_state_blocked_not_useful = 5

    	msti bag stp port state blocked not useful

    .. data:: msti_bag_stp_port_state_mac_learning_not_useful = 6

    	msti bag stp port state mac learning not useful

    .. data:: msti_bag_erp_port_state_blocked_data_only = 7

    	msti bag erp port state blocked data only

    .. data:: msti_bag_erp_port_state_evpn_mcast_pe2ce_blocked = 8

    	msti bag erp port state evpn mcast pe2ce

    	blocked

    .. data:: msti_bag_erp_port_state_evpn_port_state_mcast_blocked = 9

    	msti bag erp port state evpn port state mcast

    	blocked

    """

    msti_bag_stp_port_state_forwarding = 0

    msti_bag_stp_port_state_blocked = 1

    msti_bag_stp_port_state_mac_learning = 2

    msti_bag_stp_port_state_nack = 3

    msti_bag_stp_port_state_forwarding_not_useful = 4

    msti_bag_stp_port_state_blocked_not_useful = 5

    msti_bag_stp_port_state_mac_learning_not_useful = 6

    msti_bag_erp_port_state_blocked_data_only = 7

    msti_bag_erp_port_state_evpn_mcast_pe2ce_blocked = 8

    msti_bag_erp_port_state_evpn_port_state_mcast_blocked = 9


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnMstiStateEnum']


class L2VpnP2MpPwPtreeEnum(Enum):
    """
    L2VpnP2MpPwPtreeEnum

    L2vpn p2mp pw ptree

    .. data:: none = 0

    	None

    .. data:: rsvp_te = 1

    	RSVP TE

    .. data:: mldp = 2

    	MLDP

    """

    none = 0

    rsvp_te = 1

    mldp = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnP2MpPwPtreeEnum']


class L2VpnPeerEnum(Enum):
    """
    L2VpnPeerEnum

    L2vpn peer

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    .. data:: internal_label = 3

    	Internal Label

    """

    none = 0

    ipv4 = 1

    ipv6 = 2

    internal_label = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPeerEnum']


class L2VpnPrefpathOptionEnum(Enum):
    """
    L2VpnPrefpathOptionEnum

    Preferred Path Option

    .. data:: l2vpn_pw_mpls_pref_path_not_specified = 0

    	Not Secified

    .. data:: l2vpn_pw_mpls_pref_path_next_hop_ip = 1

    	Next Hop IP

    .. data:: l2vpn_pw_mpls_pref_path_te_tunnel = 2

    	TE Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_ip_tunnel = 3

    	IP Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_tp_tunnel = 4

    	TP Tunnel

    """

    l2vpn_pw_mpls_pref_path_not_specified = 0

    l2vpn_pw_mpls_pref_path_next_hop_ip = 1

    l2vpn_pw_mpls_pref_path_te_tunnel = 2

    l2vpn_pw_mpls_pref_path_ip_tunnel = 3

    l2vpn_pw_mpls_pref_path_tp_tunnel = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPrefpathOptionEnum']


class L2VpnProcNsrNotReadyReasonEnum(Enum):
    """
    L2VpnProcNsrNotReadyReasonEnum

    L2vpn proc nsr not ready reason

    .. data:: collab_time_out = 0

    	Collaborator connection time out

    .. data:: collab_conntection_idt = 1

    	Collaborator connection down or IDT not done

    .. data:: nsr_peer_not_connected = 2

    	NSR peer not connected

    .. data:: nsr_peer_not_in_sync = 3

    	NSR peer not in sync

    """

    collab_time_out = 0

    collab_conntection_idt = 1

    nsr_peer_not_connected = 2

    nsr_peer_not_in_sync = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnProcNsrNotReadyReasonEnum']


class L2VpnProcRoleEnum(Enum):
    """
    L2VpnProcRoleEnum

    L2VPN Process Role

    .. data:: unknown = 0

    	Unknown

    .. data:: v1_active = 1

    	V1 Active

    .. data:: v1_standby = 2

    	V1 Standby

    .. data:: v2_active = 3

    	V2 Active

    .. data:: v2_standby = 4

    	V2 Standby

    .. data:: v1_active_post_big_bang = 5

    	V1 Active post big-bang

    .. data:: v1_standby_post_big_bang = 6

    	V1 Standbyi post big-bang

    .. data:: count = 7

    	Count

    """

    unknown = 0

    v1_active = 1

    v1_standby = 2

    v2_active = 3

    v2_standby = 4

    v1_active_post_big_bang = 5

    v1_standby_post_big_bang = 6

    count = 7


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnProcRoleEnum']


class L2VpnProtectionEnum(Enum):
    """
    L2VpnProtectionEnum

    L2VPN Protection types

    .. data:: l2vpn_protection_unknown = 0

    	Unknown type of protection

    .. data:: l2vpn_protection_interface = 1

    	Interface protection type

    .. data:: l2vpn_protection_pseudowire = 2

    	PW protection type

    .. data:: l2vpn_protection_group = 3

    	Group protection type 

    """

    l2vpn_protection_unknown = 0

    l2vpn_protection_interface = 1

    l2vpn_protection_pseudowire = 2

    l2vpn_protection_group = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnProtectionEnum']


class L2VpnProtectionRoleEnum(Enum):
    """
    L2VpnProtectionRoleEnum

    L2VPN Configurable protection roles

    .. data:: l2vpn_protection_primary = 0

    	Segment configured as primary

    .. data:: l2vpn_protection_backup = 1

    	Segment configured as backup

    """

    l2vpn_protection_primary = 0

    l2vpn_protection_backup = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnProtectionRoleEnum']


class L2VpnPtreeEnum(Enum):
    """
    L2VpnPtreeEnum

    ptree type

    .. data:: none = 0

    	No ptree type

    .. data:: rsvp_te = 1

    	RSVP_TE ptree type

    .. data:: mldp = 2

    	MLDP ptree type

    """

    none = 0

    rsvp_te = 1

    mldp = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPtreeEnum']


class L2VpnPwClassControlWordEnum(Enum):
    """
    L2VpnPwClassControlWordEnum

    L2vpn pw class control word

    .. data:: unset = 0

    	Unset

    .. data:: enable = 1

    	Enable

    .. data:: disable = 2

    	Disable

    """

    unset = 0

    enable = 1

    disable = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwClassControlWordEnum']


class L2VpnPwControlWordEnum(Enum):
    """
    L2VpnPwControlWordEnum

    L2vpn pw control word

    .. data:: l2vpn_pw_control_word_unknown = 0

    	Unknown

    .. data:: l2vpn_pw_control_word_clear = 1

    	Clear

    .. data:: l2vpn_pw_control_word_set = 2

    	Set

    .. data:: l2vpn_pw_control_word_mandatory = 3

    	Mandatory

    """

    l2vpn_pw_control_word_unknown = 0

    l2vpn_pw_control_word_clear = 1

    l2vpn_pw_control_word_set = 2

    l2vpn_pw_control_word_mandatory = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwControlWordEnum']


class L2VpnPwEnum(Enum):
    """
    L2VpnPwEnum

    L2vpn pw

    .. data:: l2vpn_pw_type_unknown = 0

    	Unknown

    .. data:: l2vpn_pw_type_frame_relay_dlci = 1

    	Frame Relay DLCI

    .. data:: l2vpn_pw_type_atm_aal5_sdu = 2

    	ATM AAL5 SDU VCC transport

    .. data:: l2vpn_pw_type_atm_trans_cell = 3

    	ATM transparent cell transport

    .. data:: l2vpn_pw_type_ether_vlan = 4

    	Ethernet VLAN tagged mode 

    .. data:: l2vpn_pw_type_ether = 5

    	Ethernet

    .. data:: l2vpn_pw_type_hdlc = 6

    	HDLC

    .. data:: l2vpn_pw_type_ppp = 7

    	PPP

    .. data:: l2vpn_pw_type_sonet_over_mpls = 8

    	SONET/SDH Circuit Emulation Service Over MPLS

    	(CEM)

    .. data:: l2vpn_pw_type_atm_n_vcc_cell = 9

    	ATM n-to-one VCC cell transport

    .. data:: l2vpn_pw_type_atm_n_vpc_cell = 10

    	ATM n-to-one VPC cell transport

    .. data:: l2vpn_pw_type_ip = 11

    	IP Layer2 Transport

    .. data:: l2vpn_pw_type_atm_vcc_cell = 12

    	ATM one-to-one VCC cell transport

    .. data:: l2vpn_pw_type_atm_vpc_cell = 13

    	ATM one-to-one VPC cell transport

    .. data:: l2vpn_pw_type_atm_aal5_pdu = 14

    	ATM AAL5 PDU VCC transport

    .. data:: l2vpn_pw_type_frame_relay = 15

    	Frame Relay port mode

    .. data:: l2vpn_pw_type_sonet = 16

    	SONET/SDH Circuit

    .. data:: l2vpn_pw_type_vpls = 17

    	VPLS

    .. data:: l2vpn_pw_type_tdm_sa_to_p_e1 = 18

    	TDM E1

    .. data:: l2vpn_pw_type_tdm_sa_to_p_t1 = 19

    	TDM T1

    .. data:: l2vpn_pw_type_tdm_sa_to_p_e3 = 20

    	TDM E3

    .. data:: l2vpn_pw_type_tdm_sa_to_p_t3 = 21

    	TDM T3

    .. data:: l2vpn_pw_type_tdm_ce_so_psn = 22

    	TDM CES over PSN

    """

    l2vpn_pw_type_unknown = 0

    l2vpn_pw_type_frame_relay_dlci = 1

    l2vpn_pw_type_atm_aal5_sdu = 2

    l2vpn_pw_type_atm_trans_cell = 3

    l2vpn_pw_type_ether_vlan = 4

    l2vpn_pw_type_ether = 5

    l2vpn_pw_type_hdlc = 6

    l2vpn_pw_type_ppp = 7

    l2vpn_pw_type_sonet_over_mpls = 8

    l2vpn_pw_type_atm_n_vcc_cell = 9

    l2vpn_pw_type_atm_n_vpc_cell = 10

    l2vpn_pw_type_ip = 11

    l2vpn_pw_type_atm_vcc_cell = 12

    l2vpn_pw_type_atm_vpc_cell = 13

    l2vpn_pw_type_atm_aal5_pdu = 14

    l2vpn_pw_type_frame_relay = 15

    l2vpn_pw_type_sonet = 16

    l2vpn_pw_type_vpls = 17

    l2vpn_pw_type_tdm_sa_to_p_e1 = 18

    l2vpn_pw_type_tdm_sa_to_p_t1 = 19

    l2vpn_pw_type_tdm_sa_to_p_e3 = 20

    l2vpn_pw_type_tdm_sa_to_p_t3 = 21

    l2vpn_pw_type_tdm_ce_so_psn = 22


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwEnum']


class L2VpnPwFecEnum(Enum):
    """
    L2VpnPwFecEnum

    L2vpn pw fec

    .. data:: l2vpn_pw_fec_128 = 0

    	FEC 128 pseudowire type

    .. data:: l2vpn_pw_fec_129 = 1

    	FEC 129 pseudowire type

    .. data:: l2vpn_pw_fec_not_applicable = 268435455

    	FEC Not Applicable

    """

    l2vpn_pw_fec_128 = 0

    l2vpn_pw_fec_129 = 1

    l2vpn_pw_fec_not_applicable = 268435455


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwFecEnum']


class L2VpnPwFlowLabelEnum(Enum):
    """
    L2VpnPwFlowLabelEnum

    Pseudowire flow label load balance types

    .. data:: off = 0

    	Flow label is off

    .. data:: receive = 1

    	Flow label is enabled on the receive side

    .. data:: transmit = 2

    	Flow label is enabled on the transmit side

    .. data:: both = 3

    	Flow label is enabled on both transmit and

    	receive sides

    """

    off = 0

    receive = 1

    transmit = 2

    both = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwFlowLabelEnum']


class L2VpnPwSequenceEnum(Enum):
    """
    L2VpnPwSequenceEnum

    L2vpn pw sequence

    .. data:: l2vpn_pw_sequence_off = 0

    	Sequencing is Off

    .. data:: l2vpn_pw_sequence_xmit = 1

    	Sequencing on the transmit side

    .. data:: l2vpn_pw_sequence_recv = 2

    	Sequencing on the receive side

    .. data:: l2vpn_pw_sequence_trans = 3

    	Sequencing is transparent

    .. data:: l2vpn_pw_sequence_both = 4

    	Sequencing on both sides

    """

    l2vpn_pw_sequence_off = 0

    l2vpn_pw_sequence_xmit = 1

    l2vpn_pw_sequence_recv = 2

    l2vpn_pw_sequence_trans = 3

    l2vpn_pw_sequence_both = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwSequenceEnum']


class L2VpnPwStateEnum(Enum):
    """
    L2VpnPwStateEnum

    L2vpn pw state

    .. data:: l2vpn_pw_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_pw_state_idle = 1

    	Idle

    .. data:: l2vpn_pw_state_provisioned = 2

    	Provisioned

    .. data:: l2vpn_pw_state_remote_standby = 3

    	Remote standby

    .. data:: l2vpn_pw_state_local_ready = 4

    	Local ready

    .. data:: l2vpn_pw_state_all_ready = 5

    	All ready

    .. data:: l2vpn_pw_state_established = 6

    	Established

    """

    l2vpn_pw_state_unresolved = 0

    l2vpn_pw_state_idle = 1

    l2vpn_pw_state_provisioned = 2

    l2vpn_pw_state_remote_standby = 3

    l2vpn_pw_state_local_ready = 4

    l2vpn_pw_state_all_ready = 5

    l2vpn_pw_state_established = 6


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwStateEnum']


class L2VpnPwheIflistRepStatusEnum(Enum):
    """
    L2VpnPwheIflistRepStatusEnum

    Interface list replication status

    .. data:: invalid = 0

    	Invalid

    .. data:: pending = 1

    	Pending

    .. data:: success = 2

    	Success

    .. data:: failed = 3

    	Failed

    .. data:: not_supported = 4

    	Not supported

    """

    invalid = 0

    pending = 1

    success = 2

    failed = 3

    not_supported = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwheIflistRepStatusEnum']


class L2VpnPwheIntfEnum(Enum):
    """
    L2VpnPwheIntfEnum

    Interface type

    .. data:: pseudowire_ether = 0

    	PW Ether

    .. data:: pseudowire_iw = 1

    	PW IW

    """

    pseudowire_ether = 0

    pseudowire_iw = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnPwheIntfEnum']


class L2VpnRgStateEnum(Enum):
    """
    L2VpnRgStateEnum

    L2vpn rg state

    .. data:: unknown = 0

    	Not defined

    .. data:: active = 1

    	Active

    .. data:: standby = 2

    	Standby

    """

    unknown = 0

    active = 1

    standby = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnRgStateEnum']


class L2VpnSegmentEnum(Enum):
    """
    L2VpnSegmentEnum

    L2vpn segment

    .. data:: l2vpn_segment_type_unresolved = 0

    	Unresolved segment

    .. data:: l2vpn_segment_type_ac = 1

    	Attachment circuit segment

    .. data:: l2vpn_segment_type_pw = 2

    	Pseudowire segment

    .. data:: l2vpn_segment_type_bd_ac = 3

    	Bridge domain attachment circuit

    .. data:: l2vpn_segment_type_vfi = 4

    	Virtual forwarding instance segment

    .. data:: l2vpn_segment_type_bd_pw = 5

    	Bridge Pseudowire

    .. data:: l2vpn_segment_type_bd_pbb = 6

    	Bridge domain PBB segment

    .. data:: l2vpn_segment_type_bd_evpn = 7

    	Bridge domain EVPN segment

    .. data:: l2vpn_segment_type_vni = 8

    	VxLAN Network Identifier (VNI) segment

    """

    l2vpn_segment_type_unresolved = 0

    l2vpn_segment_type_ac = 1

    l2vpn_segment_type_pw = 2

    l2vpn_segment_type_bd_ac = 3

    l2vpn_segment_type_vfi = 4

    l2vpn_segment_type_bd_pw = 5

    l2vpn_segment_type_bd_pbb = 6

    l2vpn_segment_type_bd_evpn = 7

    l2vpn_segment_type_vni = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnSegmentEnum']


class L2VpnSegmentStateEnum(Enum):
    """
    L2VpnSegmentStateEnum

    L2vpn segment state

    .. data:: l2vpn_segment_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_segment_state_up = 1

    	Up

    .. data:: l2vpn_segment_state_down = 2

    	Down

    .. data:: l2vpn_segment_state_admin_down = 3

    	Admin down

    .. data:: l2vpn_segment_state_local_up = 4

    	Local up

    .. data:: l2vpn_segment_state_remote_up = 5

    	Remote up

    .. data:: l2vpn_segment_state_connected = 6

    	Connected

    .. data:: l2vpn_segment_state_standby = 7

    	Standby

    .. data:: l2vpn_segment_state_standby_ready = 8

    	Standby Ready

    """

    l2vpn_segment_state_unresolved = 0

    l2vpn_segment_state_up = 1

    l2vpn_segment_state_down = 2

    l2vpn_segment_state_admin_down = 3

    l2vpn_segment_state_local_up = 4

    l2vpn_segment_state_remote_up = 5

    l2vpn_segment_state_connected = 6

    l2vpn_segment_state_standby = 7

    l2vpn_segment_state_standby_ready = 8


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnSegmentStateEnum']


class L2VpnServiceEnum(Enum):
    """
    L2VpnServiceEnum

    L2vpn service

    .. data:: vpws = 0

    	VPWS service

    .. data:: vpls = 1

    	VPLS service

    """

    vpws = 0

    vpls = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnServiceEnum']


class L2VpnSignallingProtoEnum(Enum):
    """
    L2VpnSignallingProtoEnum

    L2vpn signalling proto

    .. data:: l2vpn_pw_sig_not_specified = 0

    	Not specified

    .. data:: l2vpn_pw_sig_none = 1

    	Static

    .. data:: l2vpn_pw_sig_l2tpv3 = 2

    	L2TPv3 signaling

    .. data:: l2vpn_pw_sig_l2tpv2 = 3

    	L2TPv2 signaling

    .. data:: l2vpn_pw_sig_ldp = 4

    	LDP

    .. data:: l2vpn_pw_sig_bgp = 5

    	BGP

    """

    l2vpn_pw_sig_not_specified = 0

    l2vpn_pw_sig_none = 1

    l2vpn_pw_sig_l2tpv3 = 2

    l2vpn_pw_sig_l2tpv2 = 3

    l2vpn_pw_sig_ldp = 4

    l2vpn_pw_sig_bgp = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnSignallingProtoEnum']


class L2VpnSrcAddressSetEnum(Enum):
    """
    L2VpnSrcAddressSetEnum

    L2vpn src address set

    .. data:: unset = 0

    	Unset

    .. data:: set = 1

    	Set

    """

    unset = 0

    set = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnSrcAddressSetEnum']


class L2VpnSyncStatusEnum(Enum):
    """
    L2VpnSyncStatusEnum

    L2vpn sync status

    .. data:: not_ready = 0

    	Not Ready

    .. data:: ready = 1

    	Ready

    """

    not_ready = 0

    ready = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnSyncStatusEnum']


class L2VpnTdmModeEnum(Enum):
    """
    L2VpnTdmModeEnum

    L2VPN TDM modes

    .. data:: unknown = 0

    	Unknown mode

    .. data:: ce_so_psn = 1

    	CESoPSN mode

    .. data:: sa_to_p_e1 = 2

    	SAToP E1 mode

    .. data:: sa_to_p_t1 = 3

    	SAToP T1 mode

    .. data:: sa_to_p_e3 = 4

    	SAToP E3 mode

    .. data:: sa_to_p_t3 = 5

    	SAToP T3 mode

    """

    unknown = 0

    ce_so_psn = 1

    sa_to_p_e1 = 2

    sa_to_p_t1 = 3

    sa_to_p_e3 = 4

    sa_to_p_t3 = 5


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnTdmModeEnum']


class L2VpnTdmRtpOptionEnum(Enum):
    """
    L2VpnTdmRtpOptionEnum

    L2VPN TDM RTP option

    .. data:: unknown = 0

    	Unknown RTP option

    .. data:: present = 1

    	RTP option present

    .. data:: absent = 2

    	RTP option absent

    """

    unknown = 0

    present = 1

    absent = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnTdmRtpOptionEnum']


class L2VpnTimeStampModeEnum(Enum):
    """
    L2VpnTimeStampModeEnum

    L2VPN TDM Time stamp modes

    .. data:: unknown = 0

    	Unknown time stamp mode

    .. data:: differential = 1

    	Differential time stamp mode

    .. data:: absolute = 2

    	Absolute Time Stamp mode

    .. data:: none = 3

    	time stamp mode none

    """

    unknown = 0

    differential = 1

    absolute = 2

    none = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnTimeStampModeEnum']


class L2VpnTosModeEnum(Enum):
    """
    L2VpnTosModeEnum

    L2vpn tos mode

    .. data:: l2vpn_pw_ip_tos_none = 0

    	None

    .. data:: l2vpn_pw_ip_tos_reflect = 1

    	Reflect the TOS

    """

    l2vpn_pw_ip_tos_none = 0

    l2vpn_pw_ip_tos_reflect = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnTosModeEnum']


class L2VpnTransportModeEnum(Enum):
    """
    L2VpnTransportModeEnum

    L2vpn transport mode

    .. data:: l2vpn_transport_mode_not_specified = 0

    	Not specified

    .. data:: l2vpn_transport_mode_ethernet = 1

    	Ethernet

    .. data:: l2vpn_transport_mode_vlan = 2

    	VLAN

    .. data:: l2vpn_transport_mode_vlan_passthrough = 3

    	VLAN Passthrough

    """

    l2vpn_transport_mode_not_specified = 0

    l2vpn_transport_mode_ethernet = 1

    l2vpn_transport_mode_vlan = 2

    l2vpn_transport_mode_vlan_passthrough = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnTransportModeEnum']


class L2VpnVfiP2MpSignalingEnum(Enum):
    """
    L2VpnVfiP2MpSignalingEnum

    L2vpn vfi p2mp signaling

    .. data:: none = 0

    	undefined signaling

    .. data:: bgp = 1

    	BGP signaling

    """

    none = 0

    bgp = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnVfiP2MpSignalingEnum']


class L2VpnVfiP2MpTransportEnum(Enum):
    """
    L2VpnVfiP2MpTransportEnum

    L2vpn vfi p2mp transport

    .. data:: none = 0

    	undefined transport

    .. data:: rsvp_te = 1

    	RSVP-TE transport

    """

    none = 0

    rsvp_te = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnVfiP2MpTransportEnum']


class L2VpnVfiStateEnum(Enum):
    """
    L2VpnVfiStateEnum

    L2vpn vfi state

    .. data:: unknown = 0

    	VFI Unknown

    .. data:: up = 1

    	VFI Up

    .. data:: down = 2

    	VFI Down

    .. data:: admin_down = 3

    	VFI Admin Down

    """

    unknown = 0

    up = 1

    down = 2

    admin_down = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnVfiStateEnum']


class L2VpnVirtualportStateEnum(Enum):
    """
    L2VpnVirtualportStateEnum

    L2vpn virtualport state

    .. data:: l2vpn_vp_state_undefined = 0

    	Undefined

    .. data:: l2vpn_vp_state_up = 1

    	Up

    .. data:: l2vpn_vp_state_down = 2

    	Down

    """

    l2vpn_vp_state_undefined = 0

    l2vpn_vp_state_up = 1

    l2vpn_vp_state_down = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnVirtualportStateEnum']


class L2VpnVniEncapsEnum(Enum):
    """
    L2VpnVniEncapsEnum

    L2vpn vni encaps

    .. data:: l2vpn_vni_encap_vxlan = 0

    	VXLAN

    .. data:: l2vpn_vni_encap_softgre = 1

    	SOFTGRE

    """

    l2vpn_vni_encap_vxlan = 0

    l2vpn_vni_encap_softgre = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnVniEncapsEnum']


class L2VpnVniModeEnum(Enum):
    """
    L2VpnVniModeEnum

    L2vpn vni mode

    .. data:: l2vpn_vni_mode_l2_dp = 0

    	Data Plane L2 Service

    .. data:: l2vpn_vni_mode_l3_dp = 1

    	Data Plane L3 Service

    .. data:: l2vpn_vni_mode_l2_cp = 2

    	Control Plane L2 Service

    .. data:: l2vpn_vni_mode_l3_cp = 3

    	Control Plane L3 Service

    """

    l2vpn_vni_mode_l2_dp = 0

    l2vpn_vni_mode_l3_dp = 1

    l2vpn_vni_mode_l2_cp = 2

    l2vpn_vni_mode_l3_cp = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnVniModeEnum']


class L2VpnXcStateEnum(Enum):
    """
    L2VpnXcStateEnum

    L2vpn xc state

    .. data:: l2vpn_xc_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_xc_state_down = 1

    	Down

    .. data:: l2vpn_xc_state_up = 2

    	Up

    """

    l2vpn_xc_state_unresolved = 0

    l2vpn_xc_state_down = 1

    l2vpn_xc_state_up = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnXcStateEnum']


class L2Vpnp2MpPtreeEnum(Enum):
    """
    L2Vpnp2MpPtreeEnum

    L2vpnp2mp ptree

    .. data:: rsvp_te = 1

    	RSVPTE Type

    .. data:: mldp = 2

    	MLDP Type

    """

    rsvp_te = 1

    mldp = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2Vpnp2MpPtreeEnum']


class L2VpnpwEnum(Enum):
    """
    L2VpnpwEnum

    L2vpnpw

    .. data:: manual = 1

    	Manual pseudowire

    .. data:: vpls_autodiscovered = 2

    	VPLS autodiscovered pseudowire

    .. data:: vpws_autodiscovered = 3

    	VPWS autodiscovered pseudowire

    .. data:: vpls_autodiscovered_ldp = 4

    	VPLS autodiscovered pseudowire with LDP

    	signaling

    """

    manual = 1

    vpls_autodiscovered = 2

    vpws_autodiscovered = 3

    vpls_autodiscovered_ldp = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnpwEnum']


class MgmtL2FibBridgeEnum(Enum):
    """
    MgmtL2FibBridgeEnum

    Mgmt l2fib bridge

    .. data:: mgmt_l2fib_bridge_type_default = 0

    	mgmt l2fib bridge type default

    .. data:: mgmt_l2fib_bridge_type_pbb_edge = 1

    	mgmt l2fib bridge type pbb edge

    .. data:: mgmt_l2fib_bridge_type_pbb_core = 2

    	mgmt l2fib bridge type pbb core

    """

    mgmt_l2fib_bridge_type_default = 0

    mgmt_l2fib_bridge_type_pbb_edge = 1

    mgmt_l2fib_bridge_type_pbb_core = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibBridgeEnum']


class MgmtL2FibBridgeMacEvpnCtxEnum(Enum):
    """
    MgmtL2FibBridgeMacEvpnCtxEnum

    Mgmt l2fib bridge mac evpn ctx

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_none = 0

    	mgmt l2fib bridge mac evpn ctx none

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_esi_id = 1

    	mgmt l2fib bridge mac evpn ctx esi id

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_local_label = 2

    	mgmt l2fib bridge mac evpn ctx local label

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_moi = 3

    	mgmt l2fib bridge mac evpn ctx moi

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_bp_ifh = 4

    	mgmt l2fib bridge mac evpn ctx bp ifh

    """

    mgmt_l2fib_bridge_mac_evpn_ctx_none = 0

    mgmt_l2fib_bridge_mac_evpn_ctx_esi_id = 1

    mgmt_l2fib_bridge_mac_evpn_ctx_local_label = 2

    mgmt_l2fib_bridge_mac_evpn_ctx_moi = 3

    mgmt_l2fib_bridge_mac_evpn_ctx_bp_ifh = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibBridgeMacEvpnCtxEnum']


class MgmtL2FibDataEnum(Enum):
    """
    MgmtL2FibDataEnum

    Mgmt l2fib data

    .. data:: mgmt_l2fib_data_type_min = 0

    	mgmt l2fib data type min

    .. data:: mgmt_l2fib_data_type_xcon = 1

    	mgmt l2fib data type xcon

    .. data:: mgmt_l2fib_data_type_ac = 2

    	mgmt l2fib data type ac

    .. data:: mgmt_l2fib_data_type_span = 3

    	mgmt l2fib data type span

    .. data:: mgmt_l2fib_data_type_atom = 4

    	mgmt l2fib data type atom

    .. data:: mgmt_l2fib_data_type_pbb = 5

    	mgmt l2fib data type pbb

    .. data:: mgmt_l2fib_data_type_vni = 6

    	mgmt l2fib data type vni

    .. data:: mgmt_l2fib_data_type_n_hop = 7

    	mgmt l2fib data type n hop

    .. data:: mgmt_l2fib_data_type_l2tp = 8

    	mgmt l2fib data type l2tp

    .. data:: mgmt_l2fib_data_type_l2tpv2 = 9

    	mgmt l2fib data type l2tpv2

    .. data:: mgmt_l2fib_data_type_bridge = 10

    	mgmt l2fib data type bridge

    .. data:: mgmt_l2fib_data_type_bridge_shg = 11

    	mgmt l2fib data type bridge shg

    .. data:: mgmt_l2fib_data_type_bridge_port = 12

    	mgmt l2fib data type bridge port

    .. data:: mgmt_l2fib_data_type_bridge_mac = 13

    	mgmt l2fib data type bridge mac

    .. data:: mgmt_l2fib_data_type_mcast_table = 14

    	mgmt l2fib data type mcast table

    .. data:: mgmt_l2fib_data_type_mcast_leaf = 15

    	mgmt l2fib data type mcast leaf

    .. data:: mgmt_l2fib_data_type_mcast_xid = 16

    	mgmt l2fib data type mcast xid

    .. data:: mgmt_l2fib_data_type_dhcp = 17

    	mgmt l2fib data type dhcp

    .. data:: mgmt_l2fib_data_type_l2tp_ipv6_ts = 18

    	mgmt l2fib data type l2tp ipv6 ts

    .. data:: mgmt_l2fib_data_type_pwhe_mp = 19

    	mgmt l2fib data type pwhe mp

    .. data:: mgmt_l2fib_data_type_evpn = 20

    	mgmt l2fib data type evpn

    .. data:: mgmt_l2fib_data_type_fxs = 21

    	mgmt l2fib data type fxs

    .. data:: mgmt_l2fib_data_type_max = 22

    	mgmt l2fib data type max

    """

    mgmt_l2fib_data_type_min = 0

    mgmt_l2fib_data_type_xcon = 1

    mgmt_l2fib_data_type_ac = 2

    mgmt_l2fib_data_type_span = 3

    mgmt_l2fib_data_type_atom = 4

    mgmt_l2fib_data_type_pbb = 5

    mgmt_l2fib_data_type_vni = 6

    mgmt_l2fib_data_type_n_hop = 7

    mgmt_l2fib_data_type_l2tp = 8

    mgmt_l2fib_data_type_l2tpv2 = 9

    mgmt_l2fib_data_type_bridge = 10

    mgmt_l2fib_data_type_bridge_shg = 11

    mgmt_l2fib_data_type_bridge_port = 12

    mgmt_l2fib_data_type_bridge_mac = 13

    mgmt_l2fib_data_type_mcast_table = 14

    mgmt_l2fib_data_type_mcast_leaf = 15

    mgmt_l2fib_data_type_mcast_xid = 16

    mgmt_l2fib_data_type_dhcp = 17

    mgmt_l2fib_data_type_l2tp_ipv6_ts = 18

    mgmt_l2fib_data_type_pwhe_mp = 19

    mgmt_l2fib_data_type_evpn = 20

    mgmt_l2fib_data_type_fxs = 21

    mgmt_l2fib_data_type_max = 22


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibDataEnum']


class MgmtL2FibMacLimitActionEnum(Enum):
    """
    MgmtL2FibMacLimitActionEnum

    Mgmt l2fib mac limit action

    .. data:: mgmt_l2fib_mac_limit_action_type_none = 0

    	mgmt l2fib mac limit action type none

    .. data:: mgmt_l2fib_mac_limit_action_type_flood = 1

    	mgmt l2fib mac limit action type flood

    .. data:: mgmt_l2fib_mac_limit_action_type_no_flood = 2

    	mgmt l2fib mac limit action type no flood

    .. data:: mgmt_l2fib_mac_limit_action_type_shutdown = 3

    	mgmt l2fib mac limit action type shutdown

    """

    mgmt_l2fib_mac_limit_action_type_none = 0

    mgmt_l2fib_mac_limit_action_type_flood = 1

    mgmt_l2fib_mac_limit_action_type_no_flood = 2

    mgmt_l2fib_mac_limit_action_type_shutdown = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibMacLimitActionEnum']


class MgmtL2FibMacLimitNotifyEnum(Enum):
    """
    MgmtL2FibMacLimitNotifyEnum

    Mgmt l2fib mac limit notify

    .. data:: mgmt_l2fib_mac_limit_notify_none = 0

    	mgmt l2fib mac limit notify none

    .. data:: mgmt_l2fib_mac_limit_notify_syslog = 1

    	mgmt l2fib mac limit notify syslog

    .. data:: mgmt_l2fib_mac_limit_notify_trap = 2

    	mgmt l2fib mac limit notify trap

    .. data:: mgmt_l2fib_mac_limit_notify_both = 3

    	mgmt l2fib mac limit notify both

    """

    mgmt_l2fib_mac_limit_notify_none = 0

    mgmt_l2fib_mac_limit_notify_syslog = 1

    mgmt_l2fib_mac_limit_notify_trap = 2

    mgmt_l2fib_mac_limit_notify_both = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibMacLimitNotifyEnum']


class MgmtL2FibMacSecActionEnum(Enum):
    """
    MgmtL2FibMacSecActionEnum

    Mgmt l2fib mac sec action

    .. data:: not_set = 0

    	MAC Secure Action Not Set

    .. data:: restrict = 1

    	MAC Secure Action Restrict

    .. data:: none = 2

    	MAC Secure Action None

    .. data:: shutdown = 3

    	MAC Secure Action Shutdown

    """

    not_set = 0

    restrict = 1

    none = 2

    shutdown = 3


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibMacSecActionEnum']


class MgmtL2FibStatsDataEnum(Enum):
    """
    MgmtL2FibStatsDataEnum

    Mgmt l2fib stats data

    .. data:: mgmt_l2fib_stats_type_unknown = 0

    	mgmt l2fib stats type unknown

    .. data:: mgmt_l2fib_stats_type_mcast = 1

    	mgmt l2fib stats type mcast

    """

    mgmt_l2fib_stats_type_unknown = 0

    mgmt_l2fib_stats_type_mcast = 1


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibStatsDataEnum']


class MgmtL2FibSwitchingEnum(Enum):
    """
    MgmtL2FibSwitchingEnum

    Mgmt l2fib switching

    .. data:: mgmt_l2fib_switching_type_unknown = 0

    	mgmt l2fib switching type unknown

    .. data:: mgmt_l2fib_switching_type_ac_ac = 1

    	mgmt l2fib switching type ac ac

    .. data:: mgmt_l2fib_switching_type_ac_atom = 2

    	mgmt l2fib switching type ac atom

    .. data:: mgmt_l2fib_switching_type_ac_vfi = 3

    	mgmt l2fib switching type ac vfi

    .. data:: mgmt_l2fib_switching_type_ac_l2tp = 4

    	mgmt l2fib switching type ac l2tp

    .. data:: mgmt_l2fib_switching_type_atom_atom = 5

    	mgmt l2fib switching type atom atom

    .. data:: mgmt_l2fib_switching_type_vfi_atom = 6

    	mgmt l2fib switching type vfi atom

    .. data:: mgmt_l2fib_switching_type_vfi_l2tp = 7

    	mgmt l2fib switching type vfi l2tp

    .. data:: mgmt_l2fib_switching_type_l2tp_atom = 8

    	mgmt l2fib switching type l2tp atom

    .. data:: mgmt_l2fib_switching_type_l2tp_l2tp = 9

    	mgmt l2fib switching type l2tp l2tp

    .. data:: mgmt_l2fib_switching_type_max = 10

    	mgmt l2fib switching type max

    """

    mgmt_l2fib_switching_type_unknown = 0

    mgmt_l2fib_switching_type_ac_ac = 1

    mgmt_l2fib_switching_type_ac_atom = 2

    mgmt_l2fib_switching_type_ac_vfi = 3

    mgmt_l2fib_switching_type_ac_l2tp = 4

    mgmt_l2fib_switching_type_atom_atom = 5

    mgmt_l2fib_switching_type_vfi_atom = 6

    mgmt_l2fib_switching_type_vfi_l2tp = 7

    mgmt_l2fib_switching_type_l2tp_atom = 8

    mgmt_l2fib_switching_type_l2tp_l2tp = 9

    mgmt_l2fib_switching_type_max = 10


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['MgmtL2FibSwitchingEnum']


class P2MpTransportStateEnum(Enum):
    """
    P2MpTransportStateEnum

    P2mp transport state

    .. data:: none = 0

    	no information about the transport yet

    .. data:: ok = 1

    	transport up

    .. data:: error = 2

    	transport error

    .. data:: tunnel_down = 3

    	tunnel is down

    .. data:: max_tunnels_reached = 4

    	transport down because the maximum number of

    	tunnels is reached

    """

    none = 0

    ok = 1

    error = 2

    tunnel_down = 3

    max_tunnels_reached = 4


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['P2MpTransportStateEnum']


class PwhePortImStateEnum(Enum):
    """
    PwhePortImStateEnum

    Pseudowire headend port states

    .. data:: unknown = 0

    	Unknown

    .. data:: down = 1

    	Down

    .. data:: up = 2

    	Up

    """

    unknown = 0

    down = 1

    up = 2


    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['PwhePortImStateEnum']



class L2VpnForwarding(object):
    """
    Show L2VPN forwarding
    
    .. attribute:: nodes
    
    	Per node L2VPN forwarding Operational data
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.nodes = L2VpnForwarding.Nodes()
        self.nodes.parent = self


    class Nodes(object):
        """
        Per node L2VPN forwarding Operational data
        
        .. attribute:: node
        
        	The L2VPN forwarding Operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.node = YList()
            self.node.parent = self
            self.node.name = 'node'


        class Node(object):
            """
            The L2VPN forwarding Operational data for a
            particular node
            
            .. attribute:: node_id  <key>
            
            	The identifier for the node
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: l2fib_bridge_domain_names
            
            	Bridge Domain forwarding detail
            	**type**\:   :py:class:`L2FibBridgeDomainNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames>`
            
            .. attribute:: l2fib_bridge_domains
            
            	Bridge Domain forwarding detail
            	**type**\:   :py:class:`L2FibBridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains>`
            
            .. attribute:: l2fib_bridge_ports
            
            	Bridge Port forwarding detail
            	**type**\:   :py:class:`L2FibBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts>`
            
            .. attribute:: l2fib_dhcp_binding_count
            
            	DHCP binding forwarding total count
            	**type**\:   :py:class:`L2FibDhcpBindingCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount>`
            
            .. attribute:: l2fib_dhcp_binding_details
            
            	DHCP binding forwarding detail
            	**type**\:   :py:class:`L2FibDhcpBindingDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails>`
            
            .. attribute:: l2fib_dhcp_binding_summaries
            
            	DHCP binding forwarding summary
            	**type**\:   :py:class:`L2FibDhcpBindingSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries>`
            
            .. attribute:: l2fib_evpn_incl_m_cast_hardware_egresses
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast hardware egress Table
            	**type**\:   :py:class:`L2FibEvpnInclMCastHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses>`
            
            .. attribute:: l2fib_evpn_incl_m_cast_hardware_ingresses
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast hardware ingress Table
            	**type**\:   :py:class:`L2FibEvpnInclMCastHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses>`
            
            .. attribute:: l2fib_evpn_incl_m_casts
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast Table
            	**type**\:   :py:class:`L2FibEvpnInclMCasts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts>`
            
            .. attribute:: l2fib_evpn_ip4macs
            
            	EVPN IPv4\-MAC Table
            	**type**\:   :py:class:`L2FibEvpnIp4Macs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs>`
            
            .. attribute:: l2fib_evpn_ip6macs
            
            	EVPN IPv6\-MAC Table
            	**type**\:   :py:class:`L2FibEvpnIp6Macs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs>`
            
            .. attribute:: l2fib_g8032
            
            	G8032 information
            	**type**\:   :py:class:`L2FibG8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032>`
            
            .. attribute:: l2fib_l2tp
            
            	L2TP
            	**type**\:   :py:class:`L2FibL2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp>`
            
            .. attribute:: l2fib_main_interfaces
            
            	Main Interface
            	**type**\:   :py:class:`L2FibMainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces>`
            
            .. attribute:: l2fib_message_summary
            
            	L2FIB Message Summary information
            	**type**\:   :py:class:`L2FibMessageSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary>`
            
            .. attribute:: l2fib_mmrp_summaries
            
            	Mmrp Summary Table
            	**type**\:   :py:class:`L2FibMmrpSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries>`
            
            .. attribute:: l2fib_mmrps
            
            	mmmrp information
            	**type**\:   :py:class:`L2FibMmrps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps>`
            
            .. attribute:: l2fib_mon_sess_x_cons
            
            	The L2VPN forwarding Monitor Session XConnect Information
            	**type**\:   :py:class:`L2FibMonSessXCons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons>`
            
            .. attribute:: l2fib_mroute_ipv6s
            
            	multicast information
            	**type**\:   :py:class:`L2FibMrouteIpv6S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S>`
            
            .. attribute:: l2fib_mroute_ports
            
            	multicast bridge port information 
            	**type**\:   :py:class:`L2FibMroutePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts>`
            
            .. attribute:: l2fib_mroute_summaries
            
            	Mroute Summary Table
            	**type**\:   :py:class:`L2FibMrouteSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries>`
            
            .. attribute:: l2fib_mroutes
            
            	multicast information
            	**type**\:   :py:class:`L2FibMroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes>`
            
            .. attribute:: l2fib_mstp_details
            
            	MSTP Detail Table
            	**type**\:   :py:class:`L2FibMstpDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpDetails>`
            
            .. attribute:: l2fib_mstp_summaries
            
            	MSTP Summary Table
            	**type**\:   :py:class:`L2FibMstpSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpSummaries>`
            
            .. attribute:: l2fib_nve_peers
            
            	NVE Peer Table
            	**type**\:   :py:class:`L2FibNvePeers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibNvePeers>`
            
            .. attribute:: l2fib_p2mp
            
            	p2mp information
            	**type**\:   :py:class:`L2FibP2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibP2Mp>`
            
            .. attribute:: l2fib_pw_groups
            
            	PW Group Table Information
            	**type**\:   :py:class:`L2FibPwGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwGroups>`
            
            .. attribute:: l2fib_pwhe_main_ports
            
            	PWHE Main\-port table
            	**type**\:   :py:class:`L2FibPwheMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts>`
            
            .. attribute:: l2fib_resource_availability
            
            	Resource availability information
            	**type**\:   :py:class:`L2FibResourceAvailability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibResourceAvailability>`
            
            .. attribute:: l2fib_summary
            
            	L2FIB Summary information
            	**type**\:   :py:class:`L2FibSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary>`
            
            .. attribute:: l2fibmac_details
            
            	Bridge MAC detail information
            	**type**\:   :py:class:`L2FibmacDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails>`
            
            .. attribute:: l2fibmac_hardware_egresses
            
            	Bridge Hardware Egress information
            	**type**\:   :py:class:`L2FibmacHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses>`
            
            .. attribute:: l2fibmac_hardware_ingresses
            
            	Bridge Hardware Ingress information
            	**type**\:   :py:class:`L2FibmacHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses>`
            
            .. attribute:: l2fibx_con_l2tpv2s
            
            	The L2VPN forwarding XConnect L2TPv2 Detail Table
            	**type**\:   :py:class:`L2FibxConL2Tpv2S <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S>`
            
            .. attribute:: l2fibx_con_locals
            
            	The L2VPN forwarding Local LC XConnect Detail Table
            	**type**\:   :py:class:`L2FibxConLocals <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals>`
            
            .. attribute:: l2fibx_cons
            
            	The L2VPN forwarding XConnect Detail Table
            	**type**\:   :py:class:`L2FibxCons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons>`
            
            .. attribute:: pbb_bmac_sa
            
            	PBB Backbone Source MAC information
            	**type**\:   :py:class:`PbbBmacSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.PbbBmacSa>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.node_id = None
                self.l2fib_bridge_domain_names = L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames()
                self.l2fib_bridge_domain_names.parent = self
                self.l2fib_bridge_domains = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains()
                self.l2fib_bridge_domains.parent = self
                self.l2fib_bridge_ports = L2VpnForwarding.Nodes.Node.L2FibBridgePorts()
                self.l2fib_bridge_ports.parent = self
                self.l2fib_dhcp_binding_count = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount()
                self.l2fib_dhcp_binding_count.parent = self
                self.l2fib_dhcp_binding_details = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails()
                self.l2fib_dhcp_binding_details.parent = self
                self.l2fib_dhcp_binding_summaries = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries()
                self.l2fib_dhcp_binding_summaries.parent = self
                self.l2fib_evpn_incl_m_cast_hardware_egresses = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses()
                self.l2fib_evpn_incl_m_cast_hardware_egresses.parent = self
                self.l2fib_evpn_incl_m_cast_hardware_ingresses = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses()
                self.l2fib_evpn_incl_m_cast_hardware_ingresses.parent = self
                self.l2fib_evpn_incl_m_casts = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts()
                self.l2fib_evpn_incl_m_casts.parent = self
                self.l2fib_evpn_ip4macs = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs()
                self.l2fib_evpn_ip4macs.parent = self
                self.l2fib_evpn_ip6macs = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs()
                self.l2fib_evpn_ip6macs.parent = self
                self.l2fib_g8032 = L2VpnForwarding.Nodes.Node.L2FibG8032()
                self.l2fib_g8032.parent = self
                self.l2fib_l2tp = L2VpnForwarding.Nodes.Node.L2FibL2Tp()
                self.l2fib_l2tp.parent = self
                self.l2fib_main_interfaces = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces()
                self.l2fib_main_interfaces.parent = self
                self.l2fib_message_summary = L2VpnForwarding.Nodes.Node.L2FibMessageSummary()
                self.l2fib_message_summary.parent = self
                self.l2fib_mmrp_summaries = L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries()
                self.l2fib_mmrp_summaries.parent = self
                self.l2fib_mmrps = L2VpnForwarding.Nodes.Node.L2FibMmrps()
                self.l2fib_mmrps.parent = self
                self.l2fib_mon_sess_x_cons = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons()
                self.l2fib_mon_sess_x_cons.parent = self
                self.l2fib_mroute_ipv6s = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S()
                self.l2fib_mroute_ipv6s.parent = self
                self.l2fib_mroute_ports = L2VpnForwarding.Nodes.Node.L2FibMroutePorts()
                self.l2fib_mroute_ports.parent = self
                self.l2fib_mroute_summaries = L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries()
                self.l2fib_mroute_summaries.parent = self
                self.l2fib_mroutes = L2VpnForwarding.Nodes.Node.L2FibMroutes()
                self.l2fib_mroutes.parent = self
                self.l2fib_mstp_details = L2VpnForwarding.Nodes.Node.L2FibMstpDetails()
                self.l2fib_mstp_details.parent = self
                self.l2fib_mstp_summaries = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries()
                self.l2fib_mstp_summaries.parent = self
                self.l2fib_nve_peers = L2VpnForwarding.Nodes.Node.L2FibNvePeers()
                self.l2fib_nve_peers.parent = self
                self.l2fib_p2mp = L2VpnForwarding.Nodes.Node.L2FibP2Mp()
                self.l2fib_p2mp.parent = self
                self.l2fib_pw_groups = L2VpnForwarding.Nodes.Node.L2FibPwGroups()
                self.l2fib_pw_groups.parent = self
                self.l2fib_pwhe_main_ports = L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts()
                self.l2fib_pwhe_main_ports.parent = self
                self.l2fib_resource_availability = L2VpnForwarding.Nodes.Node.L2FibResourceAvailability()
                self.l2fib_resource_availability.parent = self
                self.l2fib_summary = L2VpnForwarding.Nodes.Node.L2FibSummary()
                self.l2fib_summary.parent = self
                self.l2fibmac_details = L2VpnForwarding.Nodes.Node.L2FibmacDetails()
                self.l2fibmac_details.parent = self
                self.l2fibmac_hardware_egresses = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses()
                self.l2fibmac_hardware_egresses.parent = self
                self.l2fibmac_hardware_ingresses = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses()
                self.l2fibmac_hardware_ingresses.parent = self
                self.l2fibx_con_l2tpv2s = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S()
                self.l2fibx_con_l2tpv2s.parent = self
                self.l2fibx_con_locals = L2VpnForwarding.Nodes.Node.L2FibxConLocals()
                self.l2fibx_con_locals.parent = self
                self.l2fibx_cons = L2VpnForwarding.Nodes.Node.L2FibxCons()
                self.l2fibx_cons.parent = self
                self.pbb_bmac_sa = L2VpnForwarding.Nodes.Node.PbbBmacSa()
                self.pbb_bmac_sa.parent = self


            class L2FibxConLocals(object):
                """
                The L2VPN forwarding Local LC XConnect Detail
                Table
                
                .. attribute:: l2fibx_con_local
                
                	Specify Sub Ifh
                	**type**\: list of    :py:class:`L2FibxConLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fibx_con_local = YList()
                    self.l2fibx_con_local.parent = self
                    self.l2fibx_con_local.name = 'l2fibx_con_local'


                class L2FibxConLocal(object):
                    """
                    Specify Sub Ifh
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitchingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitchingEnum>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base()
                        self.base.parent = self
                        self.bound = None
                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1()
                        self.segment1.parent = self
                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2()
                        self.segment2.parent = self
                        self.switching_type = None
                        self.xcon_name = None


                    class Base(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Base']['meta_info']


                    class Segment1(object):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn()
                            self.evpn.parent = self
                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base()
                                self.base.parent = self
                                self.bound = None
                                self.core_pbb_evpn_enabled = None
                                self.forward_class = None
                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.Base']['meta_info']


                            class PbbUnion(object):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self.pbb_type = None


                                class Edge(object):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mac = None
                                        self.mac_configured = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mac is not None:
                                            return True

                                        if self.mac_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Edge']['meta_info']


                                class Core(object):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.vlan_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.vlan_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion.Core']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core is not None and self.core._has_data():
                                        return True

                                    if self.edge is not None and self.edge._has_data():
                                        return True

                                    if self.pbb_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb.PbbUnion']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.core_pbb_evpn_enabled is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.pbb_union is not None and self.pbb_union._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base()
                                self.base.parent = self
                                self.bound = None
                                self.encap = None
                                self.mcastip = None
                                self.parent_if = None
                                self.source_vtep_if = None
                                self.srcip = None
                                self.udp_port = None
                                self.vx_lan_mode = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.any_cast_ip is not None:
                                    return True

                                if self.anycast_mcast_ip is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.encap is not None:
                                    return True

                                if self.mcastip is not None:
                                    return True

                                if self.parent_if is not None:
                                    return True

                                if self.source_vtep_if is not None:
                                    return True

                                if self.srcip is not None:
                                    return True

                                if self.udp_port is not None:
                                    return True

                                if self.vx_lan_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evi = None
                                self.forward_class = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evi is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Evpn']['meta_info']


                        class MonitorSession(object):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self.bound = None
                                self.hardware_information = None
                                self.session_name = None
                                self.xcid = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:monitor-session'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.hardware_information is not None:
                                    return True

                                if self.session_name is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.MonitorSession']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.monitor_session is not None and self.monitor_session._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment1']['meta_info']


                    class Segment2(object):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac()
                            self.ac.parent = self
                            self.bp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp()
                            self.bp.parent = self
                            self.data_type = None
                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs()
                            self.fxs.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw()
                            self.pw.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Ac']['meta_info']


                        class Bp(object):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base()
                                self.base.parent = self
                                self.bridge_id = None
                                self.learn_key = None
                                self.msti_pointer = None
                                self.mvrp_sequence_number = None
                                self.oper = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self.segment_type = None
                                self.shg_id = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Base']['meta_info']


                            class Oper(object):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None


                                class OperationalInformation(object):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.admin_disabled = None
                                        self.bvi_configured = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.feature = YList()
                                        self.feature.parent = self
                                        self.feature.name = 'feature'
                                        self.flood_unknown_unicast_enabled = None
                                        self.flooding_disabled = None
                                        self.host_routing_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.is_bvi_up = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_evpn_cw_disable = None
                                        self.is_evpn_enabled = None
                                        self.is_evpn_flow_label = None
                                        self.is_igmp_snoop_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_vni_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.mac_aging_time = None
                                        self.mac_aging_type = None
                                        self.mac_learning_disabled = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification_type = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_secure_action = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.msti = None
                                        self.mtu = None
                                        self.number_of_macs = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.stp_participating = None
                                        self.unknown_unicast_flooding_disabled = None


                                    class Feature(object):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self.feature_type = None
                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self


                                        class Dhcp(object):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp']['meta_info']


                                        class Igmp(object):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp']['meta_info']


                                        class Mld(object):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dhcp is not None and self.dhcp._has_data():
                                                return True

                                            if self.feature_type is not None:
                                                return True

                                            if self.igmp is not None and self.igmp._has_data():
                                                return True

                                            if self.mld is not None and self.mld._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.admin_disabled is not None:
                                            return True

                                        if self.bvi_configured is not None:
                                            return True

                                        if self.dhcp_enabled is not None:
                                            return True

                                        if self.dhcp_trusted is not None:
                                            return True

                                        if self.feature is not None:
                                            for child_ref in self.feature:
                                                if child_ref._has_data():
                                                    return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flooding_disabled is not None:
                                            return True

                                        if self.host_routing_enabled is not None:
                                            return True

                                        if self.igmp_flood_forward_enabled is not None:
                                            return True

                                        if self.igmp_mroute_port_enabled is not None:
                                            return True

                                        if self.igmp_route_guard_enabled is not None:
                                            return True

                                        if self.igmp_snoop_enabled is not None:
                                            return True

                                        if self.igmp_snoop_profile_enabled is not None:
                                            return True

                                        if self.is_bvi_up is not None:
                                            return True

                                        if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_evpn_cw_disable is not None:
                                            return True

                                        if self.is_evpn_enabled is not None:
                                            return True

                                        if self.is_evpn_flow_label is not None:
                                            return True

                                        if self.is_igmp_snoop_enabled is not None:
                                            return True

                                        if self.is_ipsg_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.is_p2mp_pw_enabled is not None:
                                            return True

                                        if self.is_pbbevpn_enabled is not None:
                                            return True

                                        if self.is_swmac_learning is not None:
                                            return True

                                        if self.is_vni_enabled is not None:
                                            return True

                                        if self.is_vpls_flood_optimization_enabled is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_aging_type is not None:
                                            return True

                                        if self.mac_learning_disabled is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification_type is not None:
                                            return True

                                        if self.mac_port_down_flush_disabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_flood_forward_enabled is not None:
                                            return True

                                        if self.mld_mroute_port_enabled is not None:
                                            return True

                                        if self.mld_route_guard_enabled is not None:
                                            return True

                                        if self.mld_snoop_enabled is not None:
                                            return True

                                        if self.mld_snoop_profile_enabled is not None:
                                            return True

                                        if self.msti is not None:
                                            return True

                                        if self.mtu is not None:
                                            return True

                                        if self.number_of_macs is not None:
                                            return True

                                        if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                            return True

                                        if self.storm_control_broadcast_enabled is not None:
                                            return True

                                        if self.storm_control_broadcast_rate_unit is not None:
                                            return True

                                        if self.storm_control_multicast_enabled is not None:
                                            return True

                                        if self.storm_control_multicast_rate_unit is not None:
                                            return True

                                        if self.storm_control_unicast_enabled is not None:
                                            return True

                                        if self.storm_control_unicast_rate_unit is not None:
                                            return True

                                        if self.stp_participating is not None:
                                            return True

                                        if self.unknown_unicast_flooding_disabled is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper.OperationalInformation']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:oper'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.operational_information is not None and self.operational_information._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.Oper']['meta_info']


                            class P2Mp(object):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtreeEnum>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extended_tunnel_id = None
                                    self.lsm_id = None
                                    self.p2mp_id = None
                                    self.ptree_owner_lmrib = None
                                    self.ptree_type = None
                                    self.tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extended_tunnel_id is not None:
                                        return True

                                    if self.lsm_id is not None:
                                        return True

                                    if self.p2mp_id is not None:
                                        return True

                                    if self.ptree_owner_lmrib is not None:
                                        return True

                                    if self.ptree_type is not None:
                                        return True

                                    if self.tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp.P2Mp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bridge_id is not None:
                                    return True

                                if self.learn_key is not None:
                                    return True

                                if self.msti_pointer is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.oper is not None and self.oper._has_data():
                                    return True

                                if self.p2mp is not None and self.p2mp._has_data():
                                    return True

                                if self.segment_type is not None:
                                    return True

                                if self.shg_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Bp']['meta_info']


                        class Fxs(object):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base()
                                self.base.parent = self
                                self.fxs_id = None
                                self.segment_type = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.fxs_id is not None:
                                    return True

                                if self.segment_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Fxs']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.bp is not None and self.bp._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.fxs is not None and self.fxs._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal.Segment2']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibx-con-local[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bound is not None:
                            return True

                        if self.segment1 is not None and self.segment1._has_data():
                            return True

                        if self.segment2 is not None and self.segment2._has_data():
                            return True

                        if self.switching_type is not None:
                            return True

                        if self.xcon_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals.L2FibxConLocal']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibx-con-locals'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fibx_con_local is not None:
                        for child_ref in self.l2fibx_con_local:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConLocals']['meta_info']


            class L2FibMrouteSummaries(object):
                """
                Mroute Summary Table
                
                .. attribute:: l2fib_mroute_summary
                
                	Multicast Summary Information
                	**type**\: list of    :py:class:`L2FibMrouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mroute_summary = YList()
                    self.l2fib_mroute_summary.parent = self
                    self.l2fib_mroute_summary.name = 'l2fib_mroute_summary'


                class L2FibMrouteSummary(object):
                    """
                    Multicast Summary Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: message
                    
                    	Global Message Information
                    	**type**\: list of    :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message>`
                    
                    .. attribute:: multicast_update
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update_dropped
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_all_delete_drop
                    
                    	Number of Mroutes All Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_delete_drop
                    
                    	Number of Mroutes Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_deleted
                    
                    	Number of Mroutes Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroutes_deleted_all
                    
                    	Number of Mroutes All Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_mroute_add
                    
                    	Number of Mroutes Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes
                    
                    	Number of Routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes_with_ole_offload
                    
                    	Number of Routes with OleOffload
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_xid
                    
                    	Number of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_add
                    
                    	Number of XID Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_deleted
                    
                    	Number of XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_deleted
                    
                    	Stale Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_xid_deleted
                    
                    	Stale XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_id = None
                        self.bridge_domain_name = None
                        self.message = YList()
                        self.message.parent = self
                        self.message.name = 'message'
                        self.multicast_update = None
                        self.multicast_update_dropped = None
                        self.number_mroute_all_delete_drop = None
                        self.number_mroute_delete_drop = None
                        self.number_mroute_deleted = None
                        self.number_mroutes_deleted_all = None
                        self.number_of_mroute_add = None
                        self.number_of_routes = None
                        self.number_of_routes_with_ole_offload = None
                        self.number_of_xid = None
                        self.number_xid_add = None
                        self.number_xid_deleted = None
                        self.stale_deleted = None
                        self.stale_xid_deleted = None


                    class Message(object):
                        """
                        Global Message Information
                        
                        .. attribute:: information1
                        
                        	Extra info 1
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: information2
                        
                        	Extra info 2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: messgae_count
                        
                        	number of message
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time
                        
                        	Time string
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.information1 = None
                            self.information2 = None
                            self.messgae_count = None
                            self.time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:message'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.information1 is not None:
                                return True

                            if self.information2 is not None:
                                return True

                            if self.messgae_count is not None:
                                return True

                            if self.time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary.Message']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_group_name is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_domain_id is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.message is not None:
                            for child_ref in self.message:
                                if child_ref._has_data():
                                    return True

                        if self.multicast_update is not None:
                            return True

                        if self.multicast_update_dropped is not None:
                            return True

                        if self.number_mroute_all_delete_drop is not None:
                            return True

                        if self.number_mroute_delete_drop is not None:
                            return True

                        if self.number_mroute_deleted is not None:
                            return True

                        if self.number_mroutes_deleted_all is not None:
                            return True

                        if self.number_of_mroute_add is not None:
                            return True

                        if self.number_of_routes is not None:
                            return True

                        if self.number_of_routes_with_ole_offload is not None:
                            return True

                        if self.number_of_xid is not None:
                            return True

                        if self.number_xid_add is not None:
                            return True

                        if self.number_xid_deleted is not None:
                            return True

                        if self.stale_deleted is not None:
                            return True

                        if self.stale_xid_deleted is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries.L2FibMrouteSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mroute_summary is not None:
                        for child_ref in self.l2fib_mroute_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteSummaries']['meta_info']


            class L2FibMessageSummary(object):
                """
                L2FIB Message Summary information
                
                .. attribute:: event_history
                
                	Event history buffer
                	**type**\:   :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory>`
                
                .. attribute:: message
                
                	message
                	**type**\: list of    :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message>`
                
                .. attribute:: round_trip_delay
                
                	Round\-Trip delay
                	**type**\:   :py:class:`RoundTripDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_history = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory()
                    self.event_history.parent = self
                    self.message = YList()
                    self.message.parent = self
                    self.message.name = 'message'
                    self.round_trip_delay = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay()
                    self.round_trip_delay.parent = self


                class EventHistory(object):
                    """
                    Event history buffer
                    
                    .. attribute:: event_entry
                    
                    	event entry
                    	**type**\: list of    :py:class:`EventEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry>`
                    
                    .. attribute:: event_neighbor_entry
                    
                    	number of item in the array
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: extra_information1
                    
                    	extra information1
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: extra_information2
                    
                    	extra information2
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.event_entry = YList()
                        self.event_entry.parent = self
                        self.event_entry.name = 'event_entry'
                        self.event_neighbor_entry = None
                        self.extra_information1 = YLeafList()
                        self.extra_information1.parent = self
                        self.extra_information1.name = 'extra_information1'
                        self.extra_information2 = YLeafList()
                        self.extra_information2.parent = self
                        self.extra_information2.name = 'extra_information2'


                    class EventEntry(object):
                        """
                        event entry
                        
                        .. attribute:: event_flags
                        
                        	base flag object
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: event_many
                        
                        	Multiple event instance flag
                        	**type**\:  bool
                        
                        .. attribute:: event_sticky
                        
                        	Unwrittable flag
                        	**type**\:  bool
                        
                        .. attribute:: event_time
                        
                        	The real timestamp of the event
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: event_type
                        
                        	Event type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.event_flags = None
                            self.event_many = None
                            self.event_sticky = None
                            self.event_time = None
                            self.event_type = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:event-entry'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.event_flags is not None:
                                return True

                            if self.event_many is not None:
                                return True

                            if self.event_sticky is not None:
                                return True

                            if self.event_time is not None:
                                return True

                            if self.event_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory.EventEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:event-history'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.event_entry is not None:
                            for child_ref in self.event_entry:
                                if child_ref._has_data():
                                    return True

                        if self.event_neighbor_entry is not None:
                            return True

                        if self.extra_information1 is not None:
                            for child in self.extra_information1:
                                if child is not None:
                                    return True

                        if self.extra_information2 is not None:
                            for child in self.extra_information2:
                                if child is not None:
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.EventHistory']['meta_info']


                class RoundTripDelay(object):
                    """
                    Round\-Trip delay
                    
                    .. attribute:: aging_rtd
                    
                    	aging rtd
                    	**type**\:   :py:class:`AgingRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd>`
                    
                    .. attribute:: bdxc_rtd
                    
                    	bdxc rtd
                    	**type**\:   :py:class:`BdxcRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd>`
                    
                    .. attribute:: bind
                    
                    	bind
                    	**type**\: list of    :py:class:`Bind <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind>`
                    
                    .. attribute:: create
                    
                    	create
                    	**type**\: list of    :py:class:`Create <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create>`
                    
                    .. attribute:: delete
                    
                    	delete
                    	**type**\: list of    :py:class:`Delete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete>`
                    
                    .. attribute:: lock_rtd
                    
                    	lock rtd
                    	**type**\:   :py:class:`LockRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd>`
                    
                    .. attribute:: mac_flush
                    
                    	mac flush
                    	**type**\: list of    :py:class:`MacFlush <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush>`
                    
                    .. attribute:: modify
                    
                    	modify
                    	**type**\: list of    :py:class:`Modify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify>`
                    
                    .. attribute:: pirtd
                    
                    	pirtd
                    	**type**\: list of    :py:class:`Pirtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd>`
                    
                    .. attribute:: platform_init_rtd
                    
                    	platform init rtd
                    	**type**\:   :py:class:`PlatformInitRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd>`
                    
                    .. attribute:: punt_rtd
                    
                    	punt rtd
                    	**type**\:   :py:class:`PuntRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd>`
                    
                    .. attribute:: rtd_max_obj_type
                    
                    	RTD MAX OBJTYPE
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unbind
                    
                    	unbind
                    	**type**\: list of    :py:class:`Unbind <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.aging_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd()
                        self.aging_rtd.parent = self
                        self.bdxc_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd()
                        self.bdxc_rtd.parent = self
                        self.bind = YList()
                        self.bind.parent = self
                        self.bind.name = 'bind'
                        self.create = YList()
                        self.create.parent = self
                        self.create.name = 'create'
                        self.delete = YList()
                        self.delete.parent = self
                        self.delete.name = 'delete'
                        self.lock_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd()
                        self.lock_rtd.parent = self
                        self.mac_flush = YList()
                        self.mac_flush.parent = self
                        self.mac_flush.name = 'mac_flush'
                        self.modify = YList()
                        self.modify.parent = self
                        self.modify.name = 'modify'
                        self.pirtd = YList()
                        self.pirtd.parent = self
                        self.pirtd.name = 'pirtd'
                        self.platform_init_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd()
                        self.platform_init_rtd.parent = self
                        self.punt_rtd = L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd()
                        self.punt_rtd.parent = self
                        self.rtd_max_obj_type = None
                        self.unbind = YList()
                        self.unbind.parent = self
                        self.unbind.name = 'unbind'


                    class BdxcRtd(object):
                        """
                        bdxc rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bdxc-rtd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.BdxcRtd']['meta_info']


                    class AgingRtd(object):
                        """
                        aging rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:aging-rtd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.AgingRtd']['meta_info']


                    class PuntRtd(object):
                        """
                        punt rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:punt-rtd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PuntRtd']['meta_info']


                    class LockRtd(object):
                        """
                        lock rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:lock-rtd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.LockRtd']['meta_info']


                    class PlatformInitRtd(object):
                        """
                        platform init rtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:platform-init-rtd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.PlatformInitRtd']['meta_info']


                    class Create(object):
                        """
                        create
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:create'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Create']['meta_info']


                    class Modify(object):
                        """
                        modify
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:modify'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Modify']['meta_info']


                    class Delete(object):
                        """
                        delete
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:delete'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Delete']['meta_info']


                    class Bind(object):
                        """
                        bind
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bind'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Bind']['meta_info']


                    class Unbind(object):
                        """
                        unbind
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unbind'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Unbind']['meta_info']


                    class MacFlush(object):
                        """
                        mac flush
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-flush'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.MacFlush']['meta_info']


                    class Pirtd(object):
                        """
                        pirtd
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.average_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.minimum_round_trip_delay = None
                            self.number_pd_update = None
                            self.number_pd_update_zero = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pirtd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.average_round_trip_delay is not None:
                                return True

                            if self.maximum_round_trip_delay is not None:
                                return True

                            if self.minimum_round_trip_delay is not None:
                                return True

                            if self.number_pd_update is not None:
                                return True

                            if self.number_pd_update_zero is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay.Pirtd']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:round-trip-delay'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.aging_rtd is not None and self.aging_rtd._has_data():
                            return True

                        if self.bdxc_rtd is not None and self.bdxc_rtd._has_data():
                            return True

                        if self.bind is not None:
                            for child_ref in self.bind:
                                if child_ref._has_data():
                                    return True

                        if self.create is not None:
                            for child_ref in self.create:
                                if child_ref._has_data():
                                    return True

                        if self.delete is not None:
                            for child_ref in self.delete:
                                if child_ref._has_data():
                                    return True

                        if self.lock_rtd is not None and self.lock_rtd._has_data():
                            return True

                        if self.mac_flush is not None:
                            for child_ref in self.mac_flush:
                                if child_ref._has_data():
                                    return True

                        if self.modify is not None:
                            for child_ref in self.modify:
                                if child_ref._has_data():
                                    return True

                        if self.pirtd is not None:
                            for child_ref in self.pirtd:
                                if child_ref._has_data():
                                    return True

                        if self.platform_init_rtd is not None and self.platform_init_rtd._has_data():
                            return True

                        if self.punt_rtd is not None and self.punt_rtd._has_data():
                            return True

                        if self.rtd_max_obj_type is not None:
                            return True

                        if self.unbind is not None:
                            for child_ref in self.unbind:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.RoundTripDelay']['meta_info']


                class Message(object):
                    """
                    message
                    
                    .. attribute:: information1
                    
                    	Extra info 1
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: information2
                    
                    	Extra info 2
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: messgae_count
                    
                    	number of message
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time
                    
                    	Time string
                    	**type**\:  str
                    
                    	**length:** 0..32
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.information1 = None
                        self.information2 = None
                        self.messgae_count = None
                        self.time = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:message'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.information1 is not None:
                            return True

                        if self.information2 is not None:
                            return True

                        if self.messgae_count is not None:
                            return True

                        if self.time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary.Message']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-message-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_history is not None and self.event_history._has_data():
                        return True

                    if self.message is not None:
                        for child_ref in self.message:
                            if child_ref._has_data():
                                return True

                    if self.round_trip_delay is not None and self.round_trip_delay._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMessageSummary']['meta_info']


            class L2FibMroutes(object):
                """
                multicast information
                
                .. attribute:: l2fib_mroute
                
                	Bridge Domain Multicast Information
                	**type**\: list of    :py:class:`L2FibMroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mroute = YList()
                    self.l2fib_mroute.parent = self
                    self.l2fib_mroute.name = 'l2fib_mroute'


                class L2FibMroute(object):
                    """
                    Bridge Domain Multicast Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:   :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo>`
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation>`
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: source
                    
                    	Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix>`
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats()
                        self.forward_stats.parent = self
                        self.group = None
                        self.hardware_information = None
                        self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo()
                        self.irb_info.parent = self
                        self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self.platform_data = None
                        self.platform_data_length = None
                        self.source = None
                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix()
                        self.source_prefix.parent = self
                        self.xid_count = None


                    class MulticastBaseInformation(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-base-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.MulticastBaseInformation']['meta_info']


                    class SourcePrefix(object):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:source-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.SourcePrefix']['meta_info']


                    class DestinationPrefix(object):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:destination-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.DestinationPrefix']['meta_info']


                    class ForwardStats(object):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self


                        class ForwardStat(object):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsDataEnum>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self


                            class Mulicast(object):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self


                                class MulticastForwardStat(object):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat']['meta_info']


                                class ReceivedStat(object):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat']['meta_info']


                                class Punt(object):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:punt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Punt']['meta_info']


                                class Drop(object):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.Drop']['meta_info']


                                class MulticastCoreForwardStat(object):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-core-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat']['meta_info']


                                class CoreReceivedStat(object):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core-received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mulicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_received_stat is not None and self.core_received_stat._has_data():
                                        return True

                                    if self.drop is not None and self.drop._has_data():
                                        return True

                                    if self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat._has_data():
                                        return True

                                    if self.multicast_forward_stat is not None and self.multicast_forward_stat._has_data():
                                        return True

                                    if self.punt is not None and self.punt._has_data():
                                        return True

                                    if self.received_stat is not None and self.received_stat._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat.Mulicast']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stat'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.mulicast is not None and self.mulicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats.ForwardStat']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.forward_stat is not None and self.forward_stat._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.ForwardStats']['meta_info']


                    class IrbInfo(object):
                        """
                        IRB Information
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.irb_plat_data = YLeafList()
                            self.irb_plat_data.parent = self
                            self.irb_plat_data.name = 'irb_plat_data'
                            self.irb_plat_data_len = None
                            self.mxid_ac_interface_handle = None
                            self.mxid_next_hop_address = None
                            self.mxid_pw_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:irb-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.irb_plat_data is not None:
                                for child in self.irb_plat_data:
                                    if child is not None:
                                        return True

                            if self.irb_plat_data_len is not None:
                                return True

                            if self.mxid_ac_interface_handle is not None:
                                return True

                            if self.mxid_next_hop_address is not None:
                                return True

                            if self.mxid_pw_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute.IrbInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_group_name is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.destination_prefix is not None and self.destination_prefix._has_data():
                            return True

                        if self.forward_stats is not None and self.forward_stats._has_data():
                            return True

                        if self.group is not None:
                            return True

                        if self.hardware_information is not None:
                            return True

                        if self.irb_info is not None and self.irb_info._has_data():
                            return True

                        if self.multicast_base_information is not None and self.multicast_base_information._has_data():
                            return True

                        if self.platform_data is not None:
                            return True

                        if self.platform_data_length is not None:
                            return True

                        if self.source is not None:
                            return True

                        if self.source_prefix is not None and self.source_prefix._has_data():
                            return True

                        if self.xid_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes.L2FibMroute']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroutes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mroute is not None:
                        for child_ref in self.l2fib_mroute:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutes']['meta_info']


            class PbbBmacSa(object):
                """
                PBB Backbone Source MAC information
                
                .. attribute:: chassis_mac
                
                	Chassis Mac
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: configured
                
                	BMAC SA configured
                	**type**\:  bool
                
                .. attribute:: mac
                
                	Backbone Source Mac
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.chassis_mac = None
                    self.configured = None
                    self.mac = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-bmac-sa'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.chassis_mac is not None:
                        return True

                    if self.configured is not None:
                        return True

                    if self.mac is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.PbbBmacSa']['meta_info']


            class L2FibP2Mp(object):
                """
                p2mp information
                
                .. attribute:: ptrees
                
                	ptree information
                	**type**\:   :py:class:`Ptrees <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ptrees = L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees()
                    self.ptrees.parent = self


                class Ptrees(object):
                    """
                    ptree information
                    
                    .. attribute:: ptree
                    
                    	P2MP PTree Information
                    	**type**\: list of    :py:class:`Ptree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ptree = YList()
                        self.ptree.parent = self
                        self.ptree.name = 'ptree'


                    class Ptree(object):
                        """
                        P2MP PTree Information
                        
                        .. attribute:: extended_tunnel_id
                        
                        	Extended Tunnel Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: extended_tunnel_id_xr
                        
                        	RSVPTE Ext Tunnel Id
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: lsm_id
                        
                        	LSM Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: lsm_id_xr
                        
                        	MLDP Lsm Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_id
                        
                        	P2MP Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: p2mp_id_xr
                        
                        	RSVPTE P2MP Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ptree_type
                        
                        	PTree Type
                        	**type**\:   :py:class:`L2Vpnp2MpPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnp2MpPtreeEnum>`
                        
                        .. attribute:: tunnel_id
                        
                        	Tunnel Id
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: tunnel_id_xr
                        
                        	RSVPTE Tunnel Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.extended_tunnel_id = None
                            self.extended_tunnel_id_xr = None
                            self.lsm_id = None
                            self.lsm_id_xr = None
                            self.p2mp_id = None
                            self.p2mp_id_xr = None
                            self.ptree_type = None
                            self.tunnel_id = None
                            self.tunnel_id_xr = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ptree'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.extended_tunnel_id is not None:
                                return True

                            if self.extended_tunnel_id_xr is not None:
                                return True

                            if self.lsm_id is not None:
                                return True

                            if self.lsm_id_xr is not None:
                                return True

                            if self.p2mp_id is not None:
                                return True

                            if self.p2mp_id_xr is not None:
                                return True

                            if self.ptree_type is not None:
                                return True

                            if self.tunnel_id is not None:
                                return True

                            if self.tunnel_id_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees.Ptree']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ptrees'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ptree is not None:
                            for child_ref in self.ptree:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibP2Mp.Ptrees']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-p2mp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ptrees is not None and self.ptrees._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibP2Mp']['meta_info']


            class L2FibEvpnInclMCastHardwareEgresses(object):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast hardware egress Table
                
                .. attribute:: l2fib_evpn_incl_m_cast_hardware_egress
                
                	Specify bridge domain name
                	**type**\: list of    :py:class:`L2FibEvpnInclMCastHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_evpn_incl_m_cast_hardware_egress = YList()
                    self.l2fib_evpn_incl_m_cast_hardware_egress.parent = self
                    self.l2fib_evpn_incl_m_cast_hardware_egress.name = 'l2fib_evpn_incl_m_cast_hardware_egress'


                class L2FibEvpnInclMCastHardwareEgress(object):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  <key>
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:   :py:class:`L2FibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles>`
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:   :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_name = None
                        self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList()
                        self.mcast_replication_list.parent = self


                    class McastReplicationList(object):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_domain_id = None
                            self.bridge_domain_name = None
                            self.is_bound = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-replication-list'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_domain_id is not None:
                                return True

                            if self.bridge_domain_name is not None:
                                return True

                            if self.is_bound is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.McastReplicationList']['meta_info']


                    class L2FibEvpnInclMCastOles(object):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of    :py:class:`L2FibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.l2fib_evpn_incl_m_cast_ole = YList()
                            self.l2fib_evpn_incl_m_cast_ole.parent = self
                            self.l2fib_evpn_incl_m_cast_ole.name = 'l2fib_evpn_incl_m_cast_ole'


                        class L2FibEvpnInclMCastOle(object):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  <key>
                            
                            	Next Hop Address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\:  bool
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.is_bound = None
                                self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None


                            class McastOle(object):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mcast_label = None
                                    self.next_hop_ipv6_addr = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-ole'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mcast_label is not None:
                                        return True

                                    if self.next_hop_ipv6_addr is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.next_hop_address is None:
                                    raise YPYModelError('Key property next_hop_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-ole[Cisco-IOS-XR-l2vpn-oper:next-hop-address = ' + str(self.next_hop_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.is_bound is not None:
                                    return True

                                if self.mcast_ole is not None and self.mcast_ole._has_data():
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-oles'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.l2fib_evpn_incl_m_cast_ole is not None:
                                for child_ref in self.l2fib_evpn_incl_m_cast_ole:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress.L2FibEvpnInclMCastOles']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.bd_name is None:
                            raise YPYModelError('Key property bd_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-hardware-egress[Cisco-IOS-XR-l2vpn-oper:bd-name = ' + str(self.bd_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_name is not None:
                            return True

                        if self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles._has_data():
                            return True

                        if self.mcast_replication_list is not None and self.mcast_replication_list._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses.L2FibEvpnInclMCastHardwareEgress']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-hardware-egresses'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_evpn_incl_m_cast_hardware_egress is not None:
                        for child_ref in self.l2fib_evpn_incl_m_cast_hardware_egress:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareEgresses']['meta_info']


            class L2FibmacHardwareIngresses(object):
                """
                Bridge Hardware Ingress information
                
                .. attribute:: l2fibmac_hardware_ingress
                
                	MAC Hardware Ingress information
                	**type**\: list of    :py:class:`L2FibmacHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fibmac_hardware_ingress = YList()
                    self.l2fibmac_hardware_ingress.parent = self
                    self.l2fibmac_hardware_ingress.name = 'l2fibmac_hardware_ingress'


                class L2FibmacHardwareIngress(object):
                    """
                    MAC Hardware Ingress information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base>`
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\:  bool
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:   :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx>`
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop>`
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment>`
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base()
                        self.base.parent = self
                        self.bmac_configured = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self.flag_extension = None
                        self.group_name = None
                        self.l3_encapsulationvlan_id = None
                        self.name = None
                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop()
                        self.next_hop.parent = self
                        self.next_hop_valid = None
                        self.node_id = None
                        self.pbb_bmac = None
                        self.peer_vtep_ip = None
                        self.platform_is_hw_learn = None
                        self.segment = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment()
                        self.segment.parent = self
                        self.vni = None
                        self.vni_l3_flag = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Base']['meta_info']


                    class Segment(object):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn()
                            self.evpn.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_handle = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.parent_if = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.parent_if is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Evpn']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self.pw_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.Segment']['meta_info']


                    class EvpnCtx(object):
                        """
                        Evpn Context
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibBridgeMacEvpnCtxEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeMacEvpnCtxEnum>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bp_ifh = None
                            self.data_type = None
                            self.esi_id = None
                            self.local_label = None
                            self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self


                        class McastOle(object):
                            """
                            mcast ole
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mcast_label = None
                                self.next_hop_ipv6_addr = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-ole'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mcast_label is not None:
                                    return True

                                if self.next_hop_ipv6_addr is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx.McastOle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-ctx'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bp_ifh is not None:
                                return True

                            if self.data_type is not None:
                                return True

                            if self.esi_id is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.mcast_ole is not None and self.mcast_ole._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.EvpnCtx']['meta_info']


                    class NextHop(object):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base>`
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: plaformt_data_valid
                        
                        	Is Platform Data Valid
                        	**type**\:  bool
                        
                        .. attribute:: platform_data_length
                        
                        	Platform Data Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base()
                            self.base.parent = self
                            self.children_count = None
                            self.next_hop_address = None
                            self.next_hop_internal_label = None
                            self.plaformt_data_valid = None
                            self.platform_data_length = None


                        class Base(object):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop.Base']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.children_count is not None:
                                return True

                            if self.next_hop_address is not None:
                                return True

                            if self.next_hop_internal_label is not None:
                                return True

                            if self.plaformt_data_valid is not None:
                                return True

                            if self.platform_data_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress.NextHop']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibmac-hardware-ingress'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bmac_configured is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.evpn_ctx is not None and self.evpn_ctx._has_data():
                            return True

                        if self.flag_extension is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.l3_encapsulationvlan_id is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.next_hop_valid is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.pbb_bmac is not None:
                            return True

                        if self.peer_vtep_ip is not None:
                            return True

                        if self.platform_is_hw_learn is not None:
                            return True

                        if self.segment is not None and self.segment._has_data():
                            return True

                        if self.vni is not None:
                            return True

                        if self.vni_l3_flag is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses.L2FibmacHardwareIngress']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibmac-hardware-ingresses'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fibmac_hardware_ingress is not None:
                        for child_ref in self.l2fibmac_hardware_ingress:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareIngresses']['meta_info']


            class L2FibEvpnIp4Macs(object):
                """
                EVPN IPv4\-MAC Table
                
                .. attribute:: l2fib_evpn_ip4mac
                
                	The attributes for a particular EVPN IPv4\-MAC Entry
                	**type**\: list of    :py:class:`L2FibEvpnIp4Mac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_evpn_ip4mac = YList()
                    self.l2fib_evpn_ip4mac.parent = self
                    self.l2fib_evpn_ip4mac.name = 'l2fib_evpn_ip4mac'


                class L2FibEvpnIp4Mac(object):
                    """
                    The attributes for a particular EVPN IPv4\-MAC
                    Entry
                    
                    .. attribute:: arp_nd_delete_pending
                    
                    	Delete to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_probe_pending
                    
                    	Probe to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_sync_pending
                    
                    	Sync to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: bdid_xr
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_address
                    
                    	IP Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: ip_address_xr
                    
                    	IP Address
                    	**type**\:   :py:class:`IpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr>`
                    
                    .. attribute:: is_local
                    
                    	Entry is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: is_local_xr
                    
                    	IP\-MAC Route is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: mac_address
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: mac_address_xr
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.arp_nd_delete_pending = None
                        self.arp_nd_probe_pending = None
                        self.arp_nd_sync_pending = None
                        self.bdid = None
                        self.bdid_xr = None
                        self.ip_address = None
                        self.ip_address_xr = L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr()
                        self.ip_address_xr.parent = self
                        self.is_local = None
                        self.is_local_xr = None
                        self.mac_address = None
                        self.mac_address_xr = None


                    class IpAddressXr(object):
                        """
                        IP Address
                        
                        .. attribute:: addr_type
                        
                        	addr type
                        	**type**\:   :py:class:`L2FibIpAddrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddrEnum>`
                        
                        .. attribute:: ip
                        
                        	ip
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.addr_type = None
                            self.ip = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ip-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.addr_type is not None:
                                return True

                            if self.ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac.IpAddressXr']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-ip4mac'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.arp_nd_delete_pending is not None:
                            return True

                        if self.arp_nd_probe_pending is not None:
                            return True

                        if self.arp_nd_sync_pending is not None:
                            return True

                        if self.bdid is not None:
                            return True

                        if self.bdid_xr is not None:
                            return True

                        if self.ip_address is not None:
                            return True

                        if self.ip_address_xr is not None and self.ip_address_xr._has_data():
                            return True

                        if self.is_local is not None:
                            return True

                        if self.is_local_xr is not None:
                            return True

                        if self.mac_address is not None:
                            return True

                        if self.mac_address_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs.L2FibEvpnIp4Mac']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-ip4macs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_evpn_ip4mac is not None:
                        for child_ref in self.l2fib_evpn_ip4mac:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnIp4Macs']['meta_info']


            class L2FibPwheMainPorts(object):
                """
                PWHE Main\-port table
                
                .. attribute:: l2fib_pwhe_main_port
                
                	PWHE Main\-port
                	**type**\: list of    :py:class:`L2FibPwheMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_pwhe_main_port = YList()
                    self.l2fib_pwhe_main_port.parent = self
                    self.l2fib_pwhe_main_port.name = 'l2fib_pwhe_main_port'


                class L2FibPwheMainPort(object):
                    """
                    PWHE Main\-port
                    
                    .. attribute:: interface_name  <key>
                    
                    	PWHE Main\-port
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: control_word_enabled
                    
                    	Control Word Enabled
                    	**type**\:  bool
                    
                    .. attribute:: generic_interface_list_id
                    
                    	Generic Interface List ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: internal_label
                    
                    	Internal label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_address
                    
                    	Next Hop Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: pseudo_wire_type
                    
                    	Pseudowire type
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_label
                    
                    	Remote label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.control_word_enabled = None
                        self.generic_interface_list_id = None
                        self.internal_label = None
                        self.next_hop_address = None
                        self.next_hop_valid = None
                        self.pseudo_wire_type = None
                        self.remote_label = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-pwhe-main-port[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.control_word_enabled is not None:
                            return True

                        if self.generic_interface_list_id is not None:
                            return True

                        if self.internal_label is not None:
                            return True

                        if self.next_hop_address is not None:
                            return True

                        if self.next_hop_valid is not None:
                            return True

                        if self.pseudo_wire_type is not None:
                            return True

                        if self.remote_label is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts.L2FibPwheMainPort']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-pwhe-main-ports'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_pwhe_main_port is not None:
                        for child_ref in self.l2fib_pwhe_main_port:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibPwheMainPorts']['meta_info']


            class L2FibDhcpBindingCount(object):
                """
                DHCP binding forwarding total count
                
                .. attribute:: bindings
                
                	DHCP binding count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bindings = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-dhcp-binding-count'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bindings is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingCount']['meta_info']


            class L2FibBridgeDomains(object):
                """
                Bridge Domain forwarding detail
                
                .. attribute:: l2fib_bridge_domain
                
                	Specify Bridge Domain Name
                	**type**\: list of    :py:class:`L2FibBridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_bridge_domain = YList()
                    self.l2fib_bridge_domain.parent = self
                    self.l2fib_bridge_domain.name = 'l2fib_bridge_domain'


                class L2FibBridgeDomain(object):
                    """
                    Specify Bridge Domain Name
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base>`
                    
                    .. attribute:: bd_group_name
                    
                    	Name of the Bridge group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bd_pbb_union
                    
                    	Union of bridge Edge and Core info
                    	**type**\:   :py:class:`BdPbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_type
                    
                    	Bridge Type
                    	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                    
                    .. attribute:: bvi_info
                    
                    	BVI Information
                    	**type**\:   :py:class:`BviInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo>`
                    
                    .. attribute:: learn_key
                    
                    	Learn Key
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_of_hwmac
                    
                    	Number of HW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_swmac
                    
                    	Number of SW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: oper
                    
                    	Operational information
                    	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper>`
                    
                    .. attribute:: p2mppw_info
                    
                    	P2MP PW Information
                    	**type**\:   :py:class:`P2MppwInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo>`
                    
                    .. attribute:: shg_count
                    
                    	Number of split horizon groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base()
                        self.base.parent = self
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bd_pbb_union = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion()
                        self.bd_pbb_union.parent = self
                        self.bridge_id = None
                        self.bridge_name = None
                        self.bridge_port_count = None
                        self.bridge_type = None
                        self.bvi_info = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo()
                        self.bvi_info.parent = self
                        self.learn_key = None
                        self.number_of_hwmac = None
                        self.number_of_swmac = None
                        self.oper = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper()
                        self.oper.parent = self
                        self.p2mppw_info = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo()
                        self.p2mppw_info.parent = self
                        self.shg_count = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Base']['meta_info']


                    class Oper(object):
                        """
                        Operational information
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: operational_information
                        
                        	L2 operational information
                        	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation()
                            self.operational_information.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None


                        class OperationalInformation(object):
                            """
                            L2 operational information
                            
                            .. attribute:: admin_disabled
                            
                            	Is administratively disabled
                            	**type**\:  bool
                            
                            .. attribute:: bvi_configured
                            
                            	Is BVI Interface configured
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_enabled
                            
                            	Is DHCP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_trusted
                            
                            	Is DHCP trusted
                            	**type**\:  bool
                            
                            .. attribute:: feature
                            
                            	Feature information
                            	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature>`
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Is flooding unknown unicast disabled
                            	**type**\:  bool
                            
                            .. attribute:: flooding_disabled
                            
                            	Is flooding disabled
                            	**type**\:  bool
                            
                            .. attribute:: host_routing_enabled
                            
                            	Host Routing enabled on this BD
                            	**type**\:  bool
                            
                            .. attribute:: igmp_flood_forward_enabled
                            
                            	Is IGMP flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: igmp_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_enabled
                            
                            	Is IGMP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_profile_enabled
                            
                            	Is IGMP snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_bvi_up
                            
                            	Is BVI state UP
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                            
                            	Is DAI Destination MAC Validation enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                            
                            	Is DAI IPv4 Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_cw_disable
                            
                            	Is EVPN CW disabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_enabled
                            
                            	Is EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_flow_label
                            
                            	Is EVPN Flow Label enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_igmp_snoop_enabled
                            
                            	Is IGMP Snooping admin enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown
                            
                            	Is MAC secure accept shutdown (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_p2mp_pw_enabled
                            
                            	Is P2MP PW enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_pbbevpn_enabled
                            
                            	Is PBBEVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_swmac_learning
                            
                            	Is SW MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vni_enabled
                            
                            	Is VNI enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vpls_flood_optimization_enabled
                            
                            	Is MMRP  Flood Optimization Enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in minutes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: minute
                            
                            .. attribute:: mac_aging_type
                            
                            	MAC aging type
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning_disabled
                            
                            	Is MAC learning disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                            
                            .. attribute:: mac_limit_notification_type
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                            
                            .. attribute:: mac_port_down_flush_disabled
                            
                            	Is MAC port down flush disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC secure action
                            	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                            
                            .. attribute:: mld_flood_forward_enabled
                            
                            	Is MLD flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: mld_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_enabled
                            
                            	Is MLD snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_profile_enabled
                            
                            	Is MLD snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	Multi\-spanning tree instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_macs
                            
                            	numberOfMacs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                            
                            	nV Satellite Offload IPv4 Multicast Disabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_enabled
                            
                            	Is broadcast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_rate_unit
                            
                            	Storm control broadcast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control_multicast_enabled
                            
                            	Is multicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_multicast_rate_unit
                            
                            	Storm control multicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control_unicast_enabled
                            
                            	Is unicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_unicast_rate_unit
                            
                            	Storm control unicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                            
                            .. attribute:: stp_participating
                            
                            	Is Spanning Tree Protocol participating
                            	**type**\:  bool
                            
                            .. attribute:: unknown_unicast_flooding_disabled
                            
                            	Unknown Unicast Flooding is disabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.admin_disabled = None
                                self.bvi_configured = None
                                self.dhcp_enabled = None
                                self.dhcp_trusted = None
                                self.feature = YList()
                                self.feature.parent = self
                                self.feature.name = 'feature'
                                self.flood_unknown_unicast_enabled = None
                                self.flooding_disabled = None
                                self.host_routing_enabled = None
                                self.igmp_flood_forward_enabled = None
                                self.igmp_mroute_port_enabled = None
                                self.igmp_route_guard_enabled = None
                                self.igmp_snoop_enabled = None
                                self.igmp_snoop_profile_enabled = None
                                self.is_bvi_up = None
                                self.is_dai_addr_validation_destination_mac_enabled = None
                                self.is_dai_addr_validation_ipv4_enabled = None
                                self.is_dai_addr_validation_source_mac_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_evpn_cw_disable = None
                                self.is_evpn_enabled = None
                                self.is_evpn_flow_label = None
                                self.is_igmp_snoop_enabled = None
                                self.is_ipsg_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_mac_secure_accept_shutdown = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.is_p2mp_pw_enabled = None
                                self.is_pbbevpn_enabled = None
                                self.is_swmac_learning = None
                                self.is_vni_enabled = None
                                self.is_vpls_flood_optimization_enabled = None
                                self.mac_aging_time = None
                                self.mac_aging_type = None
                                self.mac_learning_disabled = None
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification_type = None
                                self.mac_port_down_flush_disabled = None
                                self.mac_secure_action = None
                                self.mld_flood_forward_enabled = None
                                self.mld_mroute_port_enabled = None
                                self.mld_route_guard_enabled = None
                                self.mld_snoop_enabled = None
                                self.mld_snoop_profile_enabled = None
                                self.msti = None
                                self.mtu = None
                                self.number_of_macs = None
                                self.nv_satellite_offload_ipv4_multicast_disabled = None
                                self.storm_control_broadcast_enabled = None
                                self.storm_control_broadcast_rate_unit = None
                                self.storm_control_multicast_enabled = None
                                self.storm_control_multicast_rate_unit = None
                                self.storm_control_unicast_enabled = None
                                self.storm_control_unicast_rate_unit = None
                                self.stp_participating = None
                                self.unknown_unicast_flooding_disabled = None


                            class Feature(object):
                                """
                                Feature information
                                
                                .. attribute:: dhcp
                                
                                	dhcp
                                	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp>`
                                
                                .. attribute:: feature_type
                                
                                	feature type
                                	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                
                                .. attribute:: igmp
                                
                                	igmp
                                	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp>`
                                
                                .. attribute:: mld
                                
                                	mld
                                	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp()
                                    self.dhcp.parent = self
                                    self.feature_type = None
                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp()
                                    self.igmp.parent = self
                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld()
                                    self.mld.parent = self


                                class Dhcp(object):
                                    """
                                    dhcp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.profile_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.profile_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp']['meta_info']


                                class Igmp(object):
                                    """
                                    igmp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.profile_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.profile_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Igmp']['meta_info']


                                class Mld(object):
                                    """
                                    mld
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.profile_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.profile_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature.Mld']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dhcp is not None and self.dhcp._has_data():
                                        return True

                                    if self.feature_type is not None:
                                        return True

                                    if self.igmp is not None and self.igmp._has_data():
                                        return True

                                    if self.mld is not None and self.mld._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation.Feature']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.admin_disabled is not None:
                                    return True

                                if self.bvi_configured is not None:
                                    return True

                                if self.dhcp_enabled is not None:
                                    return True

                                if self.dhcp_trusted is not None:
                                    return True

                                if self.feature is not None:
                                    for child_ref in self.feature:
                                        if child_ref._has_data():
                                            return True

                                if self.flood_unknown_unicast_enabled is not None:
                                    return True

                                if self.flooding_disabled is not None:
                                    return True

                                if self.host_routing_enabled is not None:
                                    return True

                                if self.igmp_flood_forward_enabled is not None:
                                    return True

                                if self.igmp_mroute_port_enabled is not None:
                                    return True

                                if self.igmp_route_guard_enabled is not None:
                                    return True

                                if self.igmp_snoop_enabled is not None:
                                    return True

                                if self.igmp_snoop_profile_enabled is not None:
                                    return True

                                if self.is_bvi_up is not None:
                                    return True

                                if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                    return True

                                if self.is_dai_addr_validation_ipv4_enabled is not None:
                                    return True

                                if self.is_dai_addr_validation_source_mac_enabled is not None:
                                    return True

                                if self.is_dai_enabled is not None:
                                    return True

                                if self.is_dai_logging_enabled is not None:
                                    return True

                                if self.is_evpn_cw_disable is not None:
                                    return True

                                if self.is_evpn_enabled is not None:
                                    return True

                                if self.is_evpn_flow_label is not None:
                                    return True

                                if self.is_igmp_snoop_enabled is not None:
                                    return True

                                if self.is_ipsg_enabled is not None:
                                    return True

                                if self.is_ipsg_logging_enabled is not None:
                                    return True

                                if self.is_mac_secure_accept_shutdown is not None:
                                    return True

                                if self.is_mac_secure_enabled is not None:
                                    return True

                                if self.is_mac_secure_logging_enabled is not None:
                                    return True

                                if self.is_p2mp_pw_enabled is not None:
                                    return True

                                if self.is_pbbevpn_enabled is not None:
                                    return True

                                if self.is_swmac_learning is not None:
                                    return True

                                if self.is_vni_enabled is not None:
                                    return True

                                if self.is_vpls_flood_optimization_enabled is not None:
                                    return True

                                if self.mac_aging_time is not None:
                                    return True

                                if self.mac_aging_type is not None:
                                    return True

                                if self.mac_learning_disabled is not None:
                                    return True

                                if self.mac_limit is not None:
                                    return True

                                if self.mac_limit_action is not None:
                                    return True

                                if self.mac_limit_notification_type is not None:
                                    return True

                                if self.mac_port_down_flush_disabled is not None:
                                    return True

                                if self.mac_secure_action is not None:
                                    return True

                                if self.mld_flood_forward_enabled is not None:
                                    return True

                                if self.mld_mroute_port_enabled is not None:
                                    return True

                                if self.mld_route_guard_enabled is not None:
                                    return True

                                if self.mld_snoop_enabled is not None:
                                    return True

                                if self.mld_snoop_profile_enabled is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.mtu is not None:
                                    return True

                                if self.number_of_macs is not None:
                                    return True

                                if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                    return True

                                if self.storm_control_broadcast_enabled is not None:
                                    return True

                                if self.storm_control_broadcast_rate_unit is not None:
                                    return True

                                if self.storm_control_multicast_enabled is not None:
                                    return True

                                if self.storm_control_multicast_rate_unit is not None:
                                    return True

                                if self.storm_control_unicast_enabled is not None:
                                    return True

                                if self.storm_control_unicast_rate_unit is not None:
                                    return True

                                if self.stp_participating is not None:
                                    return True

                                if self.unknown_unicast_flooding_disabled is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper.OperationalInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:oper'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.operational_information is not None and self.operational_information._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.Oper']['meta_info']


                    class BdPbbUnion(object):
                        """
                        Union of bridge Edge and Core info
                        
                        .. attribute:: core
                        
                        	core
                        	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core>`
                        
                        .. attribute:: edge
                        
                        	edge
                        	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge>`
                        
                        .. attribute:: pbb_type
                        
                        	PbbType
                        	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.core = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core()
                            self.core.parent = self
                            self.edge = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge()
                            self.edge.parent = self
                            self.pbb_type = None


                        class Edge(object):
                            """
                            edge
                            
                            .. attribute:: core_bd_name
                            
                            	Core Bridge Domain name
                            	**type**\:  str
                            
                            .. attribute:: i_sid
                            
                            	I SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mirp_lite_rx
                            
                            	MIRP\-lite Rx packet counter
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: mirp_lite_tx
                            
                            	MIRP\-lite Tx packet counter
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.core_bd_name = None
                                self.i_sid = None
                                self.mirp_lite_rx = None
                                self.mirp_lite_tx = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.core_bd_name is not None:
                                    return True

                                if self.i_sid is not None:
                                    return True

                                if self.mirp_lite_rx is not None:
                                    return True

                                if self.mirp_lite_tx is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Edge']['meta_info']


                        class Core(object):
                            """
                            core
                            
                            .. attribute:: nber_edge_bd
                            
                            	Number of associated pbb\-edge Bds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.nber_edge_bd = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.nber_edge_bd is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion.Core']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bd-pbb-union'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.core is not None and self.core._has_data():
                                return True

                            if self.edge is not None and self.edge._has_data():
                                return True

                            if self.pbb_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BdPbbUnion']['meta_info']


                    class BviInfo(object):
                        """
                        BVI Information
                        
                        .. attribute:: bvi_ifh
                        
                        	BVI interface handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bvi_name
                        
                        	BVI name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: bvi_shg_id
                        
                        	BVI Split Horizon Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bvi_xid
                        
                        	BVI xconnect id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_ifh = None
                            self.bvi_name = None
                            self.bvi_shg_id = None
                            self.bvi_xid = None
                            self.irb_plat_data = None
                            self.irb_plat_data_len = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bvi-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_ifh is not None:
                                return True

                            if self.bvi_name is not None:
                                return True

                            if self.bvi_shg_id is not None:
                                return True

                            if self.bvi_xid is not None:
                                return True

                            if self.irb_plat_data is not None:
                                return True

                            if self.irb_plat_data_len is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.BviInfo']['meta_info']


                    class P2MppwInfo(object):
                        """
                        P2MP PW Information
                        
                        .. attribute:: local_label
                        
                        	Local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsm_id
                        
                        	LSM id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_te_interface
                        
                        	P2MP TE ifh
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: parent_next_hop
                        
                        	Parent Next Hop for P2MP PW
                        	**type**\:   :py:class:`ParentNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop>`
                        
                        .. attribute:: parent_nh_bound
                        
                        	Is Parent NH Bound
                        	**type**\:  bool
                        
                        .. attribute:: parent_nh_valid
                        
                        	Is Parent NH Valid
                        	**type**\:  bool
                        
                        .. attribute:: ptree_type
                        
                        	P2MP ptree type
                        	**type**\:   :py:class:`L2VpnPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtreeEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_label = None
                            self.lsm_id = None
                            self.p2mp_te_interface = None
                            self.parent_next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop()
                            self.parent_next_hop.parent = self
                            self.parent_nh_bound = None
                            self.parent_nh_valid = None
                            self.ptree_type = None


                        class ParentNextHop(object):
                            """
                            Parent Next Hop for P2MP PW
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base>`
                            
                            .. attribute:: children_count
                            
                            	Children Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_address
                            
                            	NHOP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: next_hop_internal_label
                            
                            	NHOP Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: plaformt_data_valid
                            
                            	Is Platform Data Valid
                            	**type**\:  bool
                            
                            .. attribute:: platform_data_length
                            
                            	Platform Data Length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base()
                                self.base.parent = self
                                self.children_count = None
                                self.next_hop_address = None
                                self.next_hop_internal_label = None
                                self.plaformt_data_valid = None
                                self.platform_data_length = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parent-next-hop'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.children_count is not None:
                                    return True

                                if self.next_hop_address is not None:
                                    return True

                                if self.next_hop_internal_label is not None:
                                    return True

                                if self.plaformt_data_valid is not None:
                                    return True

                                if self.platform_data_length is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo.ParentNextHop']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mppw-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_label is not None:
                                return True

                            if self.lsm_id is not None:
                                return True

                            if self.p2mp_te_interface is not None:
                                return True

                            if self.parent_next_hop is not None and self.parent_next_hop._has_data():
                                return True

                            if self.parent_nh_bound is not None:
                                return True

                            if self.parent_nh_valid is not None:
                                return True

                            if self.ptree_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain.P2MppwInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-bridge-domain'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bd_group_name is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bd_pbb_union is not None and self.bd_pbb_union._has_data():
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.bridge_name is not None:
                            return True

                        if self.bridge_port_count is not None:
                            return True

                        if self.bridge_type is not None:
                            return True

                        if self.bvi_info is not None and self.bvi_info._has_data():
                            return True

                        if self.learn_key is not None:
                            return True

                        if self.number_of_hwmac is not None:
                            return True

                        if self.number_of_swmac is not None:
                            return True

                        if self.oper is not None and self.oper._has_data():
                            return True

                        if self.p2mppw_info is not None and self.p2mppw_info._has_data():
                            return True

                        if self.shg_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains.L2FibBridgeDomain']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-bridge-domains'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_bridge_domain is not None:
                        for child_ref in self.l2fib_bridge_domain:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomains']['meta_info']


            class L2FibMstpSummaries(object):
                """
                MSTP Summary Table
                
                .. attribute:: l2fib_mstp_summary
                
                	MSTP Summary information
                	**type**\: list of    :py:class:`L2FibMstpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mstp_summary = YList()
                    self.l2fib_mstp_summary.parent = self
                    self.l2fib_mstp_summary.name = 'l2fib_mstp_summary'


                class L2FibMstpSummary(object):
                    """
                    MSTP Summary information
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base>`
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti
                    
                    	MSTI context
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: msti_xr
                    
                    	multi\-spanning tree instance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_interface
                    
                    	Parent interface context
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: parent_interface_xr
                    
                    	main port ID
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: state
                    
                    	MSTI state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base()
                        self.base.parent = self
                        self.bridge_port_count = None
                        self.msti = None
                        self.msti_xr = None
                        self.parent_interface = None
                        self.parent_interface_xr = None
                        self.state = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary.Base']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mstp-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bridge_port_count is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.msti_xr is not None:
                            return True

                        if self.parent_interface is not None:
                            return True

                        if self.parent_interface_xr is not None:
                            return True

                        if self.state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMstpSummaries.L2FibMstpSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mstp-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mstp_summary is not None:
                        for child_ref in self.l2fib_mstp_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMstpSummaries']['meta_info']


            class L2FibResourceAvailability(object):
                """
                Resource availability information
                
                .. attribute:: hardware_resource_mode
                
                	Hardware resource mode
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: hardware_resource_mode_information
                
                	Opaque hardware resource info
                	**type**\:  str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: overall_out_of_resource_mode
                
                	Overall OOR mode
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: shm_resource
                
                	Shared memory resource info
                	**type**\:   :py:class:`ShmResource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.hardware_resource_mode = YLeafList()
                    self.hardware_resource_mode.parent = self
                    self.hardware_resource_mode.name = 'hardware_resource_mode'
                    self.hardware_resource_mode_information = None
                    self.overall_out_of_resource_mode = None
                    self.shm_resource = L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource()
                    self.shm_resource.parent = self


                class ShmResource(object):
                    """
                    Shared memory resource info
                    
                    .. attribute:: average_available
                    
                    	Average number of bytes available
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: average_utility
                    
                    	Average utilization
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: maximum_available
                    
                    	Maximum bytes available
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: oout_of_resource_mode
                    
                    	OOR mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.average_available = None
                        self.average_utility = None
                        self.maximum_available = None
                        self.oout_of_resource_mode = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:shm-resource'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.average_available is not None:
                            return True

                        if self.average_utility is not None:
                            return True

                        if self.maximum_available is not None:
                            return True

                        if self.oout_of_resource_mode is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibResourceAvailability.ShmResource']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-resource-availability'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.hardware_resource_mode is not None:
                        for child in self.hardware_resource_mode:
                            if child is not None:
                                return True

                    if self.hardware_resource_mode_information is not None:
                        return True

                    if self.overall_out_of_resource_mode is not None:
                        return True

                    if self.shm_resource is not None and self.shm_resource._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibResourceAvailability']['meta_info']


            class L2FibmacHardwareEgresses(object):
                """
                Bridge Hardware Egress information
                
                .. attribute:: l2fibmac_hardware_egress
                
                	MAC Hardware Egress information
                	**type**\: list of    :py:class:`L2FibmacHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fibmac_hardware_egress = YList()
                    self.l2fibmac_hardware_egress.parent = self
                    self.l2fibmac_hardware_egress.name = 'l2fibmac_hardware_egress'


                class L2FibmacHardwareEgress(object):
                    """
                    MAC Hardware Egress information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base>`
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\:  bool
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:   :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx>`
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop>`
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment>`
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base()
                        self.base.parent = self
                        self.bmac_configured = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self.flag_extension = None
                        self.group_name = None
                        self.l3_encapsulationvlan_id = None
                        self.name = None
                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop()
                        self.next_hop.parent = self
                        self.next_hop_valid = None
                        self.node_id = None
                        self.pbb_bmac = None
                        self.peer_vtep_ip = None
                        self.platform_is_hw_learn = None
                        self.segment = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment()
                        self.segment.parent = self
                        self.vni = None
                        self.vni_l3_flag = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Base']['meta_info']


                    class Segment(object):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn()
                            self.evpn.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_handle = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.parent_if = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.parent_if is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Evpn']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self.pw_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.Segment']['meta_info']


                    class EvpnCtx(object):
                        """
                        Evpn Context
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibBridgeMacEvpnCtxEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeMacEvpnCtxEnum>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bp_ifh = None
                            self.data_type = None
                            self.esi_id = None
                            self.local_label = None
                            self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self


                        class McastOle(object):
                            """
                            mcast ole
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mcast_label = None
                                self.next_hop_ipv6_addr = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-ole'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mcast_label is not None:
                                    return True

                                if self.next_hop_ipv6_addr is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx.McastOle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-ctx'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bp_ifh is not None:
                                return True

                            if self.data_type is not None:
                                return True

                            if self.esi_id is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.mcast_ole is not None and self.mcast_ole._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.EvpnCtx']['meta_info']


                    class NextHop(object):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base>`
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: plaformt_data_valid
                        
                        	Is Platform Data Valid
                        	**type**\:  bool
                        
                        .. attribute:: platform_data_length
                        
                        	Platform Data Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base()
                            self.base.parent = self
                            self.children_count = None
                            self.next_hop_address = None
                            self.next_hop_internal_label = None
                            self.plaformt_data_valid = None
                            self.platform_data_length = None


                        class Base(object):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop.Base']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.children_count is not None:
                                return True

                            if self.next_hop_address is not None:
                                return True

                            if self.next_hop_internal_label is not None:
                                return True

                            if self.plaformt_data_valid is not None:
                                return True

                            if self.platform_data_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress.NextHop']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibmac-hardware-egress'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bmac_configured is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.evpn_ctx is not None and self.evpn_ctx._has_data():
                            return True

                        if self.flag_extension is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.l3_encapsulationvlan_id is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.next_hop_valid is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.pbb_bmac is not None:
                            return True

                        if self.peer_vtep_ip is not None:
                            return True

                        if self.platform_is_hw_learn is not None:
                            return True

                        if self.segment is not None and self.segment._has_data():
                            return True

                        if self.vni is not None:
                            return True

                        if self.vni_l3_flag is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses.L2FibmacHardwareEgress']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibmac-hardware-egresses'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fibmac_hardware_egress is not None:
                        for child_ref in self.l2fibmac_hardware_egress:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacHardwareEgresses']['meta_info']


            class L2FibxConL2Tpv2S(object):
                """
                The L2VPN forwarding XConnect L2TPv2 Detail
                Table
                
                .. attribute:: l2fibx_con_l2tpv2
                
                	Specify Sub Ifh
                	**type**\: list of    :py:class:`L2FibxConL2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fibx_con_l2tpv2 = YList()
                    self.l2fibx_con_l2tpv2.parent = self
                    self.l2fibx_con_l2tpv2.name = 'l2fibx_con_l2tpv2'


                class L2FibxConL2Tpv2(object):
                    """
                    Specify Sub Ifh
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitchingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitchingEnum>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base()
                        self.base.parent = self
                        self.bound = None
                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1()
                        self.segment1.parent = self
                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2()
                        self.segment2.parent = self
                        self.switching_type = None
                        self.xcon_name = None


                    class Base(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Base']['meta_info']


                    class Segment1(object):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn()
                            self.evpn.parent = self
                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base()
                                self.base.parent = self
                                self.bound = None
                                self.core_pbb_evpn_enabled = None
                                self.forward_class = None
                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.Base']['meta_info']


                            class PbbUnion(object):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self.pbb_type = None


                                class Edge(object):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mac = None
                                        self.mac_configured = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mac is not None:
                                            return True

                                        if self.mac_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Edge']['meta_info']


                                class Core(object):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.vlan_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.vlan_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion.Core']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core is not None and self.core._has_data():
                                        return True

                                    if self.edge is not None and self.edge._has_data():
                                        return True

                                    if self.pbb_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb.PbbUnion']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.core_pbb_evpn_enabled is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.pbb_union is not None and self.pbb_union._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base()
                                self.base.parent = self
                                self.bound = None
                                self.encap = None
                                self.mcastip = None
                                self.parent_if = None
                                self.source_vtep_if = None
                                self.srcip = None
                                self.udp_port = None
                                self.vx_lan_mode = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.any_cast_ip is not None:
                                    return True

                                if self.anycast_mcast_ip is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.encap is not None:
                                    return True

                                if self.mcastip is not None:
                                    return True

                                if self.parent_if is not None:
                                    return True

                                if self.source_vtep_if is not None:
                                    return True

                                if self.srcip is not None:
                                    return True

                                if self.udp_port is not None:
                                    return True

                                if self.vx_lan_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evi = None
                                self.forward_class = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evi is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Evpn']['meta_info']


                        class MonitorSession(object):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self.bound = None
                                self.hardware_information = None
                                self.session_name = None
                                self.xcid = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:monitor-session'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.hardware_information is not None:
                                    return True

                                if self.session_name is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.MonitorSession']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.monitor_session is not None and self.monitor_session._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment1']['meta_info']


                    class Segment2(object):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac()
                            self.ac.parent = self
                            self.bp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp()
                            self.bp.parent = self
                            self.data_type = None
                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs()
                            self.fxs.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw()
                            self.pw.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Ac']['meta_info']


                        class Bp(object):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base()
                                self.base.parent = self
                                self.bridge_id = None
                                self.learn_key = None
                                self.msti_pointer = None
                                self.mvrp_sequence_number = None
                                self.oper = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self.segment_type = None
                                self.shg_id = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Base']['meta_info']


                            class Oper(object):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None


                                class OperationalInformation(object):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.admin_disabled = None
                                        self.bvi_configured = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.feature = YList()
                                        self.feature.parent = self
                                        self.feature.name = 'feature'
                                        self.flood_unknown_unicast_enabled = None
                                        self.flooding_disabled = None
                                        self.host_routing_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.is_bvi_up = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_evpn_cw_disable = None
                                        self.is_evpn_enabled = None
                                        self.is_evpn_flow_label = None
                                        self.is_igmp_snoop_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_vni_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.mac_aging_time = None
                                        self.mac_aging_type = None
                                        self.mac_learning_disabled = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification_type = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_secure_action = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.msti = None
                                        self.mtu = None
                                        self.number_of_macs = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.stp_participating = None
                                        self.unknown_unicast_flooding_disabled = None


                                    class Feature(object):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self.feature_type = None
                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self


                                        class Dhcp(object):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp']['meta_info']


                                        class Igmp(object):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp']['meta_info']


                                        class Mld(object):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dhcp is not None and self.dhcp._has_data():
                                                return True

                                            if self.feature_type is not None:
                                                return True

                                            if self.igmp is not None and self.igmp._has_data():
                                                return True

                                            if self.mld is not None and self.mld._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation.Feature']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.admin_disabled is not None:
                                            return True

                                        if self.bvi_configured is not None:
                                            return True

                                        if self.dhcp_enabled is not None:
                                            return True

                                        if self.dhcp_trusted is not None:
                                            return True

                                        if self.feature is not None:
                                            for child_ref in self.feature:
                                                if child_ref._has_data():
                                                    return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flooding_disabled is not None:
                                            return True

                                        if self.host_routing_enabled is not None:
                                            return True

                                        if self.igmp_flood_forward_enabled is not None:
                                            return True

                                        if self.igmp_mroute_port_enabled is not None:
                                            return True

                                        if self.igmp_route_guard_enabled is not None:
                                            return True

                                        if self.igmp_snoop_enabled is not None:
                                            return True

                                        if self.igmp_snoop_profile_enabled is not None:
                                            return True

                                        if self.is_bvi_up is not None:
                                            return True

                                        if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_evpn_cw_disable is not None:
                                            return True

                                        if self.is_evpn_enabled is not None:
                                            return True

                                        if self.is_evpn_flow_label is not None:
                                            return True

                                        if self.is_igmp_snoop_enabled is not None:
                                            return True

                                        if self.is_ipsg_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.is_p2mp_pw_enabled is not None:
                                            return True

                                        if self.is_pbbevpn_enabled is not None:
                                            return True

                                        if self.is_swmac_learning is not None:
                                            return True

                                        if self.is_vni_enabled is not None:
                                            return True

                                        if self.is_vpls_flood_optimization_enabled is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_aging_type is not None:
                                            return True

                                        if self.mac_learning_disabled is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification_type is not None:
                                            return True

                                        if self.mac_port_down_flush_disabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_flood_forward_enabled is not None:
                                            return True

                                        if self.mld_mroute_port_enabled is not None:
                                            return True

                                        if self.mld_route_guard_enabled is not None:
                                            return True

                                        if self.mld_snoop_enabled is not None:
                                            return True

                                        if self.mld_snoop_profile_enabled is not None:
                                            return True

                                        if self.msti is not None:
                                            return True

                                        if self.mtu is not None:
                                            return True

                                        if self.number_of_macs is not None:
                                            return True

                                        if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                            return True

                                        if self.storm_control_broadcast_enabled is not None:
                                            return True

                                        if self.storm_control_broadcast_rate_unit is not None:
                                            return True

                                        if self.storm_control_multicast_enabled is not None:
                                            return True

                                        if self.storm_control_multicast_rate_unit is not None:
                                            return True

                                        if self.storm_control_unicast_enabled is not None:
                                            return True

                                        if self.storm_control_unicast_rate_unit is not None:
                                            return True

                                        if self.stp_participating is not None:
                                            return True

                                        if self.unknown_unicast_flooding_disabled is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper.OperationalInformation']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:oper'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.operational_information is not None and self.operational_information._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.Oper']['meta_info']


                            class P2Mp(object):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtreeEnum>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extended_tunnel_id = None
                                    self.lsm_id = None
                                    self.p2mp_id = None
                                    self.ptree_owner_lmrib = None
                                    self.ptree_type = None
                                    self.tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extended_tunnel_id is not None:
                                        return True

                                    if self.lsm_id is not None:
                                        return True

                                    if self.p2mp_id is not None:
                                        return True

                                    if self.ptree_owner_lmrib is not None:
                                        return True

                                    if self.ptree_type is not None:
                                        return True

                                    if self.tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp.P2Mp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bridge_id is not None:
                                    return True

                                if self.learn_key is not None:
                                    return True

                                if self.msti_pointer is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.oper is not None and self.oper._has_data():
                                    return True

                                if self.p2mp is not None and self.p2mp._has_data():
                                    return True

                                if self.segment_type is not None:
                                    return True

                                if self.shg_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Bp']['meta_info']


                        class Fxs(object):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base()
                                self.base.parent = self
                                self.fxs_id = None
                                self.segment_type = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.fxs_id is not None:
                                    return True

                                if self.segment_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Fxs']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.bp is not None and self.bp._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.fxs is not None and self.fxs._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2.Segment2']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibx-con-l2tpv2[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bound is not None:
                            return True

                        if self.segment1 is not None and self.segment1._has_data():
                            return True

                        if self.segment2 is not None and self.segment2._has_data():
                            return True

                        if self.switching_type is not None:
                            return True

                        if self.xcon_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S.L2FibxConL2Tpv2']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibx-con-l2tpv2s'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fibx_con_l2tpv2 is not None:
                        for child_ref in self.l2fibx_con_l2tpv2:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxConL2Tpv2S']['meta_info']


            class L2FibMrouteIpv6S(object):
                """
                multicast information
                
                .. attribute:: l2fib_mroute_ipv6
                
                	Bridge Domain Multicast Information
                	**type**\: list of    :py:class:`L2FibMrouteIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mroute_ipv6 = YList()
                    self.l2fib_mroute_ipv6.parent = self
                    self.l2fib_mroute_ipv6.name = 'l2fib_mroute_ipv6'


                class L2FibMrouteIpv6(object):
                    """
                    Bridge Domain Multicast Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group IPv6 Address
                    	**type**\:  str
                    
                    	**length:** 1..128
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:   :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo>`
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation>`
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: source
                    
                    	Source IPv6 Address
                    	**type**\:  str
                    
                    	**length:** 1..128
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix>`
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats()
                        self.forward_stats.parent = self
                        self.group = None
                        self.hardware_information = None
                        self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo()
                        self.irb_info.parent = self
                        self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self.platform_data = None
                        self.platform_data_length = None
                        self.source = None
                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix()
                        self.source_prefix.parent = self
                        self.xid_count = None


                    class MulticastBaseInformation(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-base-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.MulticastBaseInformation']['meta_info']


                    class SourcePrefix(object):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:source-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.SourcePrefix']['meta_info']


                    class DestinationPrefix(object):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:destination-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.DestinationPrefix']['meta_info']


                    class ForwardStats(object):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self


                        class ForwardStat(object):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsDataEnum>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self


                            class Mulicast(object):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self


                                class MulticastForwardStat(object):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat']['meta_info']


                                class ReceivedStat(object):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat']['meta_info']


                                class Punt(object):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:punt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt']['meta_info']


                                class Drop(object):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop']['meta_info']


                                class MulticastCoreForwardStat(object):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-core-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat']['meta_info']


                                class CoreReceivedStat(object):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core-received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mulicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_received_stat is not None and self.core_received_stat._has_data():
                                        return True

                                    if self.drop is not None and self.drop._has_data():
                                        return True

                                    if self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat._has_data():
                                        return True

                                    if self.multicast_forward_stat is not None and self.multicast_forward_stat._has_data():
                                        return True

                                    if self.punt is not None and self.punt._has_data():
                                        return True

                                    if self.received_stat is not None and self.received_stat._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat.Mulicast']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stat'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.mulicast is not None and self.mulicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats.ForwardStat']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.forward_stat is not None and self.forward_stat._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.ForwardStats']['meta_info']


                    class IrbInfo(object):
                        """
                        IRB Information
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.irb_plat_data = YLeafList()
                            self.irb_plat_data.parent = self
                            self.irb_plat_data.name = 'irb_plat_data'
                            self.irb_plat_data_len = None
                            self.mxid_ac_interface_handle = None
                            self.mxid_next_hop_address = None
                            self.mxid_pw_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:irb-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.irb_plat_data is not None:
                                for child in self.irb_plat_data:
                                    if child is not None:
                                        return True

                            if self.irb_plat_data_len is not None:
                                return True

                            if self.mxid_ac_interface_handle is not None:
                                return True

                            if self.mxid_next_hop_address is not None:
                                return True

                            if self.mxid_pw_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6.IrbInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute-ipv6'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_group_name is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.destination_prefix is not None and self.destination_prefix._has_data():
                            return True

                        if self.forward_stats is not None and self.forward_stats._has_data():
                            return True

                        if self.group is not None:
                            return True

                        if self.hardware_information is not None:
                            return True

                        if self.irb_info is not None and self.irb_info._has_data():
                            return True

                        if self.multicast_base_information is not None and self.multicast_base_information._has_data():
                            return True

                        if self.platform_data is not None:
                            return True

                        if self.platform_data_length is not None:
                            return True

                        if self.source is not None:
                            return True

                        if self.source_prefix is not None and self.source_prefix._has_data():
                            return True

                        if self.xid_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S.L2FibMrouteIpv6']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute-ipv6s'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mroute_ipv6 is not None:
                        for child_ref in self.l2fib_mroute_ipv6:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMrouteIpv6S']['meta_info']


            class L2FibMonSessXCons(object):
                """
                The L2VPN forwarding Monitor Session XConnect
                Information
                
                .. attribute:: l2fib_mon_sess_x_con
                
                	Specify Monitor Session Name
                	**type**\: list of    :py:class:`L2FibMonSessXCon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mon_sess_x_con = YList()
                    self.l2fib_mon_sess_x_con.parent = self
                    self.l2fib_mon_sess_x_con.name = 'l2fib_mon_sess_x_con'


                class L2FibMonSessXCon(object):
                    """
                    Specify Monitor Session Name
                    
                    .. attribute:: monitor_session_name  <key>
                    
                    	Monitor Session Name
                    	**type**\:  str
                    
                    	**length:** 1..64
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitchingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitchingEnum>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.monitor_session_name = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base()
                        self.base.parent = self
                        self.bound = None
                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1()
                        self.segment1.parent = self
                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2()
                        self.segment2.parent = self
                        self.switching_type = None
                        self.xcon_name = None


                    class Base(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Base']['meta_info']


                    class Segment1(object):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn()
                            self.evpn.parent = self
                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base()
                                self.base.parent = self
                                self.bound = None
                                self.core_pbb_evpn_enabled = None
                                self.forward_class = None
                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.Base']['meta_info']


                            class PbbUnion(object):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self.pbb_type = None


                                class Edge(object):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mac = None
                                        self.mac_configured = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mac is not None:
                                            return True

                                        if self.mac_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Edge']['meta_info']


                                class Core(object):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.vlan_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.vlan_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion.Core']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core is not None and self.core._has_data():
                                        return True

                                    if self.edge is not None and self.edge._has_data():
                                        return True

                                    if self.pbb_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb.PbbUnion']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.core_pbb_evpn_enabled is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.pbb_union is not None and self.pbb_union._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base()
                                self.base.parent = self
                                self.bound = None
                                self.encap = None
                                self.mcastip = None
                                self.parent_if = None
                                self.source_vtep_if = None
                                self.srcip = None
                                self.udp_port = None
                                self.vx_lan_mode = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.any_cast_ip is not None:
                                    return True

                                if self.anycast_mcast_ip is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.encap is not None:
                                    return True

                                if self.mcastip is not None:
                                    return True

                                if self.parent_if is not None:
                                    return True

                                if self.source_vtep_if is not None:
                                    return True

                                if self.srcip is not None:
                                    return True

                                if self.udp_port is not None:
                                    return True

                                if self.vx_lan_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evi = None
                                self.forward_class = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evi is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Evpn']['meta_info']


                        class MonitorSession(object):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self.bound = None
                                self.hardware_information = None
                                self.session_name = None
                                self.xcid = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:monitor-session'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.hardware_information is not None:
                                    return True

                                if self.session_name is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.MonitorSession']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.monitor_session is not None and self.monitor_session._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment1']['meta_info']


                    class Segment2(object):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac()
                            self.ac.parent = self
                            self.bp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp()
                            self.bp.parent = self
                            self.data_type = None
                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs()
                            self.fxs.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw()
                            self.pw.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Ac']['meta_info']


                        class Bp(object):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base()
                                self.base.parent = self
                                self.bridge_id = None
                                self.learn_key = None
                                self.msti_pointer = None
                                self.mvrp_sequence_number = None
                                self.oper = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self.segment_type = None
                                self.shg_id = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Base']['meta_info']


                            class Oper(object):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None


                                class OperationalInformation(object):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.admin_disabled = None
                                        self.bvi_configured = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.feature = YList()
                                        self.feature.parent = self
                                        self.feature.name = 'feature'
                                        self.flood_unknown_unicast_enabled = None
                                        self.flooding_disabled = None
                                        self.host_routing_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.is_bvi_up = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_evpn_cw_disable = None
                                        self.is_evpn_enabled = None
                                        self.is_evpn_flow_label = None
                                        self.is_igmp_snoop_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_vni_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.mac_aging_time = None
                                        self.mac_aging_type = None
                                        self.mac_learning_disabled = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification_type = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_secure_action = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.msti = None
                                        self.mtu = None
                                        self.number_of_macs = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.stp_participating = None
                                        self.unknown_unicast_flooding_disabled = None


                                    class Feature(object):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self.feature_type = None
                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self


                                        class Dhcp(object):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp']['meta_info']


                                        class Igmp(object):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp']['meta_info']


                                        class Mld(object):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dhcp is not None and self.dhcp._has_data():
                                                return True

                                            if self.feature_type is not None:
                                                return True

                                            if self.igmp is not None and self.igmp._has_data():
                                                return True

                                            if self.mld is not None and self.mld._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.admin_disabled is not None:
                                            return True

                                        if self.bvi_configured is not None:
                                            return True

                                        if self.dhcp_enabled is not None:
                                            return True

                                        if self.dhcp_trusted is not None:
                                            return True

                                        if self.feature is not None:
                                            for child_ref in self.feature:
                                                if child_ref._has_data():
                                                    return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flooding_disabled is not None:
                                            return True

                                        if self.host_routing_enabled is not None:
                                            return True

                                        if self.igmp_flood_forward_enabled is not None:
                                            return True

                                        if self.igmp_mroute_port_enabled is not None:
                                            return True

                                        if self.igmp_route_guard_enabled is not None:
                                            return True

                                        if self.igmp_snoop_enabled is not None:
                                            return True

                                        if self.igmp_snoop_profile_enabled is not None:
                                            return True

                                        if self.is_bvi_up is not None:
                                            return True

                                        if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_evpn_cw_disable is not None:
                                            return True

                                        if self.is_evpn_enabled is not None:
                                            return True

                                        if self.is_evpn_flow_label is not None:
                                            return True

                                        if self.is_igmp_snoop_enabled is not None:
                                            return True

                                        if self.is_ipsg_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.is_p2mp_pw_enabled is not None:
                                            return True

                                        if self.is_pbbevpn_enabled is not None:
                                            return True

                                        if self.is_swmac_learning is not None:
                                            return True

                                        if self.is_vni_enabled is not None:
                                            return True

                                        if self.is_vpls_flood_optimization_enabled is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_aging_type is not None:
                                            return True

                                        if self.mac_learning_disabled is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification_type is not None:
                                            return True

                                        if self.mac_port_down_flush_disabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_flood_forward_enabled is not None:
                                            return True

                                        if self.mld_mroute_port_enabled is not None:
                                            return True

                                        if self.mld_route_guard_enabled is not None:
                                            return True

                                        if self.mld_snoop_enabled is not None:
                                            return True

                                        if self.mld_snoop_profile_enabled is not None:
                                            return True

                                        if self.msti is not None:
                                            return True

                                        if self.mtu is not None:
                                            return True

                                        if self.number_of_macs is not None:
                                            return True

                                        if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                            return True

                                        if self.storm_control_broadcast_enabled is not None:
                                            return True

                                        if self.storm_control_broadcast_rate_unit is not None:
                                            return True

                                        if self.storm_control_multicast_enabled is not None:
                                            return True

                                        if self.storm_control_multicast_rate_unit is not None:
                                            return True

                                        if self.storm_control_unicast_enabled is not None:
                                            return True

                                        if self.storm_control_unicast_rate_unit is not None:
                                            return True

                                        if self.stp_participating is not None:
                                            return True

                                        if self.unknown_unicast_flooding_disabled is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper.OperationalInformation']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:oper'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.operational_information is not None and self.operational_information._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.Oper']['meta_info']


                            class P2Mp(object):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtreeEnum>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extended_tunnel_id = None
                                    self.lsm_id = None
                                    self.p2mp_id = None
                                    self.ptree_owner_lmrib = None
                                    self.ptree_type = None
                                    self.tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extended_tunnel_id is not None:
                                        return True

                                    if self.lsm_id is not None:
                                        return True

                                    if self.p2mp_id is not None:
                                        return True

                                    if self.ptree_owner_lmrib is not None:
                                        return True

                                    if self.ptree_type is not None:
                                        return True

                                    if self.tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp.P2Mp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bridge_id is not None:
                                    return True

                                if self.learn_key is not None:
                                    return True

                                if self.msti_pointer is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.oper is not None and self.oper._has_data():
                                    return True

                                if self.p2mp is not None and self.p2mp._has_data():
                                    return True

                                if self.segment_type is not None:
                                    return True

                                if self.shg_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Bp']['meta_info']


                        class Fxs(object):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base()
                                self.base.parent = self
                                self.fxs_id = None
                                self.segment_type = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.fxs_id is not None:
                                    return True

                                if self.segment_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Fxs']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.bp is not None and self.bp._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.fxs is not None and self.fxs._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon.Segment2']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.monitor_session_name is None:
                            raise YPYModelError('Key property monitor_session_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mon-sess-x-con[Cisco-IOS-XR-l2vpn-oper:monitor-session-name = ' + str(self.monitor_session_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.monitor_session_name is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bound is not None:
                            return True

                        if self.segment1 is not None and self.segment1._has_data():
                            return True

                        if self.segment2 is not None and self.segment2._has_data():
                            return True

                        if self.switching_type is not None:
                            return True

                        if self.xcon_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons.L2FibMonSessXCon']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mon-sess-x-cons'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mon_sess_x_con is not None:
                        for child_ref in self.l2fib_mon_sess_x_con:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMonSessXCons']['meta_info']


            class L2FibMmrpSummaries(object):
                """
                Mmrp Summary Table
                
                .. attribute:: l2fib_mmrp_summary
                
                	Mmrp Summary Information
                	**type**\: list of    :py:class:`L2FibMmrpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mmrp_summary = YList()
                    self.l2fib_mmrp_summary.parent = self
                    self.l2fib_mmrp_summary.name = 'l2fib_mmrp_summary'


                class L2FibMmrpSummary(object):
                    """
                    Mmrp Summary Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: message
                    
                    	Global Message Information
                    	**type**\: list of    :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message>`
                    
                    .. attribute:: multicast_update
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update_dropped
                    
                    	Multicast Updates
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_all_delete_drop
                    
                    	Number of Mroutes All Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_delete_drop
                    
                    	Number of Mroutes Delete droped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_deleted
                    
                    	Number of Mroutes Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroutes_deleted_all
                    
                    	Number of Mroutes All Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_mroute_add
                    
                    	Number of Mroutes Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes
                    
                    	Number of Routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes_with_ole_offload
                    
                    	Number of Routes with OleOffload
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_xid
                    
                    	Number of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_add
                    
                    	Number of XID Added
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_deleted
                    
                    	Number of XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_deleted
                    
                    	Stale Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_xid_deleted
                    
                    	Stale XID Deleted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_id = None
                        self.bridge_domain_name = None
                        self.message = YList()
                        self.message.parent = self
                        self.message.name = 'message'
                        self.multicast_update = None
                        self.multicast_update_dropped = None
                        self.number_mroute_all_delete_drop = None
                        self.number_mroute_delete_drop = None
                        self.number_mroute_deleted = None
                        self.number_mroutes_deleted_all = None
                        self.number_of_mroute_add = None
                        self.number_of_routes = None
                        self.number_of_routes_with_ole_offload = None
                        self.number_of_xid = None
                        self.number_xid_add = None
                        self.number_xid_deleted = None
                        self.stale_deleted = None
                        self.stale_xid_deleted = None


                    class Message(object):
                        """
                        Global Message Information
                        
                        .. attribute:: information1
                        
                        	Extra info 1
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: information2
                        
                        	Extra info 2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: messgae_count
                        
                        	number of message
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time
                        
                        	Time string
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.information1 = None
                            self.information2 = None
                            self.messgae_count = None
                            self.time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:message'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.information1 is not None:
                                return True

                            if self.information2 is not None:
                                return True

                            if self.messgae_count is not None:
                                return True

                            if self.time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary.Message']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mmrp-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_group_name is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_domain_id is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.message is not None:
                            for child_ref in self.message:
                                if child_ref._has_data():
                                    return True

                        if self.multicast_update is not None:
                            return True

                        if self.multicast_update_dropped is not None:
                            return True

                        if self.number_mroute_all_delete_drop is not None:
                            return True

                        if self.number_mroute_delete_drop is not None:
                            return True

                        if self.number_mroute_deleted is not None:
                            return True

                        if self.number_mroutes_deleted_all is not None:
                            return True

                        if self.number_of_mroute_add is not None:
                            return True

                        if self.number_of_routes is not None:
                            return True

                        if self.number_of_routes_with_ole_offload is not None:
                            return True

                        if self.number_of_xid is not None:
                            return True

                        if self.number_xid_add is not None:
                            return True

                        if self.number_xid_deleted is not None:
                            return True

                        if self.stale_deleted is not None:
                            return True

                        if self.stale_xid_deleted is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries.L2FibMmrpSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mmrp-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mmrp_summary is not None:
                        for child_ref in self.l2fib_mmrp_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrpSummaries']['meta_info']


            class L2FibPwGroups(object):
                """
                PW Group Table Information
                
                .. attribute:: l2fib_pw_group
                
                	PW Group Information
                	**type**\: list of    :py:class:`L2FibPwGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_pw_group = YList()
                    self.l2fib_pw_group.parent = self
                    self.l2fib_pw_group.name = 'l2fib_pw_group'


                class L2FibPwGroup(object):
                    """
                    PW Group Information
                    
                    .. attribute:: group_id
                    
                    	Group Id
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: group_state
                    
                    	Group State
                    	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                    
                    .. attribute:: peer_address
                    
                    	Peer IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_list_count
                    
                    	Dependent PW List Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_if_handle
                    
                    	Tunnel Interface Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_id = None
                        self.group_state = None
                        self.peer_address = None
                        self.pw_list_count = None
                        self.tunnel_if_handle = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-pw-group'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_id is not None:
                            return True

                        if self.group_state is not None:
                            return True

                        if self.peer_address is not None:
                            return True

                        if self.pw_list_count is not None:
                            return True

                        if self.tunnel_if_handle is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibPwGroups.L2FibPwGroup']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-pw-groups'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_pw_group is not None:
                        for child_ref in self.l2fib_pw_group:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibPwGroups']['meta_info']


            class L2FibEvpnInclMCastHardwareIngresses(object):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast hardware ingress Table
                
                .. attribute:: l2fib_evpn_incl_m_cast_hardware_ingress
                
                	Specify bridge domain name
                	**type**\: list of    :py:class:`L2FibEvpnInclMCastHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_evpn_incl_m_cast_hardware_ingress = YList()
                    self.l2fib_evpn_incl_m_cast_hardware_ingress.parent = self
                    self.l2fib_evpn_incl_m_cast_hardware_ingress.name = 'l2fib_evpn_incl_m_cast_hardware_ingress'


                class L2FibEvpnInclMCastHardwareIngress(object):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  <key>
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:   :py:class:`L2FibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles>`
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:   :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_name = None
                        self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList()
                        self.mcast_replication_list.parent = self


                    class McastReplicationList(object):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_domain_id = None
                            self.bridge_domain_name = None
                            self.is_bound = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-replication-list'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_domain_id is not None:
                                return True

                            if self.bridge_domain_name is not None:
                                return True

                            if self.is_bound is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.McastReplicationList']['meta_info']


                    class L2FibEvpnInclMCastOles(object):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of    :py:class:`L2FibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.l2fib_evpn_incl_m_cast_ole = YList()
                            self.l2fib_evpn_incl_m_cast_ole.parent = self
                            self.l2fib_evpn_incl_m_cast_ole.name = 'l2fib_evpn_incl_m_cast_ole'


                        class L2FibEvpnInclMCastOle(object):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  <key>
                            
                            	Next Hop Address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\:  bool
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.is_bound = None
                                self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None


                            class McastOle(object):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mcast_label = None
                                    self.next_hop_ipv6_addr = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-ole'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mcast_label is not None:
                                        return True

                                    if self.next_hop_ipv6_addr is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.next_hop_address is None:
                                    raise YPYModelError('Key property next_hop_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-ole[Cisco-IOS-XR-l2vpn-oper:next-hop-address = ' + str(self.next_hop_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.is_bound is not None:
                                    return True

                                if self.mcast_ole is not None and self.mcast_ole._has_data():
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-oles'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.l2fib_evpn_incl_m_cast_ole is not None:
                                for child_ref in self.l2fib_evpn_incl_m_cast_ole:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress.L2FibEvpnInclMCastOles']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.bd_name is None:
                            raise YPYModelError('Key property bd_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-hardware-ingress[Cisco-IOS-XR-l2vpn-oper:bd-name = ' + str(self.bd_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_name is not None:
                            return True

                        if self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles._has_data():
                            return True

                        if self.mcast_replication_list is not None and self.mcast_replication_list._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses.L2FibEvpnInclMCastHardwareIngress']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-hardware-ingresses'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_evpn_incl_m_cast_hardware_ingress is not None:
                        for child_ref in self.l2fib_evpn_incl_m_cast_hardware_ingress:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCastHardwareIngresses']['meta_info']


            class L2FibDhcpBindingDetails(object):
                """
                DHCP binding forwarding detail
                
                .. attribute:: l2fib_dhcp_binding_detail
                
                	Specify DHCP binding detail
                	**type**\: list of    :py:class:`L2FibDhcpBindingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_dhcp_binding_detail = YList()
                    self.l2fib_dhcp_binding_detail.parent = self
                    self.l2fib_dhcp_binding_detail.name = 'l2fib_dhcp_binding_detail'


                class L2FibDhcpBindingDetail(object):
                    """
                    Specify DHCP binding detail
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base>`
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor IPv4 address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: port
                    
                    	Union of Port information
                    	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port>`
                    
                    .. attribute:: xcid
                    
                    	XConnect ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base()
                        self.base.parent = self
                        self.neighbor_address = None
                        self.port = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port()
                        self.port.parent = self
                        self.xcid = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Base']['meta_info']


                    class Port(object):
                        """
                        Union of Port information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw()
                            self.pw.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_handle = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Ac']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self.pw_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:port'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail.Port']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-dhcp-binding-detail'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.neighbor_address is not None:
                            return True

                        if self.port is not None and self.port._has_data():
                            return True

                        if self.xcid is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails.L2FibDhcpBindingDetail']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-dhcp-binding-details'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_dhcp_binding_detail is not None:
                        for child_ref in self.l2fib_dhcp_binding_detail:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingDetails']['meta_info']


            class L2FibxCons(object):
                """
                The L2VPN forwarding XConnect Detail Table
                
                .. attribute:: l2fibx_con
                
                	Specify XConnect ID
                	**type**\: list of    :py:class:`L2FibxCon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fibx_con = YList()
                    self.l2fibx_con.parent = self
                    self.l2fibx_con.name = 'l2fibx_con'


                class L2FibxCon(object):
                    """
                    Specify XConnect ID
                    
                    .. attribute:: xcid  <key>
                    
                    	XC ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base>`
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\:  bool
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2>`
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:   :py:class:`MgmtL2FibSwitchingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibSwitchingEnum>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\:  str
                    
                    	**length:** 0..72
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.xcid = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base()
                        self.base.parent = self
                        self.bound = None
                        self.segment1 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1()
                        self.segment1.parent = self
                        self.segment2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2()
                        self.segment2.parent = self
                        self.switching_type = None
                        self.xcon_name = None


                    class Base(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Base']['meta_info']


                    class Segment1(object):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:   :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn()
                            self.evpn.parent = self
                            self.monitor_session = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base()
                                self.base.parent = self
                                self.bound = None
                                self.core_pbb_evpn_enabled = None
                                self.forward_class = None
                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.Base']['meta_info']


                            class PbbUnion(object):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self.pbb_type = None


                                class Edge(object):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mac = None
                                        self.mac_configured = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mac is not None:
                                            return True

                                        if self.mac_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Edge']['meta_info']


                                class Core(object):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.vlan_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.vlan_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion.Core']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core is not None and self.core._has_data():
                                        return True

                                    if self.edge is not None and self.edge._has_data():
                                        return True

                                    if self.pbb_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb.PbbUnion']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.core_pbb_evpn_enabled is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.pbb_union is not None and self.pbb_union._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base()
                                self.base.parent = self
                                self.bound = None
                                self.encap = None
                                self.mcastip = None
                                self.parent_if = None
                                self.source_vtep_if = None
                                self.srcip = None
                                self.udp_port = None
                                self.vx_lan_mode = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.any_cast_ip is not None:
                                    return True

                                if self.anycast_mcast_ip is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.encap is not None:
                                    return True

                                if self.mcastip is not None:
                                    return True

                                if self.parent_if is not None:
                                    return True

                                if self.source_vtep_if is not None:
                                    return True

                                if self.srcip is not None:
                                    return True

                                if self.udp_port is not None:
                                    return True

                                if self.vx_lan_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evi = None
                                self.forward_class = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evi is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Evpn']['meta_info']


                        class MonitorSession(object):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\:  str
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self.bound = None
                                self.hardware_information = None
                                self.session_name = None
                                self.xcid = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:monitor-session'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.hardware_information is not None:
                                    return True

                                if self.session_name is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.MonitorSession']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.monitor_session is not None and self.monitor_session._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment1']['meta_info']


                    class Segment2(object):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:   :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:   :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac()
                            self.ac.parent = self
                            self.bp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp()
                            self.bp.parent = self
                            self.data_type = None
                            self.fxs = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs()
                            self.fxs.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw()
                            self.pw.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Ac']['meta_info']


                        class Bp(object):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:   :py:class:`P2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp>`
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base()
                                self.base.parent = self
                                self.bridge_id = None
                                self.learn_key = None
                                self.msti_pointer = None
                                self.mvrp_sequence_number = None
                                self.oper = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self.p2mp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp()
                                self.p2mp.parent = self
                                self.segment_type = None
                                self.shg_id = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Base']['meta_info']


                            class Oper(object):
                                """
                                Operational information
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.operational_information = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None


                                class OperationalInformation(object):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\:  bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: host_routing_enabled
                                    
                                    	Host Routing enabled on this BD
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\:  bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.admin_disabled = None
                                        self.bvi_configured = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.feature = YList()
                                        self.feature.parent = self
                                        self.feature.name = 'feature'
                                        self.flood_unknown_unicast_enabled = None
                                        self.flooding_disabled = None
                                        self.host_routing_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.is_bvi_up = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_evpn_cw_disable = None
                                        self.is_evpn_enabled = None
                                        self.is_evpn_flow_label = None
                                        self.is_igmp_snoop_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_vni_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.mac_aging_time = None
                                        self.mac_aging_type = None
                                        self.mac_learning_disabled = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification_type = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_secure_action = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.msti = None
                                        self.mtu = None
                                        self.number_of_macs = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.stp_participating = None
                                        self.unknown_unicast_flooding_disabled = None


                                    class Feature(object):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dhcp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self.feature_type = None
                                            self.igmp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self.mld = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self


                                        class Dhcp(object):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp']['meta_info']


                                        class Igmp(object):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp']['meta_info']


                                        class Mld(object):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.profile_name = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.profile_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dhcp is not None and self.dhcp._has_data():
                                                return True

                                            if self.feature_type is not None:
                                                return True

                                            if self.igmp is not None and self.igmp._has_data():
                                                return True

                                            if self.mld is not None and self.mld._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation.Feature']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.admin_disabled is not None:
                                            return True

                                        if self.bvi_configured is not None:
                                            return True

                                        if self.dhcp_enabled is not None:
                                            return True

                                        if self.dhcp_trusted is not None:
                                            return True

                                        if self.feature is not None:
                                            for child_ref in self.feature:
                                                if child_ref._has_data():
                                                    return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flooding_disabled is not None:
                                            return True

                                        if self.host_routing_enabled is not None:
                                            return True

                                        if self.igmp_flood_forward_enabled is not None:
                                            return True

                                        if self.igmp_mroute_port_enabled is not None:
                                            return True

                                        if self.igmp_route_guard_enabled is not None:
                                            return True

                                        if self.igmp_snoop_enabled is not None:
                                            return True

                                        if self.igmp_snoop_profile_enabled is not None:
                                            return True

                                        if self.is_bvi_up is not None:
                                            return True

                                        if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validation_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_evpn_cw_disable is not None:
                                            return True

                                        if self.is_evpn_enabled is not None:
                                            return True

                                        if self.is_evpn_flow_label is not None:
                                            return True

                                        if self.is_igmp_snoop_enabled is not None:
                                            return True

                                        if self.is_ipsg_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.is_p2mp_pw_enabled is not None:
                                            return True

                                        if self.is_pbbevpn_enabled is not None:
                                            return True

                                        if self.is_swmac_learning is not None:
                                            return True

                                        if self.is_vni_enabled is not None:
                                            return True

                                        if self.is_vpls_flood_optimization_enabled is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_aging_type is not None:
                                            return True

                                        if self.mac_learning_disabled is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification_type is not None:
                                            return True

                                        if self.mac_port_down_flush_disabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_flood_forward_enabled is not None:
                                            return True

                                        if self.mld_mroute_port_enabled is not None:
                                            return True

                                        if self.mld_route_guard_enabled is not None:
                                            return True

                                        if self.mld_snoop_enabled is not None:
                                            return True

                                        if self.mld_snoop_profile_enabled is not None:
                                            return True

                                        if self.msti is not None:
                                            return True

                                        if self.mtu is not None:
                                            return True

                                        if self.number_of_macs is not None:
                                            return True

                                        if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                            return True

                                        if self.storm_control_broadcast_enabled is not None:
                                            return True

                                        if self.storm_control_broadcast_rate_unit is not None:
                                            return True

                                        if self.storm_control_multicast_enabled is not None:
                                            return True

                                        if self.storm_control_multicast_rate_unit is not None:
                                            return True

                                        if self.storm_control_unicast_enabled is not None:
                                            return True

                                        if self.storm_control_unicast_rate_unit is not None:
                                            return True

                                        if self.stp_participating is not None:
                                            return True

                                        if self.unknown_unicast_flooding_disabled is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper.OperationalInformation']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:oper'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.operational_information is not None and self.operational_information._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.Oper']['meta_info']


                            class P2Mp(object):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\:  bool
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:   :py:class:`L2VpnPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPtreeEnum>`
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.extended_tunnel_id = None
                                    self.lsm_id = None
                                    self.p2mp_id = None
                                    self.ptree_owner_lmrib = None
                                    self.ptree_type = None
                                    self.tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.extended_tunnel_id is not None:
                                        return True

                                    if self.lsm_id is not None:
                                        return True

                                    if self.p2mp_id is not None:
                                        return True

                                    if self.ptree_owner_lmrib is not None:
                                        return True

                                    if self.ptree_type is not None:
                                        return True

                                    if self.tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp.P2Mp']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bp'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bridge_id is not None:
                                    return True

                                if self.learn_key is not None:
                                    return True

                                if self.msti_pointer is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.oper is not None and self.oper._has_data():
                                    return True

                                if self.p2mp is not None and self.p2mp._has_data():
                                    return True

                                if self.segment_type is not None:
                                    return True

                                if self.shg_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Bp']['meta_info']


                        class Fxs(object):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base()
                                self.base.parent = self
                                self.fxs_id = None
                                self.segment_type = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxs'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.fxs_id is not None:
                                    return True

                                if self.segment_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Fxs']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.bp is not None and self.bp._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.fxs is not None and self.fxs._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon.Segment2']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.xcid is None:
                            raise YPYModelError('Key property xcid is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibx-con[Cisco-IOS-XR-l2vpn-oper:xcid = ' + str(self.xcid) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.xcid is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bound is not None:
                            return True

                        if self.segment1 is not None and self.segment1._has_data():
                            return True

                        if self.segment2 is not None and self.segment2._has_data():
                            return True

                        if self.switching_type is not None:
                            return True

                        if self.xcon_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons.L2FibxCon']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibx-cons'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fibx_con is not None:
                        for child_ref in self.l2fibx_con:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibxCons']['meta_info']


            class L2FibMainInterfaces(object):
                """
                Main Interface
                
                .. attribute:: l2fib_main_interface
                
                	Main Interface Table
                	**type**\: list of    :py:class:`L2FibMainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_main_interface = YList()
                    self.l2fib_main_interface.parent = self
                    self.l2fib_main_interface.name = 'l2fib_main_interface'


                class L2FibMainInterface(object):
                    """
                    Main Interface Table
                    
                    .. attribute:: l2fib_main_interface_detail_info
                    
                    	Main Interface detail info
                    	**type**\:   :py:class:`L2FibMainInterfaceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_egress_detail_info
                    
                    	Main Interface hardware egress detail info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareEgressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_egress_info
                    
                    	Main Interface hardware egress info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_ingress_detail_info
                    
                    	Main Interface hardware ingress detail info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareIngressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_ingress_info
                    
                    	Main Interface hardware ingress info
                    	**type**\:   :py:class:`L2FibMainInterfaceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo>`
                    
                    .. attribute:: l2fib_main_interface_info
                    
                    	Main Interface info
                    	**type**\:   :py:class:`L2FibMainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo>`
                    
                    .. attribute:: l2fib_main_interface_instances
                    
                    	Main Interface Instance table
                    	**type**\:   :py:class:`L2FibMainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances>`
                    
                    .. attribute:: main_interface_id
                    
                    	Main interface id
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: main_interface_type
                    
                    	Main interface type
                    	**type**\:   :py:class:`EvpnMainInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.EvpnMainInterfaceEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.l2fib_main_interface_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo()
                        self.l2fib_main_interface_detail_info.parent = self
                        self.l2fib_main_interface_hardware_egress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo()
                        self.l2fib_main_interface_hardware_egress_detail_info.parent = self
                        self.l2fib_main_interface_hardware_egress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo()
                        self.l2fib_main_interface_hardware_egress_info.parent = self
                        self.l2fib_main_interface_hardware_ingress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo()
                        self.l2fib_main_interface_hardware_ingress_detail_info.parent = self
                        self.l2fib_main_interface_hardware_ingress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo()
                        self.l2fib_main_interface_hardware_ingress_info.parent = self
                        self.l2fib_main_interface_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo()
                        self.l2fib_main_interface_info.parent = self
                        self.l2fib_main_interface_instances = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances()
                        self.l2fib_main_interface_instances.parent = self
                        self.main_interface_id = None
                        self.main_interface_type = None


                    class L2FibMainInterfaceHardwareEgressDetailInfo(object):
                        """
                        Main Interface hardware egress detail info
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\:  list of int
                        
                        	**range:** 0..255
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of    :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo>`
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\:  str
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_port_count_instance = YLeafList()
                            self.bridge_port_count_instance.parent = self
                            self.bridge_port_count_instance.name = 'bridge_port_count_instance'
                            self.esi_id = None
                            self.ethernet_segment_identifier = YLeafList()
                            self.ethernet_segment_identifier.parent = self
                            self.ethernet_segment_identifier.name = 'ethernet_segment_identifier'
                            self.evpn_shg_local_label = None
                            self.evpn_shg_remote_info = YList()
                            self.evpn_shg_remote_info.parent = self
                            self.evpn_shg_remote_info.name = 'evpn_shg_remote_info'
                            self.instance_id = YLeafList()
                            self.instance_id.parent = self
                            self.instance_id.name = 'instance_id'
                            self.instances_provisioned = YLeafList()
                            self.instances_provisioned.parent = self
                            self.instances_provisioned.name = 'instances_provisioned'
                            self.instances_state = YLeafList()
                            self.instances_state.parent = self
                            self.instances_state.name = 'instances_state'
                            self.mac = None
                            self.main_if_type = None
                            self.main_interface = None
                            self.virtual_if_name = None


                        class EvpnShgRemoteInfo(object):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:   :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self


                            class RemoteSplitHorizonGroupLabel(object):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.label = None
                                    self.next_hop = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-split-horizon-group-label'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.label is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-shg-remote-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-hardware-egress-detail-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_port_count_instance is not None:
                                for child in self.bridge_port_count_instance:
                                    if child is not None:
                                        return True

                            if self.esi_id is not None:
                                return True

                            if self.ethernet_segment_identifier is not None:
                                for child in self.ethernet_segment_identifier:
                                    if child is not None:
                                        return True

                            if self.evpn_shg_local_label is not None:
                                return True

                            if self.evpn_shg_remote_info is not None:
                                for child_ref in self.evpn_shg_remote_info:
                                    if child_ref._has_data():
                                        return True

                            if self.instance_id is not None:
                                for child in self.instance_id:
                                    if child is not None:
                                        return True

                            if self.instances_provisioned is not None:
                                for child in self.instances_provisioned:
                                    if child is not None:
                                        return True

                            if self.instances_state is not None:
                                for child in self.instances_state:
                                    if child is not None:
                                        return True

                            if self.mac is not None:
                                return True

                            if self.main_if_type is not None:
                                return True

                            if self.main_interface is not None:
                                return True

                            if self.virtual_if_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressDetailInfo']['meta_info']


                    class L2FibMainInterfaceHardwareEgressInfo(object):
                        """
                        Main Interface hardware egress info
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance_id = YLeafList()
                            self.instance_id.parent = self
                            self.instance_id.name = 'instance_id'
                            self.instances_provisioned = YLeafList()
                            self.instances_provisioned.parent = self
                            self.instances_provisioned.name = 'instances_provisioned'
                            self.instances_state = YLeafList()
                            self.instances_state.parent = self
                            self.instances_state.name = 'instances_state'
                            self.main_if_type = None
                            self.main_interface = None
                            self.virtual_if_name = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-hardware-egress-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance_id is not None:
                                for child in self.instance_id:
                                    if child is not None:
                                        return True

                            if self.instances_provisioned is not None:
                                for child in self.instances_provisioned:
                                    if child is not None:
                                        return True

                            if self.instances_state is not None:
                                for child in self.instances_state:
                                    if child is not None:
                                        return True

                            if self.main_if_type is not None:
                                return True

                            if self.main_interface is not None:
                                return True

                            if self.virtual_if_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareEgressInfo']['meta_info']


                    class L2FibMainInterfaceInstances(object):
                        """
                        Main Interface Instance table
                        
                        .. attribute:: l2fib_main_interface_instance
                        
                        	Main Interface Instance
                        	**type**\: list of    :py:class:`L2FibMainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.l2fib_main_interface_instance = YList()
                            self.l2fib_main_interface_instance.parent = self
                            self.l2fib_main_interface_instance.name = 'l2fib_main_interface_instance'


                        class L2FibMainInterfaceInstance(object):
                            """
                            Main Interface Instance
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: l2fib_main_interface_instance_bridge_port_details
                            
                            	Main Interface Instance Bridge Port detail table
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceBridgePortDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails>`
                            
                            .. attribute:: l2fib_main_interface_instance_bridge_ports
                            
                            	Main Interface Instance Bridge Port table
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts>`
                            
                            .. attribute:: l2fib_main_interface_instance_detail_info
                            
                            	Main Interface Instance detail info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_egress_detail_info
                            
                            	Main Interface Instance hardware egress detail info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareEgressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_egress_info
                            
                            	Main Interface Instance hardware egress info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_ingress_detail_info
                            
                            	Main Interface Instance hardware ingress detail info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareIngressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_ingress_info
                            
                            	Main Interface Instance hardware ingress info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_info
                            
                            	Main Interface Instance info
                            	**type**\:   :py:class:`L2FibMainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.instance = None
                                self.l2fib_main_interface_instance_bridge_port_details = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails()
                                self.l2fib_main_interface_instance_bridge_port_details.parent = self
                                self.l2fib_main_interface_instance_bridge_ports = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts()
                                self.l2fib_main_interface_instance_bridge_ports.parent = self
                                self.l2fib_main_interface_instance_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo()
                                self.l2fib_main_interface_instance_detail_info.parent = self
                                self.l2fib_main_interface_instance_hardware_egress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo()
                                self.l2fib_main_interface_instance_hardware_egress_detail_info.parent = self
                                self.l2fib_main_interface_instance_hardware_egress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo()
                                self.l2fib_main_interface_instance_hardware_egress_info.parent = self
                                self.l2fib_main_interface_instance_hardware_ingress_detail_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo()
                                self.l2fib_main_interface_instance_hardware_ingress_detail_info.parent = self
                                self.l2fib_main_interface_instance_hardware_ingress_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo()
                                self.l2fib_main_interface_instance_hardware_ingress_info.parent = self
                                self.l2fib_main_interface_instance_info = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo()
                                self.l2fib_main_interface_instance_info.parent = self


                            class L2FibMainInterfaceInstanceDetailInfo(object):
                                """
                                Main Interface Instance detail info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_count = None
                                    self.instance = None
                                    self.instance_provisioned = None
                                    self.main_if_type = None
                                    self.main_interface = None
                                    self.state = None
                                    self.virtual_if_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-detail-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_count is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.instance_provisioned is not None:
                                        return True

                                    if self.main_if_type is not None:
                                        return True

                                    if self.main_interface is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.virtual_if_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceDetailInfo']['meta_info']


                            class L2FibMainInterfaceInstanceBridgePortDetails(object):
                                """
                                Main Interface Instance Bridge Port detail
                                table
                                
                                .. attribute:: l2fib_main_interface_instance_bridge_port_detail
                                
                                	Main Interface Bridge Port detail info
                                	**type**\: list of    :py:class:`L2FibMainInterfaceInstanceBridgePortDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.l2fib_main_interface_instance_bridge_port_detail = YList()
                                    self.l2fib_main_interface_instance_bridge_port_detail.parent = self
                                    self.l2fib_main_interface_instance_bridge_port_detail.name = 'l2fib_main_interface_instance_bridge_port_detail'


                                class L2FibMainInterfaceInstanceBridgePortDetail(object):
                                    """
                                    Main Interface Bridge Port detail info
                                    
                                    .. attribute:: bridge_port  <key>
                                    
                                    	Bridge Port
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: bp_type
                                    
                                    	Bridge Port Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bridge_id
                                    
                                    	Bridge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bridge_port_id
                                    
                                    	Bridge Port ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: main_if_type
                                    
                                    	Main Interface Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: main_interface
                                    
                                    	Main interface ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: oper
                                    
                                    	Operational information
                                    	**type**\:   :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper>`
                                    
                                    .. attribute:: state
                                    
                                    	Instance state
                                    	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                    
                                    .. attribute:: virtual_if_name
                                    
                                    	Virtual Main IfName
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bridge_port = None
                                        self.bp_type = None
                                        self.bridge_id = None
                                        self.bridge_port_id = None
                                        self.main_if_type = None
                                        self.main_interface = None
                                        self.oper = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper()
                                        self.oper.parent = self
                                        self.state = None
                                        self.virtual_if_name = None


                                    class Oper(object):
                                        """
                                        Operational information
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast storm control kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast storm control pps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast storm control kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast storm control pps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: operational_information
                                        
                                        	L2 operational information
                                        	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast storm control kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast storm control pps
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None


                                        class OperationalInformation(object):
                                            """
                                            L2 operational information
                                            
                                            .. attribute:: admin_disabled
                                            
                                            	Is administratively disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: bvi_configured
                                            
                                            	Is BVI Interface configured
                                            	**type**\:  bool
                                            
                                            .. attribute:: dhcp_enabled
                                            
                                            	Is DHCP snooping enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: dhcp_trusted
                                            
                                            	Is DHCP trusted
                                            	**type**\:  bool
                                            
                                            .. attribute:: feature
                                            
                                            	Feature information
                                            	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature>`
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Is flooding unknown unicast disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flooding_disabled
                                            
                                            	Is flooding disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: host_routing_enabled
                                            
                                            	Host Routing enabled on this BD
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_flood_forward_enabled
                                            
                                            	Is IGMP flood forwarding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_mroute_port_enabled
                                            
                                            	Is mrouter port
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_route_guard_enabled
                                            
                                            	Is router gurad enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_snoop_enabled
                                            
                                            	Is IGMP snooping enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igmp_snoop_profile_enabled
                                            
                                            	Is IGMP snooping profile enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_bvi_up
                                            
                                            	Is BVI state UP
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                            
                                            	Is DAI Destination MAC Validation enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                                            
                                            	Is DAI IPv4 Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_evpn_cw_disable
                                            
                                            	Is EVPN CW disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_evpn_enabled
                                            
                                            	Is EVPN enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_evpn_flow_label
                                            
                                            	Is EVPN Flow Label enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_igmp_snoop_enabled
                                            
                                            	Is IGMP Snooping admin enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown
                                            
                                            	Is MAC secure accept shutdown (BP only)
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_p2mp_pw_enabled
                                            
                                            	Is P2MP PW enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_pbbevpn_enabled
                                            
                                            	Is PBBEVPN enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_swmac_learning
                                            
                                            	Is SW MAC learning enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_vni_enabled
                                            
                                            	Is VNI enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_vpls_flood_optimization_enabled
                                            
                                            	Is MMRP  Flood Optimization Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in minutes
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: mac_aging_type
                                            
                                            	MAC aging type
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_learning_disabled
                                            
                                            	Is MAC learning disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC limit
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                                            
                                            .. attribute:: mac_limit_notification_type
                                            
                                            	MAC limit notification
                                            	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                                            
                                            .. attribute:: mac_port_down_flush_disabled
                                            
                                            	Is MAC port down flush disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC secure action
                                            	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                                            
                                            .. attribute:: mld_flood_forward_enabled
                                            
                                            	Is MLD flood forwarding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_mroute_port_enabled
                                            
                                            	Is mrouter port
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_route_guard_enabled
                                            
                                            	Is router gurad enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_snoop_enabled
                                            
                                            	Is MLD snooping enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mld_snoop_profile_enabled
                                            
                                            	Is MLD snooping profile enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: msti
                                            
                                            	Multi\-spanning tree instance
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mtu
                                            
                                            	MTU
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_macs
                                            
                                            	numberOfMacs
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                            
                                            	nV Satellite Offload IPv4 Multicast Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_broadcast_enabled
                                            
                                            	Is broadcast storm control enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_broadcast_rate_unit
                                            
                                            	Storm control broadcast rate unit
                                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                            
                                            .. attribute:: storm_control_multicast_enabled
                                            
                                            	Is multicast storm control enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_multicast_rate_unit
                                            
                                            	Storm control multicast rate unit
                                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                            
                                            .. attribute:: storm_control_unicast_enabled
                                            
                                            	Is unicast storm control enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: storm_control_unicast_rate_unit
                                            
                                            	Storm control unicast rate unit
                                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                                            
                                            .. attribute:: stp_participating
                                            
                                            	Is Spanning Tree Protocol participating
                                            	**type**\:  bool
                                            
                                            .. attribute:: unknown_unicast_flooding_disabled
                                            
                                            	Unknown Unicast Flooding is disabled
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.admin_disabled = None
                                                self.bvi_configured = None
                                                self.dhcp_enabled = None
                                                self.dhcp_trusted = None
                                                self.feature = YList()
                                                self.feature.parent = self
                                                self.feature.name = 'feature'
                                                self.flood_unknown_unicast_enabled = None
                                                self.flooding_disabled = None
                                                self.host_routing_enabled = None
                                                self.igmp_flood_forward_enabled = None
                                                self.igmp_mroute_port_enabled = None
                                                self.igmp_route_guard_enabled = None
                                                self.igmp_snoop_enabled = None
                                                self.igmp_snoop_profile_enabled = None
                                                self.is_bvi_up = None
                                                self.is_dai_addr_validation_destination_mac_enabled = None
                                                self.is_dai_addr_validation_ipv4_enabled = None
                                                self.is_dai_addr_validation_source_mac_enabled = None
                                                self.is_dai_enabled = None
                                                self.is_dai_logging_enabled = None
                                                self.is_evpn_cw_disable = None
                                                self.is_evpn_enabled = None
                                                self.is_evpn_flow_label = None
                                                self.is_igmp_snoop_enabled = None
                                                self.is_ipsg_enabled = None
                                                self.is_ipsg_logging_enabled = None
                                                self.is_mac_secure_accept_shutdown = None
                                                self.is_mac_secure_enabled = None
                                                self.is_mac_secure_logging_enabled = None
                                                self.is_p2mp_pw_enabled = None
                                                self.is_pbbevpn_enabled = None
                                                self.is_swmac_learning = None
                                                self.is_vni_enabled = None
                                                self.is_vpls_flood_optimization_enabled = None
                                                self.mac_aging_time = None
                                                self.mac_aging_type = None
                                                self.mac_learning_disabled = None
                                                self.mac_limit = None
                                                self.mac_limit_action = None
                                                self.mac_limit_notification_type = None
                                                self.mac_port_down_flush_disabled = None
                                                self.mac_secure_action = None
                                                self.mld_flood_forward_enabled = None
                                                self.mld_mroute_port_enabled = None
                                                self.mld_route_guard_enabled = None
                                                self.mld_snoop_enabled = None
                                                self.mld_snoop_profile_enabled = None
                                                self.msti = None
                                                self.mtu = None
                                                self.number_of_macs = None
                                                self.nv_satellite_offload_ipv4_multicast_disabled = None
                                                self.storm_control_broadcast_enabled = None
                                                self.storm_control_broadcast_rate_unit = None
                                                self.storm_control_multicast_enabled = None
                                                self.storm_control_multicast_rate_unit = None
                                                self.storm_control_unicast_enabled = None
                                                self.storm_control_unicast_rate_unit = None
                                                self.stp_participating = None
                                                self.unknown_unicast_flooding_disabled = None


                                            class Feature(object):
                                                """
                                                Feature information
                                                
                                                .. attribute:: dhcp
                                                
                                                	dhcp
                                                	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp>`
                                                
                                                .. attribute:: feature_type
                                                
                                                	feature type
                                                	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                                
                                                .. attribute:: igmp
                                                
                                                	igmp
                                                	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp>`
                                                
                                                .. attribute:: mld
                                                
                                                	mld
                                                	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self.feature_type = None
                                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self


                                                class Dhcp(object):
                                                    """
                                                    dhcp
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.profile_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.profile_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp']['meta_info']


                                                class Igmp(object):
                                                    """
                                                    igmp
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.profile_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.profile_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp']['meta_info']


                                                class Mld(object):
                                                    """
                                                    mld
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\:  str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.profile_name = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.profile_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.dhcp is not None and self.dhcp._has_data():
                                                        return True

                                                    if self.feature_type is not None:
                                                        return True

                                                    if self.igmp is not None and self.igmp._has_data():
                                                        return True

                                                    if self.mld is not None and self.mld._has_data():
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.admin_disabled is not None:
                                                    return True

                                                if self.bvi_configured is not None:
                                                    return True

                                                if self.dhcp_enabled is not None:
                                                    return True

                                                if self.dhcp_trusted is not None:
                                                    return True

                                                if self.feature is not None:
                                                    for child_ref in self.feature:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.flood_unknown_unicast_enabled is not None:
                                                    return True

                                                if self.flooding_disabled is not None:
                                                    return True

                                                if self.host_routing_enabled is not None:
                                                    return True

                                                if self.igmp_flood_forward_enabled is not None:
                                                    return True

                                                if self.igmp_mroute_port_enabled is not None:
                                                    return True

                                                if self.igmp_route_guard_enabled is not None:
                                                    return True

                                                if self.igmp_snoop_enabled is not None:
                                                    return True

                                                if self.igmp_snoop_profile_enabled is not None:
                                                    return True

                                                if self.is_bvi_up is not None:
                                                    return True

                                                if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                                    return True

                                                if self.is_dai_addr_validation_ipv4_enabled is not None:
                                                    return True

                                                if self.is_dai_addr_validation_source_mac_enabled is not None:
                                                    return True

                                                if self.is_dai_enabled is not None:
                                                    return True

                                                if self.is_dai_logging_enabled is not None:
                                                    return True

                                                if self.is_evpn_cw_disable is not None:
                                                    return True

                                                if self.is_evpn_enabled is not None:
                                                    return True

                                                if self.is_evpn_flow_label is not None:
                                                    return True

                                                if self.is_igmp_snoop_enabled is not None:
                                                    return True

                                                if self.is_ipsg_enabled is not None:
                                                    return True

                                                if self.is_ipsg_logging_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_accept_shutdown is not None:
                                                    return True

                                                if self.is_mac_secure_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_logging_enabled is not None:
                                                    return True

                                                if self.is_p2mp_pw_enabled is not None:
                                                    return True

                                                if self.is_pbbevpn_enabled is not None:
                                                    return True

                                                if self.is_swmac_learning is not None:
                                                    return True

                                                if self.is_vni_enabled is not None:
                                                    return True

                                                if self.is_vpls_flood_optimization_enabled is not None:
                                                    return True

                                                if self.mac_aging_time is not None:
                                                    return True

                                                if self.mac_aging_type is not None:
                                                    return True

                                                if self.mac_learning_disabled is not None:
                                                    return True

                                                if self.mac_limit is not None:
                                                    return True

                                                if self.mac_limit_action is not None:
                                                    return True

                                                if self.mac_limit_notification_type is not None:
                                                    return True

                                                if self.mac_port_down_flush_disabled is not None:
                                                    return True

                                                if self.mac_secure_action is not None:
                                                    return True

                                                if self.mld_flood_forward_enabled is not None:
                                                    return True

                                                if self.mld_mroute_port_enabled is not None:
                                                    return True

                                                if self.mld_route_guard_enabled is not None:
                                                    return True

                                                if self.mld_snoop_enabled is not None:
                                                    return True

                                                if self.mld_snoop_profile_enabled is not None:
                                                    return True

                                                if self.msti is not None:
                                                    return True

                                                if self.mtu is not None:
                                                    return True

                                                if self.number_of_macs is not None:
                                                    return True

                                                if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                                    return True

                                                if self.storm_control_broadcast_enabled is not None:
                                                    return True

                                                if self.storm_control_broadcast_rate_unit is not None:
                                                    return True

                                                if self.storm_control_multicast_enabled is not None:
                                                    return True

                                                if self.storm_control_multicast_rate_unit is not None:
                                                    return True

                                                if self.storm_control_unicast_enabled is not None:
                                                    return True

                                                if self.storm_control_unicast_rate_unit is not None:
                                                    return True

                                                if self.stp_participating is not None:
                                                    return True

                                                if self.unknown_unicast_flooding_disabled is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:oper'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.operational_information is not None and self.operational_information._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail.Oper']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.bridge_port is None:
                                            raise YPYModelError('Key property bridge_port is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-bridge-port-detail[Cisco-IOS-XR-l2vpn-oper:bridge-port = ' + str(self.bridge_port) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bridge_port is not None:
                                            return True

                                        if self.bp_type is not None:
                                            return True

                                        if self.bridge_id is not None:
                                            return True

                                        if self.bridge_port_id is not None:
                                            return True

                                        if self.main_if_type is not None:
                                            return True

                                        if self.main_interface is not None:
                                            return True

                                        if self.oper is not None and self.oper._has_data():
                                            return True

                                        if self.state is not None:
                                            return True

                                        if self.virtual_if_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails.L2FibMainInterfaceInstanceBridgePortDetail']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-bridge-port-details'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2fib_main_interface_instance_bridge_port_detail is not None:
                                        for child_ref in self.l2fib_main_interface_instance_bridge_port_detail:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePortDetails']['meta_info']


                            class L2FibMainInterfaceInstanceInfo(object):
                                """
                                Main Interface Instance info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_count = None
                                    self.instance = None
                                    self.instance_provisioned = None
                                    self.main_if_type = None
                                    self.main_interface = None
                                    self.state = None
                                    self.virtual_if_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_count is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.instance_provisioned is not None:
                                        return True

                                    if self.main_if_type is not None:
                                        return True

                                    if self.main_interface is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.virtual_if_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceInfo']['meta_info']


                            class L2FibMainInterfaceInstanceHardwareIngressDetailInfo(object):
                                """
                                Main Interface Instance hardware ingress
                                detail info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_count = None
                                    self.instance = None
                                    self.instance_provisioned = None
                                    self.main_if_type = None
                                    self.main_interface = None
                                    self.state = None
                                    self.virtual_if_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-hardware-ingress-detail-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_count is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.instance_provisioned is not None:
                                        return True

                                    if self.main_if_type is not None:
                                        return True

                                    if self.main_interface is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.virtual_if_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressDetailInfo']['meta_info']


                            class L2FibMainInterfaceInstanceHardwareEgressInfo(object):
                                """
                                Main Interface Instance hardware egress
                                info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_count = None
                                    self.instance = None
                                    self.instance_provisioned = None
                                    self.main_if_type = None
                                    self.main_interface = None
                                    self.state = None
                                    self.virtual_if_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-hardware-egress-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_count is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.instance_provisioned is not None:
                                        return True

                                    if self.main_if_type is not None:
                                        return True

                                    if self.main_interface is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.virtual_if_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressInfo']['meta_info']


                            class L2FibMainInterfaceInstanceHardwareIngressInfo(object):
                                """
                                Main Interface Instance hardware ingress
                                info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_count = None
                                    self.instance = None
                                    self.instance_provisioned = None
                                    self.main_if_type = None
                                    self.main_interface = None
                                    self.state = None
                                    self.virtual_if_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-hardware-ingress-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_count is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.instance_provisioned is not None:
                                        return True

                                    if self.main_if_type is not None:
                                        return True

                                    if self.main_interface is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.virtual_if_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareIngressInfo']['meta_info']


                            class L2FibMainInterfaceInstanceBridgePorts(object):
                                """
                                Main Interface Instance Bridge Port table
                                
                                .. attribute:: l2fib_main_interface_instance_bridge_port
                                
                                	Main Interface Bridge Port info
                                	**type**\: list of    :py:class:`L2FibMainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.l2fib_main_interface_instance_bridge_port = YList()
                                    self.l2fib_main_interface_instance_bridge_port.parent = self
                                    self.l2fib_main_interface_instance_bridge_port.name = 'l2fib_main_interface_instance_bridge_port'


                                class L2FibMainInterfaceInstanceBridgePort(object):
                                    """
                                    Main Interface Bridge Port info
                                    
                                    .. attribute:: bridge_port  <key>
                                    
                                    	Bridge Port
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: bp_type
                                    
                                    	Bridge Port Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: bridge_id
                                    
                                    	Bridge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bridge_port_id
                                    
                                    	Bridge Port ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: main_if_type
                                    
                                    	Main Interface Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: main_interface
                                    
                                    	Main interface ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: virtual_if_name
                                    
                                    	Virtual Main IfName
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bridge_port = None
                                        self.bp_type = None
                                        self.bridge_id = None
                                        self.bridge_port_id = None
                                        self.main_if_type = None
                                        self.main_interface = None
                                        self.virtual_if_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.bridge_port is None:
                                            raise YPYModelError('Key property bridge_port is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-bridge-port[Cisco-IOS-XR-l2vpn-oper:bridge-port = ' + str(self.bridge_port) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bridge_port is not None:
                                            return True

                                        if self.bp_type is not None:
                                            return True

                                        if self.bridge_id is not None:
                                            return True

                                        if self.bridge_port_id is not None:
                                            return True

                                        if self.main_if_type is not None:
                                            return True

                                        if self.main_interface is not None:
                                            return True

                                        if self.virtual_if_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts.L2FibMainInterfaceInstanceBridgePort']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-bridge-ports'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.l2fib_main_interface_instance_bridge_port is not None:
                                        for child_ref in self.l2fib_main_interface_instance_bridge_port:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceBridgePorts']['meta_info']


                            class L2FibMainInterfaceInstanceHardwareEgressDetailInfo(object):
                                """
                                Main Interface Instance hardware egress
                                detail info
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\:  bool
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_count = None
                                    self.instance = None
                                    self.instance_provisioned = None
                                    self.main_if_type = None
                                    self.main_interface = None
                                    self.state = None
                                    self.virtual_if_name = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance-hardware-egress-detail-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_count is not None:
                                        return True

                                    if self.instance is not None:
                                        return True

                                    if self.instance_provisioned is not None:
                                        return True

                                    if self.main_if_type is not None:
                                        return True

                                    if self.main_interface is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.virtual_if_name is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance.L2FibMainInterfaceInstanceHardwareEgressDetailInfo']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.instance is None:
                                    raise YPYModelError('Key property instance is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instance[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.instance is not None:
                                    return True

                                if self.l2fib_main_interface_instance_bridge_port_details is not None and self.l2fib_main_interface_instance_bridge_port_details._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_bridge_ports is not None and self.l2fib_main_interface_instance_bridge_ports._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_detail_info is not None and self.l2fib_main_interface_instance_detail_info._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_hardware_egress_detail_info is not None and self.l2fib_main_interface_instance_hardware_egress_detail_info._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_hardware_egress_info is not None and self.l2fib_main_interface_instance_hardware_egress_info._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_hardware_ingress_detail_info is not None and self.l2fib_main_interface_instance_hardware_ingress_detail_info._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_hardware_ingress_info is not None and self.l2fib_main_interface_instance_hardware_ingress_info._has_data():
                                    return True

                                if self.l2fib_main_interface_instance_info is not None and self.l2fib_main_interface_instance_info._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances.L2FibMainInterfaceInstance']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-instances'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.l2fib_main_interface_instance is not None:
                                for child_ref in self.l2fib_main_interface_instance:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInstances']['meta_info']


                    class L2FibMainInterfaceInfo(object):
                        """
                        Main Interface info
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance_id = YLeafList()
                            self.instance_id.parent = self
                            self.instance_id.name = 'instance_id'
                            self.instances_provisioned = YLeafList()
                            self.instances_provisioned.parent = self
                            self.instances_provisioned.name = 'instances_provisioned'
                            self.instances_state = YLeafList()
                            self.instances_state.parent = self
                            self.instances_state.name = 'instances_state'
                            self.main_if_type = None
                            self.main_interface = None
                            self.virtual_if_name = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance_id is not None:
                                for child in self.instance_id:
                                    if child is not None:
                                        return True

                            if self.instances_provisioned is not None:
                                for child in self.instances_provisioned:
                                    if child is not None:
                                        return True

                            if self.instances_state is not None:
                                for child in self.instances_state:
                                    if child is not None:
                                        return True

                            if self.main_if_type is not None:
                                return True

                            if self.main_interface is not None:
                                return True

                            if self.virtual_if_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceInfo']['meta_info']


                    class L2FibMainInterfaceDetailInfo(object):
                        """
                        Main Interface detail info
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\:  list of int
                        
                        	**range:** 0..255
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of    :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo>`
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\:  str
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_port_count_instance = YLeafList()
                            self.bridge_port_count_instance.parent = self
                            self.bridge_port_count_instance.name = 'bridge_port_count_instance'
                            self.esi_id = None
                            self.ethernet_segment_identifier = YLeafList()
                            self.ethernet_segment_identifier.parent = self
                            self.ethernet_segment_identifier.name = 'ethernet_segment_identifier'
                            self.evpn_shg_local_label = None
                            self.evpn_shg_remote_info = YList()
                            self.evpn_shg_remote_info.parent = self
                            self.evpn_shg_remote_info.name = 'evpn_shg_remote_info'
                            self.instance_id = YLeafList()
                            self.instance_id.parent = self
                            self.instance_id.name = 'instance_id'
                            self.instances_provisioned = YLeafList()
                            self.instances_provisioned.parent = self
                            self.instances_provisioned.name = 'instances_provisioned'
                            self.instances_state = YLeafList()
                            self.instances_state.parent = self
                            self.instances_state.name = 'instances_state'
                            self.mac = None
                            self.main_if_type = None
                            self.main_interface = None
                            self.virtual_if_name = None


                        class EvpnShgRemoteInfo(object):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:   :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self


                            class RemoteSplitHorizonGroupLabel(object):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.label = None
                                    self.next_hop = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-split-horizon-group-label'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.label is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-shg-remote-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo.EvpnShgRemoteInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-detail-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_port_count_instance is not None:
                                for child in self.bridge_port_count_instance:
                                    if child is not None:
                                        return True

                            if self.esi_id is not None:
                                return True

                            if self.ethernet_segment_identifier is not None:
                                for child in self.ethernet_segment_identifier:
                                    if child is not None:
                                        return True

                            if self.evpn_shg_local_label is not None:
                                return True

                            if self.evpn_shg_remote_info is not None:
                                for child_ref in self.evpn_shg_remote_info:
                                    if child_ref._has_data():
                                        return True

                            if self.instance_id is not None:
                                for child in self.instance_id:
                                    if child is not None:
                                        return True

                            if self.instances_provisioned is not None:
                                for child in self.instances_provisioned:
                                    if child is not None:
                                        return True

                            if self.instances_state is not None:
                                for child in self.instances_state:
                                    if child is not None:
                                        return True

                            if self.mac is not None:
                                return True

                            if self.main_if_type is not None:
                                return True

                            if self.main_interface is not None:
                                return True

                            if self.virtual_if_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceDetailInfo']['meta_info']


                    class L2FibMainInterfaceHardwareIngressDetailInfo(object):
                        """
                        Main Interface hardware ingress detail info
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\:  list of int
                        
                        	**range:** 0..255
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of    :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo>`
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\:  str
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_port_count_instance = YLeafList()
                            self.bridge_port_count_instance.parent = self
                            self.bridge_port_count_instance.name = 'bridge_port_count_instance'
                            self.esi_id = None
                            self.ethernet_segment_identifier = YLeafList()
                            self.ethernet_segment_identifier.parent = self
                            self.ethernet_segment_identifier.name = 'ethernet_segment_identifier'
                            self.evpn_shg_local_label = None
                            self.evpn_shg_remote_info = YList()
                            self.evpn_shg_remote_info.parent = self
                            self.evpn_shg_remote_info.name = 'evpn_shg_remote_info'
                            self.instance_id = YLeafList()
                            self.instance_id.parent = self
                            self.instance_id.name = 'instance_id'
                            self.instances_provisioned = YLeafList()
                            self.instances_provisioned.parent = self
                            self.instances_provisioned.name = 'instances_provisioned'
                            self.instances_state = YLeafList()
                            self.instances_state.parent = self
                            self.instances_state.name = 'instances_state'
                            self.mac = None
                            self.main_if_type = None
                            self.main_interface = None
                            self.virtual_if_name = None


                        class EvpnShgRemoteInfo(object):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:   :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.remote_split_horizon_group_label = L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self


                            class RemoteSplitHorizonGroupLabel(object):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.label = None
                                    self.next_hop = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-split-horizon-group-label'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.label is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-shg-remote-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.remote_split_horizon_group_label is not None and self.remote_split_horizon_group_label._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-hardware-ingress-detail-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_port_count_instance is not None:
                                for child in self.bridge_port_count_instance:
                                    if child is not None:
                                        return True

                            if self.esi_id is not None:
                                return True

                            if self.ethernet_segment_identifier is not None:
                                for child in self.ethernet_segment_identifier:
                                    if child is not None:
                                        return True

                            if self.evpn_shg_local_label is not None:
                                return True

                            if self.evpn_shg_remote_info is not None:
                                for child_ref in self.evpn_shg_remote_info:
                                    if child_ref._has_data():
                                        return True

                            if self.instance_id is not None:
                                for child in self.instance_id:
                                    if child is not None:
                                        return True

                            if self.instances_provisioned is not None:
                                for child in self.instances_provisioned:
                                    if child is not None:
                                        return True

                            if self.instances_state is not None:
                                for child in self.instances_state:
                                    if child is not None:
                                        return True

                            if self.mac is not None:
                                return True

                            if self.main_if_type is not None:
                                return True

                            if self.main_interface is not None:
                                return True

                            if self.virtual_if_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressDetailInfo']['meta_info']


                    class L2FibMainInterfaceHardwareIngressInfo(object):
                        """
                        Main Interface hardware ingress info
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\:  list of bool
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\:  list of   :py:class:`L2FibMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibMainIfInstanceStateEnum>`
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance_id = YLeafList()
                            self.instance_id.parent = self
                            self.instance_id.name = 'instance_id'
                            self.instances_provisioned = YLeafList()
                            self.instances_provisioned.parent = self
                            self.instances_provisioned.name = 'instances_provisioned'
                            self.instances_state = YLeafList()
                            self.instances_state.parent = self
                            self.instances_state.name = 'instances_state'
                            self.main_if_type = None
                            self.main_interface = None
                            self.virtual_if_name = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface-hardware-ingress-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance_id is not None:
                                for child in self.instance_id:
                                    if child is not None:
                                        return True

                            if self.instances_provisioned is not None:
                                for child in self.instances_provisioned:
                                    if child is not None:
                                        return True

                            if self.instances_state is not None:
                                for child in self.instances_state:
                                    if child is not None:
                                        return True

                            if self.main_if_type is not None:
                                return True

                            if self.main_interface is not None:
                                return True

                            if self.virtual_if_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface.L2FibMainInterfaceHardwareIngressInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.l2fib_main_interface_detail_info is not None and self.l2fib_main_interface_detail_info._has_data():
                            return True

                        if self.l2fib_main_interface_hardware_egress_detail_info is not None and self.l2fib_main_interface_hardware_egress_detail_info._has_data():
                            return True

                        if self.l2fib_main_interface_hardware_egress_info is not None and self.l2fib_main_interface_hardware_egress_info._has_data():
                            return True

                        if self.l2fib_main_interface_hardware_ingress_detail_info is not None and self.l2fib_main_interface_hardware_ingress_detail_info._has_data():
                            return True

                        if self.l2fib_main_interface_hardware_ingress_info is not None and self.l2fib_main_interface_hardware_ingress_info._has_data():
                            return True

                        if self.l2fib_main_interface_info is not None and self.l2fib_main_interface_info._has_data():
                            return True

                        if self.l2fib_main_interface_instances is not None and self.l2fib_main_interface_instances._has_data():
                            return True

                        if self.main_interface_id is not None:
                            return True

                        if self.main_interface_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces.L2FibMainInterface']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-main-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_main_interface is not None:
                        for child_ref in self.l2fib_main_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMainInterfaces']['meta_info']


            class L2FibMstpDetails(object):
                """
                MSTP Detail Table
                
                .. attribute:: l2fib_mstp_detail
                
                	MSTP Detail information
                	**type**\: list of    :py:class:`L2FibMstpDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mstp_detail = YList()
                    self.l2fib_mstp_detail.parent = self
                    self.l2fib_mstp_detail.name = 'l2fib_mstp_detail'


                class L2FibMstpDetail(object):
                    """
                    MSTP Detail information
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base>`
                    
                    .. attribute:: bridge_port_array
                    
                    	Bridge port
                    	**type**\:  list of str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_msti
                    
                    	multi\-spanning tree instance internal value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: learn_key
                    
                    	Learn Key
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: msti
                    
                    	MSTI context
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: msti_xr
                    
                    	multi\-spanning tree instance configured value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_interface
                    
                    	Parent interface context
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: parent_interface_xr
                    
                    	main port ID
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: state
                    
                    	MSTI state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base()
                        self.base.parent = self
                        self.bridge_port_array = YLeafList()
                        self.bridge_port_array.parent = self
                        self.bridge_port_array.name = 'bridge_port_array'
                        self.internal_msti = None
                        self.learn_key = None
                        self.msti = None
                        self.msti_xr = None
                        self.parent_interface = None
                        self.parent_interface_xr = None
                        self.state = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail.Base']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mstp-detail'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bridge_port_array is not None:
                            for child in self.bridge_port_array:
                                if child is not None:
                                    return True

                        if self.internal_msti is not None:
                            return True

                        if self.learn_key is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.msti_xr is not None:
                            return True

                        if self.parent_interface is not None:
                            return True

                        if self.parent_interface_xr is not None:
                            return True

                        if self.state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMstpDetails.L2FibMstpDetail']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mstp-details'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mstp_detail is not None:
                        for child_ref in self.l2fib_mstp_detail:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMstpDetails']['meta_info']


            class L2FibL2Tp(object):
                """
                L2TP
                
                .. attribute:: l2tpv2_sessions
                
                	L2TPV2 Session table
                	**type**\:   :py:class:`L2Tpv2Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions>`
                
                .. attribute:: l2tpv3_sessions
                
                	L2TPV3 Session table
                	**type**\:   :py:class:`L2Tpv3Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2tpv2_sessions = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions()
                    self.l2tpv2_sessions.parent = self
                    self.l2tpv3_sessions = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions()
                    self.l2tpv3_sessions.parent = self


                class L2Tpv3Sessions(object):
                    """
                    L2TPV3 Session table
                    
                    .. attribute:: l2tpv3_session
                    
                    	L2TPV3 Session
                    	**type**\: list of    :py:class:`L2Tpv3Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.l2tpv3_session = YList()
                        self.l2tpv3_session.parent = self
                        self.l2tpv3_session.name = 'l2tpv3_session'


                    class L2Tpv3Session(object):
                        """
                        L2TPV3 Session
                        
                        .. attribute:: session_id  <key>
                        
                        	SessionID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: base
                        
                        	Base information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base>`
                        
                        .. attribute:: bound
                        
                        	Bind status
                        	**type**\:  bool
                        
                        .. attribute:: interface_handle
                        
                        	Interface handle of egress main interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ipv4_table_id
                        
                        	IPv4 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6_table_id
                        
                        	IPv6 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nhop_ip_addr
                        
                        	NHOP IP Address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_id_xr
                        
                        	Local Session Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_type
                        
                        	L2tp or L2tpv2 session
                        	**type**\:   :py:class:`L2FibL2TpSessionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibL2TpSessionEnum>`
                        
                        .. attribute:: source_address
                        
                        	Source/Local IP address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sub_interface_name
                        
                        	SubInterface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: tunnel_id_xr
                        
                        	Tunnel ID, l2tpv2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.session_id = None
                            self.base = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base()
                            self.base.parent = self
                            self.bound = None
                            self.interface_handle = None
                            self.ipv4_table_id = None
                            self.ipv6_table_id = None
                            self.nhop_ip_addr = None
                            self.session_id_xr = None
                            self.session_type = None
                            self.source_address = None
                            self.sub_interface_name = None
                            self.tunnel_id_xr = None


                        class Base(object):
                            """
                            Base information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session.Base']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.session_id is None:
                                raise YPYModelError('Key property session_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3-session[Cisco-IOS-XR-l2vpn-oper:session-id = ' + str(self.session_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.session_id is not None:
                                return True

                            if self.base is not None and self.base._has_data():
                                return True

                            if self.bound is not None:
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.ipv4_table_id is not None:
                                return True

                            if self.ipv6_table_id is not None:
                                return True

                            if self.nhop_ip_addr is not None:
                                return True

                            if self.session_id_xr is not None:
                                return True

                            if self.session_type is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.sub_interface_name is not None:
                                return True

                            if self.tunnel_id_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions.L2Tpv3Session']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3-sessions'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.l2tpv3_session is not None:
                            for child_ref in self.l2tpv3_session:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv3Sessions']['meta_info']


                class L2Tpv2Sessions(object):
                    """
                    L2TPV2 Session table
                    
                    .. attribute:: l2tpv2_session
                    
                    	L2TPV2 Session
                    	**type**\: list of    :py:class:`L2Tpv2Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.l2tpv2_session = YList()
                        self.l2tpv2_session.parent = self
                        self.l2tpv2_session.name = 'l2tpv2_session'


                    class L2Tpv2Session(object):
                        """
                        L2TPV2 Session
                        
                        .. attribute:: base
                        
                        	Base information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base>`
                        
                        .. attribute:: bound
                        
                        	Bind status
                        	**type**\:  bool
                        
                        .. attribute:: interface_handle
                        
                        	Interface handle of egress main interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: ipv4_table_id
                        
                        	IPv4 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6_table_id
                        
                        	IPv6 Table ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nhop_ip_addr
                        
                        	NHOP IP Address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_id
                        
                        	SessionID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: session_id_xr
                        
                        	Local Session Id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: session_type
                        
                        	L2tp or L2tpv2 session
                        	**type**\:   :py:class:`L2FibL2TpSessionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibL2TpSessionEnum>`
                        
                        .. attribute:: source_address
                        
                        	Source/Local IP address of the tunnel
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: sub_interface_name
                        
                        	SubInterface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: tunnel_id
                        
                        	TunnelID
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: tunnel_id_xr
                        
                        	Tunnel ID, l2tpv2
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base()
                            self.base.parent = self
                            self.bound = None
                            self.interface_handle = None
                            self.ipv4_table_id = None
                            self.ipv6_table_id = None
                            self.nhop_ip_addr = None
                            self.session_id = None
                            self.session_id_xr = None
                            self.session_type = None
                            self.source_address = None
                            self.sub_interface_name = None
                            self.tunnel_id = None
                            self.tunnel_id_xr = None


                        class Base(object):
                            """
                            Base information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session.Base']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2-session'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.bound is not None:
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.ipv4_table_id is not None:
                                return True

                            if self.ipv6_table_id is not None:
                                return True

                            if self.nhop_ip_addr is not None:
                                return True

                            if self.session_id is not None:
                                return True

                            if self.session_id_xr is not None:
                                return True

                            if self.session_type is not None:
                                return True

                            if self.source_address is not None:
                                return True

                            if self.sub_interface_name is not None:
                                return True

                            if self.tunnel_id is not None:
                                return True

                            if self.tunnel_id_xr is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions.L2Tpv2Session']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2-sessions'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.l2tpv2_session is not None:
                            for child_ref in self.l2tpv2_session:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp.L2Tpv2Sessions']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-l2tp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2tpv2_sessions is not None and self.l2tpv2_sessions._has_data():
                        return True

                    if self.l2tpv3_sessions is not None and self.l2tpv3_sessions._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibL2Tp']['meta_info']


            class L2FibG8032(object):
                """
                G8032 information
                
                .. attribute:: l2fib_g8032_rings
                
                	G8032 Ring table
                	**type**\:   :py:class:`L2FibG8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_g8032_rings = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings()
                    self.l2fib_g8032_rings.parent = self


                class L2FibG8032Rings(object):
                    """
                    G8032 Ring table
                    
                    .. attribute:: l2fib_g8032_ring
                    
                    	G8032 Ring
                    	**type**\: list of    :py:class:`L2FibG8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.l2fib_g8032_ring = YList()
                        self.l2fib_g8032_ring.parent = self
                        self.l2fib_g8032_ring.name = 'l2fib_g8032_ring'


                    class L2FibG8032Ring(object):
                        """
                        G8032 Ring
                        
                        .. attribute:: ring_name  <key>
                        
                        	Ring Name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: l2fib_g8032_ring_detail
                        
                        	G8032 Ring detailed information
                        	**type**\:   :py:class:`L2FibG8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail>`
                        
                        .. attribute:: l2fib_g8032_ring_instance_details
                        
                        	G8032 Ring Instance detail table
                        	**type**\:   :py:class:`L2FibG8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails>`
                        
                        .. attribute:: l2fib_g8032_ring_instance_summaries
                        
                        	G8032 Ring Instance summary table
                        	**type**\:   :py:class:`L2FibG8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries>`
                        
                        .. attribute:: l2fib_g8032_ring_summary
                        
                        	G8032 Ring summary information
                        	**type**\:   :py:class:`L2FibG8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ring_name = None
                            self.l2fib_g8032_ring_detail = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail()
                            self.l2fib_g8032_ring_detail.parent = self
                            self.l2fib_g8032_ring_instance_details = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails()
                            self.l2fib_g8032_ring_instance_details.parent = self
                            self.l2fib_g8032_ring_instance_summaries = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries()
                            self.l2fib_g8032_ring_instance_summaries.parent = self
                            self.l2fib_g8032_ring_summary = L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary()
                            self.l2fib_g8032_ring_summary.parent = self


                        class L2FibG8032RingDetail(object):
                            """
                            G8032 Ring detailed information
                            
                            .. attribute:: is_open_ring
                            
                            	Open Ring
                            	**type**\:  bool
                            
                            .. attribute:: monitor0
                            
                            	Monitor port 0
                            	**type**\:  str
                            
                            .. attribute:: monitor1
                            
                            	Monitor port 1
                            	**type**\:  str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_open_ring = None
                                self.monitor0 = None
                                self.monitor1 = None
                                self.port0 = None
                                self.port1 = None
                                self.ring_name = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring-detail'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_open_ring is not None:
                                    return True

                                if self.monitor0 is not None:
                                    return True

                                if self.monitor1 is not None:
                                    return True

                                if self.port0 is not None:
                                    return True

                                if self.port1 is not None:
                                    return True

                                if self.ring_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingDetail']['meta_info']


                        class L2FibG8032RingSummary(object):
                            """
                            G8032 Ring summary information
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.port0 = None
                                self.port1 = None
                                self.ring_name = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring-summary'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.port0 is not None:
                                    return True

                                if self.port1 is not None:
                                    return True

                                if self.ring_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingSummary']['meta_info']


                        class L2FibG8032RingInstanceSummaries(object):
                            """
                            G8032 Ring Instance summary table
                            
                            .. attribute:: l2fib_g8032_ring_instance_summary
                            
                            	G8032 Ring Instance summary information
                            	**type**\: list of    :py:class:`L2FibG8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.l2fib_g8032_ring_instance_summary = YList()
                                self.l2fib_g8032_ring_instance_summary.parent = self
                                self.l2fib_g8032_ring_instance_summary.name = 'l2fib_g8032_ring_instance_summary'


                            class L2FibG8032RingInstanceSummary(object):
                                """
                                G8032 Ring Instance summary information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.instance = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.ring_instance = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.instance is None:
                                        raise YPYModelError('Key property instance is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring-instance-summary[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.instance is not None:
                                        return True

                                    if self.aps_port0 is not None:
                                        return True

                                    if self.aps_port1 is not None:
                                        return True

                                    if self.ring_instance is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries.L2FibG8032RingInstanceSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring-instance-summaries'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.l2fib_g8032_ring_instance_summary is not None:
                                    for child_ref in self.l2fib_g8032_ring_instance_summary:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceSummaries']['meta_info']


                        class L2FibG8032RingInstanceDetails(object):
                            """
                            G8032 Ring Instance detail table
                            
                            .. attribute:: l2fib_g8032_ring_instance_detail
                            
                            	G8032 Ring Instance detailed information
                            	**type**\: list of    :py:class:`L2FibG8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.l2fib_g8032_ring_instance_detail = YList()
                                self.l2fib_g8032_ring_instance_detail.parent = self
                                self.l2fib_g8032_ring_instance_detail.name = 'l2fib_g8032_ring_instance_detail'


                            class L2FibG8032RingInstanceDetail(object):
                                """
                                G8032 Ring Instance detailed information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_channel_level
                                
                                	APS channel level
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port_status0
                                
                                	Status of Port 0
                                	**type**\:   :py:class:`L2FibG8032ApsPortStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibG8032ApsPortStatusEnum>`
                                
                                .. attribute:: aps_port_status1
                                
                                	Status of Port 1
                                	**type**\:   :py:class:`L2FibG8032ApsPortStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibG8032ApsPortStatusEnum>`
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_profile
                                
                                	Ring Profile
                                	**type**\:  str
                                
                                .. attribute:: rpl
                                
                                	RPL
                                	**type**\:   :py:class:`L2FibG8032RplEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibG8032RplEnum>`
                                
                                .. attribute:: vlan_ids
                                
                                	Vlan Ids
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.instance = None
                                    self.aps_channel_level = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.aps_port_status0 = None
                                    self.aps_port_status1 = None
                                    self.ring_instance = None
                                    self.ring_profile = None
                                    self.rpl = None
                                    self.vlan_ids = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.instance is None:
                                        raise YPYModelError('Key property instance is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring-instance-detail[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.instance is not None:
                                        return True

                                    if self.aps_channel_level is not None:
                                        return True

                                    if self.aps_port0 is not None:
                                        return True

                                    if self.aps_port1 is not None:
                                        return True

                                    if self.aps_port_status0 is not None:
                                        return True

                                    if self.aps_port_status1 is not None:
                                        return True

                                    if self.ring_instance is not None:
                                        return True

                                    if self.ring_profile is not None:
                                        return True

                                    if self.rpl is not None:
                                        return True

                                    if self.vlan_ids is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails.L2FibG8032RingInstanceDetail']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring-instance-details'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.l2fib_g8032_ring_instance_detail is not None:
                                    for child_ref in self.l2fib_g8032_ring_instance_detail:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring.L2FibG8032RingInstanceDetails']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.ring_name is None:
                                raise YPYModelError('Key property ring_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-ring[Cisco-IOS-XR-l2vpn-oper:ring-name = ' + str(self.ring_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ring_name is not None:
                                return True

                            if self.l2fib_g8032_ring_detail is not None and self.l2fib_g8032_ring_detail._has_data():
                                return True

                            if self.l2fib_g8032_ring_instance_details is not None and self.l2fib_g8032_ring_instance_details._has_data():
                                return True

                            if self.l2fib_g8032_ring_instance_summaries is not None and self.l2fib_g8032_ring_instance_summaries._has_data():
                                return True

                            if self.l2fib_g8032_ring_summary is not None and self.l2fib_g8032_ring_summary._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings.L2FibG8032Ring']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032-rings'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.l2fib_g8032_ring is not None:
                            for child_ref in self.l2fib_g8032_ring:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032.L2FibG8032Rings']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-g8032'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_g8032_rings is not None and self.l2fib_g8032_rings._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibG8032']['meta_info']


            class L2FibBridgePorts(object):
                """
                Bridge Port forwarding detail
                
                .. attribute:: l2fib_bridge_port
                
                	Specify Bridge Domain Name and XC ID
                	**type**\: list of    :py:class:`L2FibBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_bridge_port = YList()
                    self.l2fib_bridge_port.parent = self
                    self.l2fib_bridge_port.name = 'l2fib_bridge_port'


                class L2FibBridgePort(object):
                    """
                    Specify Bridge Domain Name and XC ID
                    
                    .. attribute:: aging_time_out
                    
                    	Aging timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_port_operational_info
                    
                    	Bridge port operational information
                    	**type**\:   :py:class:`BridgePortOperationalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo>`
                    
                    .. attribute:: flooding_disabled
                    
                    	Is flooding disabled
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: mac_learning_disabled
                    
                    	Is MAC learning disabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_limit
                    
                    	MAC limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                    
                    .. attribute:: mac_port_down_flush_disabled
                    
                    	Is MAC port down flush disabled
                    	**type**\:  bool
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_hw_mac
                    
                    	Number of HW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_sw_mac
                    
                    	Number of SW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment>`
                    
                    .. attribute:: shg_id
                    
                    	Split horizon group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xc_id
                    
                    	xconnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xc_uint_id
                    
                    	XC ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.aging_time_out = None
                        self.bd_name = None
                        self.bridge_id = None
                        self.bridge_port_operational_info = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo()
                        self.bridge_port_operational_info.parent = self
                        self.flooding_disabled = None
                        self.group_name = None
                        self.mac_learning_disabled = None
                        self.mac_limit = None
                        self.mac_limit_action = None
                        self.mac_port_down_flush_disabled = None
                        self.mtu = None
                        self.number_of_hw_mac = None
                        self.number_of_sw_mac = None
                        self.segment = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment()
                        self.segment.parent = self
                        self.shg_id = None
                        self.xc_id = None
                        self.xc_uint_id = None


                    class Segment(object):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn()
                            self.evpn.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\:  bool
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:   :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop>`
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\:  str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.actype = None
                                self.adjacency_address = None
                                self.adjacency_valid = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self.fxc_next_hop_valid = None
                                self.inter_working_mode = None
                                self.interface_handle = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.sub_interface_handle = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.Base']['meta_info']


                            class FxcNextHop(object):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fxc-next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac.FxcNextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.actype is not None:
                                    return True

                                if self.adjacency_address is not None:
                                    return True

                                if self.adjacency_valid is not None:
                                    return True

                                if self.attachment_circuit_id is not None:
                                    return True

                                if self.attachment_circuit_mtu is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.fxc_next_hop is not None and self.fxc_next_hop._has_data():
                                    return True

                                if self.fxc_next_hop_valid is not None:
                                    return True

                                if self.inter_working_mode is not None:
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.ip_inter_working_mac is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.sub_interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:   :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base()
                                self.base.parent = self
                                self.bound = None
                                self.core_pbb_evpn_enabled = None
                                self.forward_class = None
                                self.pbb_union = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion()
                                self.pbb_union.parent = self


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.Base']['meta_info']


                            class PbbUnion(object):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:   :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:   :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:   :py:class:`MgmtL2FibBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self.edge = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self.pbb_type = None


                                class Edge(object):
                                    """
                                    edge
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mac = None
                                        self.mac_configured = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mac is not None:
                                            return True

                                        if self.mac_configured is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Edge']['meta_info']


                                class Core(object):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.vlan_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.vlan_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion.Core']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core is not None and self.core._has_data():
                                        return True

                                    if self.edge is not None and self.edge._has_data():
                                        return True

                                    if self.pbb_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb.PbbUnion']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.core_pbb_evpn_enabled is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.pbb_union is not None and self.pbb_union._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base()
                                self.base.parent = self
                                self.bound = None
                                self.encap = None
                                self.mcastip = None
                                self.parent_if = None
                                self.source_vtep_if = None
                                self.srcip = None
                                self.udp_port = None
                                self.vx_lan_mode = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.any_cast_ip is not None:
                                    return True

                                if self.anycast_mcast_ip is not None:
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.encap is not None:
                                    return True

                                if self.mcastip is not None:
                                    return True

                                if self.parent_if is not None:
                                    return True

                                if self.source_vtep_if is not None:
                                    return True

                                if self.srcip is not None:
                                    return True

                                if self.udp_port is not None:
                                    return True

                                if self.vx_lan_mode is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base()
                                self.base.parent = self
                                self.bound = None
                                self.evi = None
                                self.forward_class = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn.Base']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.evi is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Evpn']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\:  bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\:  bool
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:   :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire>`
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\:  bool
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\:  bool
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:   :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\:  bool
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac_id = None
                                self.active = None
                                self.backup_configured = None
                                self.backup_pseudo_wire = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base()
                                self.base.parent = self
                                self.bound = None
                                self.context = None
                                self.forward_class = None
                                self.global_id = None
                                self.group_id = None
                                self.group_state = None
                                self.grouping_supported = None
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None
                                self.pseudo_wire_id_type = None
                                self.pseudo_wire_union = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self.pw_flow_label_tx = None
                                self.pw_id = None
                                self.pw_load_balance_type = None
                                self.redundancy_role = None
                                self.sequence_resync_threshold = None
                                self.signal_capability_flags = None


                            class Base(object):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.Base']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.NextHop']['meta_info']


                            class PseudoWireUnion(object):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:   :py:class:`L2TpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:   :py:class:`L2Tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2>`
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.data_type = None
                                    self.l2tp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp()
                                    self.l2tp.parent = self
                                    self.l2tp_ipv6_ts = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self.l2tpv2 = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2()
                                    self.l2tpv2.parent = self
                                    self.mpls = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self


                                class Mpls(object):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.Mpls']['meta_info']


                                class L2Tp(object):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local>`
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote>`
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local()
                                        self.local.parent = self
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote()
                                        self.remote.parent = self
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tp']['meta_info']


                                class L2Tpv2(object):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local>`
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local()
                                        self.local.parent = self
                                        self.next_hop_address = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.pw_flags = None
                                        self.rem_udp_port = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote()
                                        self.remote.parent = self
                                        self.source_address = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.xconnect_id = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.session_id = None
                                            self.tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.session_id is not None:
                                                return True

                                            if self.tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv2'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.next_hop_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pw_flags is not None:
                                            return True

                                        if self.rem_udp_port is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2Tpv2']['meta_info']


                                class L2TpIpv6Ts(object):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local>`
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:   :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote>`
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local()
                                        self.local.parent = self
                                        self.local_address = None
                                        self.path_mtu = None
                                        self.remote = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self.remote_address = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None
                                        self.tos_val = None
                                        self.ttl = None


                                    class Local(object):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.secondary_cookie_high_value = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.secondary_cookie_high_value is not None:
                                                return True

                                            if self.secondary_cookie_low_value is not None:
                                                return True

                                            if self.secondary_cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Local']['meta_info']


                                    class Remote(object):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.cookie_high_value = None
                                            self.cookie_low_value = None
                                            self.cookie_size = None
                                            self.session_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.cookie_high_value is not None:
                                                return True

                                            if self.cookie_low_value is not None:
                                                return True

                                            if self.cookie_size is not None:
                                                return True

                                            if self.session_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts.Remote']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-ipv6-ts'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local is not None and self.local._has_data():
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.path_mtu is not None:
                                            return True

                                        if self.remote is not None and self.remote._has_data():
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        if self.tos_val is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion.L2TpIpv6Ts']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire-union'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.data_type is not None:
                                        return True

                                    if self.l2tp is not None and self.l2tp._has_data():
                                        return True

                                    if self.l2tp_ipv6_ts is not None and self.l2tp_ipv6_ts._has_data():
                                        return True

                                    if self.l2tpv2 is not None and self.l2tpv2._has_data():
                                        return True

                                    if self.mpls is not None and self.mpls._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.PseudoWireUnion']['meta_info']


                            class BackupPseudoWire(object):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\:  bool
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\:  bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:   :py:class:`L2FibGroupStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibGroupStateEnum>`
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\:  bool
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:   :py:class:`L2FibPwRedundancyRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwRedundancyRoleEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.atom = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.bound = None
                                    self.group_id = None
                                    self.group_state = None
                                    self.grouping_supported = None
                                    self.pw_flow_label_tx = None
                                    self.redundancy_role = None


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_label is not None:
                                            return True

                                        if self.pw_local_label is not None:
                                            return True

                                        if self.pw_tunnel_interface is not None:
                                            return True

                                        if self.pw_xcid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire.Atom']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-pseudo-wire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.backup_next_hop is not None:
                                        return True

                                    if self.backup_pseudo_wire_id is not None:
                                        return True

                                    if self.backup_pseudo_wire_id_type is not None:
                                        return True

                                    if self.bound is not None:
                                        return True

                                    if self.group_id is not None:
                                        return True

                                    if self.group_state is not None:
                                        return True

                                    if self.grouping_supported is not None:
                                        return True

                                    if self.pw_flow_label_tx is not None:
                                        return True

                                    if self.redundancy_role is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw.BackupPseudoWire']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac_id is not None:
                                    return True

                                if self.active is not None:
                                    return True

                                if self.backup_configured is not None:
                                    return True

                                if self.backup_pseudo_wire is not None and self.backup_pseudo_wire._has_data():
                                    return True

                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.bound is not None:
                                    return True

                                if self.context is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.global_id is not None:
                                    return True

                                if self.group_id is not None:
                                    return True

                                if self.group_state is not None:
                                    return True

                                if self.grouping_supported is not None:
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pseudo_wire_union is not None and self.pseudo_wire_union._has_data():
                                    return True

                                if self.pw_flow_label_tx is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.pw_load_balance_type is not None:
                                    return True

                                if self.redundancy_role is not None:
                                    return True

                                if self.sequence_resync_threshold is not None:
                                    return True

                                if self.signal_capability_flags is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.Segment']['meta_info']


                    class BridgePortOperationalInfo(object):
                        """
                        Bridge port operational information
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: operational_information
                        
                        	L2 operational information
                        	**type**\:   :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast storm control kbps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast storm control pps
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.operational_information = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation()
                            self.operational_information.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None


                        class OperationalInformation(object):
                            """
                            L2 operational information
                            
                            .. attribute:: admin_disabled
                            
                            	Is administratively disabled
                            	**type**\:  bool
                            
                            .. attribute:: bvi_configured
                            
                            	Is BVI Interface configured
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_enabled
                            
                            	Is DHCP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: dhcp_trusted
                            
                            	Is DHCP trusted
                            	**type**\:  bool
                            
                            .. attribute:: feature
                            
                            	Feature information
                            	**type**\: list of    :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature>`
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Is flooding unknown unicast disabled
                            	**type**\:  bool
                            
                            .. attribute:: flooding_disabled
                            
                            	Is flooding disabled
                            	**type**\:  bool
                            
                            .. attribute:: host_routing_enabled
                            
                            	Host Routing enabled on this BD
                            	**type**\:  bool
                            
                            .. attribute:: igmp_flood_forward_enabled
                            
                            	Is IGMP flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: igmp_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_enabled
                            
                            	Is IGMP snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: igmp_snoop_profile_enabled
                            
                            	Is IGMP snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_bvi_up
                            
                            	Is BVI state UP
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                            
                            	Is DAI Destination MAC Validation enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                            
                            	Is DAI IPv4 Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_cw_disable
                            
                            	Is EVPN CW disabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_enabled
                            
                            	Is EVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_evpn_flow_label
                            
                            	Is EVPN Flow Label enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_igmp_snoop_enabled
                            
                            	Is IGMP Snooping admin enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown
                            
                            	Is MAC secure accept shutdown (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_p2mp_pw_enabled
                            
                            	Is P2MP PW enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_pbbevpn_enabled
                            
                            	Is PBBEVPN enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_swmac_learning
                            
                            	Is SW MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vni_enabled
                            
                            	Is VNI enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_vpls_flood_optimization_enabled
                            
                            	Is MMRP  Flood Optimization Enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in minutes
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: minute
                            
                            .. attribute:: mac_aging_type
                            
                            	MAC aging type
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning_disabled
                            
                            	Is MAC learning disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                            
                            .. attribute:: mac_limit_notification_type
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`MgmtL2FibMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitNotifyEnum>`
                            
                            .. attribute:: mac_port_down_flush_disabled
                            
                            	Is MAC port down flush disabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC secure action
                            	**type**\:   :py:class:`MgmtL2FibMacSecActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacSecActionEnum>`
                            
                            .. attribute:: mld_flood_forward_enabled
                            
                            	Is MLD flood forwarding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\:  bool
                            
                            .. attribute:: mld_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_enabled
                            
                            	Is MLD snooping enabled
                            	**type**\:  bool
                            
                            .. attribute:: mld_snoop_profile_enabled
                            
                            	Is MLD snooping profile enabled
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	Multi\-spanning tree instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_macs
                            
                            	numberOfMacs
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                            
                            	nV Satellite Offload IPv4 Multicast Disabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_enabled
                            
                            	Is broadcast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_broadcast_rate_unit
                            
                            	Storm control broadcast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control_multicast_enabled
                            
                            	Is multicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_multicast_rate_unit
                            
                            	Storm control multicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control_unicast_enabled
                            
                            	Is unicast storm control enabled
                            	**type**\:  bool
                            
                            .. attribute:: storm_control_unicast_rate_unit
                            
                            	Storm control unicast rate unit
                            	**type**\:   :py:class:`L2FibStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibStormControlRateUnitEnum>`
                            
                            .. attribute:: stp_participating
                            
                            	Is Spanning Tree Protocol participating
                            	**type**\:  bool
                            
                            .. attribute:: unknown_unicast_flooding_disabled
                            
                            	Unknown Unicast Flooding is disabled
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.admin_disabled = None
                                self.bvi_configured = None
                                self.dhcp_enabled = None
                                self.dhcp_trusted = None
                                self.feature = YList()
                                self.feature.parent = self
                                self.feature.name = 'feature'
                                self.flood_unknown_unicast_enabled = None
                                self.flooding_disabled = None
                                self.host_routing_enabled = None
                                self.igmp_flood_forward_enabled = None
                                self.igmp_mroute_port_enabled = None
                                self.igmp_route_guard_enabled = None
                                self.igmp_snoop_enabled = None
                                self.igmp_snoop_profile_enabled = None
                                self.is_bvi_up = None
                                self.is_dai_addr_validation_destination_mac_enabled = None
                                self.is_dai_addr_validation_ipv4_enabled = None
                                self.is_dai_addr_validation_source_mac_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_evpn_cw_disable = None
                                self.is_evpn_enabled = None
                                self.is_evpn_flow_label = None
                                self.is_igmp_snoop_enabled = None
                                self.is_ipsg_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_mac_secure_accept_shutdown = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.is_p2mp_pw_enabled = None
                                self.is_pbbevpn_enabled = None
                                self.is_swmac_learning = None
                                self.is_vni_enabled = None
                                self.is_vpls_flood_optimization_enabled = None
                                self.mac_aging_time = None
                                self.mac_aging_type = None
                                self.mac_learning_disabled = None
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification_type = None
                                self.mac_port_down_flush_disabled = None
                                self.mac_secure_action = None
                                self.mld_flood_forward_enabled = None
                                self.mld_mroute_port_enabled = None
                                self.mld_route_guard_enabled = None
                                self.mld_snoop_enabled = None
                                self.mld_snoop_profile_enabled = None
                                self.msti = None
                                self.mtu = None
                                self.number_of_macs = None
                                self.nv_satellite_offload_ipv4_multicast_disabled = None
                                self.storm_control_broadcast_enabled = None
                                self.storm_control_broadcast_rate_unit = None
                                self.storm_control_multicast_enabled = None
                                self.storm_control_multicast_rate_unit = None
                                self.storm_control_unicast_enabled = None
                                self.storm_control_unicast_rate_unit = None
                                self.stp_participating = None
                                self.unknown_unicast_flooding_disabled = None


                            class Feature(object):
                                """
                                Feature information
                                
                                .. attribute:: dhcp
                                
                                	dhcp
                                	**type**\:   :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp>`
                                
                                .. attribute:: feature_type
                                
                                	feature type
                                	**type**\:   :py:class:`L2FibFeatureEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibFeatureEnum>`
                                
                                .. attribute:: igmp
                                
                                	igmp
                                	**type**\:   :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp>`
                                
                                .. attribute:: mld
                                
                                	mld
                                	**type**\:   :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dhcp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp()
                                    self.dhcp.parent = self
                                    self.feature_type = None
                                    self.igmp = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp()
                                    self.igmp.parent = self
                                    self.mld = L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld()
                                    self.mld.parent = self


                                class Dhcp(object):
                                    """
                                    dhcp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.profile_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dhcp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.profile_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp']['meta_info']


                                class Igmp(object):
                                    """
                                    igmp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.profile_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:igmp'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.profile_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp']['meta_info']


                                class Mld(object):
                                    """
                                    mld
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.profile_name = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mld'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.profile_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:feature'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dhcp is not None and self.dhcp._has_data():
                                        return True

                                    if self.feature_type is not None:
                                        return True

                                    if self.igmp is not None and self.igmp._has_data():
                                        return True

                                    if self.mld is not None and self.mld._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:operational-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.admin_disabled is not None:
                                    return True

                                if self.bvi_configured is not None:
                                    return True

                                if self.dhcp_enabled is not None:
                                    return True

                                if self.dhcp_trusted is not None:
                                    return True

                                if self.feature is not None:
                                    for child_ref in self.feature:
                                        if child_ref._has_data():
                                            return True

                                if self.flood_unknown_unicast_enabled is not None:
                                    return True

                                if self.flooding_disabled is not None:
                                    return True

                                if self.host_routing_enabled is not None:
                                    return True

                                if self.igmp_flood_forward_enabled is not None:
                                    return True

                                if self.igmp_mroute_port_enabled is not None:
                                    return True

                                if self.igmp_route_guard_enabled is not None:
                                    return True

                                if self.igmp_snoop_enabled is not None:
                                    return True

                                if self.igmp_snoop_profile_enabled is not None:
                                    return True

                                if self.is_bvi_up is not None:
                                    return True

                                if self.is_dai_addr_validation_destination_mac_enabled is not None:
                                    return True

                                if self.is_dai_addr_validation_ipv4_enabled is not None:
                                    return True

                                if self.is_dai_addr_validation_source_mac_enabled is not None:
                                    return True

                                if self.is_dai_enabled is not None:
                                    return True

                                if self.is_dai_logging_enabled is not None:
                                    return True

                                if self.is_evpn_cw_disable is not None:
                                    return True

                                if self.is_evpn_enabled is not None:
                                    return True

                                if self.is_evpn_flow_label is not None:
                                    return True

                                if self.is_igmp_snoop_enabled is not None:
                                    return True

                                if self.is_ipsg_enabled is not None:
                                    return True

                                if self.is_ipsg_logging_enabled is not None:
                                    return True

                                if self.is_mac_secure_accept_shutdown is not None:
                                    return True

                                if self.is_mac_secure_enabled is not None:
                                    return True

                                if self.is_mac_secure_logging_enabled is not None:
                                    return True

                                if self.is_p2mp_pw_enabled is not None:
                                    return True

                                if self.is_pbbevpn_enabled is not None:
                                    return True

                                if self.is_swmac_learning is not None:
                                    return True

                                if self.is_vni_enabled is not None:
                                    return True

                                if self.is_vpls_flood_optimization_enabled is not None:
                                    return True

                                if self.mac_aging_time is not None:
                                    return True

                                if self.mac_aging_type is not None:
                                    return True

                                if self.mac_learning_disabled is not None:
                                    return True

                                if self.mac_limit is not None:
                                    return True

                                if self.mac_limit_action is not None:
                                    return True

                                if self.mac_limit_notification_type is not None:
                                    return True

                                if self.mac_port_down_flush_disabled is not None:
                                    return True

                                if self.mac_secure_action is not None:
                                    return True

                                if self.mld_flood_forward_enabled is not None:
                                    return True

                                if self.mld_mroute_port_enabled is not None:
                                    return True

                                if self.mld_route_guard_enabled is not None:
                                    return True

                                if self.mld_snoop_enabled is not None:
                                    return True

                                if self.mld_snoop_profile_enabled is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.mtu is not None:
                                    return True

                                if self.number_of_macs is not None:
                                    return True

                                if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                    return True

                                if self.storm_control_broadcast_enabled is not None:
                                    return True

                                if self.storm_control_broadcast_rate_unit is not None:
                                    return True

                                if self.storm_control_multicast_enabled is not None:
                                    return True

                                if self.storm_control_multicast_rate_unit is not None:
                                    return True

                                if self.storm_control_unicast_enabled is not None:
                                    return True

                                if self.storm_control_unicast_rate_unit is not None:
                                    return True

                                if self.stp_participating is not None:
                                    return True

                                if self.unknown_unicast_flooding_disabled is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo.OperationalInformation']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-port-operational-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.operational_information is not None and self.operational_information._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort.BridgePortOperationalInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-bridge-port'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.aging_time_out is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.bridge_port_operational_info is not None and self.bridge_port_operational_info._has_data():
                            return True

                        if self.flooding_disabled is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.mac_learning_disabled is not None:
                            return True

                        if self.mac_limit is not None:
                            return True

                        if self.mac_limit_action is not None:
                            return True

                        if self.mac_port_down_flush_disabled is not None:
                            return True

                        if self.mtu is not None:
                            return True

                        if self.number_of_hw_mac is not None:
                            return True

                        if self.number_of_sw_mac is not None:
                            return True

                        if self.segment is not None and self.segment._has_data():
                            return True

                        if self.shg_id is not None:
                            return True

                        if self.xc_id is not None:
                            return True

                        if self.xc_uint_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts.L2FibBridgePort']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-bridge-ports'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_bridge_port is not None:
                        for child_ref in self.l2fib_bridge_port:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgePorts']['meta_info']


            class L2FibmacDetails(object):
                """
                Bridge MAC detail information
                
                .. attribute:: l2fibmac_detail
                
                	MAC Detail information
                	**type**\: list of    :py:class:`L2FibmacDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fibmac_detail = YList()
                    self.l2fibmac_detail.parent = self
                    self.l2fibmac_detail.name = 'l2fibmac_detail'


                class L2FibmacDetail(object):
                    """
                    MAC Detail information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base>`
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\:  bool
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:   :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx>`
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop>`
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:   :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment>`
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base()
                        self.base.parent = self
                        self.bmac_configured = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.evpn_ctx = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self.flag_extension = None
                        self.group_name = None
                        self.l3_encapsulationvlan_id = None
                        self.name = None
                        self.next_hop = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop()
                        self.next_hop.parent = self
                        self.next_hop_valid = None
                        self.node_id = None
                        self.pbb_bmac = None
                        self.peer_vtep_ip = None
                        self.platform_is_hw_learn = None
                        self.segment = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment()
                        self.segment.parent = self
                        self.vni = None
                        self.vni_l3_flag = None


                    class Base(object):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Base']['meta_info']


                    class Segment(object):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:   :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:   :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:   :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.evpn = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn()
                            self.evpn.parent = self
                            self.pbb = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb()
                            self.pbb.parent = self
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw()
                            self.pw.parent = self
                            self.vni = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni()
                            self.vni.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_handle = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Ac']['meta_info']


                        class Pbb(object):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pbb']['meta_info']


                        class Vni(object):
                            """
                            vni
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.parent_if = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.parent_if is not None:
                                    return True

                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Vni']['meta_info']


                        class Evpn(object):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.xcid = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.xcid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Evpn']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self.pw_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.evpn is not None and self.evpn._has_data():
                                return True

                            if self.pbb is not None and self.pbb._has_data():
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            if self.vni is not None and self.vni._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.Segment']['meta_info']


                    class EvpnCtx(object):
                        """
                        Evpn Context
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibBridgeMacEvpnCtxEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibBridgeMacEvpnCtxEnum>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bp_ifh = None
                            self.data_type = None
                            self.esi_id = None
                            self.local_label = None
                            self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self


                        class McastOle(object):
                            """
                            mcast ole
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mcast_label = None
                                self.next_hop_ipv6_addr = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-ole'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mcast_label is not None:
                                    return True

                                if self.next_hop_ipv6_addr is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx.McastOle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-ctx'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bp_ifh is not None:
                                return True

                            if self.data_type is not None:
                                return True

                            if self.esi_id is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.mcast_ole is not None and self.mcast_ole._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.EvpnCtx']['meta_info']


                    class NextHop(object):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base>`
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: plaformt_data_valid
                        
                        	Is Platform Data Valid
                        	**type**\:  bool
                        
                        .. attribute:: platform_data_length
                        
                        	Platform Data Length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base()
                            self.base.parent = self
                            self.children_count = None
                            self.next_hop_address = None
                            self.next_hop_internal_label = None
                            self.plaformt_data_valid = None
                            self.platform_data_length = None


                        class Base(object):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop.Base']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.children_count is not None:
                                return True

                            if self.next_hop_address is not None:
                                return True

                            if self.next_hop_internal_label is not None:
                                return True

                            if self.plaformt_data_valid is not None:
                                return True

                            if self.platform_data_length is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail.NextHop']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibmac-detail'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.base is not None and self.base._has_data():
                            return True

                        if self.bmac_configured is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.evpn_ctx is not None and self.evpn_ctx._has_data():
                            return True

                        if self.flag_extension is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.l3_encapsulationvlan_id is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.next_hop is not None and self.next_hop._has_data():
                            return True

                        if self.next_hop_valid is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.pbb_bmac is not None:
                            return True

                        if self.peer_vtep_ip is not None:
                            return True

                        if self.platform_is_hw_learn is not None:
                            return True

                        if self.segment is not None and self.segment._has_data():
                            return True

                        if self.vni is not None:
                            return True

                        if self.vni_l3_flag is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails.L2FibmacDetail']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fibmac-details'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fibmac_detail is not None:
                        for child_ref in self.l2fibmac_detail:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibmacDetails']['meta_info']


            class L2FibBridgeDomainNames(object):
                """
                Bridge Domain forwarding detail
                
                .. attribute:: l2fib_bridge_domain_name
                
                	Specify Bridge Domain Name
                	**type**\: list of    :py:class:`L2FibBridgeDomainName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_bridge_domain_name = YList()
                    self.l2fib_bridge_domain_name.parent = self
                    self.l2fib_bridge_domain_name.name = 'l2fib_bridge_domain_name'


                class L2FibBridgeDomainName(object):
                    """
                    Specify Bridge Domain Name
                    
                    .. attribute:: admin_disabled
                    
                    	Is administratively disabled
                    	**type**\:  bool
                    
                    .. attribute:: aging_time_out
                    
                    	Aging timeout
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_group_name
                    
                    	Name of the Bridge group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge name
                    	**type**\:  str
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flood_disabled
                    
                    	Is flooding disabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_learning_disabled
                    
                    	Is MAC learning disabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_limit
                    
                    	MAC limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:   :py:class:`MgmtL2FibMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibMacLimitActionEnum>`
                    
                    .. attribute:: mac_port_down_flush_disabled
                    
                    	Is MAC port down flush disabled
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	multi\-spanning tree instance
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: number_of_hwmac
                    
                    	Number of HW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_shg
                    
                    	Number of split horizon groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_swmac
                    
                    	Number of SW MAC addresses
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.admin_disabled = None
                        self.aging_time_out = None
                        self.bd_group_name = None
                        self.bridge_id = None
                        self.bridge_name = None
                        self.bridge_port_count = None
                        self.flood_disabled = None
                        self.mac_learning_disabled = None
                        self.mac_limit = None
                        self.mac_limit_action = None
                        self.mac_port_down_flush_disabled = None
                        self.msti = None
                        self.mtu = None
                        self.name = None
                        self.number_of_hwmac = None
                        self.number_of_shg = None
                        self.number_of_swmac = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-bridge-domain-name'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.admin_disabled is not None:
                            return True

                        if self.aging_time_out is not None:
                            return True

                        if self.bd_group_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.bridge_name is not None:
                            return True

                        if self.bridge_port_count is not None:
                            return True

                        if self.flood_disabled is not None:
                            return True

                        if self.mac_learning_disabled is not None:
                            return True

                        if self.mac_limit is not None:
                            return True

                        if self.mac_limit_action is not None:
                            return True

                        if self.mac_port_down_flush_disabled is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.mtu is not None:
                            return True

                        if self.name is not None:
                            return True

                        if self.number_of_hwmac is not None:
                            return True

                        if self.number_of_shg is not None:
                            return True

                        if self.number_of_swmac is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames.L2FibBridgeDomainName']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-bridge-domain-names'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_bridge_domain_name is not None:
                        for child_ref in self.l2fib_bridge_domain_name:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibBridgeDomainNames']['meta_info']


            class L2FibMroutePorts(object):
                """
                multicast bridge port information 
                
                .. attribute:: l2fib_mroute_port
                
                	Multicast Port Information
                	**type**\: list of    :py:class:`L2FibMroutePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mroute_port = YList()
                    self.l2fib_mroute_port.parent = self
                    self.l2fib_mroute_port.name = 'l2fib_mroute_port'


                class L2FibMroutePort(object):
                    """
                    Multicast Port Information
                    
                    .. attribute:: ac_interface_handle
                    
                    	AC If handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`BaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation>`
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_id
                    
                    	Bridge Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: csfl
                    
                    	Csfl Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_ole_master
                    
                    	Ole Master
                    	**type**\:  bool
                    
                    .. attribute:: is_ole_offloaded
                    
                    	Ole Offloaded
                    	**type**\:  bool
                    
                    .. attribute:: is_topo_hub_and_spoke
                    
                    	Topo HubAndSpoke
                    	**type**\:  bool
                    
                    .. attribute:: isid
                    
                    	Isid Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: leaf_pointer
                    
                    	Leaf Ptr
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_address
                    
                    	NHOP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\:  str
                    
                    	**length:** 0..40
                    
                    .. attribute:: sat_id
                    
                    	Sat Id
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: source
                    
                    	Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix>`
                    
                    .. attribute:: xcid
                    
                    	XConnect ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac_interface_handle = None
                        self.base_information = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation()
                        self.base_information.parent = self
                        self.bd_name = None
                        self.bridge_id = None
                        self.csfl = None
                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats()
                        self.forward_stats.parent = self
                        self.group = None
                        self.is_ole_master = None
                        self.is_ole_offloaded = None
                        self.is_topo_hub_and_spoke = None
                        self.isid = None
                        self.leaf_pointer = None
                        self.next_hop_address = None
                        self.pw_id = None
                        self.sat_id = None
                        self.source = None
                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix()
                        self.source_prefix.parent = self
                        self.xcid = None


                    class BaseInformation(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.BaseInformation']['meta_info']


                    class ForwardStats(object):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self


                        class ForwardStat(object):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsDataEnum>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self


                            class Mulicast(object):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self


                                class MulticastForwardStat(object):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat']['meta_info']


                                class ReceivedStat(object):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat']['meta_info']


                                class Punt(object):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:punt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt']['meta_info']


                                class Drop(object):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop']['meta_info']


                                class MulticastCoreForwardStat(object):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-core-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat']['meta_info']


                                class CoreReceivedStat(object):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core-received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mulicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_received_stat is not None and self.core_received_stat._has_data():
                                        return True

                                    if self.drop is not None and self.drop._has_data():
                                        return True

                                    if self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat._has_data():
                                        return True

                                    if self.multicast_forward_stat is not None and self.multicast_forward_stat._has_data():
                                        return True

                                    if self.punt is not None and self.punt._has_data():
                                        return True

                                    if self.received_stat is not None and self.received_stat._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat.Mulicast']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stat'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.mulicast is not None and self.mulicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats.ForwardStat']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.forward_stat is not None and self.forward_stat._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.ForwardStats']['meta_info']


                    class SourcePrefix(object):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:source-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.SourcePrefix']['meta_info']


                    class DestinationPrefix(object):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:destination-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort.DestinationPrefix']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute-port'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac_interface_handle is not None:
                            return True

                        if self.base_information is not None and self.base_information._has_data():
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.csfl is not None:
                            return True

                        if self.destination_prefix is not None and self.destination_prefix._has_data():
                            return True

                        if self.forward_stats is not None and self.forward_stats._has_data():
                            return True

                        if self.group is not None:
                            return True

                        if self.is_ole_master is not None:
                            return True

                        if self.is_ole_offloaded is not None:
                            return True

                        if self.is_topo_hub_and_spoke is not None:
                            return True

                        if self.isid is not None:
                            return True

                        if self.leaf_pointer is not None:
                            return True

                        if self.next_hop_address is not None:
                            return True

                        if self.pw_id is not None:
                            return True

                        if self.sat_id is not None:
                            return True

                        if self.source is not None:
                            return True

                        if self.source_prefix is not None and self.source_prefix._has_data():
                            return True

                        if self.xcid is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts.L2FibMroutePort']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mroute-ports'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mroute_port is not None:
                        for child_ref in self.l2fib_mroute_port:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMroutePorts']['meta_info']


            class L2FibSummary(object):
                """
                L2FIB Summary information
                
                .. attribute:: bridge_domain_summary
                
                	Bridge\-domain summary info
                	**type**\:   :py:class:`BridgeDomainSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary>`
                
                .. attribute:: evpn_summary
                
                	evpn summary info
                	**type**\:   :py:class:`EvpnSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary>`
                
                .. attribute:: global_cfg
                
                	Global configuration
                	**type**\:   :py:class:`GlobalCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg>`
                
                .. attribute:: l2tp_disposition_summary
                
                	L2TP disposition object summary
                	**type**\:   :py:class:`L2TpDispositionSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary>`
                
                .. attribute:: mac_summary
                
                	mac summary info
                	**type**\:   :py:class:`MacSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary>`
                
                .. attribute:: next_hop_summary
                
                	nhop db summry info
                	**type**\:   :py:class:`NextHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary>`
                
                .. attribute:: ptree_summary
                
                	P2MP PTree summary info
                	**type**\:   :py:class:`PtreeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary>`
                
                .. attribute:: pw_group_summary
                
                	PWGroup summary info
                	**type**\:   :py:class:`PwGroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary>`
                
                .. attribute:: pwhe_mp_summary
                
                	PWHE Main\-port summary info
                	**type**\:   :py:class:`PwheMpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary>`
                
                .. attribute:: queue_summary
                
                	queue summary info
                	**type**\:   :py:class:`QueueSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary>`
                
                .. attribute:: xconnect_summary
                
                	xconnect db summary info
                	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_domain_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary()
                    self.bridge_domain_summary.parent = self
                    self.evpn_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary()
                    self.evpn_summary.parent = self
                    self.global_cfg = L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg()
                    self.global_cfg.parent = self
                    self.l2tp_disposition_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary()
                    self.l2tp_disposition_summary.parent = self
                    self.mac_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary()
                    self.mac_summary.parent = self
                    self.next_hop_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary()
                    self.next_hop_summary.parent = self
                    self.ptree_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary()
                    self.ptree_summary.parent = self
                    self.pw_group_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary()
                    self.pw_group_summary.parent = self
                    self.pwhe_mp_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary()
                    self.pwhe_mp_summary.parent = self
                    self.queue_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary()
                    self.queue_summary.parent = self
                    self.xconnect_summary = L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary()
                    self.xconnect_summary.parent = self


                class XconnectSummary(object):
                    """
                    xconnect db summary info
                    
                    .. attribute:: ac_down_count_aib
                    
                    	number of down acs with reason aib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_l2vpn
                    
                    	number of down acs with reason l2vpn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_l3fib
                    
                    	number of down acs with reason fib
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_vpdn
                    
                    	number of down acs with reason vpdn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_ac_count
                    
                    	number of ac\->ac entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_bp_count
                    
                    	number of ac\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tp
                    
                    	number of ac\->pw\-l2tp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tp_ip_v6
                    
                    	number of ac\->pw\-l2tp\-ipv6 entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tpv2
                    
                    	number of ac\->pw\-l2tpv2 entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_mpls
                    
                    	number of ac\->pw\-mpls entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_unknown_count
                    
                    	number of ac\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bp_count
                    
                    	number of bridge\-port xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle_ac_max_exceeded_drop_cnt
                    
                    	number of xc updates dropped due to max Bundle ACs exceeded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to EVPN invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_to_bp_count
                    
                    	number of evpn\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_to_unknown_count
                    
                    	number of evpn\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mon_sess_to_pw_count
                    
                    	number of monitor\_session\->pw entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mon_sess_to_unknown_count
                    
                    	number of monitor\_session\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2p_count
                    
                    	number of p2p xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to PBB invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_to_bp_count
                    
                    	number of pbb\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_to_unknown_count
                    
                    	number of pbb\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_to_bp_count
                    
                    	number of pw\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_to_unknown_count
                    
                    	number of pw\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pwhe_l2_if_count
                    
                    	number of PWHE L2IF xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_ac_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to Virtual AC invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VNI invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_to_bp_count
                    
                    	number of vni\->bp entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_to_unknown_count
                    
                    	number of vni\->unknown type entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpls_pw_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VPLS PW invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpls_pw_max_exceeded_drop_cnt
                    
                    	number of xc updates dropped due to max VPLS PWs exceeded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpws_pw_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VPWS PW invalid xid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_count
                    
                    	total number of entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_down_count
                    
                    	number of down entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_up_count
                    
                    	number of up entries
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac_down_count_aib = None
                        self.ac_down_count_l2vpn = None
                        self.ac_down_count_l3fib = None
                        self.ac_down_count_vpdn = None
                        self.ac_to_ac_count = None
                        self.ac_to_bp_count = None
                        self.ac_to_pw_count_l2tp = None
                        self.ac_to_pw_count_l2tp_ip_v6 = None
                        self.ac_to_pw_count_l2tpv2 = None
                        self.ac_to_pw_count_mpls = None
                        self.ac_to_unknown_count = None
                        self.bp_count = None
                        self.bundle_ac_max_exceeded_drop_cnt = None
                        self.evpn_invalid_xid_drop_count = None
                        self.evpn_to_bp_count = None
                        self.evpn_to_unknown_count = None
                        self.mon_sess_to_pw_count = None
                        self.mon_sess_to_unknown_count = None
                        self.p2p_count = None
                        self.pbb_invalid_xid_drop_count = None
                        self.pbb_to_bp_count = None
                        self.pbb_to_unknown_count = None
                        self.pw_to_bp_count = None
                        self.pw_to_unknown_count = None
                        self.pwhe_l2_if_count = None
                        self.virtual_ac_invalid_xid_drop_count = None
                        self.vni_invalid_xid_drop_count = None
                        self.vni_to_bp_count = None
                        self.vni_to_unknown_count = None
                        self.vpls_pw_invalid_xid_drop_count = None
                        self.vpls_pw_max_exceeded_drop_cnt = None
                        self.vpws_pw_invalid_xid_drop_count = None
                        self.xconnect_count = None
                        self.xconnect_down_count = None
                        self.xconnect_up_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac_down_count_aib is not None:
                            return True

                        if self.ac_down_count_l2vpn is not None:
                            return True

                        if self.ac_down_count_l3fib is not None:
                            return True

                        if self.ac_down_count_vpdn is not None:
                            return True

                        if self.ac_to_ac_count is not None:
                            return True

                        if self.ac_to_bp_count is not None:
                            return True

                        if self.ac_to_pw_count_l2tp is not None:
                            return True

                        if self.ac_to_pw_count_l2tp_ip_v6 is not None:
                            return True

                        if self.ac_to_pw_count_l2tpv2 is not None:
                            return True

                        if self.ac_to_pw_count_mpls is not None:
                            return True

                        if self.ac_to_unknown_count is not None:
                            return True

                        if self.bp_count is not None:
                            return True

                        if self.bundle_ac_max_exceeded_drop_cnt is not None:
                            return True

                        if self.evpn_invalid_xid_drop_count is not None:
                            return True

                        if self.evpn_to_bp_count is not None:
                            return True

                        if self.evpn_to_unknown_count is not None:
                            return True

                        if self.mon_sess_to_pw_count is not None:
                            return True

                        if self.mon_sess_to_unknown_count is not None:
                            return True

                        if self.p2p_count is not None:
                            return True

                        if self.pbb_invalid_xid_drop_count is not None:
                            return True

                        if self.pbb_to_bp_count is not None:
                            return True

                        if self.pbb_to_unknown_count is not None:
                            return True

                        if self.pw_to_bp_count is not None:
                            return True

                        if self.pw_to_unknown_count is not None:
                            return True

                        if self.pwhe_l2_if_count is not None:
                            return True

                        if self.virtual_ac_invalid_xid_drop_count is not None:
                            return True

                        if self.vni_invalid_xid_drop_count is not None:
                            return True

                        if self.vni_to_bp_count is not None:
                            return True

                        if self.vni_to_unknown_count is not None:
                            return True

                        if self.vpls_pw_invalid_xid_drop_count is not None:
                            return True

                        if self.vpls_pw_max_exceeded_drop_cnt is not None:
                            return True

                        if self.vpws_pw_invalid_xid_drop_count is not None:
                            return True

                        if self.xconnect_count is not None:
                            return True

                        if self.xconnect_down_count is not None:
                            return True

                        if self.xconnect_up_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.XconnectSummary']['meta_info']


                class NextHopSummary(object):
                    """
                    nhop db summry info
                    
                    .. attribute:: l2tp
                    
                    	L2TP nexthop summary
                    	**type**\:   :py:class:`L2Tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp>`
                    
                    .. attribute:: lsm
                    
                    	LSM nexthop summary
                    	**type**\:   :py:class:`Lsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm>`
                    
                    .. attribute:: mpls
                    
                    	MPLS nexthop summary
                    	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls>`
                    
                    .. attribute:: mpls_il
                    
                    	MPLS Internal Label nexthop summary
                    	**type**\:   :py:class:`MplsIl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl>`
                    
                    .. attribute:: p2mp_tunnels
                    
                    	P2MPtun nexthop summary
                    	**type**\:   :py:class:`P2MpTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.l2tp = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp()
                        self.l2tp.parent = self
                        self.lsm = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm()
                        self.lsm.parent = self
                        self.mpls = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls()
                        self.mpls.parent = self
                        self.mpls_il = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl()
                        self.mpls_il.parent = self
                        self.p2mp_tunnels = L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels()
                        self.p2mp_tunnels.parent = self


                    class MplsIl(object):
                        """
                        MPLS Internal Label nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bound_next_hop_count = None
                            self.next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self.unbound_next_hop_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls-il'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bound_next_hop_count is not None:
                                return True

                            if self.next_hop_count is not None:
                                return True

                            if self.next_hop_pending_registration_count is not None:
                                return True

                            if self.unbound_next_hop_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.MplsIl']['meta_info']


                    class Mpls(object):
                        """
                        MPLS nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bound_next_hop_count = None
                            self.next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self.unbound_next_hop_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mpls'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bound_next_hop_count is not None:
                                return True

                            if self.next_hop_count is not None:
                                return True

                            if self.next_hop_pending_registration_count is not None:
                                return True

                            if self.unbound_next_hop_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Mpls']['meta_info']


                    class L2Tp(object):
                        """
                        L2TP nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bound_next_hop_count = None
                            self.next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self.unbound_next_hop_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bound_next_hop_count is not None:
                                return True

                            if self.next_hop_count is not None:
                                return True

                            if self.next_hop_pending_registration_count is not None:
                                return True

                            if self.unbound_next_hop_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.L2Tp']['meta_info']


                    class Lsm(object):
                        """
                        LSM nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bound_next_hop_count = None
                            self.next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self.unbound_next_hop_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:lsm'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bound_next_hop_count is not None:
                                return True

                            if self.next_hop_count is not None:
                                return True

                            if self.next_hop_pending_registration_count is not None:
                                return True

                            if self.unbound_next_hop_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.Lsm']['meta_info']


                    class P2MpTunnels(object):
                        """
                        P2MPtun nexthop summary
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bound_next_hop_count = None
                            self.next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self.unbound_next_hop_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-tunnels'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bound_next_hop_count is not None:
                                return True

                            if self.next_hop_count is not None:
                                return True

                            if self.next_hop_pending_registration_count is not None:
                                return True

                            if self.unbound_next_hop_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary.P2MpTunnels']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.l2tp is not None and self.l2tp._has_data():
                            return True

                        if self.lsm is not None and self.lsm._has_data():
                            return True

                        if self.mpls is not None and self.mpls._has_data():
                            return True

                        if self.mpls_il is not None and self.mpls_il._has_data():
                            return True

                        if self.p2mp_tunnels is not None and self.p2mp_tunnels._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.NextHopSummary']['meta_info']


                class L2TpDispositionSummary(object):
                    """
                    L2TP disposition object summary
                    
                    .. attribute:: bound_l2tp_disposition_session_count
                    
                    	number of bound l2tp dispostion objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: l2tp_disposition_session_count
                    
                    	number of l2tp disposition session objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unbound_l2tp_disposition_session_count
                    
                    	number of unbound l2tp disposition objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bound_l2tp_disposition_session_count = None
                        self.l2tp_disposition_session_count = None
                        self.unbound_l2tp_disposition_session_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tp-disposition-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bound_l2tp_disposition_session_count is not None:
                            return True

                        if self.l2tp_disposition_session_count is not None:
                            return True

                        if self.unbound_l2tp_disposition_session_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.L2TpDispositionSummary']['meta_info']


                class BridgeDomainSummary(object):
                    """
                    Bridge\-domain summary info
                    
                    .. attribute:: bridge_domain_count
                    
                    	Number of bridge\-domains
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_drop_count
                    
                    	Number of bridge\-domain updates dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_bvi_count
                    
                    	Number of bridge\-domains with BVI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_evpn_enabled
                    
                    	Number of bridge\-domains with EVPN enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_p2mp_enabled
                    
                    	Number of bridge\-domains with P2MP enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_pbbevpn_enabled
                    
                    	Number of bridge\-domains with PBB EVPN enabled
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_domain_count = None
                        self.bridge_domain_drop_count = None
                        self.bridge_domain_with_bvi_count = None
                        self.bridge_domain_with_evpn_enabled = None
                        self.bridge_domain_with_p2mp_enabled = None
                        self.bridge_domain_with_pbbevpn_enabled = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-domain-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_domain_count is not None:
                            return True

                        if self.bridge_domain_drop_count is not None:
                            return True

                        if self.bridge_domain_with_bvi_count is not None:
                            return True

                        if self.bridge_domain_with_evpn_enabled is not None:
                            return True

                        if self.bridge_domain_with_p2mp_enabled is not None:
                            return True

                        if self.bridge_domain_with_pbbevpn_enabled is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.BridgeDomainSummary']['meta_info']


                class MacSummary(object):
                    """
                    mac summary info
                    
                    .. attribute:: bmac_count
                    
                    	number of BMACs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: local_mac_count
                    
                    	number of locally learnt macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_count
                    
                    	number of all macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_mac_count
                    
                    	number of remotely learned macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routed_mac_count
                    
                    	number of routed macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sbmac_count
                    
                    	number of Source BMACs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: static_mac_count
                    
                    	number of static macs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bmac_count = None
                        self.local_mac_count = None
                        self.mac_count = None
                        self.remote_mac_count = None
                        self.routed_mac_count = None
                        self.sbmac_count = None
                        self.static_mac_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bmac_count is not None:
                            return True

                        if self.local_mac_count is not None:
                            return True

                        if self.mac_count is not None:
                            return True

                        if self.remote_mac_count is not None:
                            return True

                        if self.routed_mac_count is not None:
                            return True

                        if self.sbmac_count is not None:
                            return True

                        if self.static_mac_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.MacSummary']['meta_info']


                class QueueSummary(object):
                    """
                    queue summary info
                    
                    .. attribute:: del_cnt
                    
                    	number of objects in delete queues
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: inline_cnt
                    
                    	number of objects in inline queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: retry_cnt
                    
                    	number of objects in retry queue
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_cnt
                    
                    	number of objects in update queues
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.del_cnt = None
                        self.inline_cnt = None
                        self.retry_cnt = None
                        self.update_cnt = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:queue-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.del_cnt is not None:
                            return True

                        if self.inline_cnt is not None:
                            return True

                        if self.retry_cnt is not None:
                            return True

                        if self.update_cnt is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.QueueSummary']['meta_info']


                class EvpnSummary(object):
                    """
                    evpn summary info
                    
                    .. attribute:: default_count
                    
                    	Number of default leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: isid_count
                    
                    	Number of ISID leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_count
                    
                    	Number of EVPN Multicast Replication lists
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.default_count = None
                        self.isid_count = None
                        self.total_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.default_count is not None:
                            return True

                        if self.isid_count is not None:
                            return True

                        if self.total_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.EvpnSummary']['meta_info']


                class GlobalCfg(object):
                    """
                    Global configuration
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base>`
                    
                    .. attribute:: evpn_imc_label_block_base
                    
                    	Base of label range in use for EVPN IMC PD
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_imc_label_block_size
                    
                    	Size of label range in use for EVPN IMC PD
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: load_balance_type
                    
                    	Type of Load\-Balancing
                    	**type**\:   :py:class:`L2FibLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibLoadBalEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.base = L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base()
                        self.base.parent = self
                        self.evpn_imc_label_block_base = None
                        self.evpn_imc_label_block_size = None
                        self.load_balance_type = None


                    class Base(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg.Base']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:global-cfg'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.base is not None and self.base._has_data():
                            return True

                        if self.evpn_imc_label_block_base is not None:
                            return True

                        if self.evpn_imc_label_block_size is not None:
                            return True

                        if self.load_balance_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.GlobalCfg']['meta_info']


                class PtreeSummary(object):
                    """
                    P2MP PTree summary info
                    
                    .. attribute:: lmrib_mldp_ptree_count
                    
                    	Number of MLDP PTree Objects owned by LMRIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lmrib_rsvp_te_ptree_count
                    
                    	Number of RSVP\-TE PTree Objects owned by LMRIB
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_enabled_ptree_count
                    
                    	Number of MLDP enabled PTree objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_enabled_ptree_count
                    
                    	Number of RSVP\-TE enabled PTree objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_ptree_count
                    
                    	Number of PTree objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lmrib_mldp_ptree_count = None
                        self.lmrib_rsvp_te_ptree_count = None
                        self.mldp_enabled_ptree_count = None
                        self.rsvp_te_enabled_ptree_count = None
                        self.total_ptree_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ptree-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lmrib_mldp_ptree_count is not None:
                            return True

                        if self.lmrib_rsvp_te_ptree_count is not None:
                            return True

                        if self.mldp_enabled_ptree_count is not None:
                            return True

                        if self.rsvp_te_enabled_ptree_count is not None:
                            return True

                        if self.total_ptree_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.PtreeSummary']['meta_info']


                class PwGroupSummary(object):
                    """
                    PWGroup summary info
                    
                    .. attribute:: plat_grouping_supported
                    
                    	Platform supports Grouping
                    	**type**\:  bool
                    
                    .. attribute:: pw_groups_down
                    
                    	Number of PWGROUP objects down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_pw_groups
                    
                    	Total number of PWGROUP objects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.plat_grouping_supported = None
                        self.pw_groups_down = None
                        self.total_pw_groups = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw-group-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.plat_grouping_supported is not None:
                            return True

                        if self.pw_groups_down is not None:
                            return True

                        if self.total_pw_groups is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.PwGroupSummary']['meta_info']


                class PwheMpSummary(object):
                    """
                    PWHE Main\-port summary info
                    
                    .. attribute:: total_count
                    
                    	Number of PWHE Main\-ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.total_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pwhe-mp-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.total_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary.PwheMpSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_domain_summary is not None and self.bridge_domain_summary._has_data():
                        return True

                    if self.evpn_summary is not None and self.evpn_summary._has_data():
                        return True

                    if self.global_cfg is not None and self.global_cfg._has_data():
                        return True

                    if self.l2tp_disposition_summary is not None and self.l2tp_disposition_summary._has_data():
                        return True

                    if self.mac_summary is not None and self.mac_summary._has_data():
                        return True

                    if self.next_hop_summary is not None and self.next_hop_summary._has_data():
                        return True

                    if self.ptree_summary is not None and self.ptree_summary._has_data():
                        return True

                    if self.pw_group_summary is not None and self.pw_group_summary._has_data():
                        return True

                    if self.pwhe_mp_summary is not None and self.pwhe_mp_summary._has_data():
                        return True

                    if self.queue_summary is not None and self.queue_summary._has_data():
                        return True

                    if self.xconnect_summary is not None and self.xconnect_summary._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibSummary']['meta_info']


            class L2FibNvePeers(object):
                """
                NVE Peer Table
                
                .. attribute:: l2fib_nve_peer
                
                	The attributes for a particular NVE Peer
                	**type**\: list of    :py:class:`L2FibNvePeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_nve_peer = YList()
                    self.l2fib_nve_peer.parent = self
                    self.l2fib_nve_peer.name = 'l2fib_nve_peer'


                class L2FibNvePeer(object):
                    """
                    The attributes for a particular NVE Peer
                    
                    .. attribute:: nve_if
                    
                    	Parent NVE IF Handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: vn_iid
                    
                    	VNI ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vniid
                    
                    	VNI ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: vte_pip
                    
                    	Peer VTEP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vtep_address
                    
                    	VTEP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: xc_uint_id
                    
                    	XC ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.nve_if = None
                        self.vn_iid = None
                        self.vniid = None
                        self.vte_pip = None
                        self.vtep_address = None
                        self.xc_uint_id = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-nve-peer'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.nve_if is not None:
                            return True

                        if self.vn_iid is not None:
                            return True

                        if self.vniid is not None:
                            return True

                        if self.vte_pip is not None:
                            return True

                        if self.vtep_address is not None:
                            return True

                        if self.xc_uint_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibNvePeers.L2FibNvePeer']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-nve-peers'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_nve_peer is not None:
                        for child_ref in self.l2fib_nve_peer:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibNvePeers']['meta_info']


            class L2FibMmrps(object):
                """
                mmmrp information
                
                .. attribute:: l2fib_mmrp
                
                	Bridge Domain Mmrp Information
                	**type**\: list of    :py:class:`L2FibMmrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_mmrp = YList()
                    self.l2fib_mmrp.parent = self
                    self.l2fib_mmrp.name = 'l2fib_mmrp'


                class L2FibMmrp(object):
                    """
                    Bridge Domain Mmrp Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\:  str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:   :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:   :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats>`
                    
                    .. attribute:: group
                    
                    	Group Mac Address
                    	**type**\:  str
                    
                    	**length:** 1..15
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:   :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo>`
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:   :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation>`
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\:  str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: source
                    
                    	src Mac Address
                    	**type**\:  str
                    
                    	**length:** 1..15
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:   :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix>`
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.destination_prefix = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self.forward_stats = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats()
                        self.forward_stats.parent = self
                        self.group = None
                        self.hardware_information = None
                        self.irb_info = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo()
                        self.irb_info.parent = self
                        self.multicast_base_information = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self.platform_data = None
                        self.platform_data_length = None
                        self.source = None
                        self.source_prefix = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix()
                        self.source_prefix.parent = self
                        self.xid_count = None


                    class MulticastBaseInformation(object):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-base-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.MulticastBaseInformation']['meta_info']


                    class SourcePrefix(object):
                        """
                        Source Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:source-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.SourcePrefix']['meta_info']


                    class DestinationPrefix(object):
                        """
                        Destination Prefix
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\:  str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.prefix = None
                            self.prefix_length = None
                            self.proto = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:destination-prefix'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.prefix is not None:
                                return True

                            if self.prefix_length is not None:
                                return True

                            if self.proto is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.DestinationPrefix']['meta_info']


                    class ForwardStats(object):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:   :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self


                        class ForwardStat(object):
                            """
                            fwd stats
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:   :py:class:`MgmtL2FibStatsDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibStatsDataEnum>`
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:   :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.data_type = None
                                self.mulicast = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self


                            class Mulicast(object):
                                """
                                mulicast
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:   :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:   :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:   :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:   :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:   :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:   :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_received_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self.drop = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self.multicast_core_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self.multicast_forward_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self.punt = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self.received_stat = L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self


                                class MulticastForwardStat(object):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat']['meta_info']


                                class ReceivedStat(object):
                                    """
                                    received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat']['meta_info']


                                class Punt(object):
                                    """
                                    punted stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:punt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Punt']['meta_info']


                                class Drop(object):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.Drop']['meta_info']


                                class MulticastCoreForwardStat(object):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-core-forward-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat']['meta_info']


                                class CoreReceivedStat(object):
                                    """
                                    core received stats
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bytes = None
                                        self.packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core-received-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bytes is not None:
                                            return True

                                        if self.packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mulicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_received_stat is not None and self.core_received_stat._has_data():
                                        return True

                                    if self.drop is not None and self.drop._has_data():
                                        return True

                                    if self.multicast_core_forward_stat is not None and self.multicast_core_forward_stat._has_data():
                                        return True

                                    if self.multicast_forward_stat is not None and self.multicast_forward_stat._has_data():
                                        return True

                                    if self.punt is not None and self.punt._has_data():
                                        return True

                                    if self.received_stat is not None and self.received_stat._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat.Mulicast']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stat'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.data_type is not None:
                                    return True

                                if self.mulicast is not None and self.mulicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats.ForwardStat']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:forward-stats'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.forward_stat is not None and self.forward_stat._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.ForwardStats']['meta_info']


                    class IrbInfo(object):
                        """
                        IRB Information
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.irb_plat_data = YLeafList()
                            self.irb_plat_data.parent = self
                            self.irb_plat_data.name = 'irb_plat_data'
                            self.irb_plat_data_len = None
                            self.mxid_ac_interface_handle = None
                            self.mxid_next_hop_address = None
                            self.mxid_pw_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:irb-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.irb_plat_data is not None:
                                for child in self.irb_plat_data:
                                    if child is not None:
                                        return True

                            if self.irb_plat_data_len is not None:
                                return True

                            if self.mxid_ac_interface_handle is not None:
                                return True

                            if self.mxid_next_hop_address is not None:
                                return True

                            if self.mxid_pw_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp.IrbInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mmrp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_group_name is not None:
                            return True

                        if self.bd_name is not None:
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        if self.bridge_id is not None:
                            return True

                        if self.destination_prefix is not None and self.destination_prefix._has_data():
                            return True

                        if self.forward_stats is not None and self.forward_stats._has_data():
                            return True

                        if self.group is not None:
                            return True

                        if self.hardware_information is not None:
                            return True

                        if self.irb_info is not None and self.irb_info._has_data():
                            return True

                        if self.multicast_base_information is not None and self.multicast_base_information._has_data():
                            return True

                        if self.platform_data is not None:
                            return True

                        if self.platform_data_length is not None:
                            return True

                        if self.source is not None:
                            return True

                        if self.source_prefix is not None and self.source_prefix._has_data():
                            return True

                        if self.xid_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps.L2FibMmrp']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-mmrps'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_mmrp is not None:
                        for child_ref in self.l2fib_mmrp:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibMmrps']['meta_info']


            class L2FibEvpnIp6Macs(object):
                """
                EVPN IPv6\-MAC Table
                
                .. attribute:: l2fib_evpn_ip6mac
                
                	The attributes for a particular EVPN IPv6\-MAC Entry
                	**type**\: list of    :py:class:`L2FibEvpnIp6Mac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_evpn_ip6mac = YList()
                    self.l2fib_evpn_ip6mac.parent = self
                    self.l2fib_evpn_ip6mac.name = 'l2fib_evpn_ip6mac'


                class L2FibEvpnIp6Mac(object):
                    """
                    The attributes for a particular EVPN IPv6\-MAC
                    Entry
                    
                    .. attribute:: arp_nd_delete_pending
                    
                    	Delete to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_probe_pending
                    
                    	Probe to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: arp_nd_sync_pending
                    
                    	Sync to ARP/ND Process Pending
                    	**type**\:  bool
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: bdid_xr
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_address
                    
                    	IP Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: ip_address_xr
                    
                    	IP Address
                    	**type**\:   :py:class:`IpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr>`
                    
                    .. attribute:: is_local
                    
                    	Entry is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: is_local_xr
                    
                    	IP\-MAC Route is locally learned
                    	**type**\:  bool
                    
                    .. attribute:: mac_address
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: mac_address_xr
                    
                    	MAC Address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.arp_nd_delete_pending = None
                        self.arp_nd_probe_pending = None
                        self.arp_nd_sync_pending = None
                        self.bdid = None
                        self.bdid_xr = None
                        self.ip_address = None
                        self.ip_address_xr = L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr()
                        self.ip_address_xr.parent = self
                        self.is_local = None
                        self.is_local_xr = None
                        self.mac_address = None
                        self.mac_address_xr = None


                    class IpAddressXr(object):
                        """
                        IP Address
                        
                        .. attribute:: addr_type
                        
                        	addr type
                        	**type**\:   :py:class:`L2FibIpAddrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibIpAddrEnum>`
                        
                        .. attribute:: ip
                        
                        	ip
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.addr_type = None
                            self.ip = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ip-address-xr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.addr_type is not None:
                                return True

                            if self.ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac.IpAddressXr']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-ip6mac'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.arp_nd_delete_pending is not None:
                            return True

                        if self.arp_nd_probe_pending is not None:
                            return True

                        if self.arp_nd_sync_pending is not None:
                            return True

                        if self.bdid is not None:
                            return True

                        if self.bdid_xr is not None:
                            return True

                        if self.ip_address is not None:
                            return True

                        if self.ip_address_xr is not None and self.ip_address_xr._has_data():
                            return True

                        if self.is_local is not None:
                            return True

                        if self.is_local_xr is not None:
                            return True

                        if self.mac_address is not None:
                            return True

                        if self.mac_address_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs.L2FibEvpnIp6Mac']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-ip6macs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_evpn_ip6mac is not None:
                        for child_ref in self.l2fib_evpn_ip6mac:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnIp6Macs']['meta_info']


            class L2FibDhcpBindingSummaries(object):
                """
                DHCP binding forwarding summary
                
                .. attribute:: l2fib_dhcp_binding_summary
                
                	Specify DHCP binding summary
                	**type**\: list of    :py:class:`L2FibDhcpBindingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_dhcp_binding_summary = YList()
                    self.l2fib_dhcp_binding_summary.parent = self
                    self.l2fib_dhcp_binding_summary.name = 'l2fib_dhcp_binding_summary'


                class L2FibDhcpBindingSummary(object):
                    """
                    Specify DHCP binding summary
                    
                    .. attribute:: xcid  <key>
                    
                    	XConnect ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: bindings
                    
                    	DHCP binding count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Union of Port information
                    	**type**\:   :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.xcid = None
                        self.bindings = None
                        self.port = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port()
                        self.port.parent = self


                    class Port(object):
                        """
                        Union of Port information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:   :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:   :py:class:`MgmtL2FibDataEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2FibDataEnum>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:   :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac()
                            self.ac.parent = self
                            self.data_type = None
                            self.pw = L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw()
                            self.pw.parent = self


                        class Ac(object):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_handle = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_handle is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Ac']['meta_info']


                        class Pw(object):
                            """
                            pw
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:   :py:class:`L2FibPwIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2FibPwIdEnum>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self.pw_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.pseudo_wire_id_type is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port.Pw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:port'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac is not None and self.ac._has_data():
                                return True

                            if self.data_type is not None:
                                return True

                            if self.pw is not None and self.pw._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary.Port']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.xcid is None:
                            raise YPYModelError('Key property xcid is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-dhcp-binding-summary[Cisco-IOS-XR-l2vpn-oper:xcid = ' + str(self.xcid) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.xcid is not None:
                            return True

                        if self.bindings is not None:
                            return True

                        if self.port is not None and self.port._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries.L2FibDhcpBindingSummary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-dhcp-binding-summaries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_dhcp_binding_summary is not None:
                        for child_ref in self.l2fib_dhcp_binding_summary:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibDhcpBindingSummaries']['meta_info']


            class L2FibEvpnInclMCasts(object):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast Table
                
                .. attribute:: l2fib_evpn_incl_m_cast
                
                	Specify bridge domain name
                	**type**\: list of    :py:class:`L2FibEvpnInclMCast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.l2fib_evpn_incl_m_cast = YList()
                    self.l2fib_evpn_incl_m_cast.parent = self
                    self.l2fib_evpn_incl_m_cast.name = 'l2fib_evpn_incl_m_cast'


                class L2FibEvpnInclMCast(object):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  <key>
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..65
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:   :py:class:`L2FibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles>`
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:   :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bd_name = None
                        self.l2fib_evpn_incl_m_cast_oles = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self.mcast_replication_list = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList()
                        self.mcast_replication_list.parent = self


                    class McastReplicationList(object):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_domain_id = None
                            self.bridge_domain_name = None
                            self.is_bound = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-replication-list'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_domain_id is not None:
                                return True

                            if self.bridge_domain_name is not None:
                                return True

                            if self.is_bound is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.McastReplicationList']['meta_info']


                    class L2FibEvpnInclMCastOles(object):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of    :py:class:`L2FibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.l2fib_evpn_incl_m_cast_ole = YList()
                            self.l2fib_evpn_incl_m_cast_ole.parent = self
                            self.l2fib_evpn_incl_m_cast_ole.name = 'l2fib_evpn_incl_m_cast_ole'


                        class L2FibEvpnInclMCastOle(object):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  <key>
                            
                            	Next Hop Address
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\:  bool
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:   :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:   :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.next_hop_address = None
                                self.is_bound = None
                                self.mcast_ole = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self.next_hop = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self.next_hop_valid = None


                            class McastOle(object):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mcast_label = None
                                    self.next_hop_ipv6_addr = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mcast-ole'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mcast_label is not None:
                                        return True

                                    if self.next_hop_ipv6_addr is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.McastOle']['meta_info']


                            class NextHop(object):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: plaformt_data_valid
                                
                                	Is Platform Data Valid
                                	**type**\:  bool
                                
                                .. attribute:: platform_data_length
                                
                                	Platform Data Length
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self.children_count = None
                                    self.next_hop_address = None
                                    self.next_hop_internal_label = None
                                    self.plaformt_data_valid = None
                                    self.platform_data_length = None


                                class Base(object):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop.Base']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:next-hop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.children_count is not None:
                                        return True

                                    if self.next_hop_address is not None:
                                        return True

                                    if self.next_hop_internal_label is not None:
                                        return True

                                    if self.plaformt_data_valid is not None:
                                        return True

                                    if self.platform_data_length is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle.NextHop']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.next_hop_address is None:
                                    raise YPYModelError('Key property next_hop_address is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-ole[Cisco-IOS-XR-l2vpn-oper:next-hop-address = ' + str(self.next_hop_address) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.next_hop_address is not None:
                                    return True

                                if self.is_bound is not None:
                                    return True

                                if self.mcast_ole is not None and self.mcast_ole._has_data():
                                    return True

                                if self.next_hop is not None and self.next_hop._has_data():
                                    return True

                                if self.next_hop_valid is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles.L2FibEvpnInclMCastOle']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast-oles'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.l2fib_evpn_incl_m_cast_ole is not None:
                                for child_ref in self.l2fib_evpn_incl_m_cast_ole:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast.L2FibEvpnInclMCastOles']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.bd_name is None:
                            raise YPYModelError('Key property bd_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-cast[Cisco-IOS-XR-l2vpn-oper:bd-name = ' + str(self.bd_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bd_name is not None:
                            return True

                        if self.l2fib_evpn_incl_m_cast_oles is not None and self.l2fib_evpn_incl_m_cast_oles._has_data():
                            return True

                        if self.mcast_replication_list is not None and self.mcast_replication_list._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts.L2FibEvpnInclMCast']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fib-evpn-incl-m-casts'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.l2fib_evpn_incl_m_cast is not None:
                        for child_ref in self.l2fib_evpn_incl_m_cast:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2VpnForwarding.Nodes.Node.L2FibEvpnInclMCasts']['meta_info']

            @property
            def _common_path(self):
                if self.node_id is None:
                    raise YPYModelError('Key property node_id is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding/Cisco-IOS-XR-l2vpn-oper:nodes/Cisco-IOS-XR-l2vpn-oper:node[Cisco-IOS-XR-l2vpn-oper:node-id = ' + str(self.node_id) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.node_id is not None:
                    return True

                if self.l2fib_bridge_domain_names is not None and self.l2fib_bridge_domain_names._has_data():
                    return True

                if self.l2fib_bridge_domains is not None and self.l2fib_bridge_domains._has_data():
                    return True

                if self.l2fib_bridge_ports is not None and self.l2fib_bridge_ports._has_data():
                    return True

                if self.l2fib_dhcp_binding_count is not None and self.l2fib_dhcp_binding_count._has_data():
                    return True

                if self.l2fib_dhcp_binding_details is not None and self.l2fib_dhcp_binding_details._has_data():
                    return True

                if self.l2fib_dhcp_binding_summaries is not None and self.l2fib_dhcp_binding_summaries._has_data():
                    return True

                if self.l2fib_evpn_incl_m_cast_hardware_egresses is not None and self.l2fib_evpn_incl_m_cast_hardware_egresses._has_data():
                    return True

                if self.l2fib_evpn_incl_m_cast_hardware_ingresses is not None and self.l2fib_evpn_incl_m_cast_hardware_ingresses._has_data():
                    return True

                if self.l2fib_evpn_incl_m_casts is not None and self.l2fib_evpn_incl_m_casts._has_data():
                    return True

                if self.l2fib_evpn_ip4macs is not None and self.l2fib_evpn_ip4macs._has_data():
                    return True

                if self.l2fib_evpn_ip6macs is not None and self.l2fib_evpn_ip6macs._has_data():
                    return True

                if self.l2fib_g8032 is not None and self.l2fib_g8032._has_data():
                    return True

                if self.l2fib_l2tp is not None and self.l2fib_l2tp._has_data():
                    return True

                if self.l2fib_main_interfaces is not None and self.l2fib_main_interfaces._has_data():
                    return True

                if self.l2fib_message_summary is not None and self.l2fib_message_summary._has_data():
                    return True

                if self.l2fib_mmrp_summaries is not None and self.l2fib_mmrp_summaries._has_data():
                    return True

                if self.l2fib_mmrps is not None and self.l2fib_mmrps._has_data():
                    return True

                if self.l2fib_mon_sess_x_cons is not None and self.l2fib_mon_sess_x_cons._has_data():
                    return True

                if self.l2fib_mroute_ipv6s is not None and self.l2fib_mroute_ipv6s._has_data():
                    return True

                if self.l2fib_mroute_ports is not None and self.l2fib_mroute_ports._has_data():
                    return True

                if self.l2fib_mroute_summaries is not None and self.l2fib_mroute_summaries._has_data():
                    return True

                if self.l2fib_mroutes is not None and self.l2fib_mroutes._has_data():
                    return True

                if self.l2fib_mstp_details is not None and self.l2fib_mstp_details._has_data():
                    return True

                if self.l2fib_mstp_summaries is not None and self.l2fib_mstp_summaries._has_data():
                    return True

                if self.l2fib_nve_peers is not None and self.l2fib_nve_peers._has_data():
                    return True

                if self.l2fib_p2mp is not None and self.l2fib_p2mp._has_data():
                    return True

                if self.l2fib_pw_groups is not None and self.l2fib_pw_groups._has_data():
                    return True

                if self.l2fib_pwhe_main_ports is not None and self.l2fib_pwhe_main_ports._has_data():
                    return True

                if self.l2fib_resource_availability is not None and self.l2fib_resource_availability._has_data():
                    return True

                if self.l2fib_summary is not None and self.l2fib_summary._has_data():
                    return True

                if self.l2fibmac_details is not None and self.l2fibmac_details._has_data():
                    return True

                if self.l2fibmac_hardware_egresses is not None and self.l2fibmac_hardware_egresses._has_data():
                    return True

                if self.l2fibmac_hardware_ingresses is not None and self.l2fibmac_hardware_ingresses._has_data():
                    return True

                if self.l2fibx_con_l2tpv2s is not None and self.l2fibx_con_l2tpv2s._has_data():
                    return True

                if self.l2fibx_con_locals is not None and self.l2fibx_con_locals._has_data():
                    return True

                if self.l2fibx_cons is not None and self.l2fibx_cons._has_data():
                    return True

                if self.pbb_bmac_sa is not None and self.pbb_bmac_sa._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2VpnForwarding.Nodes.Node']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding/Cisco-IOS-XR-l2vpn-oper:nodes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.node is not None:
                for child_ref in self.node:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2VpnForwarding.Nodes']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.nodes is not None and self.nodes._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2VpnForwarding']['meta_info']


class L2Vpnv2(object):
    """
    l2vpnv2
    
    .. attribute:: active
    
    	Active L2VPN operational data
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active>`
    
    .. attribute:: nodes
    
    	Table of L2VPN operational data for a particular node
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes>`
    
    .. attribute:: standby
    
    	Standby L2VPN operational data
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.active = L2Vpnv2.Active()
        self.active.parent = self
        self.nodes = L2Vpnv2.Nodes()
        self.nodes.parent = self
        self.standby = L2Vpnv2.Standby()
        self.standby.parent = self


    class Standby(object):
        """
        Standby L2VPN operational data
        
        .. attribute:: bridge_domains
        
        	VPLS Bridge Domain Information
        	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains>`
        
        .. attribute:: bridge_summary
        
        	Bridge Domain summary information
        	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeSummary>`
        
        .. attribute:: discoveries
        
        	Discovery Table
        	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries>`
        
        .. attribute:: discovery_summary
        
        	Discovery summary information
        	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.DiscoverySummary>`
        
        .. attribute:: flexible_xconnect_service_summary
        
        	Flexible XConnect Service summary information
        	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServiceSummary>`
        
        .. attribute:: flexible_xconnect_services
        
        	Flexible XConnect Service Table
        	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices>`
        
        .. attribute:: g8032
        
        	G8032 information
        	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032>`
        
        .. attribute:: generic_interface_list_details
        
        	L2VPN generic interface list Detail Table
        	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails>`
        
        .. attribute:: generic_interfaces
        
        	L2VPN generic interface list Table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaces>`
        
        .. attribute:: global_settings
        
        	L2VPN global settings
        	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GlobalSettings>`
        
        .. attribute:: iccp_sm
        
        	ICCP\-based Service Multi\-homing operational data
        	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm>`
        
        .. attribute:: indexes
        
        	ID Manager Index Table
        	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Indexes>`
        
        .. attribute:: l2vpn_collaborators
        
        	L2VPN collaborator information
        	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnCollaborators>`
        
        .. attribute:: l2vpn_pbb_bsa
        
        	L2VPN PBB Backbone Source MAC information
        	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnPbbBsa>`
        
        .. attribute:: l2vpn_resource_state
        
        	L2VPN resource state information
        	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnResourceState>`
        
        .. attribute:: main_interfaces
        
        	Main Interface
        	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces>`
        
        .. attribute:: mstp_ports
        
        	L2VPN MSTP Port Table
        	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts>`
        
        .. attribute:: mstp_vlans
        
        	L2VPN MSTP VLAN Table
        	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpVlans>`
        
        .. attribute:: mvrp
        
        	MVRP
        	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp>`
        
        .. attribute:: nsr
        
        	L2VPN NSR information
        	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr>`
        
        .. attribute:: proc_fsm
        
        	L2VPN Process FSM information
        	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm>`
        
        .. attribute:: pseudowire_classes
        
        	List of pseudowire classes
        	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses>`
        
        .. attribute:: pwr
        
        	Pseudowire Routing Table
        	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr>`
        
        .. attribute:: xconnect_brief
        
        	XConnect brief information
        	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief>`
        
        .. attribute:: xconnect_groups
        
        	XConnect group Table
        	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectGroups>`
        
        .. attribute:: xconnect_mp2mp_ce2ces
        
        	XConnect MP2MP CE2CE Table
        	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2MpCe2Ces>`
        
        .. attribute:: xconnect_mp2mps
        
        	XConnect MP2MP Table
        	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps>`
        
        .. attribute:: xconnect_summary
        
        	XConnect summary information
        	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectSummary>`
        
        .. attribute:: xconnects
        
        	XConnect Table
        	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.bridge_domains = L2Vpnv2.Standby.BridgeDomains()
            self.bridge_domains.parent = self
            self.bridge_summary = L2Vpnv2.Standby.BridgeSummary()
            self.bridge_summary.parent = self
            self.discoveries = L2Vpnv2.Standby.Discoveries()
            self.discoveries.parent = self
            self.discovery_summary = L2Vpnv2.Standby.DiscoverySummary()
            self.discovery_summary.parent = self
            self.flexible_xconnect_service_summary = L2Vpnv2.Standby.FlexibleXconnectServiceSummary()
            self.flexible_xconnect_service_summary.parent = self
            self.flexible_xconnect_services = L2Vpnv2.Standby.FlexibleXconnectServices()
            self.flexible_xconnect_services.parent = self
            self.g8032 = L2Vpnv2.Standby.G8032()
            self.g8032.parent = self
            self.generic_interface_list_details = L2Vpnv2.Standby.GenericInterfaceListDetails()
            self.generic_interface_list_details.parent = self
            self.generic_interfaces = L2Vpnv2.Standby.GenericInterfaces()
            self.generic_interfaces.parent = self
            self.global_settings = L2Vpnv2.Standby.GlobalSettings()
            self.global_settings.parent = self
            self.iccp_sm = L2Vpnv2.Standby.IccpSm()
            self.iccp_sm.parent = self
            self.indexes = L2Vpnv2.Standby.Indexes()
            self.indexes.parent = self
            self.l2vpn_collaborators = L2Vpnv2.Standby.L2VpnCollaborators()
            self.l2vpn_collaborators.parent = self
            self.l2vpn_pbb_bsa = L2Vpnv2.Standby.L2VpnPbbBsa()
            self.l2vpn_pbb_bsa.parent = self
            self.l2vpn_resource_state = L2Vpnv2.Standby.L2VpnResourceState()
            self.l2vpn_resource_state.parent = self
            self.main_interfaces = L2Vpnv2.Standby.MainInterfaces()
            self.main_interfaces.parent = self
            self.mstp_ports = L2Vpnv2.Standby.MstpPorts()
            self.mstp_ports.parent = self
            self.mstp_vlans = L2Vpnv2.Standby.MstpVlans()
            self.mstp_vlans.parent = self
            self.mvrp = L2Vpnv2.Standby.Mvrp()
            self.mvrp.parent = self
            self.nsr = L2Vpnv2.Standby.Nsr()
            self.nsr.parent = self
            self.proc_fsm = L2Vpnv2.Standby.ProcFsm()
            self.proc_fsm.parent = self
            self.pseudowire_classes = L2Vpnv2.Standby.PseudowireClasses()
            self.pseudowire_classes.parent = self
            self.pwr = L2Vpnv2.Standby.Pwr()
            self.pwr.parent = self
            self.xconnect_brief = L2Vpnv2.Standby.XconnectBrief()
            self.xconnect_brief.parent = self
            self.xconnect_groups = L2Vpnv2.Standby.XconnectGroups()
            self.xconnect_groups.parent = self
            self.xconnect_mp2mp_ce2ces = L2Vpnv2.Standby.XconnectMp2MpCe2Ces()
            self.xconnect_mp2mp_ce2ces.parent = self
            self.xconnect_mp2mps = L2Vpnv2.Standby.XconnectMp2Mps()
            self.xconnect_mp2mps.parent = self
            self.xconnect_summary = L2Vpnv2.Standby.XconnectSummary()
            self.xconnect_summary.parent = self
            self.xconnects = L2Vpnv2.Standby.Xconnects()
            self.xconnects.parent = self


        class Discoveries(object):
            """
            Discovery Table
            
            .. attribute:: discovery
            
            	VPLS Discovery information
            	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.discovery = YList()
                self.discovery.parent = self
                self.discovery.name = 'discovery'


            class Discovery(object):
                """
                VPLS Discovery information
                
                .. attribute:: group_name
                
                	Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: is_service_connected
                
                	Is the service connected
                	**type**\:  bool
                
                .. attribute:: mtu_mismatch_ignore
                
                	Ignore MTU Mismatch
                	**type**\:  bool
                
                .. attribute:: number_vpn
                
                	Number of vpns
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: service_name
                
                	Service type
                	**type**\:   :py:class:`L2VpnServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnServiceEnum>`
                
                .. attribute:: service_name_xr
                
                	Service Type
                	**type**\:  str
                
                .. attribute:: signalling_info
                
                	Info about signalling protocol
                	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo>`
                
                .. attribute:: vpn_id
                
                	VPN id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_name
                
                	VPN Name
                	**type**\:  str
                
                	**length:** 1..27
                
                .. attribute:: vpn_name_xr
                
                	VPN instance name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_name = None
                    self.group_name_xr = None
                    self.is_service_connected = None
                    self.mtu_mismatch_ignore = None
                    self.number_vpn = None
                    self.service_name = None
                    self.service_name_xr = None
                    self.signalling_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo()
                    self.signalling_info.parent = self
                    self.vpn_id = None
                    self.vpn_name = None
                    self.vpn_name_xr = None


                class SignallingInfo(object):
                    """
                    Info about signalling protocol
                    
                    .. attribute:: ad_signalling_method
                    
                    	ADSignallingMethod
                    	**type**\:   :py:class:`L2VpnAdSigMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethodEnum>`
                    
                    .. attribute:: bgp_sig_info
                    
                    	bgp sig info
                    	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                    
                    .. attribute:: ldp_sig_info
                    
                    	ldp sig info
                    	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_signalling_method = None
                        self.bgp_sig_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                        self.bgp_sig_info.parent = self
                        self.ldp_sig_info = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                        self.ldp_sig_info.parent = self


                    class BgpSigInfo(object):
                        """
                        bgp sig info
                        
                        .. attribute:: edge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                        
                        .. attribute:: number_edges
                        
                        	Number of Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.edge = YList()
                            self.edge.parent = self
                            self.edge.name = 'edge'
                            self.number_edges = None
                            self.number_remote_edges = None
                            self.redge = YList()
                            self.redge.parent = self
                            self.redge.name = 'redge'


                        class Edge(object):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.edge_id = None
                                self.label_block = YList()
                                self.label_block.parent = self
                                self.label_block.name = 'label_block'
                                self.label_count = None


                            class LabelBlock(object):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.label_base = None
                                    self.label_error = None
                                    self.label_time_created = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.status_vector = YLeafList()
                                    self.status_vector.parent = self
                                    self.status_vector.name = 'status_vector'

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:edge/Cisco-IOS-XR-l2vpn-oper:label-block'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.block_offset is not None:
                                        return True

                                    if self.block_size is not None:
                                        return True

                                    if self.label_base is not None:
                                        return True

                                    if self.label_error is not None:
                                        return True

                                    if self.label_time_created is not None:
                                        return True

                                    if self.local_edge_id is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    if self.status_vector is not None:
                                        for child in self.status_vector:
                                            if child is not None:
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:edge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.edge_id is not None:
                                    return True

                                if self.label_block is not None:
                                    for child_ref in self.label_block:
                                        if child_ref._has_data():
                                            return True

                                if self.label_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge']['meta_info']


                        class Redge(object):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.edge_id = None
                                self.label_block = YList()
                                self.label_block.parent = self
                                self.label_block.name = 'label_block'
                                self.label_count = None


                            class LabelBlock(object):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.label_base = None
                                    self.label_error = None
                                    self.label_time_created = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.status_vector = YLeafList()
                                    self.status_vector.parent = self
                                    self.status_vector.name = 'status_vector'

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:redge/Cisco-IOS-XR-l2vpn-oper:label-block'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.block_offset is not None:
                                        return True

                                    if self.block_size is not None:
                                        return True

                                    if self.label_base is not None:
                                        return True

                                    if self.label_error is not None:
                                        return True

                                    if self.label_time_created is not None:
                                        return True

                                    if self.local_edge_id is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    if self.status_vector is not None:
                                        for child in self.status_vector:
                                            if child is not None:
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:redge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.edge_id is not None:
                                    return True

                                if self.label_block is not None:
                                    for child_ref in self.label_block:
                                        if child_ref._has_data():
                                            return True

                                if self.label_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.edge is not None:
                                for child_ref in self.edge:
                                    if child_ref._has_data():
                                        return True

                            if self.number_edges is not None:
                                return True

                            if self.number_remote_edges is not None:
                                return True

                            if self.redge is not None:
                                for child_ref in self.redge:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo']['meta_info']


                    class LdpSigInfo(object):
                        """
                        ldp sig info
                        
                        .. attribute:: local_l2_router_id
                        
                        	Local L2VPN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_vpls_id
                        
                        	Local VPLS\-ID
                        	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_nlri
                        
                        	List of NLRIs
                        	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_l2_router_id = None
                            self.local_vpls_id = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                            self.local_vpls_id.parent = self
                            self.number_remote_edges = None
                            self.remote_nlri = YList()
                            self.remote_nlri.parent = self
                            self.remote_nlri.name = 'remote_nlri'


                        class LocalVplsId(object):
                            """
                            Local VPLS\-ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                self.auto.parent = self
                                self.two_byte_as = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                self.v4_addr.parent = self
                                self.vpls_id_type = None


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asn = None
                                    self.vpn_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asn is not None:
                                        return True

                                    if self.vpn_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                if self.vpls_id_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId']['meta_info']


                        class RemoteNlri(object):
                            """
                            List of NLRIs
                            
                            .. attribute:: local_address
                            
                            	Local BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nlri_time_created
                            
                            	NLRI creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_l2_router_id
                            
                            	Remote L2VPN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_address = None
                                self.nlri_time_created = None
                                self.remote_address = None
                                self.remote_l2_router_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:remote-nlri'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_address is not None:
                                    return True

                                if self.nlri_time_created is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                if self.remote_l2_router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_l2_router_id is not None:
                                return True

                            if self.local_vpls_id is not None and self.local_vpls_id._has_data():
                                return True

                            if self.number_remote_edges is not None:
                                return True

                            if self.remote_nlri is not None:
                                for child_ref in self.remote_nlri:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_signalling_method is not None:
                            return True

                        if self.bgp_sig_info is not None and self.bgp_sig_info._has_data():
                            return True

                        if self.ldp_sig_info is not None and self.ldp_sig_info._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery.SignallingInfo']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.is_service_connected is not None:
                        return True

                    if self.mtu_mismatch_ignore is not None:
                        return True

                    if self.number_vpn is not None:
                        return True

                    if self.service_name is not None:
                        return True

                    if self.service_name_xr is not None:
                        return True

                    if self.signalling_info is not None and self.signalling_info._has_data():
                        return True

                    if self.vpn_id is not None:
                        return True

                    if self.vpn_name is not None:
                        return True

                    if self.vpn_name_xr is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Discoveries.Discovery']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discoveries'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.discovery is not None:
                    for child_ref in self.discovery:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.Discoveries']['meta_info']


        class FlexibleXconnectServiceSummary(object):
            """
            Flexible XConnect Service summary information
            
            .. attribute:: number_fxc
            
            	Number of flexible xconnect services
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_down
            
            	Number of flexible xconnect services whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_up
            
            	Number of flexible xconnect services whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.number_fxc = None
                self.number_fxc_down = None
                self.number_fxc_up = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.number_fxc is not None:
                    return True

                if self.number_fxc_down is not None:
                    return True

                if self.number_fxc_up is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServiceSummary']['meta_info']


        class MainInterfaces(object):
            """
            Main Interface
            
            .. attribute:: main_interface
            
            	Main Interface Table
            	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.main_interface = YList()
                self.main_interface.parent = self
                self.main_interface.name = 'main_interface'


            class MainInterface(object):
                """
                Main Interface Table
                
                .. attribute:: interface_name  <key>
                
                	Main interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: main_interface_info
                
                	Main Interface info
                	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo>`
                
                .. attribute:: main_interface_instances
                
                	Main Interface Instance table
                	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_name = None
                    self.main_interface_info = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo()
                    self.main_interface_info.parent = self
                    self.main_interface_instances = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances()
                    self.main_interface_instances.parent = self


                class MainInterfaceInstances(object):
                    """
                    Main Interface Instance table
                    
                    .. attribute:: main_interface_instance
                    
                    	Main Interface Instance
                    	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.main_interface_instance = YList()
                        self.main_interface_instance.parent = self
                        self.main_interface_instance.name = 'main_interface_instance'


                    class MainInterfaceInstance(object):
                        """
                        Main Interface Instance
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: main_interface_instance_bridge_ports
                        
                        	Main Interface Instance Bridge Port table
                        	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                        
                        .. attribute:: main_interface_instance_info
                        
                        	Main Interface Instance info
                        	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance = None
                            self.main_interface_instance_bridge_ports = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                            self.main_interface_instance_bridge_ports.parent = self
                            self.main_interface_instance_info = L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                            self.main_interface_instance_info.parent = self


                        class MainInterfaceInstanceInfo(object):
                            """
                            Main Interface Instance info
                            
                            .. attribute:: configured_instance
                            
                            	Configured Instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flush_count
                            
                            	Flush count 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_flags
                            
                            	Instance Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_state
                            
                            	Instance State
                            	**type**\:   :py:class:`L2VpnMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceStateEnum>`
                            
                            .. attribute:: interface_count
                            
                            	Interface count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.configured_instance = None
                                self.flush_count = None
                                self.instance_flags = None
                                self.instance_id = None
                                self.instance_state = None
                                self.interface_count = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.configured_instance is not None:
                                    return True

                                if self.flush_count is not None:
                                    return True

                                if self.instance_flags is not None:
                                    return True

                                if self.instance_id is not None:
                                    return True

                                if self.instance_state is not None:
                                    return True

                                if self.interface_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo']['meta_info']


                        class MainInterfaceInstanceBridgePorts(object):
                            """
                            Main Interface Instance Bridge Port table
                            
                            .. attribute:: main_interface_instance_bridge_port
                            
                            	Main Interface Bridge Port info
                            	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.main_interface_instance_bridge_port = YList()
                                self.main_interface_instance_bridge_port.parent = self
                                self.main_interface_instance_bridge_port.name = 'main_interface_instance_bridge_port'


                            class MainInterfaceInstanceBridgePort(object):
                                """
                                Main Interface Bridge Port info
                                
                                .. attribute:: bridge_port  <key>
                                
                                	Bridge Port
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: bridge_port_xr
                                
                                	Bridge port ifhandle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port = None
                                    self.bridge_port_xr = None
                                    self.instance_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.bridge_port is None:
                                        raise YPYModelError('Key property bridge_port is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-port[Cisco-IOS-XR-l2vpn-oper:bridge-port = ' + str(self.bridge_port) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port is not None:
                                        return True

                                    if self.bridge_port_xr is not None:
                                        return True

                                    if self.instance_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-ports'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.main_interface_instance_bridge_port is not None:
                                    for child_ref in self.main_interface_instance_bridge_port:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.instance is None:
                                raise YPYModelError('Key property instance is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance is not None:
                                return True

                            if self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports._has_data():
                                return True

                            if self.main_interface_instance_info is not None and self.main_interface_instance_info._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instances'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.main_interface_instance is not None:
                            for child_ref in self.main_interface_instance:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances']['meta_info']


                class MainInterfaceInfo(object):
                    """
                    Main Interface info
                    
                    .. attribute:: interface_count
                    
                    	Sub Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: main_interface_handle
                    
                    	Main Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:   :py:class:`L2VpnMainIfProtectectedEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectectedEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_count = None
                        self.main_interface_handle = None
                        self.protected = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_count is not None:
                            return True

                        if self.main_interface_handle is not None:
                            return True

                        if self.protected is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_name is None:
                        raise YPYModelError('Key property interface_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:main-interfaces/Cisco-IOS-XR-l2vpn-oper:main-interface[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_name is not None:
                        return True

                    if self.main_interface_info is not None and self.main_interface_info._has_data():
                        return True

                    if self.main_interface_instances is not None and self.main_interface_instances._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.MainInterfaces.MainInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:main-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.main_interface is not None:
                    for child_ref in self.main_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.MainInterfaces']['meta_info']


        class IccpSm(object):
            """
            ICCP\-based Service Multi\-homing operational data
            
            .. attribute:: iccp_groups
            
            	ICCP Group Table
            	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups>`
            
            .. attribute:: iccp_sm_summary
            
            	ICCP\-based Service Multi\-homing database summary
            	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpSmSummary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.iccp_groups = L2Vpnv2.Standby.IccpSm.IccpGroups()
                self.iccp_groups.parent = self
                self.iccp_sm_summary = L2Vpnv2.Standby.IccpSm.IccpSmSummary()
                self.iccp_sm_summary.parent = self


            class IccpSmSummary(object):
                """
                ICCP\-based Service Multi\-homing database
                summary
                
                .. attribute:: connected_groups
                
                	Number of Connected Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: connecting_groups
                
                	Number of Connecting Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: failed_ports
                
                	Number of Failed Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groups
                
                	Total Number of Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: operational_ports
                
                	Number of Operational Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ports
                
                	Total Number of Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: provisioned_groups
                
                	Number of Provisioned Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reverting_ports
                
                	Number of Reverting Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronized_groups
                
                	Number of Synchronized Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronizing_groups
                
                	Number of Synchronizing Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unconfigured_ports
                
                	Number of Unconfigured Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_ports
                
                	Number of Unknown Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_groups
                
                	Number of Unresolved Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsynchronized_ports
                
                	Number of Unsynchronized Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.connected_groups = None
                    self.connecting_groups = None
                    self.failed_ports = None
                    self.groups = None
                    self.operational_ports = None
                    self.ports = None
                    self.provisioned_groups = None
                    self.reverting_ports = None
                    self.synchronized_groups = None
                    self.synchronizing_groups = None
                    self.unconfigured_ports = None
                    self.unknown_ports = None
                    self.unresolved_groups = None
                    self.unsynchronized_ports = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-sm-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.connected_groups is not None:
                        return True

                    if self.connecting_groups is not None:
                        return True

                    if self.failed_ports is not None:
                        return True

                    if self.groups is not None:
                        return True

                    if self.operational_ports is not None:
                        return True

                    if self.ports is not None:
                        return True

                    if self.provisioned_groups is not None:
                        return True

                    if self.reverting_ports is not None:
                        return True

                    if self.synchronized_groups is not None:
                        return True

                    if self.synchronizing_groups is not None:
                        return True

                    if self.unconfigured_ports is not None:
                        return True

                    if self.unknown_ports is not None:
                        return True

                    if self.unresolved_groups is not None:
                        return True

                    if self.unsynchronized_ports is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpSmSummary']['meta_info']


            class IccpGroups(object):
                """
                ICCP Group Table
                
                .. attribute:: iccp_group
                
                	ICCP Group
                	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.iccp_group = YList()
                    self.iccp_group.parent = self
                    self.iccp_group.name = 'iccp_group'


                class IccpGroup(object):
                    """
                    ICCP Group
                    
                    .. attribute:: group_id  <key>
                    
                    	Group ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: iccp_group_info
                    
                    	ICCP Group Information
                    	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                    
                    .. attribute:: iccp_ports
                    
                    	ICCP Port Table
                    	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_id = None
                        self.iccp_group_info = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                        self.iccp_group_info.parent = self
                        self.iccp_ports = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                        self.iccp_ports.parent = self


                    class IccpGroupInfo(object):
                        """
                        ICCP Group Information
                        
                        .. attribute:: group_id
                        
                        	Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_member_up
                        
                        	ICCP Member Up
                        	**type**\:  bool
                        
                        .. attribute:: iccp_transport_up
                        
                        	ICCP Transport Up
                        	**type**\:  bool
                        
                        .. attribute:: local_node_id
                        
                        	Local Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ports
                        
                        	List of ports in the group
                        	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                        
                        .. attribute:: remote_node_id
                        
                        	Remote Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`IccpSmStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_id = None
                            self.iccp_member_up = None
                            self.iccp_transport_up = None
                            self.local_node_id = None
                            self.ports = YList()
                            self.ports.parent = self
                            self.ports.name = 'ports'
                            self.remote_node_id = None
                            self.state = None


                        class Ports(object):
                            """
                            List of ports in the group
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.local_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                self.local_port.parent = self
                                self.mac_flush_tcn = None
                                self.remote_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                self.remote_port.parent = self


                            class LocalPort(object):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort']['meta_info']


                            class RemotePort(object):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ports'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.local_port is not None and self.local_port._has_data():
                                    return True

                                if self.mac_flush_tcn is not None:
                                    return True

                                if self.remote_port is not None and self.remote_port._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-group-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_id is not None:
                                return True

                            if self.iccp_member_up is not None:
                                return True

                            if self.iccp_transport_up is not None:
                                return True

                            if self.local_node_id is not None:
                                return True

                            if self.ports is not None:
                                for child_ref in self.ports:
                                    if child_ref._has_data():
                                        return True

                            if self.remote_node_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo']['meta_info']


                    class IccpPorts(object):
                        """
                        ICCP Port Table
                        
                        .. attribute:: iccp_port
                        
                        	ICCP Port
                        	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.iccp_port = YList()
                            self.iccp_port.parent = self
                            self.iccp_port.name = 'iccp_port'


                        class IccpPort(object):
                            """
                            ICCP Port
                            
                            .. attribute:: interface  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface = None
                                self.interface_name = None
                                self.local_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                self.local_port.parent = self
                                self.mac_flush_tcn = None
                                self.remote_port = L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                self.remote_port.parent = self


                            class LocalPort(object):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort']['meta_info']


                            class RemotePort(object):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface is None:
                                    raise YPYModelError('Key property interface is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.local_port is not None and self.local_port._has_data():
                                    return True

                                if self.mac_flush_tcn is not None:
                                    return True

                                if self.remote_port is not None and self.remote_port._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-ports'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.iccp_port is not None:
                                for child_ref in self.iccp_port:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_id is None:
                            raise YPYModelError('Key property group_id is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-groups/Cisco-IOS-XR-l2vpn-oper:iccp-group[Cisco-IOS-XR-l2vpn-oper:group-id = ' + str(self.group_id) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_id is not None:
                            return True

                        if self.iccp_group_info is not None and self.iccp_group_info._has_data():
                            return True

                        if self.iccp_ports is not None and self.iccp_ports._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups.IccpGroup']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-groups'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.iccp_group is not None:
                        for child_ref in self.iccp_group:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.IccpSm.IccpGroups']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:iccp-sm'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.iccp_groups is not None and self.iccp_groups._has_data():
                    return True

                if self.iccp_sm_summary is not None and self.iccp_sm_summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.IccpSm']['meta_info']


        class BridgeSummary(object):
            """
            Bridge Domain summary information
            
            .. attribute:: num_vn_is
            
            	Number of VNIs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_down
            
            	Number of VNIs down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_unresolved
            
            	Number of VNIs unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_up
            
            	Number of VNIs up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs
            
            	Number of attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_up
            
            	Number of attachment circuits whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains
            
            	Number of bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_shut
            
            	Number of bridge\-domains admin disabled
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_up
            
            	Number of bridge\-domains up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_default_bridge_doamins
            
            	Number of default bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp
            
            	Number of P2MPs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_down
            
            	Number of P2MPs whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_up
            
            	Number of P2MPs whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_up
            
            	Number of pseudowires whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_core
            
            	Number of PBB Core
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_edge
            
            	Number of PBB Edge
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pseudowires
            
            	Number of pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_a_cs
            
            	Number of partially programmed attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_bridges
            
            	Number of partially programmed bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_pseudowires
            
            	Number of partially programmed pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_pseudowires
            
            	Number of pseudowires whose state is standby
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.num_vn_is = None
                self.num_vn_is_down = None
                self.num_vn_is_unresolved = None
                self.num_vn_is_up = None
                self.number_a_cs = None
                self.number_a_cs_up = None
                self.number_bridge_domains = None
                self.number_bridge_domains_shut = None
                self.number_bridge_domains_up = None
                self.number_default_bridge_doamins = None
                self.number_groups = None
                self.number_p2mp = None
                self.number_p2mp_down = None
                self.number_p2mp_up = None
                self.number_p_ws_up = None
                self.number_pbb_core = None
                self.number_pbb_edge = None
                self.number_pseudowires = None
                self.out_of_memory_state = None
                self.partially_programmed_a_cs = None
                self.partially_programmed_bridges = None
                self.partially_programmed_pseudowires = None
                self.standby_pseudowires = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.num_vn_is is not None:
                    return True

                if self.num_vn_is_down is not None:
                    return True

                if self.num_vn_is_unresolved is not None:
                    return True

                if self.num_vn_is_up is not None:
                    return True

                if self.number_a_cs is not None:
                    return True

                if self.number_a_cs_up is not None:
                    return True

                if self.number_bridge_domains is not None:
                    return True

                if self.number_bridge_domains_shut is not None:
                    return True

                if self.number_bridge_domains_up is not None:
                    return True

                if self.number_default_bridge_doamins is not None:
                    return True

                if self.number_groups is not None:
                    return True

                if self.number_p2mp is not None:
                    return True

                if self.number_p2mp_down is not None:
                    return True

                if self.number_p2mp_up is not None:
                    return True

                if self.number_p_ws_up is not None:
                    return True

                if self.number_pbb_core is not None:
                    return True

                if self.number_pbb_edge is not None:
                    return True

                if self.number_pseudowires is not None:
                    return True

                if self.out_of_memory_state is not None:
                    return True

                if self.partially_programmed_a_cs is not None:
                    return True

                if self.partially_programmed_bridges is not None:
                    return True

                if self.partially_programmed_pseudowires is not None:
                    return True

                if self.standby_pseudowires is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.BridgeSummary']['meta_info']


        class Nsr(object):
            """
            L2VPN NSR information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.event_history = YList()
                self.event_history.parent = self
                self.event_history.name = 'event_history'
                self.failover_status = L2Vpnv2.Standby.Nsr.FailoverStatus()
                self.failover_status.parent = self
                self.issu_status = L2Vpnv2.Standby.Nsr.IssuStatus()
                self.issu_status.parent = self
                self.nsr_status = L2Vpnv2.Standby.Nsr.NsrStatus()
                self.nsr_status.parent = self
                self.process_role = None
                self.process_state = None
                self.report_card = YList()
                self.report_card.parent = self
                self.report_card.name = 'report_card'
                self.state_transition_time = YLeafList()
                self.state_transition_time.parent = self
                self.state_transition_time.name = 'state_transition_time'
                self.sw_install_in_progress = None
                self.sync_flags = None
                self.xid_info = YList()
                self.xid_info.parent = self
                self.xid_info.name = 'xid_info'


            class FailoverStatus(object):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.master_time = None
                    self.start_time = None
                    self.triggered_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:failover-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.master_time is not None:
                        return True

                    if self.start_time is not None:
                        return True

                    if self.triggered_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Nsr.FailoverStatus']['meta_info']


            class NsrStatus(object):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Nsr.NsrStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Nsr.NsrStatus']['meta_info']


            class IssuStatus(object):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Nsr.IssuStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Nsr.IssuStatus']['meta_info']


            class XidInfo(object):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.app_type = None
                    self.sent_ids = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:xid-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.app_type is not None:
                        return True

                    if self.sent_ids is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Nsr.XidInfo']['meta_info']


            class ReportCard(object):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.collaborator_idt_done = None
                    self.collaborator_is_connected = None
                    self.collaborator_skipped = None
                    self.connection_change_time = None
                    self.idt_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:report-card'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.collaborator_idt_done is not None:
                        return True

                    if self.collaborator_is_connected is not None:
                        return True

                    if self.collaborator_skipped is not None:
                        return True

                    if self.connection_change_time is not None:
                        return True

                    if self.idt_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Nsr.ReportCard']['meta_info']


            class EventHistory(object):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_timestamp = None
                    self.new_state = None
                    self.previous_state = None
                    self.process_collaborator = None
                    self.process_event = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:event-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_timestamp is not None:
                        return True

                    if self.new_state is not None:
                        return True

                    if self.previous_state is not None:
                        return True

                    if self.process_collaborator is not None:
                        return True

                    if self.process_event is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Nsr.EventHistory']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:nsr'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.event_history is not None:
                    for child_ref in self.event_history:
                        if child_ref._has_data():
                            return True

                if self.failover_status is not None and self.failover_status._has_data():
                    return True

                if self.issu_status is not None and self.issu_status._has_data():
                    return True

                if self.nsr_status is not None and self.nsr_status._has_data():
                    return True

                if self.process_role is not None:
                    return True

                if self.process_state is not None:
                    return True

                if self.report_card is not None:
                    for child_ref in self.report_card:
                        if child_ref._has_data():
                            return True

                if self.state_transition_time is not None:
                    for child in self.state_transition_time:
                        if child is not None:
                            return True

                if self.sw_install_in_progress is not None:
                    return True

                if self.sync_flags is not None:
                    return True

                if self.xid_info is not None:
                    for child_ref in self.xid_info:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.Nsr']['meta_info']


        class GlobalSettings(object):
            """
            L2VPN global settings
            
            .. attribute:: going_active
            
            	transitioning to Active functional role
            	**type**\:  bool
            
            .. attribute:: ha_role
            
            	Node redundancy role
            	**type**\:  str
            
            .. attribute:: issu_role
            
            	Node ISSU role
            	**type**\:  str
            
            .. attribute:: logging_bd_enabled
            
            	Logging BD state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_df_election_enabled
            
            	Logging EVPN Designated Forwarder changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_nsr_enabled
            
            	Logging NSR state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_pw_enabled
            
            	Logging PW enabled
            	**type**\:  bool
            
            .. attribute:: logging_vfi_enabled
            
            	Logging VFI state changes enabled
            	**type**\:  bool
            
            .. attribute:: process_fsm
            
            	Current L2VPN FSM role
            	**type**\:  str
            
            .. attribute:: pw_grouping_enabled
            
            	PW Grouping enabled
            	**type**\:  bool
            
            .. attribute:: pw_oam_refresh_transmit_time
            
            	PW OAM refresh transmit (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: pw_status_enabled
            
            	PW Status enabled
            	**type**\:  bool
            
            .. attribute:: tcn_propagation_enabled
            
            	TCN propagation enabled
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.going_active = None
                self.ha_role = None
                self.issu_role = None
                self.logging_bd_enabled = None
                self.logging_df_election_enabled = None
                self.logging_nsr_enabled = None
                self.logging_pw_enabled = None
                self.logging_vfi_enabled = None
                self.process_fsm = None
                self.pw_grouping_enabled = None
                self.pw_oam_refresh_transmit_time = None
                self.pw_status_enabled = None
                self.tcn_propagation_enabled = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:global-settings'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.going_active is not None:
                    return True

                if self.ha_role is not None:
                    return True

                if self.issu_role is not None:
                    return True

                if self.logging_bd_enabled is not None:
                    return True

                if self.logging_df_election_enabled is not None:
                    return True

                if self.logging_nsr_enabled is not None:
                    return True

                if self.logging_pw_enabled is not None:
                    return True

                if self.logging_vfi_enabled is not None:
                    return True

                if self.process_fsm is not None:
                    return True

                if self.pw_grouping_enabled is not None:
                    return True

                if self.pw_oam_refresh_transmit_time is not None:
                    return True

                if self.pw_status_enabled is not None:
                    return True

                if self.tcn_propagation_enabled is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.GlobalSettings']['meta_info']


        class Pwr(object):
            """
            Pseudowire Routing Table
            
            .. attribute:: summary
            
            	L2VPN Pseudowire Routing Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.summary = L2Vpnv2.Standby.Pwr.Summary()
                self.summary.parent = self


            class Summary(object):
                """
                L2VPN Pseudowire Routing Summary
                
                .. attribute:: bgp_as
                
                	BGP AS number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_router_id
                
                	BGP Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cfg_global_id
                
                	Configured Global ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: cfg_router_id
                
                	Configured Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: l2vpn_has_bgp_eod
                
                	L2VPN got BGP EOD
                	**type**\:  bool
                
                .. attribute:: rd_auto
                
                	Automatic Route Distingtuisher
                	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto>`
                
                .. attribute:: rd_configured
                
                	Configured Route Distinguisher
                	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_as = None
                    self.bgp_router_id = None
                    self.cfg_global_id = None
                    self.cfg_router_id = None
                    self.l2vpn_has_bgp_eod = None
                    self.rd_auto = L2Vpnv2.Standby.Pwr.Summary.RdAuto()
                    self.rd_auto.parent = self
                    self.rd_configured = L2Vpnv2.Standby.Pwr.Summary.RdConfigured()
                    self.rd_configured.parent = self


                class RdAuto(object):
                    """
                    Automatic Route Distingtuisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto = L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto()
                        self.auto.parent = self
                        self.four_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rd = None
                        self.two_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr()
                        self.v4_addr.parent = self


                    class Auto(object):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto_index = None
                            self.router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto_index is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdAuto.Auto']['meta_info']


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto is not None and self.auto._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rd is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdAuto']['meta_info']


                class RdConfigured(object):
                    """
                    Configured Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto()
                        self.auto.parent = self
                        self.four_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rd = None
                        self.two_byte_as = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr()
                        self.v4_addr.parent = self


                    class Auto(object):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto_index = None
                            self.router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto_index is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdConfigured.Auto']['meta_info']


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto is not None and self.auto._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rd is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary.RdConfigured']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_as is not None:
                        return True

                    if self.bgp_router_id is not None:
                        return True

                    if self.cfg_global_id is not None:
                        return True

                    if self.cfg_router_id is not None:
                        return True

                    if self.l2vpn_has_bgp_eod is not None:
                        return True

                    if self.rd_auto is not None and self.rd_auto._has_data():
                        return True

                    if self.rd_configured is not None and self.rd_configured._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Pwr.Summary']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pwr'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.Pwr']['meta_info']


        class XconnectMp2MpCe2Ces(object):
            """
            XConnect MP2MP CE2CE Table
            
            .. attribute:: xconnect_mp2mp_ce2ce
            
            	XConnect MP2MP CE2CE information
            	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect_mp2mp_ce2ce = YList()
                self.xconnect_mp2mp_ce2ce.parent = self
                self.xconnect_mp2mp_ce2ce.name = 'xconnect_mp2mp_ce2ce'


            class XconnectMp2MpCe2Ce(object):
                """
                XConnect MP2MP CE2CE information
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\:  bool
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: local_ceid
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: remote_ceid
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ce_added = None
                    self.group_name = None
                    self.local_ceid = None
                    self.local_customer_edge_id = None
                    self.mp2_mp_name = None
                    self.remote_ceid = None
                    self.remote_customer_edge_id = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ce'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ce_added is not None:
                        return True

                    if self.group_name is not None:
                        return True

                    if self.local_ceid is not None:
                        return True

                    if self.local_customer_edge_id is not None:
                        return True

                    if self.mp2_mp_name is not None:
                        return True

                    if self.remote_ceid is not None:
                        return True

                    if self.remote_customer_edge_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect_mp2mp_ce2ce is not None:
                    for child_ref in self.xconnect_mp2mp_ce2ce:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2MpCe2Ces']['meta_info']


        class Xconnects(object):
            """
            XConnect Table
            
            .. attribute:: xconnect
            
            	XConnect information
            	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect = YList()
                self.xconnect.parent = self
                self.xconnect.name = 'xconnect'


            class Xconnect(object):
                """
                XConnect information
                
                .. attribute:: backup
                
                	LCR backup
                	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup>`
                
                .. attribute:: backup_segment
                
                	Backup Segment
                	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment>`
                
                .. attribute:: ce2ce
                
                	CE2CE
                	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce>`
                
                .. attribute:: description
                
                	P2P Description
                	**type**\:  str
                
                .. attribute:: diag_mask
                
                	Mask indicating what if anything is missing before the XC can be provisioned
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: interworking
                
                	Interworking type
                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                
                .. attribute:: is_mp2mp
                
                	xconnect is mp2mp
                	**type**\:  bool
                
                .. attribute:: number_of_backup_p_ws
                
                	Number of backups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: segment1
                
                	Segment 1
                	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1>`
                
                .. attribute:: segment2
                
                	Segment 2
                	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2>`
                
                .. attribute:: state
                
                	State of the xconnect
                	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                
                .. attribute:: xconnect_name
                
                	XConnect Name
                	**type**\:  str
                
                	**length:** 1..38
                
                .. attribute:: xconnect_name_xr
                
                	XConnect name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.backup = L2Vpnv2.Standby.Xconnects.Xconnect.Backup()
                    self.backup.parent = self
                    self.backup_segment = YList()
                    self.backup_segment.parent = self
                    self.backup_segment.name = 'backup_segment'
                    self.ce2ce = L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce()
                    self.ce2ce.parent = self
                    self.description = None
                    self.diag_mask = None
                    self.group_name = None
                    self.group_name_xr = None
                    self.interworking = None
                    self.is_mp2mp = None
                    self.number_of_backup_p_ws = None
                    self.segment1 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1()
                    self.segment1.parent = self
                    self.segment2 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2()
                    self.segment2.parent = self
                    self.state = None
                    self.xconnect_name = None
                    self.xconnect_name_xr = None


                class Backup(object):
                    """
                    LCR backup
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Backup']['meta_info']


                class Segment1(object):
                    """
                    Segment 1
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment1']['meta_info']


                class Segment2(object):
                    """
                    Segment 2
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Segment2']['meta_info']


                class Ce2Ce(object):
                    """
                    CE2CE
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\:  bool
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ce_added = None
                        self.local_customer_edge_id = None
                        self.remote_customer_edge_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:ce2ce'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ce_added is not None:
                            return True

                        if self.local_customer_edge_id is not None:
                            return True

                        if self.remote_customer_edge_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.Ce2Ce']['meta_info']


                class BackupSegment(object):
                    """
                    Backup Segment
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect.BackupSegment']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.backup is not None and self.backup._has_data():
                        return True

                    if self.backup_segment is not None:
                        for child_ref in self.backup_segment:
                            if child_ref._has_data():
                                return True

                    if self.ce2ce is not None and self.ce2ce._has_data():
                        return True

                    if self.description is not None:
                        return True

                    if self.diag_mask is not None:
                        return True

                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.interworking is not None:
                        return True

                    if self.is_mp2mp is not None:
                        return True

                    if self.number_of_backup_p_ws is not None:
                        return True

                    if self.segment1 is not None and self.segment1._has_data():
                        return True

                    if self.segment2 is not None and self.segment2._has_data():
                        return True

                    if self.state is not None:
                        return True

                    if self.xconnect_name is not None:
                        return True

                    if self.xconnect_name_xr is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Xconnects.Xconnect']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnects'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect is not None:
                    for child_ref in self.xconnect:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.Xconnects']['meta_info']


        class XconnectGroups(object):
            """
            XConnect group Table
            
            .. attribute:: xconnect_group
            
            	XConnect group information
            	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectGroups.XconnectGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect_group = YList()
                self.xconnect_group.parent = self
                self.xconnect_group.name = 'xconnect_group'


            class XconnectGroup(object):
                """
                XConnect group information
                
                .. attribute:: group_name  <key>
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_name = None
                    self.group_name_xr = None
                    self.number_xconnects = None

                @property
                def _common_path(self):
                    if self.group_name is None:
                        raise YPYModelError('Key property group_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-groups/Cisco-IOS-XR-l2vpn-oper:xconnect-group[Cisco-IOS-XR-l2vpn-oper:group-name = ' + str(self.group_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.number_xconnects is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.XconnectGroups.XconnectGroup']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-groups'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect_group is not None:
                    for child_ref in self.xconnect_group:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.XconnectGroups']['meta_info']


        class XconnectMp2Mps(object):
            """
            XConnect MP2MP Table
            
            .. attribute:: xconnect_mp2mp
            
            	XConnect MP2MP information
            	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect_mp2mp = YList()
                self.xconnect_mp2mp.parent = self
                self.xconnect_mp2mp.name = 'xconnect_mp2mp'


            class XconnectMp2Mp(object):
                """
                XConnect MP2MP information
                
                .. attribute:: discovery
                
                	l2vpn xc auto discovery info
                	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: l2_encapsulation
                
                	L2 Encapsulation
                	**type**\:   :py:class:`L2VpnBagAdEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncapEnum>`
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: mp2mp_name
                
                	MP2MP name
                	**type**\:  str
                
                .. attribute:: mp2mpid
                
                	Identification Number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	Vpn ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_mtu
                
                	VPN MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect_shutdown
                
                	Administratively disabled
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.discovery = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                    self.discovery.parent = self
                    self.group_name = None
                    self.group_name_xr = None
                    self.l2_encapsulation = None
                    self.mp2_mp_name = None
                    self.mp2mp_name = None
                    self.mp2mpid = None
                    self.vpn_id = None
                    self.vpn_mtu = None
                    self.xconnect_shutdown = None


                class Discovery(object):
                    """
                    l2vpn xc auto discovery info
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery Method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_service_connected
                    
                    	Service Connected
                    	**type**\:  bool
                    
                    .. attribute:: ad_signalling_method
                    
                    	Signaling Protocol
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ce_range
                    
                    	CE Range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: export_route_policy
                    
                    	Export Route Policy
                    	**type**\:  str
                    
                    .. attribute:: export_rt
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                    
                    .. attribute:: import_rt
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2c_es
                    
                    	Number of ce2ce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2ce_advertised
                    
                    	Number of ce2ce Advertised
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rd_value
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                    
                    .. attribute:: vpn_added
                    
                    	VPN Added
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_service_connected = None
                        self.ad_signalling_method = None
                        self.ce_range = None
                        self.export_route_policy = None
                        self.export_rt = YList()
                        self.export_rt.parent = self
                        self.export_rt.name = 'export_rt'
                        self.import_rt = YList()
                        self.import_rt.parent = self
                        self.import_rt.name = 'import_rt'
                        self.number_a_cs = None
                        self.number_a_cs_up = None
                        self.number_ce2c_es = None
                        self.number_ce2ce_advertised = None
                        self.number_p_ws_up = None
                        self.number_pseudowires = None
                        self.rd_value = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                        self.rd_value.parent = self
                        self.vpn_added = None


                    class RdValue(object):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                            self.auto.parent = self
                            self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rd = None
                            self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                            self.v4_addr.parent = self


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto_index = None
                                self.router_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto_index is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rd is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue']['meta_info']


                    class ImportRt(object):
                        """
                        Import Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.es_import = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                            self.es_import.parent = self
                            self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rt = None
                            self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                            self.v4_addr.parent = self


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr']['meta_info']


                        class EsImport(object):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.high_bytes = None
                                self.low_bytes = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.high_bytes is not None:
                                    return True

                                if self.low_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.es_import is not None and self.es_import._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rt is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt']['meta_info']


                    class ExportRt(object):
                        """
                        Export Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.es_import = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                            self.es_import.parent = self
                            self.four_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rt = None
                            self.two_byte_as = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                            self.v4_addr.parent = self


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr']['meta_info']


                        class EsImport(object):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.high_bytes = None
                                self.low_bytes = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.high_bytes is not None:
                                    return True

                                if self.low_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.es_import is not None and self.es_import._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rt is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_service_connected is not None:
                            return True

                        if self.ad_signalling_method is not None:
                            return True

                        if self.ce_range is not None:
                            return True

                        if self.export_route_policy is not None:
                            return True

                        if self.export_rt is not None:
                            for child_ref in self.export_rt:
                                if child_ref._has_data():
                                    return True

                        if self.import_rt is not None:
                            for child_ref in self.import_rt:
                                if child_ref._has_data():
                                    return True

                        if self.number_a_cs is not None:
                            return True

                        if self.number_a_cs_up is not None:
                            return True

                        if self.number_ce2c_es is not None:
                            return True

                        if self.number_ce2ce_advertised is not None:
                            return True

                        if self.number_p_ws_up is not None:
                            return True

                        if self.number_pseudowires is not None:
                            return True

                        if self.rd_value is not None and self.rd_value._has_data():
                            return True

                        if self.vpn_added is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp.Discovery']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.discovery is not None and self.discovery._has_data():
                        return True

                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.l2_encapsulation is not None:
                        return True

                    if self.mp2_mp_name is not None:
                        return True

                    if self.mp2mp_name is not None:
                        return True

                    if self.mp2mpid is not None:
                        return True

                    if self.vpn_id is not None:
                        return True

                    if self.vpn_mtu is not None:
                        return True

                    if self.xconnect_shutdown is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps.XconnectMp2Mp']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect_mp2mp is not None:
                    for child_ref in self.xconnect_mp2mp:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.XconnectMp2Mps']['meta_info']


        class Indexes(object):
            """
            ID Manager Index Table
            
            .. attribute:: index
            
            	ID Manager Index Pool
            	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Indexes.Index>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.index = YList()
                self.index.parent = self
                self.index.name = 'index'


            class Index(object):
                """
                ID Manager Index Pool
                
                .. attribute:: pool_id  <key>
                
                	Pool ID
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: allocated_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: application_type
                
                	Application Type
                	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                
                .. attribute:: max_num_id_mgr
                
                	Maximum number of pool extensions
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_id_mgr_in_use
                
                	ID mgr instances in use
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_id_xr
                
                	Pool Id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_size
                
                	Pool size
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: zombied_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.pool_id = None
                    self.allocated_ids = None
                    self.application_type = None
                    self.max_num_id_mgr = None
                    self.num_id_mgr_in_use = None
                    self.pool_id_xr = None
                    self.pool_size = None
                    self.zombied_ids = None

                @property
                def _common_path(self):
                    if self.pool_id is None:
                        raise YPYModelError('Key property pool_id is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:indexes/Cisco-IOS-XR-l2vpn-oper:index[Cisco-IOS-XR-l2vpn-oper:pool-id = ' + str(self.pool_id) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.pool_id is not None:
                        return True

                    if self.allocated_ids is not None:
                        return True

                    if self.application_type is not None:
                        return True

                    if self.max_num_id_mgr is not None:
                        return True

                    if self.num_id_mgr_in_use is not None:
                        return True

                    if self.pool_id_xr is not None:
                        return True

                    if self.pool_size is not None:
                        return True

                    if self.zombied_ids is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Indexes.Index']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:indexes'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.index is not None:
                    for child_ref in self.index:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.Indexes']['meta_info']


        class XconnectSummary(object):
            """
            XConnect summary information
            
            .. attribute:: admin_down_backup_interface_xconnects
            
            	Number of XCs with backup interface in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_xconnects
            
            	Number of XCs with backup PW in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_interface_xconnects
            
            	Number of XCs with backup interface in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_xconnects
            
            	Number of XCs with backup PW in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2_ceconnections
            
            	Number of Ce2Ce connections
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_advertized
            
            	Number of CE2CE connections that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_not_advertized
            
            	Number of CE2CE connections that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects
            
            	Number of mp2mp xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_advertised
            
            	Number of Mp2mp XCs that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_down
            
            	Number of Mp2mp XCs that have ben admined down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_up
            
            	Number of Mp2mp XCs that have been admined up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnectss_not_advertised
            
            	Number of Mp2mp XCs that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_administratively_down
            
            	Number of xconnects with segments in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup
            
            	Number of XCs currently using backup PW (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup_interface
            
            	Number of XCs currently using backup interface (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_down
            
            	Number of xconnects whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_locally_switched
            
            	Number of locally switched xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
            
            	Number of xconnects of type attachment circuit to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
            
            	Number of xconnects of type monitor session to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
            
            	Number of xconnects of type PseudoWire To PseudoWire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_unresolved
            
            	Number of xconnects whose state is unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_up
            
            	Numxber of xconnects whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_interface
            
            	Number of XCs configured with backup interface
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_pw
            
            	Number of XCs configured with backup PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_xconnects
            
            	Number of cross\-connects partially programmed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_interface_xconnects
            
            	Number of XCs with backup interface in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_xconnects
            
            	Number of XCs with backup PW in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_ready_backup_xconnects
            
            	Number of XCs with backup PW in standby ready state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_interface_xconnects
            
            	Number of XCs with backup interface in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_xconnects
            
            	Number of XCs with backup PW in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.admin_down_backup_interface_xconnects = None
                self.admin_down_backup_xconnects = None
                self.down_backup_interface_xconnects = None
                self.down_backup_xconnects = None
                self.number_ce2_ceconnections = None
                self.number_ce2ce_advertized = None
                self.number_ce2ce_not_advertized = None
                self.number_groups = None
                self.number_mp2mp_xconnects = None
                self.number_mp2mp_xconnects_advertised = None
                self.number_mp2mp_xconnects_down = None
                self.number_mp2mp_xconnects_up = None
                self.number_mp2mp_xconnectss_not_advertised = None
                self.number_xconnects = None
                self.number_xconnects_administratively_down = None
                self.number_xconnects_currently_using_backup = None
                self.number_xconnects_currently_using_backup_interface = None
                self.number_xconnects_down = None
                self.number_xconnects_locally_switched = None
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
                self.number_xconnects_type_monitor_session_to_pseudo_wire = None
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
                self.number_xconnects_unresolved = None
                self.number_xconnects_up = None
                self.number_xconnects_with_backup_interface = None
                self.number_xconnects_with_backup_pw = None
                self.out_of_memory_state = None
                self.partially_programmed_xconnects = None
                self.standby_backup_interface_xconnects = None
                self.standby_backup_xconnects = None
                self.standby_ready_backup_xconnects = None
                self.unresolved_backup_interface_xconnects = None
                self.unresolved_backup_xconnects = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.admin_down_backup_interface_xconnects is not None:
                    return True

                if self.admin_down_backup_xconnects is not None:
                    return True

                if self.down_backup_interface_xconnects is not None:
                    return True

                if self.down_backup_xconnects is not None:
                    return True

                if self.number_ce2_ceconnections is not None:
                    return True

                if self.number_ce2ce_advertized is not None:
                    return True

                if self.number_ce2ce_not_advertized is not None:
                    return True

                if self.number_groups is not None:
                    return True

                if self.number_mp2mp_xconnects is not None:
                    return True

                if self.number_mp2mp_xconnects_advertised is not None:
                    return True

                if self.number_mp2mp_xconnects_down is not None:
                    return True

                if self.number_mp2mp_xconnects_up is not None:
                    return True

                if self.number_mp2mp_xconnectss_not_advertised is not None:
                    return True

                if self.number_xconnects is not None:
                    return True

                if self.number_xconnects_administratively_down is not None:
                    return True

                if self.number_xconnects_currently_using_backup is not None:
                    return True

                if self.number_xconnects_currently_using_backup_interface is not None:
                    return True

                if self.number_xconnects_down is not None:
                    return True

                if self.number_xconnects_locally_switched is not None:
                    return True

                if self.number_xconnects_type_attachment_circuit_to_pseudo_wire is not None:
                    return True

                if self.number_xconnects_type_monitor_session_to_pseudo_wire is not None:
                    return True

                if self.number_xconnects_type_pseudo_wire_to_pseudo_wire is not None:
                    return True

                if self.number_xconnects_unresolved is not None:
                    return True

                if self.number_xconnects_up is not None:
                    return True

                if self.number_xconnects_with_backup_interface is not None:
                    return True

                if self.number_xconnects_with_backup_pw is not None:
                    return True

                if self.out_of_memory_state is not None:
                    return True

                if self.partially_programmed_xconnects is not None:
                    return True

                if self.standby_backup_interface_xconnects is not None:
                    return True

                if self.standby_backup_xconnects is not None:
                    return True

                if self.standby_ready_backup_xconnects is not None:
                    return True

                if self.unresolved_backup_interface_xconnects is not None:
                    return True

                if self.unresolved_backup_xconnects is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.XconnectSummary']['meta_info']


        class ProcFsm(object):
            """
            L2VPN Process FSM information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.event_history = YList()
                self.event_history.parent = self
                self.event_history.name = 'event_history'
                self.failover_status = L2Vpnv2.Standby.ProcFsm.FailoverStatus()
                self.failover_status.parent = self
                self.issu_status = L2Vpnv2.Standby.ProcFsm.IssuStatus()
                self.issu_status.parent = self
                self.nsr_status = L2Vpnv2.Standby.ProcFsm.NsrStatus()
                self.nsr_status.parent = self
                self.process_role = None
                self.process_state = None
                self.report_card = YList()
                self.report_card.parent = self
                self.report_card.name = 'report_card'
                self.state_transition_time = YLeafList()
                self.state_transition_time.parent = self
                self.state_transition_time.name = 'state_transition_time'
                self.sw_install_in_progress = None
                self.sync_flags = None
                self.xid_info = YList()
                self.xid_info.parent = self
                self.xid_info.name = 'xid_info'


            class FailoverStatus(object):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.master_time = None
                    self.start_time = None
                    self.triggered_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:failover-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.master_time is not None:
                        return True

                    if self.start_time is not None:
                        return True

                    if self.triggered_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.ProcFsm.FailoverStatus']['meta_info']


            class NsrStatus(object):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.ProcFsm.NsrStatus']['meta_info']


            class IssuStatus(object):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.ProcFsm.IssuStatus']['meta_info']


            class XidInfo(object):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.app_type = None
                    self.sent_ids = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:xid-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.app_type is not None:
                        return True

                    if self.sent_ids is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.ProcFsm.XidInfo']['meta_info']


            class ReportCard(object):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.collaborator_idt_done = None
                    self.collaborator_is_connected = None
                    self.collaborator_skipped = None
                    self.connection_change_time = None
                    self.idt_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:report-card'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.collaborator_idt_done is not None:
                        return True

                    if self.collaborator_is_connected is not None:
                        return True

                    if self.collaborator_skipped is not None:
                        return True

                    if self.connection_change_time is not None:
                        return True

                    if self.idt_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.ProcFsm.ReportCard']['meta_info']


            class EventHistory(object):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_timestamp = None
                    self.new_state = None
                    self.previous_state = None
                    self.process_collaborator = None
                    self.process_event = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:event-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_timestamp is not None:
                        return True

                    if self.new_state is not None:
                        return True

                    if self.previous_state is not None:
                        return True

                    if self.process_collaborator is not None:
                        return True

                    if self.process_event is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.ProcFsm.EventHistory']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:proc-fsm'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.event_history is not None:
                    for child_ref in self.event_history:
                        if child_ref._has_data():
                            return True

                if self.failover_status is not None and self.failover_status._has_data():
                    return True

                if self.issu_status is not None and self.issu_status._has_data():
                    return True

                if self.nsr_status is not None and self.nsr_status._has_data():
                    return True

                if self.process_role is not None:
                    return True

                if self.process_state is not None:
                    return True

                if self.report_card is not None:
                    for child_ref in self.report_card:
                        if child_ref._has_data():
                            return True

                if self.state_transition_time is not None:
                    for child in self.state_transition_time:
                        if child is not None:
                            return True

                if self.sw_install_in_progress is not None:
                    return True

                if self.sync_flags is not None:
                    return True

                if self.xid_info is not None:
                    for child_ref in self.xid_info:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.ProcFsm']['meta_info']


        class MstpPorts(object):
            """
            L2VPN MSTP Port Table
            
            .. attribute:: mstp_port
            
            	MSTP Port information
            	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts.MstpPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mstp_port = YList()
                self.mstp_port.parent = self
                self.mstp_port.name = 'mstp_port'


            class MstpPort(object):
                """
                MSTP Port information
                
                .. attribute:: interface  <key>
                
                	Interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: msti_entry
                
                	MSTI
                	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry>`
                
                .. attribute:: mstp_interface_handle
                
                	Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protected
                
                	Protected
                	**type**\:  bool
                
                .. attribute:: reference_count
                
                	Reference Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = None
                    self.interface_name = None
                    self.msti_entry = YList()
                    self.msti_entry.parent = self
                    self.msti_entry.name = 'msti_entry'
                    self.mstp_interface_handle = None
                    self.protected = None
                    self.reference_count = None


                class MstiEntry(object):
                    """
                    MSTI
                    
                    .. attribute:: ack_count
                    
                    	Ack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_count
                    
                    	BD count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_entry
                    
                    	BD entries
                    	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                    
                    .. attribute:: cfg_ms_ti
                    
                    	 Configured MSTi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flush_count
                    
                    	Flush count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_flags
                    
                    	Msti Flags
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_state
                    
                    	Msti State
                    	**type**\:   :py:class:`L2VpnMstiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiStateEnum>`
                    
                    .. attribute:: nack_count
                    
                    	Nack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rcv_count
                    
                    	Receive count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ack_count = None
                        self.bd_count = None
                        self.bd_entry = YList()
                        self.bd_entry.parent = self
                        self.bd_entry.name = 'bd_entry'
                        self.cfg_ms_ti = None
                        self.flush_count = None
                        self.interface_count = None
                        self.msti_flags = None
                        self.msti_state = None
                        self.nack_count = None
                        self.rcv_count = None


                    class BdEntry(object):
                        """
                        BD entries
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bdif_count
                        
                        	BD Intf Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bdid = None
                            self.bdif_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bd-entry'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bdid is not None:
                                return True

                            if self.bdif_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:msti-entry'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ack_count is not None:
                            return True

                        if self.bd_count is not None:
                            return True

                        if self.bd_entry is not None:
                            for child_ref in self.bd_entry:
                                if child_ref._has_data():
                                    return True

                        if self.cfg_ms_ti is not None:
                            return True

                        if self.flush_count is not None:
                            return True

                        if self.interface_count is not None:
                            return True

                        if self.msti_flags is not None:
                            return True

                        if self.msti_state is not None:
                            return True

                        if self.nack_count is not None:
                            return True

                        if self.rcv_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.MstpPorts.MstpPort.MstiEntry']['meta_info']

                @property
                def _common_path(self):
                    if self.interface is None:
                        raise YPYModelError('Key property interface is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mstp-ports/Cisco-IOS-XR-l2vpn-oper:mstp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        return True

                    if self.interface_name is not None:
                        return True

                    if self.msti_entry is not None:
                        for child_ref in self.msti_entry:
                            if child_ref._has_data():
                                return True

                    if self.mstp_interface_handle is not None:
                        return True

                    if self.protected is not None:
                        return True

                    if self.reference_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.MstpPorts.MstpPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mstp-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mstp_port is not None:
                    for child_ref in self.mstp_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.MstpPorts']['meta_info']


        class GenericInterfaceListDetails(object):
            """
            L2VPN generic interface list Detail Table
            
            .. attribute:: generic_interface_list_detail
            
            	Generic Interface List detail information
            	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.generic_interface_list_detail = YList()
                self.generic_interface_list_detail.parent = self
                self.generic_interface_list_detail.name = 'generic_interface_list_detail'


            class GenericInterfaceListDetail(object):
                """
                Generic Interface List detail information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: psedowire_ether_items
                
                	Number PW Ether Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_ether_range
                
                	PW\-Ether ranges
                	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                
                .. attribute:: pseudowire_iw_items
                
                	Number PW IW Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_iw_range
                
                	PW\-IW ranges
                	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                
                .. attribute:: summary
                
                	Summary information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_list_name = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.is_provisioned = None
                    self.items = None
                    self.psedowire_ether_items = None
                    self.pseudowire_ether_range = YList()
                    self.pseudowire_ether_range.parent = self
                    self.pseudowire_ether_range.name = 'pseudowire_ether_range'
                    self.pseudowire_iw_items = None
                    self.pseudowire_iw_range = YList()
                    self.pseudowire_iw_range.parent = self
                    self.pseudowire_iw_range.name = 'pseudowire_iw_range'
                    self.summary = L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                    self.summary.parent = self


                class Summary(object):
                    """
                    Summary information
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'
                        self.interface_list_id = None
                        self.interface_list_name_xr = None
                        self.items = None
                        self.number_of_interfaces = None


                    class Interface(object):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_fib_downloaded = None
                            self.not_supported_replications = None
                            self.pending_replications = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_fib_downloaded is not None:
                                return True

                            if self.not_supported_replications is not None:
                                return True

                            if self.pending_replications is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        if self.interface_list_id is not None:
                            return True

                        if self.interface_list_name_xr is not None:
                            return True

                        if self.items is not None:
                            return True

                        if self.number_of_interfaces is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary']['meta_info']


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface']['meta_info']


                class PseudowireEtherRange(object):
                    """
                    PW\-Ether ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lower = None
                        self.upper = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lower is not None:
                            return True

                        if self.upper is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange']['meta_info']


                class PseudowireIwRange(object):
                    """
                    PW\-IW ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lower = None
                        self.upper = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lower is not None:
                            return True

                        if self.upper is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_list_name is None:
                        raise YPYModelError('Key property interface_list_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-detail[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_list_name is not None:
                        return True

                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.is_provisioned is not None:
                        return True

                    if self.items is not None:
                        return True

                    if self.psedowire_ether_items is not None:
                        return True

                    if self.pseudowire_ether_range is not None:
                        for child_ref in self.pseudowire_ether_range:
                            if child_ref._has_data():
                                return True

                    if self.pseudowire_iw_items is not None:
                        return True

                    if self.pseudowire_iw_range is not None:
                        for child_ref in self.pseudowire_iw_range:
                            if child_ref._has_data():
                                return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.generic_interface_list_detail is not None:
                    for child_ref in self.generic_interface_list_detail:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.GenericInterfaceListDetails']['meta_info']


        class L2VpnResourceState(object):
            """
            L2VPN resource state information
            
            .. attribute:: resource_out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.resource_out_of_memory_state = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:l2vpn-resource-state'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.resource_out_of_memory_state is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.L2VpnResourceState']['meta_info']


        class BridgeDomains(object):
            """
            VPLS Bridge Domain Information
            
            .. attribute:: bridge_domain
            
            	VPLS Bridge Domain Information
            	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bridge_domain = YList()
                self.bridge_domain.parent = self
                self.bridge_domain.name = 'bridge_domain'


            class BridgeDomain(object):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: bridge_access_pws
                
                	VPLS Bridge Domain Access Pseudowire Table
                	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                
                .. attribute:: bridge_access_vfi_table
                
                	Bridge Domain Access VFI Table
                	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                
                .. attribute:: bridge_acs
                
                	VPLS Bridge Domain Attachment Circuit Table
                	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs>`
                
                .. attribute:: bridge_core_vfi_table
                
                	Bridge Domain Core VFI Table
                	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                
                .. attribute:: bridge_domain_group_name
                
                	Bridge Domain Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: bridge_domain_info
                
                	VPLS Bridge Domain Information
                	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                
                .. attribute:: bridge_domain_name
                
                	Bridge Domain Name
                	**type**\:  str
                
                	**length:** 1..27
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_access_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws()
                    self.bridge_access_pws.parent = self
                    self.bridge_access_vfi_table = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                    self.bridge_access_vfi_table.parent = self
                    self.bridge_acs = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs()
                    self.bridge_acs.parent = self
                    self.bridge_core_vfi_table = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                    self.bridge_core_vfi_table.parent = self
                    self.bridge_domain_group_name = None
                    self.bridge_domain_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                    self.bridge_domain_info.parent = self
                    self.bridge_domain_name = None


                class BridgeAccessVfiTable(object):
                    """
                    Bridge Domain Access VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                        self.bridge_pws.parent = self


                    class BridgePws(object):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_pw = YList()
                            self.bridge_pw.parent = self
                            self.bridge_pw.name = 'bridge_pw'


                        class BridgePw(object):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_access = None
                                self.neighbor = None
                                self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self.pseudowire_id = None
                                self.pw_type = None
                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None


                            class Pseudowire(object):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_remote_down = None
                                    self.admited_bw = None
                                    self.auto_discovery = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.backup_pw = None
                                    self.bitrate_mismatched = None
                                    self.bridge_pw_type_mismatch = None
                                    self.cas_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.disable_delay = None
                                    self.disable_never = None
                                    self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self.evpn_src_acid = None
                                    self.fe_ctype = None
                                    self.forward_class = None
                                    self.freq_mismatched = None
                                    self.illegal_control_word = None
                                    self.imposed_vlan_id = None
                                    self.interworking = None
                                    self.ipv6_local_source_address = None
                                    self.is_evpnvpws_type = None
                                    self.is_flow_label_static = None
                                    self.is_multi_segment_pseudowire = None
                                    self.is_partially_programmed = None
                                    self.is_pwr_type = None
                                    self.is_vfi = None
                                    self.last_time_status_changed = None
                                    self.last_time_status_down = None
                                    self.ldp_label_advertise_failed = None
                                    self.load_balance = None
                                    self.local_control_word = None
                                    self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self.local_label_failed = None
                                    self.local_pseudo_wire_type = None
                                    self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self.local_source_address = None
                                    self.mac_limit_oper_down = None
                                    self.mtu_mismatched = None
                                    self.not_supported_qinq = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.out_of_memory_state = None
                                    self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self.payload_bytes_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self.preferred_path_disable_fallback = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.primary_pw = None
                                    self.protocol = None
                                    self.pseudo_wire_id = None
                                    self.pseudo_wire_state = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.pw_class_name = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_redundancy_initial_delay = None
                                    self.pw_redundancy_one_way = None
                                    self.pw_status_use = None
                                    self.pwlsd_rewrite_failed = None
                                    self.remote_control_word = None
                                    self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self.remote_label_failed = None
                                    self.remote_pseudo_wire_type = None
                                    self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self.required_bw = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.rtp_mismatched = None
                                    self.sequencing_type = None
                                    self.shutdown = None
                                    self.sig_pkts_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self.table_policy_name = None
                                    self.tag_rewrite = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.time_elapsed_status_changed = None
                                    self.time_elapsed_status_down = None
                                    self.transport_lsp_down = None
                                    self.xconnect_id = None


                                class PeerId(object):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.internal_label = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.type = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.internal_label is not None:
                                            return True

                                        if self.ipv4_peer_id is not None:
                                            return True

                                        if self.ipv6_peer_id is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                                class EncapsulationInfo(object):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self.encapsulation = None
                                        self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self


                                    class Atom(object):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_pseudowire_headend = None
                                            self.is_sai_itype2 = None
                                            self.is_tai_itype2 = None
                                            self.ldp_label_advertisment_failed = None
                                            self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self.local_c_ctype = None
                                            self.local_ceid = None
                                            self.local_cv_type = None
                                            self.local_group_id = None
                                            self.local_label = None
                                            self.local_ldp_id = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.local_veid = None
                                            self.lsd_rewrite_failed = None
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self.rem_saii = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self.remote_c_ctype = None
                                            self.remote_ceid = None
                                            self.remote_cv_type = None
                                            self.remote_group_id = None
                                            self.remote_label = None
                                            self.remote_ldp_id = None
                                            self.remote_source_address = None
                                            self.remote_veid = None
                                            self.saii = None
                                            self.source_address = None
                                            self.taii = None


                                        class LocalAgi(object):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                        class RemoteAgi(object):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                        class MultiSegmentPseudowireStats(object):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.received_bytes = None
                                                self.received_packets = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.received_bytes is not None:
                                                    return True

                                                if self.received_packets is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_pseudowire_headend is not None:
                                                return True

                                            if self.is_sai_itype2 is not None:
                                                return True

                                            if self.is_tai_itype2 is not None:
                                                return True

                                            if self.ldp_label_advertisment_failed is not None:
                                                return True

                                            if self.local_agi is not None and self.local_agi._has_data():
                                                return True

                                            if self.local_c_ctype is not None:
                                                return True

                                            if self.local_ceid is not None:
                                                return True

                                            if self.local_cv_type is not None:
                                                return True

                                            if self.local_group_id is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_ldp_id is not None:
                                                return True

                                            if self.local_saii_gbl_id is not None:
                                                return True

                                            if self.local_saiiac_id is not None:
                                                return True

                                            if self.local_taii_gbl_id is not None:
                                                return True

                                            if self.local_taiiac_id is not None:
                                                return True

                                            if self.local_veid is not None:
                                                return True

                                            if self.lsd_rewrite_failed is not None:
                                                return True

                                            if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                return True

                                            if self.rem_saii is not None:
                                                return True

                                            if self.rem_saii_gbl_id is not None:
                                                return True

                                            if self.rem_saiiac_id is not None:
                                                return True

                                            if self.rem_taii is not None:
                                                return True

                                            if self.rem_taii_gbl_id is not None:
                                                return True

                                            if self.rem_taiiac_id is not None:
                                                return True

                                            if self.remote_agi is not None and self.remote_agi._has_data():
                                                return True

                                            if self.remote_c_ctype is not None:
                                                return True

                                            if self.remote_ceid is not None:
                                                return True

                                            if self.remote_cv_type is not None:
                                                return True

                                            if self.remote_group_id is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_ldp_id is not None:
                                                return True

                                            if self.remote_source_address is not None:
                                                return True

                                            if self.remote_veid is not None:
                                                return True

                                            if self.saii is not None:
                                                return True

                                            if self.source_address is not None:
                                                return True

                                            if self.taii is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                    class L2Tpv3(object):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dont_fragment_bit = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.l2tp_class_name = None
                                            self.local_cookie_high_value = None
                                            self.local_cookie_low_value = None
                                            self.local_cookie_size = None
                                            self.local_secondary_cookie_high_value = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_size = None
                                            self.local_session_id = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.remote_circuit_status_up = None
                                            self.remote_cookie_high_value = None
                                            self.remote_cookie_low_value = None
                                            self.remote_cookie_size = None
                                            self.remote_session_id = None
                                            self.tos = None
                                            self.tos_mode = None
                                            self.ttl = None
                                            self.tunnel_state = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dont_fragment_bit is not None:
                                                return True

                                            if self.ipv4_source_address is not None:
                                                return True

                                            if self.ipv6_source_address is not None:
                                                return True

                                            if self.l2tp_class_name is not None:
                                                return True

                                            if self.local_cookie_high_value is not None:
                                                return True

                                            if self.local_cookie_low_value is not None:
                                                return True

                                            if self.local_cookie_size is not None:
                                                return True

                                            if self.local_secondary_cookie_high_value is not None:
                                                return True

                                            if self.local_secondary_cookie_low_value is not None:
                                                return True

                                            if self.local_secondary_cookie_size is not None:
                                                return True

                                            if self.local_session_id is not None:
                                                return True

                                            if self.path_mtu_enabled is not None:
                                                return True

                                            if self.path_mtu_max_value is not None:
                                                return True

                                            if self.remote_circuit_status_up is not None:
                                                return True

                                            if self.remote_cookie_high_value is not None:
                                                return True

                                            if self.remote_cookie_low_value is not None:
                                                return True

                                            if self.remote_cookie_size is not None:
                                                return True

                                            if self.remote_session_id is not None:
                                                return True

                                            if self.tos is not None:
                                                return True

                                            if self.tos_mode is not None:
                                                return True

                                            if self.ttl is not None:
                                                return True

                                            if self.tunnel_state is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atom is not None and self.atom._has_data():
                                            return True

                                        if self.encapsulation is not None:
                                            return True

                                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                                class LocalInterface(object):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                                class RemoteInterface(object):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                                class PreferredPath(object):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ip_tunnel_interface_number = None
                                        self.next_hop_ip = None
                                        self.option = None
                                        self.te_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ip_tunnel_interface_number is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        if self.option is not None:
                                            return True

                                        if self.te_tunnel_interface_number is not None:
                                            return True

                                        if self.tp_tunnel_interface_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                                class LocalSignalling(object):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                                class RemoteSignalling(object):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                                class P2MpPw(object):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local_available = None
                                        self.local_extended_tunnel_id = None
                                        self.local_flags = None
                                        self.local_label = None
                                        self.local_p2mp_id = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.remote_available = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_flags = None
                                        self.remote_label = None
                                        self.remote_p2mp_id = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local_available is not None:
                                            return True

                                        if self.local_extended_tunnel_id is not None:
                                            return True

                                        if self.local_flags is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_p2mp_id is not None:
                                            return True

                                        if self.local_ptree_type is not None:
                                            return True

                                        if self.local_tunnel_id is not None:
                                            return True

                                        if self.remote_available is not None:
                                            return True

                                        if self.remote_extended_tunnel_id is not None:
                                            return True

                                        if self.remote_flags is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_p2mp_id is not None:
                                            return True

                                        if self.remote_ptree_type is not None:
                                            return True

                                        if self.remote_tunnel_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_remote_down is not None:
                                        return True

                                    if self.admited_bw is not None:
                                        return True

                                    if self.auto_discovery is not None:
                                        return True

                                    if self.backup_active is not None:
                                        return True

                                    if self.backup_force_active is not None:
                                        return True

                                    if self.backup_pw is not None:
                                        return True

                                    if self.bitrate_mismatched is not None:
                                        return True

                                    if self.bridge_pw_type_mismatch is not None:
                                        return True

                                    if self.cas_mismatched is not None:
                                        return True

                                    if self.diff_ts_mismatched is not None:
                                        return True

                                    if self.disable_delay is not None:
                                        return True

                                    if self.disable_never is not None:
                                        return True

                                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                        return True

                                    if self.evpn_src_acid is not None:
                                        return True

                                    if self.fe_ctype is not None:
                                        return True

                                    if self.forward_class is not None:
                                        return True

                                    if self.freq_mismatched is not None:
                                        return True

                                    if self.illegal_control_word is not None:
                                        return True

                                    if self.imposed_vlan_id is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.ipv6_local_source_address is not None:
                                        return True

                                    if self.is_evpnvpws_type is not None:
                                        return True

                                    if self.is_flow_label_static is not None:
                                        return True

                                    if self.is_multi_segment_pseudowire is not None:
                                        return True

                                    if self.is_partially_programmed is not None:
                                        return True

                                    if self.is_pwr_type is not None:
                                        return True

                                    if self.is_vfi is not None:
                                        return True

                                    if self.last_time_status_changed is not None:
                                        return True

                                    if self.last_time_status_down is not None:
                                        return True

                                    if self.ldp_label_advertise_failed is not None:
                                        return True

                                    if self.load_balance is not None:
                                        return True

                                    if self.local_control_word is not None:
                                        return True

                                    if self.local_interface is not None and self.local_interface._has_data():
                                        return True

                                    if self.local_label_failed is not None:
                                        return True

                                    if self.local_pseudo_wire_type is not None:
                                        return True

                                    if self.local_signalling is not None and self.local_signalling._has_data():
                                        return True

                                    if self.local_source_address is not None:
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.not_supported_qinq is not None:
                                        return True

                                    if self.num_ma_cwithdraw_msg_received is not None:
                                        return True

                                    if self.number_ma_cwithdraw_message_sent is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                        return True

                                    if self.payload_bytes_mismatched is not None:
                                        return True

                                    if self.payload_type_mismatched is not None:
                                        return True

                                    if self.peer_id is not None and self.peer_id._has_data():
                                        return True

                                    if self.preferred_path is not None and self.preferred_path._has_data():
                                        return True

                                    if self.preferred_path_disable_fallback is not None:
                                        return True

                                    if self.primary_peer_id is not None:
                                        return True

                                    if self.primary_pseudo_wire_id is not None:
                                        return True

                                    if self.primary_pw is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    if self.pseudo_wire_id is not None:
                                        return True

                                    if self.pseudo_wire_state is not None:
                                        return True

                                    if self.pseudo_wire_type_mismatched is not None:
                                        return True

                                    if self.pw_class_name is not None:
                                        return True

                                    if self.pw_flow_label_code17_disabled is not None:
                                        return True

                                    if self.pw_flow_label_type is not None:
                                        return True

                                    if self.pw_flow_label_type_cfg is not None:
                                        return True

                                    if self.pw_redundancy_initial_delay is not None:
                                        return True

                                    if self.pw_redundancy_one_way is not None:
                                        return True

                                    if self.pw_status_use is not None:
                                        return True

                                    if self.pwlsd_rewrite_failed is not None:
                                        return True

                                    if self.remote_control_word is not None:
                                        return True

                                    if self.remote_interface is not None and self.remote_interface._has_data():
                                        return True

                                    if self.remote_label_failed is not None:
                                        return True

                                    if self.remote_pseudo_wire_type is not None:
                                        return True

                                    if self.remote_signalling is not None and self.remote_signalling._has_data():
                                        return True

                                    if self.required_bw is not None:
                                        return True

                                    if self.resync_enabled is not None:
                                        return True

                                    if self.resync_threshold is not None:
                                        return True

                                    if self.rtp_mismatched is not None:
                                        return True

                                    if self.sequencing_type is not None:
                                        return True

                                    if self.shutdown is not None:
                                        return True

                                    if self.sig_pkts_mismatched is not None:
                                        return True

                                    if self.ssrc_mismatched is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.table_policy_name is not None:
                                        return True

                                    if self.tag_rewrite is not None:
                                        return True

                                    if self.time_created is not None:
                                        return True

                                    if self.time_elapsed_creation is not None:
                                        return True

                                    if self.time_elapsed_status_changed is not None:
                                        return True

                                    if self.time_elapsed_status_down is not None:
                                        return True

                                    if self.transport_lsp_down is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_access is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.pseudowire is not None and self.pseudowire._has_data():
                                    return True

                                if self.pseudowire_id is not None:
                                    return True

                                if self.pw_type is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                if self.ve_id_vpls_id_0_3 is not None:
                                    return True

                                if self.vpls_id_4_7 is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_pw is not None:
                                for child_ref in self.bridge_pw:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_pws is not None and self.bridge_pws._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable']['meta_info']


                class BridgeCoreVfiTable(object):
                    """
                    Bridge Domain Core VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_pws = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                        self.bridge_pws.parent = self


                    class BridgePws(object):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_pw = YList()
                            self.bridge_pw.parent = self
                            self.bridge_pw.name = 'bridge_pw'


                        class BridgePw(object):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_access = None
                                self.neighbor = None
                                self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self.pseudowire_id = None
                                self.pw_type = None
                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None


                            class Pseudowire(object):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_remote_down = None
                                    self.admited_bw = None
                                    self.auto_discovery = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.backup_pw = None
                                    self.bitrate_mismatched = None
                                    self.bridge_pw_type_mismatch = None
                                    self.cas_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.disable_delay = None
                                    self.disable_never = None
                                    self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self.evpn_src_acid = None
                                    self.fe_ctype = None
                                    self.forward_class = None
                                    self.freq_mismatched = None
                                    self.illegal_control_word = None
                                    self.imposed_vlan_id = None
                                    self.interworking = None
                                    self.ipv6_local_source_address = None
                                    self.is_evpnvpws_type = None
                                    self.is_flow_label_static = None
                                    self.is_multi_segment_pseudowire = None
                                    self.is_partially_programmed = None
                                    self.is_pwr_type = None
                                    self.is_vfi = None
                                    self.last_time_status_changed = None
                                    self.last_time_status_down = None
                                    self.ldp_label_advertise_failed = None
                                    self.load_balance = None
                                    self.local_control_word = None
                                    self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self.local_label_failed = None
                                    self.local_pseudo_wire_type = None
                                    self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self.local_source_address = None
                                    self.mac_limit_oper_down = None
                                    self.mtu_mismatched = None
                                    self.not_supported_qinq = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.out_of_memory_state = None
                                    self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self.payload_bytes_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self.preferred_path_disable_fallback = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.primary_pw = None
                                    self.protocol = None
                                    self.pseudo_wire_id = None
                                    self.pseudo_wire_state = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.pw_class_name = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_redundancy_initial_delay = None
                                    self.pw_redundancy_one_way = None
                                    self.pw_status_use = None
                                    self.pwlsd_rewrite_failed = None
                                    self.remote_control_word = None
                                    self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self.remote_label_failed = None
                                    self.remote_pseudo_wire_type = None
                                    self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self.required_bw = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.rtp_mismatched = None
                                    self.sequencing_type = None
                                    self.shutdown = None
                                    self.sig_pkts_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self.table_policy_name = None
                                    self.tag_rewrite = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.time_elapsed_status_changed = None
                                    self.time_elapsed_status_down = None
                                    self.transport_lsp_down = None
                                    self.xconnect_id = None


                                class PeerId(object):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.internal_label = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.type = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.internal_label is not None:
                                            return True

                                        if self.ipv4_peer_id is not None:
                                            return True

                                        if self.ipv6_peer_id is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                                class EncapsulationInfo(object):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self.encapsulation = None
                                        self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self


                                    class Atom(object):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_pseudowire_headend = None
                                            self.is_sai_itype2 = None
                                            self.is_tai_itype2 = None
                                            self.ldp_label_advertisment_failed = None
                                            self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self.local_c_ctype = None
                                            self.local_ceid = None
                                            self.local_cv_type = None
                                            self.local_group_id = None
                                            self.local_label = None
                                            self.local_ldp_id = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.local_veid = None
                                            self.lsd_rewrite_failed = None
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self.rem_saii = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self.remote_c_ctype = None
                                            self.remote_ceid = None
                                            self.remote_cv_type = None
                                            self.remote_group_id = None
                                            self.remote_label = None
                                            self.remote_ldp_id = None
                                            self.remote_source_address = None
                                            self.remote_veid = None
                                            self.saii = None
                                            self.source_address = None
                                            self.taii = None


                                        class LocalAgi(object):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                        class RemoteAgi(object):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                        class MultiSegmentPseudowireStats(object):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.received_bytes = None
                                                self.received_packets = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.received_bytes is not None:
                                                    return True

                                                if self.received_packets is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_pseudowire_headend is not None:
                                                return True

                                            if self.is_sai_itype2 is not None:
                                                return True

                                            if self.is_tai_itype2 is not None:
                                                return True

                                            if self.ldp_label_advertisment_failed is not None:
                                                return True

                                            if self.local_agi is not None and self.local_agi._has_data():
                                                return True

                                            if self.local_c_ctype is not None:
                                                return True

                                            if self.local_ceid is not None:
                                                return True

                                            if self.local_cv_type is not None:
                                                return True

                                            if self.local_group_id is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_ldp_id is not None:
                                                return True

                                            if self.local_saii_gbl_id is not None:
                                                return True

                                            if self.local_saiiac_id is not None:
                                                return True

                                            if self.local_taii_gbl_id is not None:
                                                return True

                                            if self.local_taiiac_id is not None:
                                                return True

                                            if self.local_veid is not None:
                                                return True

                                            if self.lsd_rewrite_failed is not None:
                                                return True

                                            if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                return True

                                            if self.rem_saii is not None:
                                                return True

                                            if self.rem_saii_gbl_id is not None:
                                                return True

                                            if self.rem_saiiac_id is not None:
                                                return True

                                            if self.rem_taii is not None:
                                                return True

                                            if self.rem_taii_gbl_id is not None:
                                                return True

                                            if self.rem_taiiac_id is not None:
                                                return True

                                            if self.remote_agi is not None and self.remote_agi._has_data():
                                                return True

                                            if self.remote_c_ctype is not None:
                                                return True

                                            if self.remote_ceid is not None:
                                                return True

                                            if self.remote_cv_type is not None:
                                                return True

                                            if self.remote_group_id is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_ldp_id is not None:
                                                return True

                                            if self.remote_source_address is not None:
                                                return True

                                            if self.remote_veid is not None:
                                                return True

                                            if self.saii is not None:
                                                return True

                                            if self.source_address is not None:
                                                return True

                                            if self.taii is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                    class L2Tpv3(object):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dont_fragment_bit = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.l2tp_class_name = None
                                            self.local_cookie_high_value = None
                                            self.local_cookie_low_value = None
                                            self.local_cookie_size = None
                                            self.local_secondary_cookie_high_value = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_size = None
                                            self.local_session_id = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.remote_circuit_status_up = None
                                            self.remote_cookie_high_value = None
                                            self.remote_cookie_low_value = None
                                            self.remote_cookie_size = None
                                            self.remote_session_id = None
                                            self.tos = None
                                            self.tos_mode = None
                                            self.ttl = None
                                            self.tunnel_state = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dont_fragment_bit is not None:
                                                return True

                                            if self.ipv4_source_address is not None:
                                                return True

                                            if self.ipv6_source_address is not None:
                                                return True

                                            if self.l2tp_class_name is not None:
                                                return True

                                            if self.local_cookie_high_value is not None:
                                                return True

                                            if self.local_cookie_low_value is not None:
                                                return True

                                            if self.local_cookie_size is not None:
                                                return True

                                            if self.local_secondary_cookie_high_value is not None:
                                                return True

                                            if self.local_secondary_cookie_low_value is not None:
                                                return True

                                            if self.local_secondary_cookie_size is not None:
                                                return True

                                            if self.local_session_id is not None:
                                                return True

                                            if self.path_mtu_enabled is not None:
                                                return True

                                            if self.path_mtu_max_value is not None:
                                                return True

                                            if self.remote_circuit_status_up is not None:
                                                return True

                                            if self.remote_cookie_high_value is not None:
                                                return True

                                            if self.remote_cookie_low_value is not None:
                                                return True

                                            if self.remote_cookie_size is not None:
                                                return True

                                            if self.remote_session_id is not None:
                                                return True

                                            if self.tos is not None:
                                                return True

                                            if self.tos_mode is not None:
                                                return True

                                            if self.ttl is not None:
                                                return True

                                            if self.tunnel_state is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atom is not None and self.atom._has_data():
                                            return True

                                        if self.encapsulation is not None:
                                            return True

                                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                                class LocalInterface(object):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                                class RemoteInterface(object):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                                class PreferredPath(object):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ip_tunnel_interface_number = None
                                        self.next_hop_ip = None
                                        self.option = None
                                        self.te_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ip_tunnel_interface_number is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        if self.option is not None:
                                            return True

                                        if self.te_tunnel_interface_number is not None:
                                            return True

                                        if self.tp_tunnel_interface_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                                class LocalSignalling(object):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                                class RemoteSignalling(object):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                                class P2MpPw(object):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local_available = None
                                        self.local_extended_tunnel_id = None
                                        self.local_flags = None
                                        self.local_label = None
                                        self.local_p2mp_id = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.remote_available = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_flags = None
                                        self.remote_label = None
                                        self.remote_p2mp_id = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local_available is not None:
                                            return True

                                        if self.local_extended_tunnel_id is not None:
                                            return True

                                        if self.local_flags is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_p2mp_id is not None:
                                            return True

                                        if self.local_ptree_type is not None:
                                            return True

                                        if self.local_tunnel_id is not None:
                                            return True

                                        if self.remote_available is not None:
                                            return True

                                        if self.remote_extended_tunnel_id is not None:
                                            return True

                                        if self.remote_flags is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_p2mp_id is not None:
                                            return True

                                        if self.remote_ptree_type is not None:
                                            return True

                                        if self.remote_tunnel_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_remote_down is not None:
                                        return True

                                    if self.admited_bw is not None:
                                        return True

                                    if self.auto_discovery is not None:
                                        return True

                                    if self.backup_active is not None:
                                        return True

                                    if self.backup_force_active is not None:
                                        return True

                                    if self.backup_pw is not None:
                                        return True

                                    if self.bitrate_mismatched is not None:
                                        return True

                                    if self.bridge_pw_type_mismatch is not None:
                                        return True

                                    if self.cas_mismatched is not None:
                                        return True

                                    if self.diff_ts_mismatched is not None:
                                        return True

                                    if self.disable_delay is not None:
                                        return True

                                    if self.disable_never is not None:
                                        return True

                                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                        return True

                                    if self.evpn_src_acid is not None:
                                        return True

                                    if self.fe_ctype is not None:
                                        return True

                                    if self.forward_class is not None:
                                        return True

                                    if self.freq_mismatched is not None:
                                        return True

                                    if self.illegal_control_word is not None:
                                        return True

                                    if self.imposed_vlan_id is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.ipv6_local_source_address is not None:
                                        return True

                                    if self.is_evpnvpws_type is not None:
                                        return True

                                    if self.is_flow_label_static is not None:
                                        return True

                                    if self.is_multi_segment_pseudowire is not None:
                                        return True

                                    if self.is_partially_programmed is not None:
                                        return True

                                    if self.is_pwr_type is not None:
                                        return True

                                    if self.is_vfi is not None:
                                        return True

                                    if self.last_time_status_changed is not None:
                                        return True

                                    if self.last_time_status_down is not None:
                                        return True

                                    if self.ldp_label_advertise_failed is not None:
                                        return True

                                    if self.load_balance is not None:
                                        return True

                                    if self.local_control_word is not None:
                                        return True

                                    if self.local_interface is not None and self.local_interface._has_data():
                                        return True

                                    if self.local_label_failed is not None:
                                        return True

                                    if self.local_pseudo_wire_type is not None:
                                        return True

                                    if self.local_signalling is not None and self.local_signalling._has_data():
                                        return True

                                    if self.local_source_address is not None:
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.not_supported_qinq is not None:
                                        return True

                                    if self.num_ma_cwithdraw_msg_received is not None:
                                        return True

                                    if self.number_ma_cwithdraw_message_sent is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                        return True

                                    if self.payload_bytes_mismatched is not None:
                                        return True

                                    if self.payload_type_mismatched is not None:
                                        return True

                                    if self.peer_id is not None and self.peer_id._has_data():
                                        return True

                                    if self.preferred_path is not None and self.preferred_path._has_data():
                                        return True

                                    if self.preferred_path_disable_fallback is not None:
                                        return True

                                    if self.primary_peer_id is not None:
                                        return True

                                    if self.primary_pseudo_wire_id is not None:
                                        return True

                                    if self.primary_pw is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    if self.pseudo_wire_id is not None:
                                        return True

                                    if self.pseudo_wire_state is not None:
                                        return True

                                    if self.pseudo_wire_type_mismatched is not None:
                                        return True

                                    if self.pw_class_name is not None:
                                        return True

                                    if self.pw_flow_label_code17_disabled is not None:
                                        return True

                                    if self.pw_flow_label_type is not None:
                                        return True

                                    if self.pw_flow_label_type_cfg is not None:
                                        return True

                                    if self.pw_redundancy_initial_delay is not None:
                                        return True

                                    if self.pw_redundancy_one_way is not None:
                                        return True

                                    if self.pw_status_use is not None:
                                        return True

                                    if self.pwlsd_rewrite_failed is not None:
                                        return True

                                    if self.remote_control_word is not None:
                                        return True

                                    if self.remote_interface is not None and self.remote_interface._has_data():
                                        return True

                                    if self.remote_label_failed is not None:
                                        return True

                                    if self.remote_pseudo_wire_type is not None:
                                        return True

                                    if self.remote_signalling is not None and self.remote_signalling._has_data():
                                        return True

                                    if self.required_bw is not None:
                                        return True

                                    if self.resync_enabled is not None:
                                        return True

                                    if self.resync_threshold is not None:
                                        return True

                                    if self.rtp_mismatched is not None:
                                        return True

                                    if self.sequencing_type is not None:
                                        return True

                                    if self.shutdown is not None:
                                        return True

                                    if self.sig_pkts_mismatched is not None:
                                        return True

                                    if self.ssrc_mismatched is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.table_policy_name is not None:
                                        return True

                                    if self.tag_rewrite is not None:
                                        return True

                                    if self.time_created is not None:
                                        return True

                                    if self.time_elapsed_creation is not None:
                                        return True

                                    if self.time_elapsed_status_changed is not None:
                                        return True

                                    if self.time_elapsed_status_down is not None:
                                        return True

                                    if self.transport_lsp_down is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_access is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.pseudowire is not None and self.pseudowire._has_data():
                                    return True

                                if self.pseudowire_id is not None:
                                    return True

                                if self.pw_type is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                if self.ve_id_vpls_id_0_3 is not None:
                                    return True

                                if self.vpls_id_4_7 is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_pw is not None:
                                for child_ref in self.bridge_pw:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_pws is not None and self.bridge_pws._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable']['meta_info']


                class BridgeAcs(object):
                    """
                    VPLS Bridge Domain Attachment Circuit Table
                    
                    .. attribute:: bridge_ac
                    
                    	VPLS Bridge Domain Attachment Circuit
                    	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_ac = YList()
                        self.bridge_ac.parent = self
                        self.bridge_ac.name = 'bridge_ac'


                    class BridgeAc(object):
                        """
                        VPLS Bridge Domain Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                        
                        .. attribute:: bvi_mac_index
                        
                        	MyMac Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bvimac
                        
                        	BVI MAC addresses
                        	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.attachment_circuit = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self.bvi_mac_index = None
                            self.bvimac = YList()
                            self.bvimac.parent = self
                            self.bvimac.name = 'bvimac'
                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                            self.security_parameters.parent = self
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'


                        class AttachmentCircuit(object):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit']['meta_info']


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac']['meta_info']


                        class Bvimac(object):
                            """
                            BVI MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bvimac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac']['meta_info']

                        @property
                        def _common_path(self):
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-acs/Cisco-IOS-XR-l2vpn-oper:bridge-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            if self.bvi_mac_index is not None:
                                return True

                            if self.bvimac is not None:
                                for child_ref in self.bvimac:
                                    if child_ref._has_data():
                                        return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-acs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_ac is not None:
                            for child_ref in self.bridge_ac:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs']['meta_info']


                class BridgeAccessPws(object):
                    """
                    VPLS Bridge Domain Access Pseudowire Table
                    
                    .. attribute:: bridge_access_pw
                    
                    	VPLS Bridge Domain Access Pseudowire
                    	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_access_pw = YList()
                        self.bridge_access_pw.parent = self
                        self.bridge_access_pw.name = 'bridge_access_pw'


                    class BridgeAccessPw(object):
                        """
                        VPLS Bridge Domain Access Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.is_access = None
                            self.neighbor = None
                            self.pseudowire = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                            self.pseudowire.parent = self
                            self.pseudowire_id = None
                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                            self.security_parameters.parent = self
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'


                        class Pseudowire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire']['meta_info']


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.is_access is not None:
                                return True

                            if self.neighbor is not None:
                                return True

                            if self.pseudowire is not None and self.pseudowire._has_data():
                                return True

                            if self.pseudowire_id is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_access_pw is not None:
                            for child_ref in self.bridge_access_pw:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws']['meta_info']


                class BridgeDomainInfo(object):
                    """
                    VPLS Bridge Domain Information
                    
                    .. attribute:: acpwup
                    
                    	Number of bridge ports (AC,PW) which are up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: as_
                    
                    	BGP AS number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_access_vfi
                    
                    	Access Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                    
                    .. attribute:: bridge_coupled_state
                    
                    	Bridge\-domain coupled state
                    	**type**\:   :py:class:`L2VpnBridgeCoupledStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledStateEnum>`
                    
                    .. attribute:: bridge_description
                    
                    	Human\-readable bridge\-domain description
                    	**type**\:  str
                    
                    .. attribute:: bridge_domain_id
                    
                    	Identification number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_internal_msti
                    
                    	Bridge\-domain internal msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_msti
                    
                    	Bridge\-domain msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_mtu
                    
                    	Maximum transmission unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge\-domain name
                    	**type**\:  str
                    
                    .. attribute:: bridge_shg_id
                    
                    	Bridge\-domain shgid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_state
                    
                    	Bridge\-domain state
                    	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                    
                    .. attribute:: bridge_type
                    
                    	Bridge\-domain type
                    	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                    
                    .. attribute:: bridge_vfi
                    
                    	Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                    
                    .. attribute:: configured
                    
                    	Bridge\-domain is configured
                    	**type**\:  bool
                    
                    .. attribute:: disposition_bytecount
                    
                    	EVPN Disposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_pkt_count
                    
                    	EVPN Disposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_parameters
                    
                    	EVPN parameters
                    	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                    
                    .. attribute:: flodd_group_id_down
                    
                    	Oper down because no FGID
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: imposition_byte_count
                    
                    	EVPN Imposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: imposition_pkt_count
                    
                    	EVPN Imposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: is_bridge_partially_programmed
                    
                    	Bridge is partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_rd_configured
                    
                    	Config or Auto
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the bridge domain status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: mac_filter
                    
                    	MAC addresses for filtering
                    	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                    
                    .. attribute:: mac_limit_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw
                    
                    	MAC withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_access
                    
                    	MAC Access PW withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_option
                    
                    	Event on which MAC withdraw is sent
                    	**type**\:   :py:class:`L2VpnBagMacWithdrawOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOptionEnum>`
                    
                    .. attribute:: mac_withdraw_relay
                    
                    	MAC Access PW withdraw relaying from access to access enabled
                    	**type**\:  bool
                    
                    .. attribute:: num_vn_is
                    
                    	Number of VNIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_vn_is_up
                    
                    	Number of VNIs up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_access_vf_is
                    
                    	Number of Access VFIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pb_bs
                    
                    	Number of pbbs
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pb_bs_up
                    
                    	Number of pbbs up
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_vf_is
                    
                    	Number of virtual forwarding interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                    
                    	nV Satellite Offload IPv4 Multicast Disabled
                    	**type**\:  bool
                    
                    .. attribute:: p2mp_enabled
                    
                    	P2MP Enabled on this Bridge Domain
                    	**type**\:  bool
                    
                    .. attribute:: partially_programmed_a_cs
                    
                    	Number of attachment circuits partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_pseudowires
                    
                    	Number of pseudowires partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_parameters
                    
                    	PBB parameters
                    	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                    
                    .. attribute:: rd
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                    
                    .. attribute:: security_parameters
                    
                    	Security parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                    
                    .. attribute:: shutdown
                    
                    	Administratively disabled
                    	**type**\:  bool
                    
                    .. attribute:: standby_pseudowires
                    
                    	Number of pseudowires standby
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_created
                    
                    	Time when the bridge domain was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: vine_fsm_state
                    
                    	VNI, IRB, Native\-Evpn state
                    	**type**\:  str
                    
                    .. attribute:: vni_parameters
                    
                    	VNI parameters
                    	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.acpwup = None
                        self.as_ = None
                        self.bridge_access_vfi = YList()
                        self.bridge_access_vfi.parent = self
                        self.bridge_access_vfi.name = 'bridge_access_vfi'
                        self.bridge_coupled_state = None
                        self.bridge_description = None
                        self.bridge_domain_id = None
                        self.bridge_internal_msti = None
                        self.bridge_msti = None
                        self.bridge_mtu = None
                        self.bridge_name = None
                        self.bridge_shg_id = None
                        self.bridge_state = None
                        self.bridge_type = None
                        self.bridge_vfi = YList()
                        self.bridge_vfi.parent = self
                        self.bridge_vfi.name = 'bridge_vfi'
                        self.configured = None
                        self.disposition_bytecount = None
                        self.disposition_pkt_count = None
                        self.evi = None
                        self.evpn_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                        self.evpn_parameters.parent = self
                        self.flodd_group_id_down = None
                        self.group_name = None
                        self.imposition_byte_count = None
                        self.imposition_pkt_count = None
                        self.is_bridge_partially_programmed = None
                        self.is_rd_configured = None
                        self.last_time_status_changed = None
                        self.load_balance = None
                        self.mac_filter = YList()
                        self.mac_filter.parent = self
                        self.mac_filter.name = 'mac_filter'
                        self.mac_limit_down = None
                        self.mac_withdraw = None
                        self.mac_withdraw_access = None
                        self.mac_withdraw_option = None
                        self.mac_withdraw_relay = None
                        self.num_vn_is = None
                        self.num_vn_is_up = None
                        self.number_a_cs = None
                        self.number_a_cs_up = None
                        self.number_access_vf_is = None
                        self.number_p_ws_up = None
                        self.number_pb_bs = None
                        self.number_pb_bs_up = None
                        self.number_pseudowires = None
                        self.number_vf_is = None
                        self.nv_satellite_offload_ipv4_multicast_disabled = None
                        self.p2mp_enabled = None
                        self.partially_programmed_a_cs = None
                        self.partially_programmed_pseudowires = None
                        self.pbb_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                        self.pbb_parameters.parent = self
                        self.rd = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                        self.rd.parent = self
                        self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                        self.security_parameters.parent = self
                        self.shutdown = None
                        self.standby_pseudowires = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.vine_fsm_state = None
                        self.vni_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                        self.vni_parameters.parent = self


                    class SecurityParameters(object):
                        """
                        Security parameters
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: dai_address_validation_mask
                        
                        	DAI Address Validation mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dhcpv4_profile_name
                        
                        	DHCPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: dhcpv4_snoop
                        
                        	DHCPv4 Snoop Status
                        	**type**\:  bool
                        
                        .. attribute:: flood_unknown_unicast_enabled
                        
                        	Flooding unknown unicast enabled
                        	**type**\:  bool
                        
                        .. attribute:: flood_uu_disabled_mac_limit_action
                        
                        	Flooding of unknown\-unicast disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_disabled
                        
                        	IGMPv4 Disabled
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_profile_name
                        
                        	IGMPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                        
                        	Is DAI Dstination MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                        
                        	Is DAI IPv4 Addr Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                        
                        	Is DAI Source MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_enabled
                        
                        	Is Dynamic ARP Inspection Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_logging_enabled
                        
                        	Is DAI Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_source_guard_enabled
                        
                        	Is IP Source Guard Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ipsg_logging_enabled
                        
                        	Is IP Source Guard Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                        
                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_enabled
                        
                        	Is MAC Secure Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_logging_enabled
                        
                        	Is MAC Secure Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: learn_disabled_mac_limit_action
                        
                        	Learning disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: mac_aging_mode
                        
                        	MAC Aging Mode
                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                        
                        .. attribute:: mac_aging_time
                        
                        	MAC aging time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: mac_flooding
                        
                        	MAC flooding enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_learning
                        
                        	MAC learning enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_limit
                        
                        	MAC address limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_limit_action
                        
                        	MAC limit action
                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                        
                        .. attribute:: mac_limit_notification
                        
                        	MAC limit notification
                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                        
                        .. attribute:: mac_limit_reached
                        
                        	MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mac_port_down_flush_enabled
                        
                        	MAC Flush when port goes down
                        	**type**\:  bool
                        
                        .. attribute:: mac_secure_action
                        
                        	MAC Secure Action
                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                        
                        .. attribute:: mld_profile_name
                        
                        	MLD Profile Name
                        	**type**\:  str
                        
                        .. attribute:: mmrp_flood_optimization
                        
                        	MMRP Flood Optimization Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: split_horizon_group_id
                        
                        	Split Horizon Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.dai_address_validation_mask = None
                            self.dhcpv4_profile_name = None
                            self.dhcpv4_snoop = None
                            self.flood_unknown_unicast_enabled = None
                            self.flood_uu_disabled_mac_limit_action = None
                            self.igm_pv4_disabled = None
                            self.igm_pv4_profile_name = None
                            self.is_dai_addr_validate_destination_mac_enabled = None
                            self.is_dai_addr_validate_ipv4_enabled = None
                            self.is_dai_addr_validate_source_mac_enabled = None
                            self.is_dai_enabled = None
                            self.is_dai_logging_enabled = None
                            self.is_ip_source_guard_enabled = None
                            self.is_ipsg_logging_enabled = None
                            self.is_mac_secure_accept_shutdown_enabled = None
                            self.is_mac_secure_enabled = None
                            self.is_mac_secure_logging_enabled = None
                            self.learn_disabled_mac_limit_action = None
                            self.mac_aging_mode = None
                            self.mac_aging_time = None
                            self.mac_flooding = None
                            self.mac_learning = None
                            self.mac_limit = None
                            self.mac_limit_action = None
                            self.mac_limit_notification = None
                            self.mac_limit_reached = None
                            self.mac_port_down_flush_enabled = None
                            self.mac_secure_action = None
                            self.mld_profile_name = None
                            self.mmrp_flood_optimization = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_rate_unit = None
                            self.split_horizon_group_id = None
                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_rate_unit = None


                        class StormControl(object):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bd_policer = None
                                self.broadcast = None
                                self.multicast = None
                                self.unicast = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bd_policer is not None:
                                    return True

                                if self.broadcast is not None:
                                    return True

                                if self.multicast is not None:
                                    return True

                                if self.unicast is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.broadcast_storm_control_rate_unit is not None:
                                return True

                            if self.dai_address_validation_mask is not None:
                                return True

                            if self.dhcpv4_profile_name is not None:
                                return True

                            if self.dhcpv4_snoop is not None:
                                return True

                            if self.flood_unknown_unicast_enabled is not None:
                                return True

                            if self.flood_uu_disabled_mac_limit_action is not None:
                                return True

                            if self.igm_pv4_disabled is not None:
                                return True

                            if self.igm_pv4_profile_name is not None:
                                return True

                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                return True

                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                return True

                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                return True

                            if self.is_dai_enabled is not None:
                                return True

                            if self.is_dai_logging_enabled is not None:
                                return True

                            if self.is_ip_source_guard_enabled is not None:
                                return True

                            if self.is_ipsg_logging_enabled is not None:
                                return True

                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                return True

                            if self.is_mac_secure_enabled is not None:
                                return True

                            if self.is_mac_secure_logging_enabled is not None:
                                return True

                            if self.learn_disabled_mac_limit_action is not None:
                                return True

                            if self.mac_aging_mode is not None:
                                return True

                            if self.mac_aging_time is not None:
                                return True

                            if self.mac_flooding is not None:
                                return True

                            if self.mac_learning is not None:
                                return True

                            if self.mac_limit is not None:
                                return True

                            if self.mac_limit_action is not None:
                                return True

                            if self.mac_limit_notification is not None:
                                return True

                            if self.mac_limit_reached is not None:
                                return True

                            if self.mac_port_down_flush_enabled is not None:
                                return True

                            if self.mac_secure_action is not None:
                                return True

                            if self.mld_profile_name is not None:
                                return True

                            if self.mmrp_flood_optimization is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_rate_unit is not None:
                                return True

                            if self.split_horizon_group_id is not None:
                                return True

                            if self.storm_control is not None and self.storm_control._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            if self.unicast_storm_control_rate_unit is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters']['meta_info']


                    class PbbParameters(object):
                        """
                        PBB parameters
                        
                        .. attribute:: pbb_core
                        
                        	PBB Core
                        	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                        
                        .. attribute:: pbb_edge
                        
                        	PBB Edge
                        	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                        
                        .. attribute:: type
                        
                        	Type
                        	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pbb_core = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                            self.pbb_core.parent = self
                            self.pbb_edge = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                            self.pbb_edge.parent = self
                            self.type = None


                        class PbbEdge(object):
                            """
                            PBB Edge
                            
                            .. attribute:: core_bridge_name
                            
                            	Core Bridge Domain Name
                            	**type**\:  str
                            
                            .. attribute:: core_bridge_state
                            
                            	Core Bridge State
                            	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                            
                            .. attribute:: edge_port
                            
                            	PBB Edge Port
                            	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                            
                            .. attribute:: i_sid
                            
                            	SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mirp_lite_protocol
                            
                            	MIRP\-lite protocol info
                            	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfoEnum>`
                            
                            .. attribute:: mirp_lite_status
                            
                            	MIRP\-lite Status
                            	**type**\:   :py:class:`L2VpnMirpLiteStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatusEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.core_bridge_name = None
                                self.core_bridge_state = None
                                self.edge_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                self.edge_port.parent = self
                                self.i_sid = None
                                self.mirp_lite_protocol = None
                                self.mirp_lite_status = None


                            class EdgePort(object):
                                """
                                PBB Edge Port
                                
                                .. attribute:: bmac_mapping
                                
                                	CMAC to BMAC Mapping
                                	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                
                                .. attribute:: edge_port_state
                                
                                	PBB Edge Port State
                                	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                
                                .. attribute:: unknown_unicast_mac
                                
                                	Unknown Unicast MAC
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: unknown_unicast_mac_set
                                
                                	Unknown Unicast MAC Configured
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bmac_mapping = YList()
                                    self.bmac_mapping.parent = self
                                    self.bmac_mapping.name = 'bmac_mapping'
                                    self.edge_port_state = None
                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                    self.statistics.parent = self
                                    self.unknown_unicast_mac = None
                                    self.unknown_unicast_mac_set = None
                                    self.xconnect_id = None


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics']['meta_info']


                                class BmacMapping(object):
                                    """
                                    CMAC to BMAC Mapping
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:bmac-mapping'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address is not None:
                                            return True

                                        if self.bmac is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bmac_mapping is not None:
                                        for child_ref in self.bmac_mapping:
                                            if child_ref._has_data():
                                                return True

                                    if self.edge_port_state is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.unknown_unicast_mac is not None:
                                        return True

                                    if self.unknown_unicast_mac_set is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.core_bridge_name is not None:
                                    return True

                                if self.core_bridge_state is not None:
                                    return True

                                if self.edge_port is not None and self.edge_port._has_data():
                                    return True

                                if self.i_sid is not None:
                                    return True

                                if self.mirp_lite_protocol is not None:
                                    return True

                                if self.mirp_lite_status is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge']['meta_info']


                        class PbbCore(object):
                            """
                            PBB Core
                            
                            .. attribute:: core_port
                            
                            	PBB Core Port
                            	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                            
                            .. attribute:: num_ass_edge
                            
                            	Number of Associated PBB Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.core_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                self.core_port.parent = self
                                self.num_ass_edge = None


                            class CorePort(object):
                                """
                                PBB Core Port
                                
                                .. attribute:: core_port_state
                                
                                	PBB Core Port State
                                	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                
                                .. attribute:: vlan_id
                                
                                	Vlan ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_port_state = None
                                    self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.vlan_id = None
                                    self.xconnect_id = None


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_port_state is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.vlan_id is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.core_port is not None and self.core_port._has_data():
                                    return True

                                if self.num_ass_edge is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pbb_core is not None and self.pbb_core._has_data():
                                return True

                            if self.pbb_edge is not None and self.pbb_edge._has_data():
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters']['meta_info']


                    class EvpnParameters(object):
                        """
                        EVPN parameters
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_port
                        
                        	EVPN Port
                        	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.evi = None
                            self.evpn_port = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                            self.evpn_port.parent = self


                        class EvpnPort(object):
                            """
                            EVPN Port
                            
                            .. attribute:: evpn_port_state
                            
                            	EVPN Port State
                            	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.evpn_port_state = None
                                self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                self.security_parameters.parent = self
                                self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                self.statistics.parent = self
                                self.xconnect_id = None


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.evpn_port_state is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.evi is not None:
                                return True

                            if self.evpn_port is not None and self.evpn_port._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters']['meta_info']


                    class VniParameters(object):
                        """
                        VNI parameters
                        
                        .. attribute:: anycast_mcast_group_addr
                        
                        	Anycast Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_vtep_ip_addr
                        
                        	Anycast VTEP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_addr
                        
                        	Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: overlay
                        
                        	NVE Overlay
                        	**type**\:  str
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                        
                        .. attribute:: source_ip_addr
                        
                        	Source IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                        
                        .. attribute:: udp_port
                        
                        	UDP Port
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni
                        
                        	VNI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni_encap_type
                        
                        	VNI Encapsulation Type
                        	**type**\:   :py:class:`L2VpnVniEncapsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncapsEnum>`
                        
                        .. attribute:: vni_mode
                        
                        	VNI Mode
                        	**type**\:   :py:class:`L2VpnVniModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniModeEnum>`
                        
                        .. attribute:: vni_port_state
                        
                        	VNI Port State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_mcast_group_addr = None
                            self.anycast_vtep_ip_addr = None
                            self.multicast_group_addr = None
                            self.overlay = None
                            self.security_parameters = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                            self.security_parameters.parent = self
                            self.source_ip_addr = None
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'
                            self.statistics = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                            self.statistics.parent = self
                            self.udp_port = None
                            self.vni = None
                            self.vni_encap_type = None
                            self.vni_mode = None
                            self.vni_port_state = None
                            self.xconnect_id = None


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_mcast_group_addr is not None:
                                return True

                            if self.anycast_vtep_ip_addr is not None:
                                return True

                            if self.multicast_group_addr is not None:
                                return True

                            if self.overlay is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.source_ip_addr is not None:
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.udp_port is not None:
                                return True

                            if self.vni is not None:
                                return True

                            if self.vni_encap_type is not None:
                                return True

                            if self.vni_mode is not None:
                                return True

                            if self.vni_port_state is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters']['meta_info']


                    class Rd(object):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                            self.auto.parent = self
                            self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rd = None
                            self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                            self.v4_addr.parent = self


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto_index = None
                                self.router_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto_index is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rd is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd']['meta_info']


                    class MacFilter(object):
                        """
                        MAC addresses for filtering
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:mac-filter'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.bmac is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter']['meta_info']


                    class BridgeVfi(object):
                        """
                        Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.access = None
                            self.discovery_information = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self.number_pseudowires = None
                            self.p2mp_information = YList()
                            self.p2mp_information.parent = self
                            self.p2mp_information.name = 'p2mp_information'
                            self.shutdown = None
                            self.vfi_name = None
                            self.vfi_state = None


                        class DiscoveryInformation(object):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_signalling_method = None
                                self.as_number = None
                                self.export_route_policy = None
                                self.export_rt = YList()
                                self.export_rt.parent = self
                                self.export_rt.name = 'export_rt'
                                self.import_rt = YList()
                                self.import_rt.parent = self
                                self.import_rt.name = 'import_rt'
                                self.l2vpn_router_id = None
                                self.provisioned_ve_id = None
                                self.rd_value = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self.service_connected = None
                                self.ve_id = None
                                self.ve_range = None
                                self.vpls_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self.vpls_id_conflict = None
                                self.vpn_added = None
                                self.vpn_id = None


                            class RdValue(object):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rd = None
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto_index = None
                                        self.router_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto_index is not None:
                                            return True

                                        if self.router_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rd is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue']['meta_info']


                            class VplsId(object):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId']['meta_info']


                            class ImportRt(object):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt']['meta_info']


                            class ExportRt(object):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_signalling_method is not None:
                                    return True

                                if self.as_number is not None:
                                    return True

                                if self.export_route_policy is not None:
                                    return True

                                if self.export_rt is not None:
                                    for child_ref in self.export_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.import_rt is not None:
                                    for child_ref in self.import_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.l2vpn_router_id is not None:
                                    return True

                                if self.provisioned_ve_id is not None:
                                    return True

                                if self.rd_value is not None and self.rd_value._has_data():
                                    return True

                                if self.service_connected is not None:
                                    return True

                                if self.ve_id is not None:
                                    return True

                                if self.ve_range is not None:
                                    return True

                                if self.vpls_id is not None and self.vpls_id._has_data():
                                    return True

                                if self.vpls_id_conflict is not None:
                                    return True

                                if self.vpn_added is not None:
                                    return True

                                if self.vpn_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation']['meta_info']


                        class P2MpInformation(object):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.attribute_set_name = None
                                self.local_label = None
                                self.ptree_id = None
                                self.signaling = None
                                self.transport = None
                                self.transport_status = None
                                self.tunnel_interface = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attribute_set_name is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.ptree_id is not None:
                                    return True

                                if self.signaling is not None:
                                    return True

                                if self.transport is not None:
                                    return True

                                if self.transport_status is not None:
                                    return True

                                if self.tunnel_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.access is not None:
                                return True

                            if self.discovery_information is not None and self.discovery_information._has_data():
                                return True

                            if self.number_pseudowires is not None:
                                return True

                            if self.p2mp_information is not None:
                                for child_ref in self.p2mp_information:
                                    if child_ref._has_data():
                                        return True

                            if self.shutdown is not None:
                                return True

                            if self.vfi_name is not None:
                                return True

                            if self.vfi_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi']['meta_info']


                    class BridgeAccessVfi(object):
                        """
                        Access Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.access = None
                            self.discovery_information = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self.number_pseudowires = None
                            self.p2mp_information = YList()
                            self.p2mp_information.parent = self
                            self.p2mp_information.name = 'p2mp_information'
                            self.shutdown = None
                            self.vfi_name = None
                            self.vfi_state = None


                        class DiscoveryInformation(object):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_signalling_method = None
                                self.as_number = None
                                self.export_route_policy = None
                                self.export_rt = YList()
                                self.export_rt.parent = self
                                self.export_rt.name = 'export_rt'
                                self.import_rt = YList()
                                self.import_rt.parent = self
                                self.import_rt.name = 'import_rt'
                                self.l2vpn_router_id = None
                                self.provisioned_ve_id = None
                                self.rd_value = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self.service_connected = None
                                self.ve_id = None
                                self.ve_range = None
                                self.vpls_id = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self.vpls_id_conflict = None
                                self.vpn_added = None
                                self.vpn_id = None


                            class RdValue(object):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rd = None
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto_index = None
                                        self.router_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto_index is not None:
                                            return True

                                        if self.router_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rd is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue']['meta_info']


                            class VplsId(object):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId']['meta_info']


                            class ImportRt(object):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt']['meta_info']


                            class ExportRt(object):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_signalling_method is not None:
                                    return True

                                if self.as_number is not None:
                                    return True

                                if self.export_route_policy is not None:
                                    return True

                                if self.export_rt is not None:
                                    for child_ref in self.export_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.import_rt is not None:
                                    for child_ref in self.import_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.l2vpn_router_id is not None:
                                    return True

                                if self.provisioned_ve_id is not None:
                                    return True

                                if self.rd_value is not None and self.rd_value._has_data():
                                    return True

                                if self.service_connected is not None:
                                    return True

                                if self.ve_id is not None:
                                    return True

                                if self.ve_range is not None:
                                    return True

                                if self.vpls_id is not None and self.vpls_id._has_data():
                                    return True

                                if self.vpls_id_conflict is not None:
                                    return True

                                if self.vpn_added is not None:
                                    return True

                                if self.vpn_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation']['meta_info']


                        class P2MpInformation(object):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.attribute_set_name = None
                                self.local_label = None
                                self.ptree_id = None
                                self.signaling = None
                                self.transport = None
                                self.transport_status = None
                                self.tunnel_interface = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attribute_set_name is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.ptree_id is not None:
                                    return True

                                if self.signaling is not None:
                                    return True

                                if self.transport is not None:
                                    return True

                                if self.transport_status is not None:
                                    return True

                                if self.tunnel_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.access is not None:
                                return True

                            if self.discovery_information is not None and self.discovery_information._has_data():
                                return True

                            if self.number_pseudowires is not None:
                                return True

                            if self.p2mp_information is not None:
                                for child_ref in self.p2mp_information:
                                    if child_ref._has_data():
                                        return True

                            if self.shutdown is not None:
                                return True

                            if self.vfi_name is not None:
                                return True

                            if self.vfi_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.acpwup is not None:
                            return True

                        if self.as_ is not None:
                            return True

                        if self.bridge_access_vfi is not None:
                            for child_ref in self.bridge_access_vfi:
                                if child_ref._has_data():
                                    return True

                        if self.bridge_coupled_state is not None:
                            return True

                        if self.bridge_description is not None:
                            return True

                        if self.bridge_domain_id is not None:
                            return True

                        if self.bridge_internal_msti is not None:
                            return True

                        if self.bridge_msti is not None:
                            return True

                        if self.bridge_mtu is not None:
                            return True

                        if self.bridge_name is not None:
                            return True

                        if self.bridge_shg_id is not None:
                            return True

                        if self.bridge_state is not None:
                            return True

                        if self.bridge_type is not None:
                            return True

                        if self.bridge_vfi is not None:
                            for child_ref in self.bridge_vfi:
                                if child_ref._has_data():
                                    return True

                        if self.configured is not None:
                            return True

                        if self.disposition_bytecount is not None:
                            return True

                        if self.disposition_pkt_count is not None:
                            return True

                        if self.evi is not None:
                            return True

                        if self.evpn_parameters is not None and self.evpn_parameters._has_data():
                            return True

                        if self.flodd_group_id_down is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.imposition_byte_count is not None:
                            return True

                        if self.imposition_pkt_count is not None:
                            return True

                        if self.is_bridge_partially_programmed is not None:
                            return True

                        if self.is_rd_configured is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.mac_filter is not None:
                            for child_ref in self.mac_filter:
                                if child_ref._has_data():
                                    return True

                        if self.mac_limit_down is not None:
                            return True

                        if self.mac_withdraw is not None:
                            return True

                        if self.mac_withdraw_access is not None:
                            return True

                        if self.mac_withdraw_option is not None:
                            return True

                        if self.mac_withdraw_relay is not None:
                            return True

                        if self.num_vn_is is not None:
                            return True

                        if self.num_vn_is_up is not None:
                            return True

                        if self.number_a_cs is not None:
                            return True

                        if self.number_a_cs_up is not None:
                            return True

                        if self.number_access_vf_is is not None:
                            return True

                        if self.number_p_ws_up is not None:
                            return True

                        if self.number_pb_bs is not None:
                            return True

                        if self.number_pb_bs_up is not None:
                            return True

                        if self.number_pseudowires is not None:
                            return True

                        if self.number_vf_is is not None:
                            return True

                        if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                            return True

                        if self.p2mp_enabled is not None:
                            return True

                        if self.partially_programmed_a_cs is not None:
                            return True

                        if self.partially_programmed_pseudowires is not None:
                            return True

                        if self.pbb_parameters is not None and self.pbb_parameters._has_data():
                            return True

                        if self.rd is not None and self.rd._has_data():
                            return True

                        if self.security_parameters is not None and self.security_parameters._has_data():
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.standby_pseudowires is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.vine_fsm_state is not None:
                            return True

                        if self.vni_parameters is not None and self.vni_parameters._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_access_pws is not None and self.bridge_access_pws._has_data():
                        return True

                    if self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table._has_data():
                        return True

                    if self.bridge_acs is not None and self.bridge_acs._has_data():
                        return True

                    if self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table._has_data():
                        return True

                    if self.bridge_domain_group_name is not None:
                        return True

                    if self.bridge_domain_info is not None and self.bridge_domain_info._has_data():
                        return True

                    if self.bridge_domain_name is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.BridgeDomains.BridgeDomain']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:bridge-domains'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bridge_domain is not None:
                    for child_ref in self.bridge_domain:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.BridgeDomains']['meta_info']


        class DiscoverySummary(object):
            """
            Discovery summary information
            
            .. attribute:: bgp_current_node_id
            
            	BGP current node id
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: bgp_ipc_transport_mode
            
            	IPC Transport mode with BGP
            	**type**\:   :py:class:`L2VpnIpcTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportModeEnum>`
            
            .. attribute:: bgp_stateon_active_rp
            
            	BGP state on the active RP
            	**type**\:  bool
            
            .. attribute:: bgp_stateon_standby_rp
            
            	BGP state on standby RP
            	**type**\:  bool
            
            .. attribute:: number_bridge_domainvpns
            
            	Number of BDs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_bridge_domain
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_xconnect
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2m_pxconnect_vpns
            
            	Number of XCs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_bridge_domain
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_xconnect
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_bridge_domain
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_xconnect
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpls_registered
            
            	Is the VPLS service registered
            	**type**\:  bool
            
            .. attribute:: vpws_registered
            
            	Is the VPWS service registered
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bgp_current_node_id = None
                self.bgp_ipc_transport_mode = None
                self.bgp_stateon_active_rp = None
                self.bgp_stateon_standby_rp = None
                self.number_bridge_domainvpns = None
                self.number_local_edges_bridge_domain = None
                self.number_local_edges_xconnect = None
                self.number_mp2m_pxconnect_vpns = None
                self.number_nlri_bridge_domain = None
                self.number_nlri_xconnect = None
                self.number_remote_edges_bridge_domain = None
                self.number_remote_edges_xconnect = None
                self.vpls_registered = None
                self.vpws_registered = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:discovery-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bgp_current_node_id is not None:
                    return True

                if self.bgp_ipc_transport_mode is not None:
                    return True

                if self.bgp_stateon_active_rp is not None:
                    return True

                if self.bgp_stateon_standby_rp is not None:
                    return True

                if self.number_bridge_domainvpns is not None:
                    return True

                if self.number_local_edges_bridge_domain is not None:
                    return True

                if self.number_local_edges_xconnect is not None:
                    return True

                if self.number_mp2m_pxconnect_vpns is not None:
                    return True

                if self.number_nlri_bridge_domain is not None:
                    return True

                if self.number_nlri_xconnect is not None:
                    return True

                if self.number_remote_edges_bridge_domain is not None:
                    return True

                if self.number_remote_edges_xconnect is not None:
                    return True

                if self.vpls_registered is not None:
                    return True

                if self.vpws_registered is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.DiscoverySummary']['meta_info']


        class G8032(object):
            """
            G8032 information
            
            .. attribute:: g8032_rings
            
            	G8032 Ring table
            	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.g8032_rings = L2Vpnv2.Standby.G8032.G8032Rings()
                self.g8032_rings.parent = self


            class G8032Rings(object):
                """
                G8032 Ring table
                
                .. attribute:: g8032_ring
                
                	G8032 Ring
                	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.g8032_ring = YList()
                    self.g8032_ring.parent = self
                    self.g8032_ring.name = 'g8032_ring'


                class G8032Ring(object):
                    """
                    G8032 Ring
                    
                    .. attribute:: ring_name  <key>
                    
                    	Ring Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: g8032_ring_detail
                    
                    	G8032 Ring detailed information
                    	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                    
                    .. attribute:: g8032_ring_instance_details
                    
                    	G8032 Ring Instance detail table
                    	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                    
                    .. attribute:: g8032_ring_instance_summaries
                    
                    	G8032 Ring Instance summary table
                    	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                    
                    .. attribute:: g8032_ring_summary
                    
                    	G8032 Ring summary information
                    	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ring_name = None
                        self.g8032_ring_detail = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                        self.g8032_ring_detail.parent = self
                        self.g8032_ring_instance_details = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                        self.g8032_ring_instance_details.parent = self
                        self.g8032_ring_instance_summaries = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                        self.g8032_ring_instance_summaries.parent = self
                        self.g8032_ring_summary = L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                        self.g8032_ring_summary.parent = self


                    class G8032RingDetail(object):
                        """
                        G8032 Ring detailed information
                        
                        .. attribute:: excluded_vlan_id
                        
                        	Exclusion Vlan ids list 
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_open_ring
                        
                        	Flag open ring
                        	**type**\:  bool
                        
                        .. attribute:: is_provider_bridge
                        
                        	Operating mode Customer/Provider 
                        	**type**\:  bool
                        
                        .. attribute:: monitor0
                        
                        	Monitor port 0
                        	**type**\:  str
                        
                        .. attribute:: monitor1
                        
                        	Monitor port 1
                        	**type**\:  str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        .. attribute:: tcn_propagation
                        
                        	Global TCN propagation
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.excluded_vlan_id = YLeafList()
                            self.excluded_vlan_id.parent = self
                            self.excluded_vlan_id.name = 'excluded_vlan_id'
                            self.is_open_ring = None
                            self.is_provider_bridge = None
                            self.monitor0 = None
                            self.monitor1 = None
                            self.port0 = None
                            self.port1 = None
                            self.ring_name = None
                            self.tcn_propagation = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-detail'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.excluded_vlan_id is not None:
                                for child in self.excluded_vlan_id:
                                    if child is not None:
                                        return True

                            if self.is_open_ring is not None:
                                return True

                            if self.is_provider_bridge is not None:
                                return True

                            if self.monitor0 is not None:
                                return True

                            if self.monitor1 is not None:
                                return True

                            if self.port0 is not None:
                                return True

                            if self.port1 is not None:
                                return True

                            if self.ring_name is not None:
                                return True

                            if self.tcn_propagation is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail']['meta_info']


                    class G8032RingInstanceSummaries(object):
                        """
                        G8032 Ring Instance summary table
                        
                        .. attribute:: g8032_ring_instance_summary
                        
                        	G8032 Ring Instance summary information
                        	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.g8032_ring_instance_summary = YList()
                            self.g8032_ring_instance_summary.parent = self
                            self.g8032_ring_instance_summary.name = 'g8032_ring_instance_summary'


                        class G8032RingInstanceSummary(object):
                            """
                            G8032 Ring Instance summary information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.instance = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None
                                self.included_vlan_id = YLeafList()
                                self.included_vlan_id.parent = self
                                self.included_vlan_id.name = 'included_vlan_id'
                                self.ring_instance = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.instance is None:
                                    raise YPYModelError('Key property instance is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summary[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.instance is not None:
                                    return True

                                if self.aps_port0 is not None:
                                    return True

                                if self.aps_port1 is not None:
                                    return True

                                if self.config_state is not None:
                                    return True

                                if self.included_vlan_id is not None:
                                    for child in self.included_vlan_id:
                                        if child is not None:
                                            return True

                                if self.ring_instance is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summaries'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.g8032_ring_instance_summary is not None:
                                for child_ref in self.g8032_ring_instance_summary:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries']['meta_info']


                    class G8032RingSummary(object):
                        """
                        G8032 Ring summary information
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.port0 = None
                            self.port1 = None
                            self.ring_name = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-summary'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.port0 is not None:
                                return True

                            if self.port1 is not None:
                                return True

                            if self.ring_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary']['meta_info']


                    class G8032RingInstanceDetails(object):
                        """
                        G8032 Ring Instance detail table
                        
                        .. attribute:: g8032_ring_instance_detail
                        
                        	G8032 Ring Instance detailed information
                        	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.g8032_ring_instance_detail = YList()
                            self.g8032_ring_instance_detail.parent = self
                            self.g8032_ring_instance_detail.name = 'g8032_ring_instance_detail'


                        class G8032RingInstanceDetail(object):
                            """
                            G8032 Ring Instance detailed information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_channel_level
                            
                            	APS channel level
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_description
                            
                            	Ring description
                            	**type**\:  str
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_profile
                            
                            	Ring Profile
                            	**type**\:  str
                            
                            .. attribute:: rpl
                            
                            	RPL
                            	**type**\:   :py:class:`L2VpnG8032RplEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032RplEnum>`
                            
                            .. attribute:: unresolved_reason
                            
                            	Reason of unresolved state state
                            	**type**\:   :py:class:`L2VpnG8032UncfgReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReasonEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.instance = None
                                self.aps_channel_level = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None
                                self.included_vlan_id = YLeafList()
                                self.included_vlan_id.parent = self
                                self.included_vlan_id.name = 'included_vlan_id'
                                self.ring_description = None
                                self.ring_instance = None
                                self.ring_profile = None
                                self.rpl = None
                                self.unresolved_reason = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.instance is None:
                                    raise YPYModelError('Key property instance is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-detail[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.instance is not None:
                                    return True

                                if self.aps_channel_level is not None:
                                    return True

                                if self.aps_port0 is not None:
                                    return True

                                if self.aps_port1 is not None:
                                    return True

                                if self.config_state is not None:
                                    return True

                                if self.included_vlan_id is not None:
                                    for child in self.included_vlan_id:
                                        if child is not None:
                                            return True

                                if self.ring_description is not None:
                                    return True

                                if self.ring_instance is not None:
                                    return True

                                if self.ring_profile is not None:
                                    return True

                                if self.rpl is not None:
                                    return True

                                if self.unresolved_reason is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-details'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.g8032_ring_instance_detail is not None:
                                for child_ref in self.g8032_ring_instance_detail:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails']['meta_info']

                    @property
                    def _common_path(self):
                        if self.ring_name is None:
                            raise YPYModelError('Key property ring_name is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:g8032/Cisco-IOS-XR-l2vpn-oper:g8032-rings/Cisco-IOS-XR-l2vpn-oper:g8032-ring[Cisco-IOS-XR-l2vpn-oper:ring-name = ' + str(self.ring_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ring_name is not None:
                            return True

                        if self.g8032_ring_detail is not None and self.g8032_ring_detail._has_data():
                            return True

                        if self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details._has_data():
                            return True

                        if self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries._has_data():
                            return True

                        if self.g8032_ring_summary is not None and self.g8032_ring_summary._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings.G8032Ring']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:g8032/Cisco-IOS-XR-l2vpn-oper:g8032-rings'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.g8032_ring is not None:
                        for child_ref in self.g8032_ring:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.G8032.G8032Rings']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:g8032'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.g8032_rings is not None and self.g8032_rings._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.G8032']['meta_info']


        class PseudowireClasses(object):
            """
            List of pseudowire classes
            
            .. attribute:: pseudowire_class
            
            	Pseudowire class information
            	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.pseudowire_class = YList()
                self.pseudowire_class.parent = self
                self.pseudowire_class.name = 'pseudowire_class'


            class PseudowireClass(object):
                """
                Pseudowire class information
                
                .. attribute:: pseudowire_class_name  <key>
                
                	Pseudowire Class Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: backup_mac_withdraw
                
                	TRUE if MAC withdraw message is sent
                	**type**\:  bool
                
                .. attribute:: control_word
                
                	Control word
                	**type**\:   :py:class:`L2VpnPwClassControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWordEnum>`
                
                .. attribute:: disable_delay
                
                	Disable Deley
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: disable_never
                
                	TRUE if backup is not automatically disabled
                	**type**\:  bool
                
                .. attribute:: encapsulation_info
                
                	Encapsulation specific pseudowire information
                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                
                .. attribute:: is_flow_label_static
                
                	is flow label static
                	**type**\:  bool
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                
                .. attribute:: local_source_address
                
                	Local source address
                	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                
                .. attribute:: preferred_path
                
                	MPLS Preferred Path
                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath>`
                
                .. attribute:: preferred_path_disable_fallback
                
                	PreferredPathDisableFallback
                	**type**\:  bool
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                
                .. attribute:: pw_class_name
                
                	Pseudowire class name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: pw_flow_label_code17_disabled
                
                	Disable sending Code 17 TLV
                	**type**\:  bool
                
                .. attribute:: pw_flow_label_type_cfg
                
                	Configured pseudowire flow label type
                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                
                .. attribute:: resync_enabled
                
                	Resync if packets out of sequence
                	**type**\:  bool
                
                .. attribute:: resync_threshold
                
                	Number of Packets Out of Seqence to trigger resync
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sequencing_type
                
                	Sequencing Type
                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                
                .. attribute:: tag_rewrite
                
                	Static tag rewrite
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: transport_mode
                
                	Transport mode
                	**type**\:   :py:class:`L2VpnTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportModeEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.pseudowire_class_name = None
                    self.backup_mac_withdraw = None
                    self.control_word = None
                    self.disable_delay = None
                    self.disable_never = None
                    self.encapsulation_info = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                    self.encapsulation_info.parent = self
                    self.is_flow_label_static = None
                    self.load_balance = None
                    self.local_source_address = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                    self.local_source_address.parent = self
                    self.preferred_path = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath()
                    self.preferred_path.parent = self
                    self.preferred_path_disable_fallback = None
                    self.protocol = None
                    self.pw_class_name = None
                    self.pw_flow_label_code17_disabled = None
                    self.pw_flow_label_type_cfg = None
                    self.resync_enabled = None
                    self.resync_threshold = None
                    self.sequencing_type = None
                    self.tag_rewrite = None
                    self.transport_mode = None


                class EncapsulationInfo(object):
                    """
                    Encapsulation specific pseudowire information
                    
                    .. attribute:: encapsulation
                    
                    	Encapsulation
                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                    
                    .. attribute:: l2tpv3
                    
                    	l2tpv3
                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.encapsulation = None
                        self.l2tpv3 = L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                        self.l2tpv3.parent = self


                    class L2Tpv3(object):
                        """
                        l2tpv3
                        
                        .. attribute:: cookie_size
                        
                        	Cookie size\: 0, 4, or 8 bytes
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dont_fragment_bit
                        
                        	Don't Fragment Bit
                        	**type**\:  bool
                        
                        .. attribute:: ipv4_source_address
                        
                        	IPv4 source address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: l2tp_class_name
                        
                        	L2TPClassName
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: path_mtu_enabled
                        
                        	Path MTU enabled
                        	**type**\:  bool
                        
                        .. attribute:: path_mtu_max_value
                        
                        	Path MTU Maximum allowable session MTU
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: tos
                        
                        	Type Of Service Value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tos_mode
                        
                        	Type Of Service Mode
                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                        
                        .. attribute:: ttl
                        
                        	Time To Live value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.cookie_size = None
                            self.dont_fragment_bit = None
                            self.ipv4_source_address = None
                            self.l2tp_class_name = None
                            self.path_mtu_enabled = None
                            self.path_mtu_max_value = None
                            self.tos = None
                            self.tos_mode = None
                            self.ttl = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.cookie_size is not None:
                                return True

                            if self.dont_fragment_bit is not None:
                                return True

                            if self.ipv4_source_address is not None:
                                return True

                            if self.l2tp_class_name is not None:
                                return True

                            if self.path_mtu_enabled is not None:
                                return True

                            if self.path_mtu_max_value is not None:
                                return True

                            if self.tos is not None:
                                return True

                            if self.tos_mode is not None:
                                return True

                            if self.ttl is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.encapsulation is not None:
                            return True

                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo']['meta_info']


                class PreferredPath(object):
                    """
                    MPLS Preferred Path
                    
                    .. attribute:: ip_tunnel_interface_number
                    
                    	IPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_ip
                    
                    	NextHopIP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: option
                    
                    	Option
                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                    
                    .. attribute:: te_tunnel_interface_number
                    
                    	TETunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tp_tunnel_interface_number
                    
                    	TPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ip_tunnel_interface_number = None
                        self.next_hop_ip = None
                        self.option = None
                        self.te_tunnel_interface_number = None
                        self.tp_tunnel_interface_number = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ip_tunnel_interface_number is not None:
                            return True

                        if self.next_hop_ip is not None:
                            return True

                        if self.option is not None:
                            return True

                        if self.te_tunnel_interface_number is not None:
                            return True

                        if self.tp_tunnel_interface_number is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath']['meta_info']


                class LocalSourceAddress(object):
                    """
                    Local source address
                    
                    .. attribute:: address
                    
                    	Local source address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: configuration
                    
                    	Configuration
                    	**type**\:   :py:class:`L2VpnSrcAddressSetEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSetEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.configuration = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-source-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.configuration is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress']['meta_info']

                @property
                def _common_path(self):
                    if self.pseudowire_class_name is None:
                        raise YPYModelError('Key property pseudowire_class_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes/Cisco-IOS-XR-l2vpn-oper:pseudowire-class[Cisco-IOS-XR-l2vpn-oper:pseudowire-class-name = ' + str(self.pseudowire_class_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.pseudowire_class_name is not None:
                        return True

                    if self.backup_mac_withdraw is not None:
                        return True

                    if self.control_word is not None:
                        return True

                    if self.disable_delay is not None:
                        return True

                    if self.disable_never is not None:
                        return True

                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                        return True

                    if self.is_flow_label_static is not None:
                        return True

                    if self.load_balance is not None:
                        return True

                    if self.local_source_address is not None and self.local_source_address._has_data():
                        return True

                    if self.preferred_path is not None and self.preferred_path._has_data():
                        return True

                    if self.preferred_path_disable_fallback is not None:
                        return True

                    if self.protocol is not None:
                        return True

                    if self.pw_class_name is not None:
                        return True

                    if self.pw_flow_label_code17_disabled is not None:
                        return True

                    if self.pw_flow_label_type_cfg is not None:
                        return True

                    if self.resync_enabled is not None:
                        return True

                    if self.resync_threshold is not None:
                        return True

                    if self.sequencing_type is not None:
                        return True

                    if self.tag_rewrite is not None:
                        return True

                    if self.transport_mode is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.PseudowireClasses.PseudowireClass']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.pseudowire_class is not None:
                    for child_ref in self.pseudowire_class:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.PseudowireClasses']['meta_info']


        class L2VpnCollaborators(object):
            """
            L2VPN collaborator information
            
            .. attribute:: collaborator_statistics
            
            	Collaborator Statistics
            	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.collaborator_statistics = L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics()
                self.collaborator_statistics.parent = self


            class CollaboratorStatistics(object):
                """
                Collaborator Statistics
                
                .. attribute:: count
                
                	count
                	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.count = YList()
                    self.count.parent = self
                    self.count.name = 'count'


                class Count(object):
                    """
                    count
                    
                    .. attribute:: collaborator_name
                    
                    	Collaborator Name
                    	**type**\:  str
                    
                    .. attribute:: down
                    
                    	Down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_up
                    
                    	Is up
                    	**type**\:  bool
                    
                    .. attribute:: up
                    
                    	Up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.collaborator_name = None
                        self.down = None
                        self.is_up = None
                        self.up = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics/Cisco-IOS-XR-l2vpn-oper:count'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.collaborator_name is not None:
                            return True

                        if self.down is not None:
                            return True

                        if self.is_up is not None:
                            return True

                        if self.up is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics.Count']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.count is not None:
                        for child_ref in self.count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.L2VpnCollaborators.CollaboratorStatistics']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.collaborator_statistics is not None and self.collaborator_statistics._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.L2VpnCollaborators']['meta_info']


        class Mvrp(object):
            """
            MVRP
            
            .. attribute:: mvrp_main_ports
            
            	MVRP Main Port Table
            	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mvrp_main_ports = L2Vpnv2.Standby.Mvrp.MvrpMainPorts()
                self.mvrp_main_ports.parent = self


            class MvrpMainPorts(object):
                """
                MVRP Main Port Table
                
                .. attribute:: mvrp_main_port
                
                	MVRP Main Port
                	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mvrp_main_port = YList()
                    self.mvrp_main_port.parent = self
                    self.mvrp_main_port.name = 'mvrp_main_port'


                class MvrpMainPort(object):
                    """
                    MVRP Main Port
                    
                    .. attribute:: main_port_interface_name  <key>
                    
                    	Main Port interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mvrp_bridge_ports
                    
                    	MVRP Bridge Port Table
                    	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                    
                    .. attribute:: mvrp_main_port_info
                    
                    	MVRP Main Port Information
                    	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.main_port_interface_name = None
                        self.mvrp_bridge_ports = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                        self.mvrp_bridge_ports.parent = self
                        self.mvrp_main_port_info = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                        self.mvrp_main_port_info.parent = self


                    class MvrpMainPortInfo(object):
                        """
                        MVRP Main Port Information
                        
                        .. attribute:: default_bridge_port
                        
                        	Trunk or default Bridge Port
                        	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                        
                        .. attribute:: is_default_encap
                        
                        	Is default encap set
                        	**type**\:  bool
                        
                        .. attribute:: is_trunk
                        
                        	Is main port a trunk
                        	**type**\:  bool
                        
                        .. attribute:: main_port_interface_name
                        
                        	Main Port Interface name
                        	**type**\:  str
                        
                        .. attribute:: number_of_bridge_ports
                        
                        	Number of Bridge Ports
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.default_bridge_port = L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                            self.default_bridge_port.parent = self
                            self.is_default_encap = None
                            self.is_trunk = None
                            self.main_port_interface_name = None
                            self.number_of_bridge_ports = None


                        class DefaultBridgePort(object):
                            """
                            Trunk or default Bridge Port
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None
                                self.vlan_range = YList()
                                self.vlan_range.parent = self
                                self.vlan_range.name = 'vlan_range'


                            class VlanRange(object):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lower = None
                                    self.upper = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lower is not None:
                                        return True

                                    if self.upper is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:default-bridge-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bridge_port_interface_name is not None:
                                    return True

                                if self.bridge_port_xconnect_id is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.vlan_range is not None:
                                    for child_ref in self.vlan_range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.default_bridge_port is not None and self.default_bridge_port._has_data():
                                return True

                            if self.is_default_encap is not None:
                                return True

                            if self.is_trunk is not None:
                                return True

                            if self.main_port_interface_name is not None:
                                return True

                            if self.number_of_bridge_ports is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo']['meta_info']


                    class MvrpBridgePorts(object):
                        """
                        MVRP Bridge Port Table
                        
                        .. attribute:: mvrp_bridge_port
                        
                        	MVRP Bridge Port Information
                        	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mvrp_bridge_port = YList()
                            self.mvrp_bridge_port.parent = self
                            self.mvrp_bridge_port.name = 'mvrp_bridge_port'


                        class MvrpBridgePort(object):
                            """
                            MVRP Bridge Port Information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Bridge Port Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None
                                self.vlan_range = YList()
                                self.vlan_range.parent = self
                                self.vlan_range.name = 'vlan_range'


                            class VlanRange(object):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lower = None
                                    self.upper = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lower is not None:
                                        return True

                                    if self.upper is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-port[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.bridge_port_interface_name is not None:
                                    return True

                                if self.bridge_port_xconnect_id is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.vlan_range is not None:
                                    for child_ref in self.vlan_range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-ports'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mvrp_bridge_port is not None:
                                for child_ref in self.mvrp_bridge_port:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts']['meta_info']

                    @property
                    def _common_path(self):
                        if self.main_port_interface_name is None:
                            raise YPYModelError('Key property main_port_interface_name is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mvrp/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port[Cisco-IOS-XR-l2vpn-oper:main-port-interface-name = ' + str(self.main_port_interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.main_port_interface_name is not None:
                            return True

                        if self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports._has_data():
                            return True

                        if self.mvrp_main_port_info is not None and self.mvrp_main_port_info._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mvrp/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mvrp_main_port is not None:
                        for child_ref in self.mvrp_main_port:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.Mvrp.MvrpMainPorts']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mvrp'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mvrp_main_ports is not None and self.mvrp_main_ports._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.Mvrp']['meta_info']


        class GenericInterfaces(object):
            """
            L2VPN generic interface list Table
            
            .. attribute:: generic_interface
            
            	Generic Interface List information
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.generic_interface = YList()
                self.generic_interface.parent = self
                self.generic_interface.name = 'generic_interface'


            class GenericInterface(object):
                """
                Generic Interface List information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_list_name = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.interface_list_id = None
                    self.interface_list_name_xr = None
                    self.items = None
                    self.number_of_interfaces = None


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.GenericInterfaces.GenericInterface.Interface']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_list_name is None:
                        raise YPYModelError('Key property interface_list_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:generic-interfaces/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_list_name is not None:
                        return True

                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.interface_list_id is not None:
                        return True

                    if self.interface_list_name_xr is not None:
                        return True

                    if self.items is not None:
                        return True

                    if self.number_of_interfaces is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.GenericInterfaces.GenericInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.generic_interface is not None:
                    for child_ref in self.generic_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.GenericInterfaces']['meta_info']


        class MstpVlans(object):
            """
            L2VPN MSTP VLAN Table
            
            .. attribute:: mstp_vlan
            
            	L2VPN MSTP VLAN information
            	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpVlans.MstpVlan>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mstp_vlan = YList()
                self.mstp_vlan.parent = self
                self.mstp_vlan.name = 'mstp_vlan'


            class MstpVlan(object):
                """
                L2VPN MSTP VLAN information
                
                .. attribute:: vlan_id  <key>
                
                	vlan id
                	**type**\:  int
                
                	**range:** 0..4098
                
                .. attribute:: msti_id
                
                	MSTI id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_count
                
                	Port Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_interface
                
                	Sub interfaces
                	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface>`
                
                .. attribute:: vlan_id_xr
                
                	Vlan id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vlan_id = None
                    self.msti_id = None
                    self.port_count = None
                    self.sub_interface = YList()
                    self.sub_interface.parent = self
                    self.sub_interface.name = 'sub_interface'
                    self.vlan_id_xr = None


                class SubInterface(object):
                    """
                    Sub interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sub-interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.MstpVlans.MstpVlan.SubInterface']['meta_info']

                @property
                def _common_path(self):
                    if self.vlan_id is None:
                        raise YPYModelError('Key property vlan_id is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mstp-vlans/Cisco-IOS-XR-l2vpn-oper:mstp-vlan[Cisco-IOS-XR-l2vpn-oper:vlan-id = ' + str(self.vlan_id) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vlan_id is not None:
                        return True

                    if self.msti_id is not None:
                        return True

                    if self.port_count is not None:
                        return True

                    if self.sub_interface is not None:
                        for child_ref in self.sub_interface:
                            if child_ref._has_data():
                                return True

                    if self.vlan_id_xr is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.MstpVlans.MstpVlan']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:mstp-vlans'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mstp_vlan is not None:
                    for child_ref in self.mstp_vlan:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.MstpVlans']['meta_info']


        class L2VpnPbbBsa(object):
            """
            L2VPN PBB Backbone Source MAC information
            
            .. attribute:: bmac_sa
            
            	BMAC SA
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: chassis_is_provisioned
            
            	Chassis MAC is configured
            	**type**\:  bool
            
            .. attribute:: chassis_mac
            
            	Chassis MAC
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: provisioned
            
            	BMAC SA configured
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bmac_sa = None
                self.chassis_is_provisioned = None
                self.chassis_mac = None
                self.provisioned = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:l2vpn-pbb-bsa'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bmac_sa is not None:
                    return True

                if self.chassis_is_provisioned is not None:
                    return True

                if self.chassis_mac is not None:
                    return True

                if self.provisioned is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.L2VpnPbbBsa']['meta_info']


        class FlexibleXconnectServices(object):
            """
            Flexible XConnect Service Table
            
            .. attribute:: flexible_xconnect_service
            
            	Flexible XConnect Service Information
            	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.flexible_xconnect_service = YList()
                self.flexible_xconnect_service.parent = self
                self.flexible_xconnect_service.name = 'flexible_xconnect_service'


            class FlexibleXconnectService(object):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name  <key>
                
                	Flexible XConnect Service Name
                	**type**\:  str
                
                	**length:** 1..23
                
                .. attribute:: flexible_xconnect_service_acs
                
                	Flexible XConnect Service Attachment Circuit Table
                	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                
                .. attribute:: flexible_xconnect_service_info
                
                	Flexible XConnect Service Information
                	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.flexible_xconnect_service_acs = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                    self.flexible_xconnect_service_acs.parent = self
                    self.flexible_xconnect_service_info = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                    self.flexible_xconnect_service_info.parent = self


                class FlexibleXconnectServiceAcs(object):
                    """
                    Flexible XConnect Service Attachment Circuit
                    Table
                    
                    .. attribute:: flexible_xconnect_service_ac
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.flexible_xconnect_service_ac = YList()
                        self.flexible_xconnect_service_ac.parent = self
                        self.flexible_xconnect_service_ac.name = 'flexible_xconnect_service_ac'


                    class FlexibleXconnectServiceAc(object):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.attachment_circuit = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self


                        class AttachmentCircuit(object):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-acs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.flexible_xconnect_service_ac is not None:
                            for child_ref in self.flexible_xconnect_service_ac:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs']['meta_info']


                class FlexibleXconnectServiceInfo(object):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: name
                    
                    	Flexible XConnect Service Name
                    	**type**\:  str
                    
                    .. attribute:: num_p_ws
                    
                    	Number of Pseudowires in Pseudowire List
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: pseudowire
                    
                    	Flexible XConnect Service Pseudowire List
                    	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                    
                    .. attribute:: state
                    
                    	State of the Flexible XConnect Service
                    	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.num_p_ws = None
                        self.pseudowire = YList()
                        self.pseudowire.parent = self
                        self.pseudowire.name = 'pseudowire'
                        self.state = None


                    class Pseudowire(object):
                        """
                        Flexible XConnect Service Pseudowire List
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.num_p_ws is not None:
                            return True

                        if self.pseudowire is not None:
                            for child_ref in self.pseudowire:
                                if child_ref._has_data():
                                    return True

                        if self.state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service[Cisco-IOS-XR-l2vpn-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs._has_data():
                        return True

                    if self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.flexible_xconnect_service is not None:
                    for child_ref in self.flexible_xconnect_service:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.FlexibleXconnectServices']['meta_info']


        class XconnectBrief(object):
            """
            XConnect brief information
            
            .. attribute:: encapsulation_report_matrix
            
            	Encapsulation report counters matrix
            	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix>`
            
            .. attribute:: encapsulation_total
            
            	Total summary
            	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal>`
            
            .. attribute:: main_total_down
            
            	Total Number of non\-active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_unresolved
            
            	Total Number of unresolved Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_up
            
            	Total Number of active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: memory_state
            
            	L2VPN memory state
            	**type**\:   :py:class:`L2VpnMemoryStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryStateEnum>`
            
            .. attribute:: undefined_xc
            
            	Undefined xc including PW\-PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.encapsulation_report_matrix = YList()
                self.encapsulation_report_matrix.parent = self
                self.encapsulation_report_matrix.name = 'encapsulation_report_matrix'
                self.encapsulation_total = YList()
                self.encapsulation_total.parent = self
                self.encapsulation_total.name = 'encapsulation_total'
                self.main_total_down = None
                self.main_total_unresolved = None
                self.main_total_up = None
                self.memory_state = None
                self.undefined_xc = None


            class EncapsulationReportMatrix(object):
                """
                Encapsulation report counters matrix
                
                .. attribute:: ac1
                
                	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ac1 = YList()
                    self.ac1.parent = self
                    self.ac1.name = 'ac1'


                class Ac1(object):
                    """
                    Array of l2vpn\_xc\_brief\_first layer indexed by
                    the AC1 encapsulation type
                    
                    .. attribute:: ac2
                    
                    	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                    	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac2 = YList()
                        self.ac2.parent = self
                        self.ac2.name = 'ac2'


                    class Ac2(object):
                        """
                        Array of l2vpn\_xc\_brief\_line indexed by the AC2
                        encapsulation type plus one type for PW
                        
                        .. attribute:: ac1_encapsulation
                        
                        	AC1 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                        
                        .. attribute:: ac2_encapsulation
                        
                        	AC2 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                        
                        .. attribute:: down_count
                        
                        	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unresolved_count
                        
                        	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: up_count
                        
                        	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac1_encapsulation = None
                            self.ac2_encapsulation = None
                            self.down_count = YLeafList()
                            self.down_count.parent = self
                            self.down_count.name = 'down_count'
                            self.unresolved_count = YLeafList()
                            self.unresolved_count.parent = self
                            self.unresolved_count.name = 'unresolved_count'
                            self.up_count = YLeafList()
                            self.up_count.parent = self
                            self.up_count.name = 'up_count'

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix/Cisco-IOS-XR-l2vpn-oper:ac1/Cisco-IOS-XR-l2vpn-oper:ac2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac1_encapsulation is not None:
                                return True

                            if self.ac2_encapsulation is not None:
                                return True

                            if self.down_count is not None:
                                for child in self.down_count:
                                    if child is not None:
                                        return True

                            if self.unresolved_count is not None:
                                for child in self.unresolved_count:
                                    if child is not None:
                                        return True

                            if self.up_count is not None:
                                for child in self.up_count:
                                    if child is not None:
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix/Cisco-IOS-XR-l2vpn-oper:ac1'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac2 is not None:
                            for child_ref in self.ac2:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ac1 is not None:
                        for child_ref in self.ac1:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix']['meta_info']


            class EncapsulationTotal(object):
                """
                Total summary
                
                .. attribute:: ac1_encapsulation
                
                	AC1 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                
                .. attribute:: ac2_encapsulation
                
                	AC2 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                
                .. attribute:: down_count
                
                	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_count
                
                	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ac1_encapsulation = None
                    self.ac2_encapsulation = None
                    self.down_count = YLeafList()
                    self.down_count.parent = self
                    self.down_count.name = 'down_count'
                    self.unresolved_count = YLeafList()
                    self.unresolved_count.parent = self
                    self.unresolved_count.name = 'unresolved_count'
                    self.up_count = YLeafList()
                    self.up_count.parent = self
                    self.up_count.name = 'up_count'

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-total'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ac1_encapsulation is not None:
                        return True

                    if self.ac2_encapsulation is not None:
                        return True

                    if self.down_count is not None:
                        for child in self.down_count:
                            if child is not None:
                                return True

                    if self.unresolved_count is not None:
                        for child in self.unresolved_count:
                            if child is not None:
                                return True

                    if self.up_count is not None:
                        for child in self.up_count:
                            if child is not None:
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Standby.XconnectBrief.EncapsulationTotal']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:xconnect-brief'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.encapsulation_report_matrix is not None:
                    for child_ref in self.encapsulation_report_matrix:
                        if child_ref._has_data():
                            return True

                if self.encapsulation_total is not None:
                    for child_ref in self.encapsulation_total:
                        if child_ref._has_data():
                            return True

                if self.main_total_down is not None:
                    return True

                if self.main_total_unresolved is not None:
                    return True

                if self.main_total_up is not None:
                    return True

                if self.memory_state is not None:
                    return True

                if self.undefined_xc is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Standby.XconnectBrief']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:standby'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.bridge_domains is not None and self.bridge_domains._has_data():
                return True

            if self.bridge_summary is not None and self.bridge_summary._has_data():
                return True

            if self.discoveries is not None and self.discoveries._has_data():
                return True

            if self.discovery_summary is not None and self.discovery_summary._has_data():
                return True

            if self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary._has_data():
                return True

            if self.flexible_xconnect_services is not None and self.flexible_xconnect_services._has_data():
                return True

            if self.g8032 is not None and self.g8032._has_data():
                return True

            if self.generic_interface_list_details is not None and self.generic_interface_list_details._has_data():
                return True

            if self.generic_interfaces is not None and self.generic_interfaces._has_data():
                return True

            if self.global_settings is not None and self.global_settings._has_data():
                return True

            if self.iccp_sm is not None and self.iccp_sm._has_data():
                return True

            if self.indexes is not None and self.indexes._has_data():
                return True

            if self.l2vpn_collaborators is not None and self.l2vpn_collaborators._has_data():
                return True

            if self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa._has_data():
                return True

            if self.l2vpn_resource_state is not None and self.l2vpn_resource_state._has_data():
                return True

            if self.main_interfaces is not None and self.main_interfaces._has_data():
                return True

            if self.mstp_ports is not None and self.mstp_ports._has_data():
                return True

            if self.mstp_vlans is not None and self.mstp_vlans._has_data():
                return True

            if self.mvrp is not None and self.mvrp._has_data():
                return True

            if self.nsr is not None and self.nsr._has_data():
                return True

            if self.proc_fsm is not None and self.proc_fsm._has_data():
                return True

            if self.pseudowire_classes is not None and self.pseudowire_classes._has_data():
                return True

            if self.pwr is not None and self.pwr._has_data():
                return True

            if self.xconnect_brief is not None and self.xconnect_brief._has_data():
                return True

            if self.xconnect_groups is not None and self.xconnect_groups._has_data():
                return True

            if self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces._has_data():
                return True

            if self.xconnect_mp2mps is not None and self.xconnect_mp2mps._has_data():
                return True

            if self.xconnect_summary is not None and self.xconnect_summary._has_data():
                return True

            if self.xconnects is not None and self.xconnects._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpnv2.Standby']['meta_info']


    class Active(object):
        """
        Active L2VPN operational data
        
        .. attribute:: bridge_domains
        
        	VPLS Bridge Domain Information
        	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains>`
        
        .. attribute:: bridge_summary
        
        	Bridge Domain summary information
        	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeSummary>`
        
        .. attribute:: discoveries
        
        	Discovery Table
        	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries>`
        
        .. attribute:: discovery_summary
        
        	Discovery summary information
        	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.DiscoverySummary>`
        
        .. attribute:: flexible_xconnect_service_summary
        
        	Flexible XConnect Service summary information
        	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServiceSummary>`
        
        .. attribute:: flexible_xconnect_services
        
        	Flexible XConnect Service Table
        	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices>`
        
        .. attribute:: g8032
        
        	G8032 information
        	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032>`
        
        .. attribute:: generic_interface_list_details
        
        	L2VPN generic interface list Detail Table
        	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails>`
        
        .. attribute:: generic_interfaces
        
        	L2VPN generic interface list Table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaces>`
        
        .. attribute:: global_settings
        
        	L2VPN global settings
        	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GlobalSettings>`
        
        .. attribute:: iccp_sm
        
        	ICCP\-based Service Multi\-homing operational data
        	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm>`
        
        .. attribute:: indexes
        
        	ID Manager Index Table
        	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Indexes>`
        
        .. attribute:: l2vpn_collaborators
        
        	L2VPN collaborator information
        	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnCollaborators>`
        
        .. attribute:: l2vpn_pbb_bsa
        
        	L2VPN PBB Backbone Source MAC information
        	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnPbbBsa>`
        
        .. attribute:: l2vpn_resource_state
        
        	L2VPN resource state information
        	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnResourceState>`
        
        .. attribute:: main_interfaces
        
        	Main Interface
        	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces>`
        
        .. attribute:: mstp_ports
        
        	L2VPN MSTP Port Table
        	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts>`
        
        .. attribute:: mstp_vlans
        
        	L2VPN MSTP VLAN Table
        	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpVlans>`
        
        .. attribute:: mvrp
        
        	MVRP
        	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp>`
        
        .. attribute:: nsr
        
        	L2VPN NSR information
        	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr>`
        
        .. attribute:: proc_fsm
        
        	L2VPN Process FSM information
        	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm>`
        
        .. attribute:: pseudowire_classes
        
        	List of pseudowire classes
        	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses>`
        
        .. attribute:: pwr
        
        	Pseudowire Routing Table
        	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr>`
        
        .. attribute:: xconnect_brief
        
        	XConnect brief information
        	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief>`
        
        .. attribute:: xconnect_groups
        
        	XConnect group Table
        	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectGroups>`
        
        .. attribute:: xconnect_mp2mp_ce2ces
        
        	XConnect MP2MP CE2CE Table
        	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2MpCe2Ces>`
        
        .. attribute:: xconnect_mp2mps
        
        	XConnect MP2MP Table
        	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps>`
        
        .. attribute:: xconnect_summary
        
        	XConnect summary information
        	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectSummary>`
        
        .. attribute:: xconnects
        
        	XConnect Table
        	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.bridge_domains = L2Vpnv2.Active.BridgeDomains()
            self.bridge_domains.parent = self
            self.bridge_summary = L2Vpnv2.Active.BridgeSummary()
            self.bridge_summary.parent = self
            self.discoveries = L2Vpnv2.Active.Discoveries()
            self.discoveries.parent = self
            self.discovery_summary = L2Vpnv2.Active.DiscoverySummary()
            self.discovery_summary.parent = self
            self.flexible_xconnect_service_summary = L2Vpnv2.Active.FlexibleXconnectServiceSummary()
            self.flexible_xconnect_service_summary.parent = self
            self.flexible_xconnect_services = L2Vpnv2.Active.FlexibleXconnectServices()
            self.flexible_xconnect_services.parent = self
            self.g8032 = L2Vpnv2.Active.G8032()
            self.g8032.parent = self
            self.generic_interface_list_details = L2Vpnv2.Active.GenericInterfaceListDetails()
            self.generic_interface_list_details.parent = self
            self.generic_interfaces = L2Vpnv2.Active.GenericInterfaces()
            self.generic_interfaces.parent = self
            self.global_settings = L2Vpnv2.Active.GlobalSettings()
            self.global_settings.parent = self
            self.iccp_sm = L2Vpnv2.Active.IccpSm()
            self.iccp_sm.parent = self
            self.indexes = L2Vpnv2.Active.Indexes()
            self.indexes.parent = self
            self.l2vpn_collaborators = L2Vpnv2.Active.L2VpnCollaborators()
            self.l2vpn_collaborators.parent = self
            self.l2vpn_pbb_bsa = L2Vpnv2.Active.L2VpnPbbBsa()
            self.l2vpn_pbb_bsa.parent = self
            self.l2vpn_resource_state = L2Vpnv2.Active.L2VpnResourceState()
            self.l2vpn_resource_state.parent = self
            self.main_interfaces = L2Vpnv2.Active.MainInterfaces()
            self.main_interfaces.parent = self
            self.mstp_ports = L2Vpnv2.Active.MstpPorts()
            self.mstp_ports.parent = self
            self.mstp_vlans = L2Vpnv2.Active.MstpVlans()
            self.mstp_vlans.parent = self
            self.mvrp = L2Vpnv2.Active.Mvrp()
            self.mvrp.parent = self
            self.nsr = L2Vpnv2.Active.Nsr()
            self.nsr.parent = self
            self.proc_fsm = L2Vpnv2.Active.ProcFsm()
            self.proc_fsm.parent = self
            self.pseudowire_classes = L2Vpnv2.Active.PseudowireClasses()
            self.pseudowire_classes.parent = self
            self.pwr = L2Vpnv2.Active.Pwr()
            self.pwr.parent = self
            self.xconnect_brief = L2Vpnv2.Active.XconnectBrief()
            self.xconnect_brief.parent = self
            self.xconnect_groups = L2Vpnv2.Active.XconnectGroups()
            self.xconnect_groups.parent = self
            self.xconnect_mp2mp_ce2ces = L2Vpnv2.Active.XconnectMp2MpCe2Ces()
            self.xconnect_mp2mp_ce2ces.parent = self
            self.xconnect_mp2mps = L2Vpnv2.Active.XconnectMp2Mps()
            self.xconnect_mp2mps.parent = self
            self.xconnect_summary = L2Vpnv2.Active.XconnectSummary()
            self.xconnect_summary.parent = self
            self.xconnects = L2Vpnv2.Active.Xconnects()
            self.xconnects.parent = self


        class Discoveries(object):
            """
            Discovery Table
            
            .. attribute:: discovery
            
            	VPLS Discovery information
            	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.discovery = YList()
                self.discovery.parent = self
                self.discovery.name = 'discovery'


            class Discovery(object):
                """
                VPLS Discovery information
                
                .. attribute:: group_name
                
                	Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: is_service_connected
                
                	Is the service connected
                	**type**\:  bool
                
                .. attribute:: mtu_mismatch_ignore
                
                	Ignore MTU Mismatch
                	**type**\:  bool
                
                .. attribute:: number_vpn
                
                	Number of vpns
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: service_name
                
                	Service type
                	**type**\:   :py:class:`L2VpnServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnServiceEnum>`
                
                .. attribute:: service_name_xr
                
                	Service Type
                	**type**\:  str
                
                .. attribute:: signalling_info
                
                	Info about signalling protocol
                	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo>`
                
                .. attribute:: vpn_id
                
                	VPN id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_name
                
                	VPN Name
                	**type**\:  str
                
                	**length:** 1..27
                
                .. attribute:: vpn_name_xr
                
                	VPN instance name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_name = None
                    self.group_name_xr = None
                    self.is_service_connected = None
                    self.mtu_mismatch_ignore = None
                    self.number_vpn = None
                    self.service_name = None
                    self.service_name_xr = None
                    self.signalling_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo()
                    self.signalling_info.parent = self
                    self.vpn_id = None
                    self.vpn_name = None
                    self.vpn_name_xr = None


                class SignallingInfo(object):
                    """
                    Info about signalling protocol
                    
                    .. attribute:: ad_signalling_method
                    
                    	ADSignallingMethod
                    	**type**\:   :py:class:`L2VpnAdSigMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethodEnum>`
                    
                    .. attribute:: bgp_sig_info
                    
                    	bgp sig info
                    	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                    
                    .. attribute:: ldp_sig_info
                    
                    	ldp sig info
                    	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_signalling_method = None
                        self.bgp_sig_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                        self.bgp_sig_info.parent = self
                        self.ldp_sig_info = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                        self.ldp_sig_info.parent = self


                    class BgpSigInfo(object):
                        """
                        bgp sig info
                        
                        .. attribute:: edge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                        
                        .. attribute:: number_edges
                        
                        	Number of Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redge
                        
                        	List of edge ids
                        	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.edge = YList()
                            self.edge.parent = self
                            self.edge.name = 'edge'
                            self.number_edges = None
                            self.number_remote_edges = None
                            self.redge = YList()
                            self.redge.parent = self
                            self.redge.name = 'redge'


                        class Edge(object):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.edge_id = None
                                self.label_block = YList()
                                self.label_block.parent = self
                                self.label_block.name = 'label_block'
                                self.label_count = None


                            class LabelBlock(object):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.label_base = None
                                    self.label_error = None
                                    self.label_time_created = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.status_vector = YLeafList()
                                    self.status_vector.parent = self
                                    self.status_vector.name = 'status_vector'

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:edge/Cisco-IOS-XR-l2vpn-oper:label-block'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.block_offset is not None:
                                        return True

                                    if self.block_size is not None:
                                        return True

                                    if self.label_base is not None:
                                        return True

                                    if self.label_error is not None:
                                        return True

                                    if self.label_time_created is not None:
                                        return True

                                    if self.local_edge_id is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    if self.status_vector is not None:
                                        for child in self.status_vector:
                                            if child is not None:
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:edge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.edge_id is not None:
                                    return True

                                if self.label_block is not None:
                                    for child_ref in self.label_block:
                                        if child_ref._has_data():
                                            return True

                                if self.label_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge']['meta_info']


                        class Redge(object):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.edge_id = None
                                self.label_block = YList()
                                self.label_block.parent = self
                                self.label_block.name = 'label_block'
                                self.label_count = None


                            class LabelBlock(object):
                                """
                                List of label blocks
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\:  list of int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.label_base = None
                                    self.label_error = None
                                    self.label_time_created = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.status_vector = YLeafList()
                                    self.status_vector.parent = self
                                    self.status_vector.name = 'status_vector'

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:redge/Cisco-IOS-XR-l2vpn-oper:label-block'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.block_offset is not None:
                                        return True

                                    if self.block_size is not None:
                                        return True

                                    if self.label_base is not None:
                                        return True

                                    if self.label_error is not None:
                                        return True

                                    if self.label_time_created is not None:
                                        return True

                                    if self.local_edge_id is not None:
                                        return True

                                    if self.next_hop is not None:
                                        return True

                                    if self.status_vector is not None:
                                        for child in self.status_vector:
                                            if child is not None:
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:redge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.edge_id is not None:
                                    return True

                                if self.label_block is not None:
                                    for child_ref in self.label_block:
                                        if child_ref._has_data():
                                            return True

                                if self.label_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.edge is not None:
                                for child_ref in self.edge:
                                    if child_ref._has_data():
                                        return True

                            if self.number_edges is not None:
                                return True

                            if self.number_remote_edges is not None:
                                return True

                            if self.redge is not None:
                                for child_ref in self.redge:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo']['meta_info']


                    class LdpSigInfo(object):
                        """
                        ldp sig info
                        
                        .. attribute:: local_l2_router_id
                        
                        	Local L2VPN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_vpls_id
                        
                        	Local VPLS\-ID
                        	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_nlri
                        
                        	List of NLRIs
                        	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_l2_router_id = None
                            self.local_vpls_id = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                            self.local_vpls_id.parent = self
                            self.number_remote_edges = None
                            self.remote_nlri = YList()
                            self.remote_nlri.parent = self
                            self.remote_nlri.name = 'remote_nlri'


                        class LocalVplsId(object):
                            """
                            Local VPLS\-ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                self.auto.parent = self
                                self.two_byte_as = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                self.v4_addr.parent = self
                                self.vpls_id_type = None


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asn = None
                                    self.vpn_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asn is not None:
                                        return True

                                    if self.vpn_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                if self.vpls_id_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId']['meta_info']


                        class RemoteNlri(object):
                            """
                            List of NLRIs
                            
                            .. attribute:: local_address
                            
                            	Local BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: nlri_time_created
                            
                            	NLRI creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote BGP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_l2_router_id
                            
                            	Remote L2VPN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_address = None
                                self.nlri_time_created = None
                                self.remote_address = None
                                self.remote_l2_router_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:remote-nlri'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_address is not None:
                                    return True

                                if self.nlri_time_created is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                if self.remote_l2_router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_l2_router_id is not None:
                                return True

                            if self.local_vpls_id is not None and self.local_vpls_id._has_data():
                                return True

                            if self.number_remote_edges is not None:
                                return True

                            if self.remote_nlri is not None:
                                for child_ref in self.remote_nlri:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_signalling_method is not None:
                            return True

                        if self.bgp_sig_info is not None and self.bgp_sig_info._has_data():
                            return True

                        if self.ldp_sig_info is not None and self.ldp_sig_info._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery.SignallingInfo']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.is_service_connected is not None:
                        return True

                    if self.mtu_mismatch_ignore is not None:
                        return True

                    if self.number_vpn is not None:
                        return True

                    if self.service_name is not None:
                        return True

                    if self.service_name_xr is not None:
                        return True

                    if self.signalling_info is not None and self.signalling_info._has_data():
                        return True

                    if self.vpn_id is not None:
                        return True

                    if self.vpn_name is not None:
                        return True

                    if self.vpn_name_xr is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Discoveries.Discovery']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discoveries'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.discovery is not None:
                    for child_ref in self.discovery:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.Discoveries']['meta_info']


        class FlexibleXconnectServiceSummary(object):
            """
            Flexible XConnect Service summary information
            
            .. attribute:: number_fxc
            
            	Number of flexible xconnect services
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_down
            
            	Number of flexible xconnect services whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_up
            
            	Number of flexible xconnect services whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.number_fxc = None
                self.number_fxc_down = None
                self.number_fxc_up = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.number_fxc is not None:
                    return True

                if self.number_fxc_down is not None:
                    return True

                if self.number_fxc_up is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServiceSummary']['meta_info']


        class MainInterfaces(object):
            """
            Main Interface
            
            .. attribute:: main_interface
            
            	Main Interface Table
            	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.main_interface = YList()
                self.main_interface.parent = self
                self.main_interface.name = 'main_interface'


            class MainInterface(object):
                """
                Main Interface Table
                
                .. attribute:: interface_name  <key>
                
                	Main interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: main_interface_info
                
                	Main Interface info
                	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo>`
                
                .. attribute:: main_interface_instances
                
                	Main Interface Instance table
                	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_name = None
                    self.main_interface_info = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo()
                    self.main_interface_info.parent = self
                    self.main_interface_instances = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances()
                    self.main_interface_instances.parent = self


                class MainInterfaceInstances(object):
                    """
                    Main Interface Instance table
                    
                    .. attribute:: main_interface_instance
                    
                    	Main Interface Instance
                    	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.main_interface_instance = YList()
                        self.main_interface_instance.parent = self
                        self.main_interface_instance.name = 'main_interface_instance'


                    class MainInterfaceInstance(object):
                        """
                        Main Interface Instance
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: main_interface_instance_bridge_ports
                        
                        	Main Interface Instance Bridge Port table
                        	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                        
                        .. attribute:: main_interface_instance_info
                        
                        	Main Interface Instance info
                        	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance = None
                            self.main_interface_instance_bridge_ports = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                            self.main_interface_instance_bridge_ports.parent = self
                            self.main_interface_instance_info = L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                            self.main_interface_instance_info.parent = self


                        class MainInterfaceInstanceInfo(object):
                            """
                            Main Interface Instance info
                            
                            .. attribute:: configured_instance
                            
                            	Configured Instance
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flush_count
                            
                            	Flush count 
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_flags
                            
                            	Instance Flags
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_state
                            
                            	Instance State
                            	**type**\:   :py:class:`L2VpnMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceStateEnum>`
                            
                            .. attribute:: interface_count
                            
                            	Interface count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.configured_instance = None
                                self.flush_count = None
                                self.instance_flags = None
                                self.instance_id = None
                                self.instance_state = None
                                self.interface_count = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.configured_instance is not None:
                                    return True

                                if self.flush_count is not None:
                                    return True

                                if self.instance_flags is not None:
                                    return True

                                if self.instance_id is not None:
                                    return True

                                if self.instance_state is not None:
                                    return True

                                if self.interface_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo']['meta_info']


                        class MainInterfaceInstanceBridgePorts(object):
                            """
                            Main Interface Instance Bridge Port table
                            
                            .. attribute:: main_interface_instance_bridge_port
                            
                            	Main Interface Bridge Port info
                            	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.main_interface_instance_bridge_port = YList()
                                self.main_interface_instance_bridge_port.parent = self
                                self.main_interface_instance_bridge_port.name = 'main_interface_instance_bridge_port'


                            class MainInterfaceInstanceBridgePort(object):
                                """
                                Main Interface Bridge Port info
                                
                                .. attribute:: bridge_port  <key>
                                
                                	Bridge Port
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: bridge_port_xr
                                
                                	Bridge port ifhandle
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port = None
                                    self.bridge_port_xr = None
                                    self.instance_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.bridge_port is None:
                                        raise YPYModelError('Key property bridge_port is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-port[Cisco-IOS-XR-l2vpn-oper:bridge-port = ' + str(self.bridge_port) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port is not None:
                                        return True

                                    if self.bridge_port_xr is not None:
                                        return True

                                    if self.instance_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-ports'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.main_interface_instance_bridge_port is not None:
                                    for child_ref in self.main_interface_instance_bridge_port:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.instance is None:
                                raise YPYModelError('Key property instance is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance is not None:
                                return True

                            if self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports._has_data():
                                return True

                            if self.main_interface_instance_info is not None and self.main_interface_instance_info._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instances'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.main_interface_instance is not None:
                            for child_ref in self.main_interface_instance:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances']['meta_info']


                class MainInterfaceInfo(object):
                    """
                    Main Interface info
                    
                    .. attribute:: interface_count
                    
                    	Sub Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: main_interface_handle
                    
                    	Main Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:   :py:class:`L2VpnMainIfProtectectedEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectectedEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_count = None
                        self.main_interface_handle = None
                        self.protected = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_count is not None:
                            return True

                        if self.main_interface_handle is not None:
                            return True

                        if self.protected is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_name is None:
                        raise YPYModelError('Key property interface_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:main-interfaces/Cisco-IOS-XR-l2vpn-oper:main-interface[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_name is not None:
                        return True

                    if self.main_interface_info is not None and self.main_interface_info._has_data():
                        return True

                    if self.main_interface_instances is not None and self.main_interface_instances._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.MainInterfaces.MainInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:main-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.main_interface is not None:
                    for child_ref in self.main_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.MainInterfaces']['meta_info']


        class IccpSm(object):
            """
            ICCP\-based Service Multi\-homing operational data
            
            .. attribute:: iccp_groups
            
            	ICCP Group Table
            	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups>`
            
            .. attribute:: iccp_sm_summary
            
            	ICCP\-based Service Multi\-homing database summary
            	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpSmSummary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.iccp_groups = L2Vpnv2.Active.IccpSm.IccpGroups()
                self.iccp_groups.parent = self
                self.iccp_sm_summary = L2Vpnv2.Active.IccpSm.IccpSmSummary()
                self.iccp_sm_summary.parent = self


            class IccpSmSummary(object):
                """
                ICCP\-based Service Multi\-homing database
                summary
                
                .. attribute:: connected_groups
                
                	Number of Connected Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: connecting_groups
                
                	Number of Connecting Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: failed_ports
                
                	Number of Failed Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groups
                
                	Total Number of Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: operational_ports
                
                	Number of Operational Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ports
                
                	Total Number of Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: provisioned_groups
                
                	Number of Provisioned Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: reverting_ports
                
                	Number of Reverting Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronized_groups
                
                	Number of Synchronized Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronizing_groups
                
                	Number of Synchronizing Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unconfigured_ports
                
                	Number of Unconfigured Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_ports
                
                	Number of Unknown Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_groups
                
                	Number of Unresolved Groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsynchronized_ports
                
                	Number of Unsynchronized Ports
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.connected_groups = None
                    self.connecting_groups = None
                    self.failed_ports = None
                    self.groups = None
                    self.operational_ports = None
                    self.ports = None
                    self.provisioned_groups = None
                    self.reverting_ports = None
                    self.synchronized_groups = None
                    self.synchronizing_groups = None
                    self.unconfigured_ports = None
                    self.unknown_ports = None
                    self.unresolved_groups = None
                    self.unsynchronized_ports = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-sm-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.connected_groups is not None:
                        return True

                    if self.connecting_groups is not None:
                        return True

                    if self.failed_ports is not None:
                        return True

                    if self.groups is not None:
                        return True

                    if self.operational_ports is not None:
                        return True

                    if self.ports is not None:
                        return True

                    if self.provisioned_groups is not None:
                        return True

                    if self.reverting_ports is not None:
                        return True

                    if self.synchronized_groups is not None:
                        return True

                    if self.synchronizing_groups is not None:
                        return True

                    if self.unconfigured_ports is not None:
                        return True

                    if self.unknown_ports is not None:
                        return True

                    if self.unresolved_groups is not None:
                        return True

                    if self.unsynchronized_ports is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpSmSummary']['meta_info']


            class IccpGroups(object):
                """
                ICCP Group Table
                
                .. attribute:: iccp_group
                
                	ICCP Group
                	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.iccp_group = YList()
                    self.iccp_group.parent = self
                    self.iccp_group.name = 'iccp_group'


                class IccpGroup(object):
                    """
                    ICCP Group
                    
                    .. attribute:: group_id  <key>
                    
                    	Group ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: iccp_group_info
                    
                    	ICCP Group Information
                    	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                    
                    .. attribute:: iccp_ports
                    
                    	ICCP Port Table
                    	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_id = None
                        self.iccp_group_info = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                        self.iccp_group_info.parent = self
                        self.iccp_ports = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                        self.iccp_ports.parent = self


                    class IccpGroupInfo(object):
                        """
                        ICCP Group Information
                        
                        .. attribute:: group_id
                        
                        	Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: iccp_member_up
                        
                        	ICCP Member Up
                        	**type**\:  bool
                        
                        .. attribute:: iccp_transport_up
                        
                        	ICCP Transport Up
                        	**type**\:  bool
                        
                        .. attribute:: local_node_id
                        
                        	Local Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ports
                        
                        	List of ports in the group
                        	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                        
                        .. attribute:: remote_node_id
                        
                        	Remote Node ID
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`IccpSmStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_id = None
                            self.iccp_member_up = None
                            self.iccp_transport_up = None
                            self.local_node_id = None
                            self.ports = YList()
                            self.ports.parent = self
                            self.ports.name = 'ports'
                            self.remote_node_id = None
                            self.state = None


                        class Ports(object):
                            """
                            List of ports in the group
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.local_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                self.local_port.parent = self
                                self.mac_flush_tcn = None
                                self.remote_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                self.remote_port.parent = self


                            class LocalPort(object):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort']['meta_info']


                            class RemotePort(object):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ports'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.local_port is not None and self.local_port._has_data():
                                    return True

                                if self.mac_flush_tcn is not None:
                                    return True

                                if self.remote_port is not None and self.remote_port._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-group-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_id is not None:
                                return True

                            if self.iccp_member_up is not None:
                                return True

                            if self.iccp_transport_up is not None:
                                return True

                            if self.local_node_id is not None:
                                return True

                            if self.ports is not None:
                                for child_ref in self.ports:
                                    if child_ref._has_data():
                                        return True

                            if self.remote_node_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo']['meta_info']


                    class IccpPorts(object):
                        """
                        ICCP Port Table
                        
                        .. attribute:: iccp_port
                        
                        	ICCP Port
                        	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.iccp_port = YList()
                            self.iccp_port.parent = self
                            self.iccp_port.name = 'iccp_port'


                        class IccpPort(object):
                            """
                            ICCP Port
                            
                            .. attribute:: interface  <key>
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\:  bool
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface = None
                                self.interface_name = None
                                self.local_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                self.local_port.parent = self
                                self.mac_flush_tcn = None
                                self.remote_port = L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                self.remote_port.parent = self


                            class LocalPort(object):
                                """
                                Local port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort']['meta_info']


                            class RemotePort(object):
                                """
                                Remote port info
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\:  str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.fsm_state = None
                                    self.port_fail_code = None
                                    self.port_state = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self.vlan_state = None
                                    self.vlan_vector = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.fsm_state is not None:
                                        return True

                                    if self.port_fail_code is not None:
                                        return True

                                    if self.port_state is not None:
                                        return True

                                    if self.reversion_time is not None:
                                        return True

                                    if self.reversion_time_remaining is not None:
                                        return True

                                    if self.vlan_state is not None:
                                        return True

                                    if self.vlan_vector is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface is None:
                                    raise YPYModelError('Key property interface is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface is not None:
                                    return True

                                if self.interface_name is not None:
                                    return True

                                if self.local_port is not None and self.local_port._has_data():
                                    return True

                                if self.mac_flush_tcn is not None:
                                    return True

                                if self.remote_port is not None and self.remote_port._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-ports'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.iccp_port is not None:
                                for child_ref in self.iccp_port:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts']['meta_info']

                    @property
                    def _common_path(self):
                        if self.group_id is None:
                            raise YPYModelError('Key property group_id is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-groups/Cisco-IOS-XR-l2vpn-oper:iccp-group[Cisco-IOS-XR-l2vpn-oper:group-id = ' + str(self.group_id) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_id is not None:
                            return True

                        if self.iccp_group_info is not None and self.iccp_group_info._has_data():
                            return True

                        if self.iccp_ports is not None and self.iccp_ports._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups.IccpGroup']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-groups'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.iccp_group is not None:
                        for child_ref in self.iccp_group:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.IccpSm.IccpGroups']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:iccp-sm'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.iccp_groups is not None and self.iccp_groups._has_data():
                    return True

                if self.iccp_sm_summary is not None and self.iccp_sm_summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.IccpSm']['meta_info']


        class BridgeSummary(object):
            """
            Bridge Domain summary information
            
            .. attribute:: num_vn_is
            
            	Number of VNIs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_down
            
            	Number of VNIs down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_unresolved
            
            	Number of VNIs unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_up
            
            	Number of VNIs up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs
            
            	Number of attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_up
            
            	Number of attachment circuits whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains
            
            	Number of bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_shut
            
            	Number of bridge\-domains admin disabled
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_up
            
            	Number of bridge\-domains up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_default_bridge_doamins
            
            	Number of default bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp
            
            	Number of P2MPs
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_down
            
            	Number of P2MPs whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_up
            
            	Number of P2MPs whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_up
            
            	Number of pseudowires whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_core
            
            	Number of PBB Core
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_edge
            
            	Number of PBB Edge
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pseudowires
            
            	Number of pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_a_cs
            
            	Number of partially programmed attachment circuits
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_bridges
            
            	Number of partially programmed bridge\-domains
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_pseudowires
            
            	Number of partially programmed pseudowires
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_pseudowires
            
            	Number of pseudowires whose state is standby
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.num_vn_is = None
                self.num_vn_is_down = None
                self.num_vn_is_unresolved = None
                self.num_vn_is_up = None
                self.number_a_cs = None
                self.number_a_cs_up = None
                self.number_bridge_domains = None
                self.number_bridge_domains_shut = None
                self.number_bridge_domains_up = None
                self.number_default_bridge_doamins = None
                self.number_groups = None
                self.number_p2mp = None
                self.number_p2mp_down = None
                self.number_p2mp_up = None
                self.number_p_ws_up = None
                self.number_pbb_core = None
                self.number_pbb_edge = None
                self.number_pseudowires = None
                self.out_of_memory_state = None
                self.partially_programmed_a_cs = None
                self.partially_programmed_bridges = None
                self.partially_programmed_pseudowires = None
                self.standby_pseudowires = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.num_vn_is is not None:
                    return True

                if self.num_vn_is_down is not None:
                    return True

                if self.num_vn_is_unresolved is not None:
                    return True

                if self.num_vn_is_up is not None:
                    return True

                if self.number_a_cs is not None:
                    return True

                if self.number_a_cs_up is not None:
                    return True

                if self.number_bridge_domains is not None:
                    return True

                if self.number_bridge_domains_shut is not None:
                    return True

                if self.number_bridge_domains_up is not None:
                    return True

                if self.number_default_bridge_doamins is not None:
                    return True

                if self.number_groups is not None:
                    return True

                if self.number_p2mp is not None:
                    return True

                if self.number_p2mp_down is not None:
                    return True

                if self.number_p2mp_up is not None:
                    return True

                if self.number_p_ws_up is not None:
                    return True

                if self.number_pbb_core is not None:
                    return True

                if self.number_pbb_edge is not None:
                    return True

                if self.number_pseudowires is not None:
                    return True

                if self.out_of_memory_state is not None:
                    return True

                if self.partially_programmed_a_cs is not None:
                    return True

                if self.partially_programmed_bridges is not None:
                    return True

                if self.partially_programmed_pseudowires is not None:
                    return True

                if self.standby_pseudowires is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.BridgeSummary']['meta_info']


        class Nsr(object):
            """
            L2VPN NSR information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.event_history = YList()
                self.event_history.parent = self
                self.event_history.name = 'event_history'
                self.failover_status = L2Vpnv2.Active.Nsr.FailoverStatus()
                self.failover_status.parent = self
                self.issu_status = L2Vpnv2.Active.Nsr.IssuStatus()
                self.issu_status.parent = self
                self.nsr_status = L2Vpnv2.Active.Nsr.NsrStatus()
                self.nsr_status.parent = self
                self.process_role = None
                self.process_state = None
                self.report_card = YList()
                self.report_card.parent = self
                self.report_card.name = 'report_card'
                self.state_transition_time = YLeafList()
                self.state_transition_time.parent = self
                self.state_transition_time.name = 'state_transition_time'
                self.sw_install_in_progress = None
                self.sync_flags = None
                self.xid_info = YList()
                self.xid_info.parent = self
                self.xid_info.name = 'xid_info'


            class FailoverStatus(object):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.master_time = None
                    self.start_time = None
                    self.triggered_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:failover-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.master_time is not None:
                        return True

                    if self.start_time is not None:
                        return True

                    if self.triggered_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Nsr.FailoverStatus']['meta_info']


            class NsrStatus(object):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Nsr.NsrStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Nsr.NsrStatus']['meta_info']


            class IssuStatus(object):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Nsr.IssuStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Nsr.IssuStatus']['meta_info']


            class XidInfo(object):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.app_type = None
                    self.sent_ids = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:xid-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.app_type is not None:
                        return True

                    if self.sent_ids is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Nsr.XidInfo']['meta_info']


            class ReportCard(object):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.collaborator_idt_done = None
                    self.collaborator_is_connected = None
                    self.collaborator_skipped = None
                    self.connection_change_time = None
                    self.idt_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:report-card'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.collaborator_idt_done is not None:
                        return True

                    if self.collaborator_is_connected is not None:
                        return True

                    if self.collaborator_skipped is not None:
                        return True

                    if self.connection_change_time is not None:
                        return True

                    if self.idt_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Nsr.ReportCard']['meta_info']


            class EventHistory(object):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_timestamp = None
                    self.new_state = None
                    self.previous_state = None
                    self.process_collaborator = None
                    self.process_event = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:event-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_timestamp is not None:
                        return True

                    if self.new_state is not None:
                        return True

                    if self.previous_state is not None:
                        return True

                    if self.process_collaborator is not None:
                        return True

                    if self.process_event is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Nsr.EventHistory']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:nsr'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.event_history is not None:
                    for child_ref in self.event_history:
                        if child_ref._has_data():
                            return True

                if self.failover_status is not None and self.failover_status._has_data():
                    return True

                if self.issu_status is not None and self.issu_status._has_data():
                    return True

                if self.nsr_status is not None and self.nsr_status._has_data():
                    return True

                if self.process_role is not None:
                    return True

                if self.process_state is not None:
                    return True

                if self.report_card is not None:
                    for child_ref in self.report_card:
                        if child_ref._has_data():
                            return True

                if self.state_transition_time is not None:
                    for child in self.state_transition_time:
                        if child is not None:
                            return True

                if self.sw_install_in_progress is not None:
                    return True

                if self.sync_flags is not None:
                    return True

                if self.xid_info is not None:
                    for child_ref in self.xid_info:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.Nsr']['meta_info']


        class GlobalSettings(object):
            """
            L2VPN global settings
            
            .. attribute:: going_active
            
            	transitioning to Active functional role
            	**type**\:  bool
            
            .. attribute:: ha_role
            
            	Node redundancy role
            	**type**\:  str
            
            .. attribute:: issu_role
            
            	Node ISSU role
            	**type**\:  str
            
            .. attribute:: logging_bd_enabled
            
            	Logging BD state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_df_election_enabled
            
            	Logging EVPN Designated Forwarder changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_nsr_enabled
            
            	Logging NSR state changes enabled
            	**type**\:  bool
            
            .. attribute:: logging_pw_enabled
            
            	Logging PW enabled
            	**type**\:  bool
            
            .. attribute:: logging_vfi_enabled
            
            	Logging VFI state changes enabled
            	**type**\:  bool
            
            .. attribute:: process_fsm
            
            	Current L2VPN FSM role
            	**type**\:  str
            
            .. attribute:: pw_grouping_enabled
            
            	PW Grouping enabled
            	**type**\:  bool
            
            .. attribute:: pw_oam_refresh_transmit_time
            
            	PW OAM refresh transmit (seconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: pw_status_enabled
            
            	PW Status enabled
            	**type**\:  bool
            
            .. attribute:: tcn_propagation_enabled
            
            	TCN propagation enabled
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.going_active = None
                self.ha_role = None
                self.issu_role = None
                self.logging_bd_enabled = None
                self.logging_df_election_enabled = None
                self.logging_nsr_enabled = None
                self.logging_pw_enabled = None
                self.logging_vfi_enabled = None
                self.process_fsm = None
                self.pw_grouping_enabled = None
                self.pw_oam_refresh_transmit_time = None
                self.pw_status_enabled = None
                self.tcn_propagation_enabled = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:global-settings'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.going_active is not None:
                    return True

                if self.ha_role is not None:
                    return True

                if self.issu_role is not None:
                    return True

                if self.logging_bd_enabled is not None:
                    return True

                if self.logging_df_election_enabled is not None:
                    return True

                if self.logging_nsr_enabled is not None:
                    return True

                if self.logging_pw_enabled is not None:
                    return True

                if self.logging_vfi_enabled is not None:
                    return True

                if self.process_fsm is not None:
                    return True

                if self.pw_grouping_enabled is not None:
                    return True

                if self.pw_oam_refresh_transmit_time is not None:
                    return True

                if self.pw_status_enabled is not None:
                    return True

                if self.tcn_propagation_enabled is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.GlobalSettings']['meta_info']


        class Pwr(object):
            """
            Pseudowire Routing Table
            
            .. attribute:: summary
            
            	L2VPN Pseudowire Routing Summary
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.summary = L2Vpnv2.Active.Pwr.Summary()
                self.summary.parent = self


            class Summary(object):
                """
                L2VPN Pseudowire Routing Summary
                
                .. attribute:: bgp_as
                
                	BGP AS number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_router_id
                
                	BGP Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cfg_global_id
                
                	Configured Global ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: cfg_router_id
                
                	Configured Router ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: l2vpn_has_bgp_eod
                
                	L2VPN got BGP EOD
                	**type**\:  bool
                
                .. attribute:: rd_auto
                
                	Automatic Route Distingtuisher
                	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto>`
                
                .. attribute:: rd_configured
                
                	Configured Route Distinguisher
                	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_as = None
                    self.bgp_router_id = None
                    self.cfg_global_id = None
                    self.cfg_router_id = None
                    self.l2vpn_has_bgp_eod = None
                    self.rd_auto = L2Vpnv2.Active.Pwr.Summary.RdAuto()
                    self.rd_auto.parent = self
                    self.rd_configured = L2Vpnv2.Active.Pwr.Summary.RdConfigured()
                    self.rd_configured.parent = self


                class RdAuto(object):
                    """
                    Automatic Route Distingtuisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto = L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto()
                        self.auto.parent = self
                        self.four_byte_as = L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rd = None
                        self.two_byte_as = L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr()
                        self.v4_addr.parent = self


                    class Auto(object):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto_index = None
                            self.router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto_index is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdAuto.Auto']['meta_info']


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdAuto.V4Addr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto is not None and self.auto._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rd is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdAuto']['meta_info']


                class RdConfigured(object):
                    """
                    Configured Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto = L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto()
                        self.auto.parent = self
                        self.four_byte_as = L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rd = None
                        self.two_byte_as = L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr()
                        self.v4_addr.parent = self


                    class Auto(object):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto_index = None
                            self.router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto_index is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdConfigured.Auto']['meta_info']


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto is not None and self.auto._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rd is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Pwr.Summary.RdConfigured']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_as is not None:
                        return True

                    if self.bgp_router_id is not None:
                        return True

                    if self.cfg_global_id is not None:
                        return True

                    if self.cfg_router_id is not None:
                        return True

                    if self.l2vpn_has_bgp_eod is not None:
                        return True

                    if self.rd_auto is not None and self.rd_auto._has_data():
                        return True

                    if self.rd_configured is not None and self.rd_configured._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Pwr.Summary']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pwr'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.Pwr']['meta_info']


        class XconnectMp2MpCe2Ces(object):
            """
            XConnect MP2MP CE2CE Table
            
            .. attribute:: xconnect_mp2mp_ce2ce
            
            	XConnect MP2MP CE2CE information
            	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect_mp2mp_ce2ce = YList()
                self.xconnect_mp2mp_ce2ce.parent = self
                self.xconnect_mp2mp_ce2ce.name = 'xconnect_mp2mp_ce2ce'


            class XconnectMp2MpCe2Ce(object):
                """
                XConnect MP2MP CE2CE information
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\:  bool
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: local_ceid
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: remote_ceid
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ce_added = None
                    self.group_name = None
                    self.local_ceid = None
                    self.local_customer_edge_id = None
                    self.mp2_mp_name = None
                    self.remote_ceid = None
                    self.remote_customer_edge_id = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ce'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ce_added is not None:
                        return True

                    if self.group_name is not None:
                        return True

                    if self.local_ceid is not None:
                        return True

                    if self.local_customer_edge_id is not None:
                        return True

                    if self.mp2_mp_name is not None:
                        return True

                    if self.remote_ceid is not None:
                        return True

                    if self.remote_customer_edge_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect_mp2mp_ce2ce is not None:
                    for child_ref in self.xconnect_mp2mp_ce2ce:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.XconnectMp2MpCe2Ces']['meta_info']


        class Xconnects(object):
            """
            XConnect Table
            
            .. attribute:: xconnect
            
            	XConnect information
            	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect = YList()
                self.xconnect.parent = self
                self.xconnect.name = 'xconnect'


            class Xconnect(object):
                """
                XConnect information
                
                .. attribute:: backup
                
                	LCR backup
                	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup>`
                
                .. attribute:: backup_segment
                
                	Backup Segment
                	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment>`
                
                .. attribute:: ce2ce
                
                	CE2CE
                	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce>`
                
                .. attribute:: description
                
                	P2P Description
                	**type**\:  str
                
                .. attribute:: diag_mask
                
                	Mask indicating what if anything is missing before the XC can be provisioned
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: interworking
                
                	Interworking type
                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                
                .. attribute:: is_mp2mp
                
                	xconnect is mp2mp
                	**type**\:  bool
                
                .. attribute:: number_of_backup_p_ws
                
                	Number of backups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: segment1
                
                	Segment 1
                	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1>`
                
                .. attribute:: segment2
                
                	Segment 2
                	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2>`
                
                .. attribute:: state
                
                	State of the xconnect
                	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                
                .. attribute:: xconnect_name
                
                	XConnect Name
                	**type**\:  str
                
                	**length:** 1..38
                
                .. attribute:: xconnect_name_xr
                
                	XConnect name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.backup = L2Vpnv2.Active.Xconnects.Xconnect.Backup()
                    self.backup.parent = self
                    self.backup_segment = YList()
                    self.backup_segment.parent = self
                    self.backup_segment.name = 'backup_segment'
                    self.ce2ce = L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce()
                    self.ce2ce.parent = self
                    self.description = None
                    self.diag_mask = None
                    self.group_name = None
                    self.group_name_xr = None
                    self.interworking = None
                    self.is_mp2mp = None
                    self.number_of_backup_p_ws = None
                    self.segment1 = L2Vpnv2.Active.Xconnects.Xconnect.Segment1()
                    self.segment1.parent = self
                    self.segment2 = L2Vpnv2.Active.Xconnects.Xconnect.Segment2()
                    self.segment2.parent = self
                    self.state = None
                    self.xconnect_name = None
                    self.xconnect_name_xr = None


                class Backup(object):
                    """
                    LCR backup
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Backup']['meta_info']


                class Segment1(object):
                    """
                    Segment 1
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment1']['meta_info']


                class Segment2(object):
                    """
                    Segment 2
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Segment2']['meta_info']


                class Ce2Ce(object):
                    """
                    CE2CE
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\:  bool
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ce_added = None
                        self.local_customer_edge_id = None
                        self.remote_customer_edge_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:ce2ce'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ce_added is not None:
                            return True

                        if self.local_customer_edge_id is not None:
                            return True

                        if self.remote_customer_edge_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.Ce2Ce']['meta_info']


                class BackupSegment(object):
                    """
                    Backup Segment
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.attachment_circuit = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.pseudo_wire = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire()
                        self.pseudo_wire.parent = self
                        self.segment_type = None


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit']['meta_info']


                    class PseudoWire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                            return True

                        if self.segment_type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect.BackupSegment']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.backup is not None and self.backup._has_data():
                        return True

                    if self.backup_segment is not None:
                        for child_ref in self.backup_segment:
                            if child_ref._has_data():
                                return True

                    if self.ce2ce is not None and self.ce2ce._has_data():
                        return True

                    if self.description is not None:
                        return True

                    if self.diag_mask is not None:
                        return True

                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.interworking is not None:
                        return True

                    if self.is_mp2mp is not None:
                        return True

                    if self.number_of_backup_p_ws is not None:
                        return True

                    if self.segment1 is not None and self.segment1._has_data():
                        return True

                    if self.segment2 is not None and self.segment2._has_data():
                        return True

                    if self.state is not None:
                        return True

                    if self.xconnect_name is not None:
                        return True

                    if self.xconnect_name_xr is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Xconnects.Xconnect']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnects'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect is not None:
                    for child_ref in self.xconnect:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.Xconnects']['meta_info']


        class XconnectGroups(object):
            """
            XConnect group Table
            
            .. attribute:: xconnect_group
            
            	XConnect group information
            	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectGroups.XconnectGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect_group = YList()
                self.xconnect_group.parent = self
                self.xconnect_group.name = 'xconnect_group'


            class XconnectGroup(object):
                """
                XConnect group information
                
                .. attribute:: group_name  <key>
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_name = None
                    self.group_name_xr = None
                    self.number_xconnects = None

                @property
                def _common_path(self):
                    if self.group_name is None:
                        raise YPYModelError('Key property group_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-groups/Cisco-IOS-XR-l2vpn-oper:xconnect-group[Cisco-IOS-XR-l2vpn-oper:group-name = ' + str(self.group_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.number_xconnects is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.XconnectGroups.XconnectGroup']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-groups'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect_group is not None:
                    for child_ref in self.xconnect_group:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.XconnectGroups']['meta_info']


        class XconnectMp2Mps(object):
            """
            XConnect MP2MP Table
            
            .. attribute:: xconnect_mp2mp
            
            	XConnect MP2MP information
            	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.xconnect_mp2mp = YList()
                self.xconnect_mp2mp.parent = self
                self.xconnect_mp2mp.name = 'xconnect_mp2mp'


            class XconnectMp2Mp(object):
                """
                XConnect MP2MP information
                
                .. attribute:: discovery
                
                	l2vpn xc auto discovery info
                	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\:  str
                
                .. attribute:: l2_encapsulation
                
                	L2 Encapsulation
                	**type**\:   :py:class:`L2VpnBagAdEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncapEnum>`
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\:  str
                
                	**length:** 1..26
                
                .. attribute:: mp2mp_name
                
                	MP2MP name
                	**type**\:  str
                
                .. attribute:: mp2mpid
                
                	Identification Number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	Vpn ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_mtu
                
                	VPN MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xconnect_shutdown
                
                	Administratively disabled
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.discovery = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                    self.discovery.parent = self
                    self.group_name = None
                    self.group_name_xr = None
                    self.l2_encapsulation = None
                    self.mp2_mp_name = None
                    self.mp2mp_name = None
                    self.mp2mpid = None
                    self.vpn_id = None
                    self.vpn_mtu = None
                    self.xconnect_shutdown = None


                class Discovery(object):
                    """
                    l2vpn xc auto discovery info
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery Method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_service_connected
                    
                    	Service Connected
                    	**type**\:  bool
                    
                    .. attribute:: ad_signalling_method
                    
                    	Signaling Protocol
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ce_range
                    
                    	CE Range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: export_route_policy
                    
                    	Export Route Policy
                    	**type**\:  str
                    
                    .. attribute:: export_rt
                    
                    	Export Route Targets
                    	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                    
                    .. attribute:: import_rt
                    
                    	Import Route Targets
                    	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2c_es
                    
                    	Number of ce2ce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2ce_advertised
                    
                    	Number of ce2ce Advertised
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rd_value
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                    
                    .. attribute:: vpn_added
                    
                    	VPN Added
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_service_connected = None
                        self.ad_signalling_method = None
                        self.ce_range = None
                        self.export_route_policy = None
                        self.export_rt = YList()
                        self.export_rt.parent = self
                        self.export_rt.name = 'export_rt'
                        self.import_rt = YList()
                        self.import_rt.parent = self
                        self.import_rt.name = 'import_rt'
                        self.number_a_cs = None
                        self.number_a_cs_up = None
                        self.number_ce2c_es = None
                        self.number_ce2ce_advertised = None
                        self.number_p_ws_up = None
                        self.number_pseudowires = None
                        self.rd_value = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                        self.rd_value.parent = self
                        self.vpn_added = None


                    class RdValue(object):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                            self.auto.parent = self
                            self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rd = None
                            self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                            self.v4_addr.parent = self


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto_index = None
                                self.router_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto_index is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rd is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue']['meta_info']


                    class ImportRt(object):
                        """
                        Import Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.es_import = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                            self.es_import.parent = self
                            self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rt = None
                            self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                            self.v4_addr.parent = self


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr']['meta_info']


                        class EsImport(object):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.high_bytes = None
                                self.low_bytes = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.high_bytes is not None:
                                    return True

                                if self.low_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.es_import is not None and self.es_import._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rt is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt']['meta_info']


                    class ExportRt(object):
                        """
                        Export Route Targets
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.es_import = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                            self.es_import.parent = self
                            self.four_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rt = None
                            self.two_byte_as = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                            self.v4_addr.parent = self


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr']['meta_info']


                        class EsImport(object):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.high_bytes = None
                                self.low_bytes = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.high_bytes is not None:
                                    return True

                                if self.low_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.es_import is not None and self.es_import._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rt is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_service_connected is not None:
                            return True

                        if self.ad_signalling_method is not None:
                            return True

                        if self.ce_range is not None:
                            return True

                        if self.export_route_policy is not None:
                            return True

                        if self.export_rt is not None:
                            for child_ref in self.export_rt:
                                if child_ref._has_data():
                                    return True

                        if self.import_rt is not None:
                            for child_ref in self.import_rt:
                                if child_ref._has_data():
                                    return True

                        if self.number_a_cs is not None:
                            return True

                        if self.number_a_cs_up is not None:
                            return True

                        if self.number_ce2c_es is not None:
                            return True

                        if self.number_ce2ce_advertised is not None:
                            return True

                        if self.number_p_ws_up is not None:
                            return True

                        if self.number_pseudowires is not None:
                            return True

                        if self.rd_value is not None and self.rd_value._has_data():
                            return True

                        if self.vpn_added is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp.Discovery']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.discovery is not None and self.discovery._has_data():
                        return True

                    if self.group_name is not None:
                        return True

                    if self.group_name_xr is not None:
                        return True

                    if self.l2_encapsulation is not None:
                        return True

                    if self.mp2_mp_name is not None:
                        return True

                    if self.mp2mp_name is not None:
                        return True

                    if self.mp2mpid is not None:
                        return True

                    if self.vpn_id is not None:
                        return True

                    if self.vpn_mtu is not None:
                        return True

                    if self.xconnect_shutdown is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps.XconnectMp2Mp']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.xconnect_mp2mp is not None:
                    for child_ref in self.xconnect_mp2mp:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.XconnectMp2Mps']['meta_info']


        class Indexes(object):
            """
            ID Manager Index Table
            
            .. attribute:: index
            
            	ID Manager Index Pool
            	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Indexes.Index>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.index = YList()
                self.index.parent = self
                self.index.name = 'index'


            class Index(object):
                """
                ID Manager Index Pool
                
                .. attribute:: pool_id  <key>
                
                	Pool ID
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: allocated_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: application_type
                
                	Application Type
                	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                
                .. attribute:: max_num_id_mgr
                
                	Maximum number of pool extensions
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_id_mgr_in_use
                
                	ID mgr instances in use
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_id_xr
                
                	Pool Id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_size
                
                	Pool size
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: zombied_ids
                
                	Number of IDs allocated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.pool_id = None
                    self.allocated_ids = None
                    self.application_type = None
                    self.max_num_id_mgr = None
                    self.num_id_mgr_in_use = None
                    self.pool_id_xr = None
                    self.pool_size = None
                    self.zombied_ids = None

                @property
                def _common_path(self):
                    if self.pool_id is None:
                        raise YPYModelError('Key property pool_id is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:indexes/Cisco-IOS-XR-l2vpn-oper:index[Cisco-IOS-XR-l2vpn-oper:pool-id = ' + str(self.pool_id) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.pool_id is not None:
                        return True

                    if self.allocated_ids is not None:
                        return True

                    if self.application_type is not None:
                        return True

                    if self.max_num_id_mgr is not None:
                        return True

                    if self.num_id_mgr_in_use is not None:
                        return True

                    if self.pool_id_xr is not None:
                        return True

                    if self.pool_size is not None:
                        return True

                    if self.zombied_ids is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Indexes.Index']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:indexes'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.index is not None:
                    for child_ref in self.index:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.Indexes']['meta_info']


        class XconnectSummary(object):
            """
            XConnect summary information
            
            .. attribute:: admin_down_backup_interface_xconnects
            
            	Number of XCs with backup interface in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_xconnects
            
            	Number of XCs with backup PW in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_interface_xconnects
            
            	Number of XCs with backup interface in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_xconnects
            
            	Number of XCs with backup PW in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2_ceconnections
            
            	Number of Ce2Ce connections
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_advertized
            
            	Number of CE2CE connections that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_not_advertized
            
            	Number of CE2CE connections that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects
            
            	Number of mp2mp xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_advertised
            
            	Number of Mp2mp XCs that have been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_down
            
            	Number of Mp2mp XCs that have ben admined down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_up
            
            	Number of Mp2mp XCs that have been admined up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnectss_not_advertised
            
            	Number of Mp2mp XCs that have not been advertized
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_administratively_down
            
            	Number of xconnects with segments in admin down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup
            
            	Number of XCs currently using backup PW (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup_interface
            
            	Number of XCs currently using backup interface (UP state)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_down
            
            	Number of xconnects whose state is down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_locally_switched
            
            	Number of locally switched xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
            
            	Number of xconnects of type attachment circuit to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
            
            	Number of xconnects of type monitor session to pseudowire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
            
            	Number of xconnects of type PseudoWire To PseudoWire
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_unresolved
            
            	Number of xconnects whose state is unresolved
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_up
            
            	Numxber of xconnects whose state is up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_interface
            
            	Number of XCs configured with backup interface
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_pw
            
            	Number of XCs configured with backup PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_xconnects
            
            	Number of cross\-connects partially programmed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_interface_xconnects
            
            	Number of XCs with backup interface in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_xconnects
            
            	Number of XCs with backup PW in standby state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_ready_backup_xconnects
            
            	Number of XCs with backup PW in standby ready state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_interface_xconnects
            
            	Number of XCs with backup interface in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_xconnects
            
            	Number of XCs with backup PW in unresolved state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.admin_down_backup_interface_xconnects = None
                self.admin_down_backup_xconnects = None
                self.down_backup_interface_xconnects = None
                self.down_backup_xconnects = None
                self.number_ce2_ceconnections = None
                self.number_ce2ce_advertized = None
                self.number_ce2ce_not_advertized = None
                self.number_groups = None
                self.number_mp2mp_xconnects = None
                self.number_mp2mp_xconnects_advertised = None
                self.number_mp2mp_xconnects_down = None
                self.number_mp2mp_xconnects_up = None
                self.number_mp2mp_xconnectss_not_advertised = None
                self.number_xconnects = None
                self.number_xconnects_administratively_down = None
                self.number_xconnects_currently_using_backup = None
                self.number_xconnects_currently_using_backup_interface = None
                self.number_xconnects_down = None
                self.number_xconnects_locally_switched = None
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
                self.number_xconnects_type_monitor_session_to_pseudo_wire = None
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
                self.number_xconnects_unresolved = None
                self.number_xconnects_up = None
                self.number_xconnects_with_backup_interface = None
                self.number_xconnects_with_backup_pw = None
                self.out_of_memory_state = None
                self.partially_programmed_xconnects = None
                self.standby_backup_interface_xconnects = None
                self.standby_backup_xconnects = None
                self.standby_ready_backup_xconnects = None
                self.unresolved_backup_interface_xconnects = None
                self.unresolved_backup_xconnects = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.admin_down_backup_interface_xconnects is not None:
                    return True

                if self.admin_down_backup_xconnects is not None:
                    return True

                if self.down_backup_interface_xconnects is not None:
                    return True

                if self.down_backup_xconnects is not None:
                    return True

                if self.number_ce2_ceconnections is not None:
                    return True

                if self.number_ce2ce_advertized is not None:
                    return True

                if self.number_ce2ce_not_advertized is not None:
                    return True

                if self.number_groups is not None:
                    return True

                if self.number_mp2mp_xconnects is not None:
                    return True

                if self.number_mp2mp_xconnects_advertised is not None:
                    return True

                if self.number_mp2mp_xconnects_down is not None:
                    return True

                if self.number_mp2mp_xconnects_up is not None:
                    return True

                if self.number_mp2mp_xconnectss_not_advertised is not None:
                    return True

                if self.number_xconnects is not None:
                    return True

                if self.number_xconnects_administratively_down is not None:
                    return True

                if self.number_xconnects_currently_using_backup is not None:
                    return True

                if self.number_xconnects_currently_using_backup_interface is not None:
                    return True

                if self.number_xconnects_down is not None:
                    return True

                if self.number_xconnects_locally_switched is not None:
                    return True

                if self.number_xconnects_type_attachment_circuit_to_pseudo_wire is not None:
                    return True

                if self.number_xconnects_type_monitor_session_to_pseudo_wire is not None:
                    return True

                if self.number_xconnects_type_pseudo_wire_to_pseudo_wire is not None:
                    return True

                if self.number_xconnects_unresolved is not None:
                    return True

                if self.number_xconnects_up is not None:
                    return True

                if self.number_xconnects_with_backup_interface is not None:
                    return True

                if self.number_xconnects_with_backup_pw is not None:
                    return True

                if self.out_of_memory_state is not None:
                    return True

                if self.partially_programmed_xconnects is not None:
                    return True

                if self.standby_backup_interface_xconnects is not None:
                    return True

                if self.standby_backup_xconnects is not None:
                    return True

                if self.standby_ready_backup_xconnects is not None:
                    return True

                if self.unresolved_backup_interface_xconnects is not None:
                    return True

                if self.unresolved_backup_xconnects is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.XconnectSummary']['meta_info']


        class ProcFsm(object):
            """
            L2VPN Process FSM information
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.EventHistory>`
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.FailoverStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.IssuStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.NsrStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.ReportCard>`
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\:  bool
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.XidInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.event_history = YList()
                self.event_history.parent = self
                self.event_history.name = 'event_history'
                self.failover_status = L2Vpnv2.Active.ProcFsm.FailoverStatus()
                self.failover_status.parent = self
                self.issu_status = L2Vpnv2.Active.ProcFsm.IssuStatus()
                self.issu_status.parent = self
                self.nsr_status = L2Vpnv2.Active.ProcFsm.NsrStatus()
                self.nsr_status.parent = self
                self.process_role = None
                self.process_state = None
                self.report_card = YList()
                self.report_card.parent = self
                self.report_card.name = 'report_card'
                self.state_transition_time = YLeafList()
                self.state_transition_time.parent = self
                self.state_transition_time.name = 'state_transition_time'
                self.sw_install_in_progress = None
                self.sync_flags = None
                self.xid_info = YList()
                self.xid_info.parent = self
                self.xid_info.name = 'xid_info'


            class FailoverStatus(object):
                """
                L2VPN failover status
                
                .. attribute:: master_time
                
                	Master time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.master_time = None
                    self.start_time = None
                    self.triggered_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:failover-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.master_time is not None:
                        return True

                    if self.start_time is not None:
                        return True

                    if self.triggered_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.ProcFsm.FailoverStatus']['meta_info']


            class NsrStatus(object):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.ProcFsm.NsrStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.ProcFsm.NsrStatus']['meta_info']


            class IssuStatus(object):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.idt_status = L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self.previ_ous_idt_status = L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self.role = None


                class IdtStatus(object):
                    """
                    IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.ProcFsm.IssuStatus.IdtStatus']['meta_info']


                class PreviOusIdtStatus(object):
                    """
                    Previous IDT status
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.declare_time = None
                        self.idt_end_time = None
                        self.idt_start_time = None
                        self.not_ready_reason = None
                        self.sync_status = None
                        self.withdraw_time = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.declare_time is not None:
                            return True

                        if self.idt_end_time is not None:
                            return True

                        if self.idt_start_time is not None:
                            return True

                        if self.not_ready_reason is not None:
                            return True

                        if self.sync_status is not None:
                            return True

                        if self.withdraw_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.idt_status is not None and self.idt_status._has_data():
                        return True

                    if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                        return True

                    if self.role is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.ProcFsm.IssuStatus']['meta_info']


            class XidInfo(object):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.app_type = None
                    self.sent_ids = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:xid-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.app_type is not None:
                        return True

                    if self.sent_ids is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.ProcFsm.XidInfo']['meta_info']


            class ReportCard(object):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\:  bool
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\:  bool
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\:  bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.collaborator_idt_done = None
                    self.collaborator_is_connected = None
                    self.collaborator_skipped = None
                    self.connection_change_time = None
                    self.idt_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:report-card'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.collaborator_idt_done is not None:
                        return True

                    if self.collaborator_is_connected is not None:
                        return True

                    if self.collaborator_skipped is not None:
                        return True

                    if self.connection_change_time is not None:
                        return True

                    if self.idt_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.ProcFsm.ReportCard']['meta_info']


            class EventHistory(object):
                """
                L2VPN Process event history
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: new_state
                
                	New state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: process_event
                
                	Process event
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_timestamp = None
                    self.new_state = None
                    self.previous_state = None
                    self.process_collaborator = None
                    self.process_event = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:event-history'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_timestamp is not None:
                        return True

                    if self.new_state is not None:
                        return True

                    if self.previous_state is not None:
                        return True

                    if self.process_collaborator is not None:
                        return True

                    if self.process_event is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.ProcFsm.EventHistory']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:proc-fsm'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.event_history is not None:
                    for child_ref in self.event_history:
                        if child_ref._has_data():
                            return True

                if self.failover_status is not None and self.failover_status._has_data():
                    return True

                if self.issu_status is not None and self.issu_status._has_data():
                    return True

                if self.nsr_status is not None and self.nsr_status._has_data():
                    return True

                if self.process_role is not None:
                    return True

                if self.process_state is not None:
                    return True

                if self.report_card is not None:
                    for child_ref in self.report_card:
                        if child_ref._has_data():
                            return True

                if self.state_transition_time is not None:
                    for child in self.state_transition_time:
                        if child is not None:
                            return True

                if self.sw_install_in_progress is not None:
                    return True

                if self.sync_flags is not None:
                    return True

                if self.xid_info is not None:
                    for child_ref in self.xid_info:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.ProcFsm']['meta_info']


        class MstpPorts(object):
            """
            L2VPN MSTP Port Table
            
            .. attribute:: mstp_port
            
            	MSTP Port information
            	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts.MstpPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mstp_port = YList()
                self.mstp_port.parent = self
                self.mstp_port.name = 'mstp_port'


            class MstpPort(object):
                """
                MSTP Port information
                
                .. attribute:: interface  <key>
                
                	Interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: msti_entry
                
                	MSTI
                	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry>`
                
                .. attribute:: mstp_interface_handle
                
                	Interface handle
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protected
                
                	Protected
                	**type**\:  bool
                
                .. attribute:: reference_count
                
                	Reference Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = None
                    self.interface_name = None
                    self.msti_entry = YList()
                    self.msti_entry.parent = self
                    self.msti_entry.name = 'msti_entry'
                    self.mstp_interface_handle = None
                    self.protected = None
                    self.reference_count = None


                class MstiEntry(object):
                    """
                    MSTI
                    
                    .. attribute:: ack_count
                    
                    	Ack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_count
                    
                    	BD count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_entry
                    
                    	BD entries
                    	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                    
                    .. attribute:: cfg_ms_ti
                    
                    	 Configured MSTi
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flush_count
                    
                    	Flush count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_flags
                    
                    	Msti Flags
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_state
                    
                    	Msti State
                    	**type**\:   :py:class:`L2VpnMstiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiStateEnum>`
                    
                    .. attribute:: nack_count
                    
                    	Nack count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rcv_count
                    
                    	Receive count 
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ack_count = None
                        self.bd_count = None
                        self.bd_entry = YList()
                        self.bd_entry.parent = self
                        self.bd_entry.name = 'bd_entry'
                        self.cfg_ms_ti = None
                        self.flush_count = None
                        self.interface_count = None
                        self.msti_flags = None
                        self.msti_state = None
                        self.nack_count = None
                        self.rcv_count = None


                    class BdEntry(object):
                        """
                        BD entries
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bdif_count
                        
                        	BD Intf Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bdid = None
                            self.bdif_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bd-entry'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bdid is not None:
                                return True

                            if self.bdif_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:msti-entry'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ack_count is not None:
                            return True

                        if self.bd_count is not None:
                            return True

                        if self.bd_entry is not None:
                            for child_ref in self.bd_entry:
                                if child_ref._has_data():
                                    return True

                        if self.cfg_ms_ti is not None:
                            return True

                        if self.flush_count is not None:
                            return True

                        if self.interface_count is not None:
                            return True

                        if self.msti_flags is not None:
                            return True

                        if self.msti_state is not None:
                            return True

                        if self.nack_count is not None:
                            return True

                        if self.rcv_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.MstpPorts.MstpPort.MstiEntry']['meta_info']

                @property
                def _common_path(self):
                    if self.interface is None:
                        raise YPYModelError('Key property interface is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mstp-ports/Cisco-IOS-XR-l2vpn-oper:mstp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        return True

                    if self.interface_name is not None:
                        return True

                    if self.msti_entry is not None:
                        for child_ref in self.msti_entry:
                            if child_ref._has_data():
                                return True

                    if self.mstp_interface_handle is not None:
                        return True

                    if self.protected is not None:
                        return True

                    if self.reference_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.MstpPorts.MstpPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mstp-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mstp_port is not None:
                    for child_ref in self.mstp_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.MstpPorts']['meta_info']


        class GenericInterfaceListDetails(object):
            """
            L2VPN generic interface list Detail Table
            
            .. attribute:: generic_interface_list_detail
            
            	Generic Interface List detail information
            	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.generic_interface_list_detail = YList()
                self.generic_interface_list_detail.parent = self
                self.generic_interface_list_detail.name = 'generic_interface_list_detail'


            class GenericInterfaceListDetail(object):
                """
                Generic Interface List detail information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: psedowire_ether_items
                
                	Number PW Ether Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_ether_range
                
                	PW\-Ether ranges
                	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                
                .. attribute:: pseudowire_iw_items
                
                	Number PW IW Items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_iw_range
                
                	PW\-IW ranges
                	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                
                .. attribute:: summary
                
                	Summary information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_list_name = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.is_provisioned = None
                    self.items = None
                    self.psedowire_ether_items = None
                    self.pseudowire_ether_range = YList()
                    self.pseudowire_ether_range.parent = self
                    self.pseudowire_ether_range.name = 'pseudowire_ether_range'
                    self.pseudowire_iw_items = None
                    self.pseudowire_iw_range = YList()
                    self.pseudowire_iw_range.parent = self
                    self.pseudowire_iw_range.name = 'pseudowire_iw_range'
                    self.summary = L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                    self.summary.parent = self


                class Summary(object):
                    """
                    Summary information
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'
                        self.interface_list_id = None
                        self.interface_list_name_xr = None
                        self.items = None
                        self.number_of_interfaces = None


                    class Interface(object):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_fib_downloaded = None
                            self.not_supported_replications = None
                            self.pending_replications = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_fib_downloaded is not None:
                                return True

                            if self.not_supported_replications is not None:
                                return True

                            if self.pending_replications is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        if self.interface_list_id is not None:
                            return True

                        if self.interface_list_name_xr is not None:
                            return True

                        if self.items is not None:
                            return True

                        if self.number_of_interfaces is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary']['meta_info']


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface']['meta_info']


                class PseudowireEtherRange(object):
                    """
                    PW\-Ether ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lower = None
                        self.upper = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lower is not None:
                            return True

                        if self.upper is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange']['meta_info']


                class PseudowireIwRange(object):
                    """
                    PW\-IW ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.lower = None
                        self.upper = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw-range'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.lower is not None:
                            return True

                        if self.upper is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_list_name is None:
                        raise YPYModelError('Key property interface_list_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-detail[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_list_name is not None:
                        return True

                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.is_provisioned is not None:
                        return True

                    if self.items is not None:
                        return True

                    if self.psedowire_ether_items is not None:
                        return True

                    if self.pseudowire_ether_range is not None:
                        for child_ref in self.pseudowire_ether_range:
                            if child_ref._has_data():
                                return True

                    if self.pseudowire_iw_items is not None:
                        return True

                    if self.pseudowire_iw_range is not None:
                        for child_ref in self.pseudowire_iw_range:
                            if child_ref._has_data():
                                return True

                    if self.summary is not None and self.summary._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.generic_interface_list_detail is not None:
                    for child_ref in self.generic_interface_list_detail:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.GenericInterfaceListDetails']['meta_info']


        class L2VpnResourceState(object):
            """
            L2VPN resource state information
            
            .. attribute:: resource_out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.resource_out_of_memory_state = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:l2vpn-resource-state'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.resource_out_of_memory_state is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.L2VpnResourceState']['meta_info']


        class BridgeDomains(object):
            """
            VPLS Bridge Domain Information
            
            .. attribute:: bridge_domain
            
            	VPLS Bridge Domain Information
            	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bridge_domain = YList()
                self.bridge_domain.parent = self
                self.bridge_domain.name = 'bridge_domain'


            class BridgeDomain(object):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: bridge_access_pws
                
                	VPLS Bridge Domain Access Pseudowire Table
                	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                
                .. attribute:: bridge_access_vfi_table
                
                	Bridge Domain Access VFI Table
                	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                
                .. attribute:: bridge_acs
                
                	VPLS Bridge Domain Attachment Circuit Table
                	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs>`
                
                .. attribute:: bridge_core_vfi_table
                
                	Bridge Domain Core VFI Table
                	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                
                .. attribute:: bridge_domain_group_name
                
                	Bridge Domain Group Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: bridge_domain_info
                
                	VPLS Bridge Domain Information
                	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                
                .. attribute:: bridge_domain_name
                
                	Bridge Domain Name
                	**type**\:  str
                
                	**length:** 1..27
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_access_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws()
                    self.bridge_access_pws.parent = self
                    self.bridge_access_vfi_table = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                    self.bridge_access_vfi_table.parent = self
                    self.bridge_acs = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs()
                    self.bridge_acs.parent = self
                    self.bridge_core_vfi_table = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                    self.bridge_core_vfi_table.parent = self
                    self.bridge_domain_group_name = None
                    self.bridge_domain_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                    self.bridge_domain_info.parent = self
                    self.bridge_domain_name = None


                class BridgeAccessVfiTable(object):
                    """
                    Bridge Domain Access VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                        self.bridge_pws.parent = self


                    class BridgePws(object):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_pw = YList()
                            self.bridge_pw.parent = self
                            self.bridge_pw.name = 'bridge_pw'


                        class BridgePw(object):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_access = None
                                self.neighbor = None
                                self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self.pseudowire_id = None
                                self.pw_type = None
                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None


                            class Pseudowire(object):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_remote_down = None
                                    self.admited_bw = None
                                    self.auto_discovery = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.backup_pw = None
                                    self.bitrate_mismatched = None
                                    self.bridge_pw_type_mismatch = None
                                    self.cas_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.disable_delay = None
                                    self.disable_never = None
                                    self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self.evpn_src_acid = None
                                    self.fe_ctype = None
                                    self.forward_class = None
                                    self.freq_mismatched = None
                                    self.illegal_control_word = None
                                    self.imposed_vlan_id = None
                                    self.interworking = None
                                    self.ipv6_local_source_address = None
                                    self.is_evpnvpws_type = None
                                    self.is_flow_label_static = None
                                    self.is_multi_segment_pseudowire = None
                                    self.is_partially_programmed = None
                                    self.is_pwr_type = None
                                    self.is_vfi = None
                                    self.last_time_status_changed = None
                                    self.last_time_status_down = None
                                    self.ldp_label_advertise_failed = None
                                    self.load_balance = None
                                    self.local_control_word = None
                                    self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self.local_label_failed = None
                                    self.local_pseudo_wire_type = None
                                    self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self.local_source_address = None
                                    self.mac_limit_oper_down = None
                                    self.mtu_mismatched = None
                                    self.not_supported_qinq = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.out_of_memory_state = None
                                    self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self.payload_bytes_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self.preferred_path_disable_fallback = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.primary_pw = None
                                    self.protocol = None
                                    self.pseudo_wire_id = None
                                    self.pseudo_wire_state = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.pw_class_name = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_redundancy_initial_delay = None
                                    self.pw_redundancy_one_way = None
                                    self.pw_status_use = None
                                    self.pwlsd_rewrite_failed = None
                                    self.remote_control_word = None
                                    self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self.remote_label_failed = None
                                    self.remote_pseudo_wire_type = None
                                    self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self.required_bw = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.rtp_mismatched = None
                                    self.sequencing_type = None
                                    self.shutdown = None
                                    self.sig_pkts_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self.table_policy_name = None
                                    self.tag_rewrite = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.time_elapsed_status_changed = None
                                    self.time_elapsed_status_down = None
                                    self.transport_lsp_down = None
                                    self.xconnect_id = None


                                class PeerId(object):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.internal_label = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.type = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.internal_label is not None:
                                            return True

                                        if self.ipv4_peer_id is not None:
                                            return True

                                        if self.ipv6_peer_id is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                                class EncapsulationInfo(object):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self.encapsulation = None
                                        self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self


                                    class Atom(object):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_pseudowire_headend = None
                                            self.is_sai_itype2 = None
                                            self.is_tai_itype2 = None
                                            self.ldp_label_advertisment_failed = None
                                            self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self.local_c_ctype = None
                                            self.local_ceid = None
                                            self.local_cv_type = None
                                            self.local_group_id = None
                                            self.local_label = None
                                            self.local_ldp_id = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.local_veid = None
                                            self.lsd_rewrite_failed = None
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self.rem_saii = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self.remote_c_ctype = None
                                            self.remote_ceid = None
                                            self.remote_cv_type = None
                                            self.remote_group_id = None
                                            self.remote_label = None
                                            self.remote_ldp_id = None
                                            self.remote_source_address = None
                                            self.remote_veid = None
                                            self.saii = None
                                            self.source_address = None
                                            self.taii = None


                                        class LocalAgi(object):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                        class RemoteAgi(object):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                        class MultiSegmentPseudowireStats(object):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.received_bytes = None
                                                self.received_packets = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.received_bytes is not None:
                                                    return True

                                                if self.received_packets is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_pseudowire_headend is not None:
                                                return True

                                            if self.is_sai_itype2 is not None:
                                                return True

                                            if self.is_tai_itype2 is not None:
                                                return True

                                            if self.ldp_label_advertisment_failed is not None:
                                                return True

                                            if self.local_agi is not None and self.local_agi._has_data():
                                                return True

                                            if self.local_c_ctype is not None:
                                                return True

                                            if self.local_ceid is not None:
                                                return True

                                            if self.local_cv_type is not None:
                                                return True

                                            if self.local_group_id is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_ldp_id is not None:
                                                return True

                                            if self.local_saii_gbl_id is not None:
                                                return True

                                            if self.local_saiiac_id is not None:
                                                return True

                                            if self.local_taii_gbl_id is not None:
                                                return True

                                            if self.local_taiiac_id is not None:
                                                return True

                                            if self.local_veid is not None:
                                                return True

                                            if self.lsd_rewrite_failed is not None:
                                                return True

                                            if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                return True

                                            if self.rem_saii is not None:
                                                return True

                                            if self.rem_saii_gbl_id is not None:
                                                return True

                                            if self.rem_saiiac_id is not None:
                                                return True

                                            if self.rem_taii is not None:
                                                return True

                                            if self.rem_taii_gbl_id is not None:
                                                return True

                                            if self.rem_taiiac_id is not None:
                                                return True

                                            if self.remote_agi is not None and self.remote_agi._has_data():
                                                return True

                                            if self.remote_c_ctype is not None:
                                                return True

                                            if self.remote_ceid is not None:
                                                return True

                                            if self.remote_cv_type is not None:
                                                return True

                                            if self.remote_group_id is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_ldp_id is not None:
                                                return True

                                            if self.remote_source_address is not None:
                                                return True

                                            if self.remote_veid is not None:
                                                return True

                                            if self.saii is not None:
                                                return True

                                            if self.source_address is not None:
                                                return True

                                            if self.taii is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                    class L2Tpv3(object):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dont_fragment_bit = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.l2tp_class_name = None
                                            self.local_cookie_high_value = None
                                            self.local_cookie_low_value = None
                                            self.local_cookie_size = None
                                            self.local_secondary_cookie_high_value = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_size = None
                                            self.local_session_id = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.remote_circuit_status_up = None
                                            self.remote_cookie_high_value = None
                                            self.remote_cookie_low_value = None
                                            self.remote_cookie_size = None
                                            self.remote_session_id = None
                                            self.tos = None
                                            self.tos_mode = None
                                            self.ttl = None
                                            self.tunnel_state = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dont_fragment_bit is not None:
                                                return True

                                            if self.ipv4_source_address is not None:
                                                return True

                                            if self.ipv6_source_address is not None:
                                                return True

                                            if self.l2tp_class_name is not None:
                                                return True

                                            if self.local_cookie_high_value is not None:
                                                return True

                                            if self.local_cookie_low_value is not None:
                                                return True

                                            if self.local_cookie_size is not None:
                                                return True

                                            if self.local_secondary_cookie_high_value is not None:
                                                return True

                                            if self.local_secondary_cookie_low_value is not None:
                                                return True

                                            if self.local_secondary_cookie_size is not None:
                                                return True

                                            if self.local_session_id is not None:
                                                return True

                                            if self.path_mtu_enabled is not None:
                                                return True

                                            if self.path_mtu_max_value is not None:
                                                return True

                                            if self.remote_circuit_status_up is not None:
                                                return True

                                            if self.remote_cookie_high_value is not None:
                                                return True

                                            if self.remote_cookie_low_value is not None:
                                                return True

                                            if self.remote_cookie_size is not None:
                                                return True

                                            if self.remote_session_id is not None:
                                                return True

                                            if self.tos is not None:
                                                return True

                                            if self.tos_mode is not None:
                                                return True

                                            if self.ttl is not None:
                                                return True

                                            if self.tunnel_state is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atom is not None and self.atom._has_data():
                                            return True

                                        if self.encapsulation is not None:
                                            return True

                                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                                class LocalInterface(object):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                                class RemoteInterface(object):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                                class PreferredPath(object):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ip_tunnel_interface_number = None
                                        self.next_hop_ip = None
                                        self.option = None
                                        self.te_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ip_tunnel_interface_number is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        if self.option is not None:
                                            return True

                                        if self.te_tunnel_interface_number is not None:
                                            return True

                                        if self.tp_tunnel_interface_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                                class LocalSignalling(object):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                                class RemoteSignalling(object):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                                class P2MpPw(object):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local_available = None
                                        self.local_extended_tunnel_id = None
                                        self.local_flags = None
                                        self.local_label = None
                                        self.local_p2mp_id = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.remote_available = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_flags = None
                                        self.remote_label = None
                                        self.remote_p2mp_id = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local_available is not None:
                                            return True

                                        if self.local_extended_tunnel_id is not None:
                                            return True

                                        if self.local_flags is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_p2mp_id is not None:
                                            return True

                                        if self.local_ptree_type is not None:
                                            return True

                                        if self.local_tunnel_id is not None:
                                            return True

                                        if self.remote_available is not None:
                                            return True

                                        if self.remote_extended_tunnel_id is not None:
                                            return True

                                        if self.remote_flags is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_p2mp_id is not None:
                                            return True

                                        if self.remote_ptree_type is not None:
                                            return True

                                        if self.remote_tunnel_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_remote_down is not None:
                                        return True

                                    if self.admited_bw is not None:
                                        return True

                                    if self.auto_discovery is not None:
                                        return True

                                    if self.backup_active is not None:
                                        return True

                                    if self.backup_force_active is not None:
                                        return True

                                    if self.backup_pw is not None:
                                        return True

                                    if self.bitrate_mismatched is not None:
                                        return True

                                    if self.bridge_pw_type_mismatch is not None:
                                        return True

                                    if self.cas_mismatched is not None:
                                        return True

                                    if self.diff_ts_mismatched is not None:
                                        return True

                                    if self.disable_delay is not None:
                                        return True

                                    if self.disable_never is not None:
                                        return True

                                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                        return True

                                    if self.evpn_src_acid is not None:
                                        return True

                                    if self.fe_ctype is not None:
                                        return True

                                    if self.forward_class is not None:
                                        return True

                                    if self.freq_mismatched is not None:
                                        return True

                                    if self.illegal_control_word is not None:
                                        return True

                                    if self.imposed_vlan_id is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.ipv6_local_source_address is not None:
                                        return True

                                    if self.is_evpnvpws_type is not None:
                                        return True

                                    if self.is_flow_label_static is not None:
                                        return True

                                    if self.is_multi_segment_pseudowire is not None:
                                        return True

                                    if self.is_partially_programmed is not None:
                                        return True

                                    if self.is_pwr_type is not None:
                                        return True

                                    if self.is_vfi is not None:
                                        return True

                                    if self.last_time_status_changed is not None:
                                        return True

                                    if self.last_time_status_down is not None:
                                        return True

                                    if self.ldp_label_advertise_failed is not None:
                                        return True

                                    if self.load_balance is not None:
                                        return True

                                    if self.local_control_word is not None:
                                        return True

                                    if self.local_interface is not None and self.local_interface._has_data():
                                        return True

                                    if self.local_label_failed is not None:
                                        return True

                                    if self.local_pseudo_wire_type is not None:
                                        return True

                                    if self.local_signalling is not None and self.local_signalling._has_data():
                                        return True

                                    if self.local_source_address is not None:
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.not_supported_qinq is not None:
                                        return True

                                    if self.num_ma_cwithdraw_msg_received is not None:
                                        return True

                                    if self.number_ma_cwithdraw_message_sent is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                        return True

                                    if self.payload_bytes_mismatched is not None:
                                        return True

                                    if self.payload_type_mismatched is not None:
                                        return True

                                    if self.peer_id is not None and self.peer_id._has_data():
                                        return True

                                    if self.preferred_path is not None and self.preferred_path._has_data():
                                        return True

                                    if self.preferred_path_disable_fallback is not None:
                                        return True

                                    if self.primary_peer_id is not None:
                                        return True

                                    if self.primary_pseudo_wire_id is not None:
                                        return True

                                    if self.primary_pw is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    if self.pseudo_wire_id is not None:
                                        return True

                                    if self.pseudo_wire_state is not None:
                                        return True

                                    if self.pseudo_wire_type_mismatched is not None:
                                        return True

                                    if self.pw_class_name is not None:
                                        return True

                                    if self.pw_flow_label_code17_disabled is not None:
                                        return True

                                    if self.pw_flow_label_type is not None:
                                        return True

                                    if self.pw_flow_label_type_cfg is not None:
                                        return True

                                    if self.pw_redundancy_initial_delay is not None:
                                        return True

                                    if self.pw_redundancy_one_way is not None:
                                        return True

                                    if self.pw_status_use is not None:
                                        return True

                                    if self.pwlsd_rewrite_failed is not None:
                                        return True

                                    if self.remote_control_word is not None:
                                        return True

                                    if self.remote_interface is not None and self.remote_interface._has_data():
                                        return True

                                    if self.remote_label_failed is not None:
                                        return True

                                    if self.remote_pseudo_wire_type is not None:
                                        return True

                                    if self.remote_signalling is not None and self.remote_signalling._has_data():
                                        return True

                                    if self.required_bw is not None:
                                        return True

                                    if self.resync_enabled is not None:
                                        return True

                                    if self.resync_threshold is not None:
                                        return True

                                    if self.rtp_mismatched is not None:
                                        return True

                                    if self.sequencing_type is not None:
                                        return True

                                    if self.shutdown is not None:
                                        return True

                                    if self.sig_pkts_mismatched is not None:
                                        return True

                                    if self.ssrc_mismatched is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.table_policy_name is not None:
                                        return True

                                    if self.tag_rewrite is not None:
                                        return True

                                    if self.time_created is not None:
                                        return True

                                    if self.time_elapsed_creation is not None:
                                        return True

                                    if self.time_elapsed_status_changed is not None:
                                        return True

                                    if self.time_elapsed_status_down is not None:
                                        return True

                                    if self.transport_lsp_down is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_access is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.pseudowire is not None and self.pseudowire._has_data():
                                    return True

                                if self.pseudowire_id is not None:
                                    return True

                                if self.pw_type is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                if self.ve_id_vpls_id_0_3 is not None:
                                    return True

                                if self.vpls_id_4_7 is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_pw is not None:
                                for child_ref in self.bridge_pw:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_pws is not None and self.bridge_pws._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable']['meta_info']


                class BridgeCoreVfiTable(object):
                    """
                    Bridge Domain Core VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_pws = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                        self.bridge_pws.parent = self


                    class BridgePws(object):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	VPLS Bridge Domain Pseudowire
                        	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_pw = YList()
                            self.bridge_pw.parent = self
                            self.bridge_pw.name = 'bridge_pw'


                        class BridgePw(object):
                            """
                            VPLS Bridge Domain Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_access = None
                                self.neighbor = None
                                self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self.pseudowire_id = None
                                self.pw_type = None
                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None


                            class Pseudowire(object):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_remote_down = None
                                    self.admited_bw = None
                                    self.auto_discovery = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.backup_pw = None
                                    self.bitrate_mismatched = None
                                    self.bridge_pw_type_mismatch = None
                                    self.cas_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.disable_delay = None
                                    self.disable_never = None
                                    self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self.evpn_src_acid = None
                                    self.fe_ctype = None
                                    self.forward_class = None
                                    self.freq_mismatched = None
                                    self.illegal_control_word = None
                                    self.imposed_vlan_id = None
                                    self.interworking = None
                                    self.ipv6_local_source_address = None
                                    self.is_evpnvpws_type = None
                                    self.is_flow_label_static = None
                                    self.is_multi_segment_pseudowire = None
                                    self.is_partially_programmed = None
                                    self.is_pwr_type = None
                                    self.is_vfi = None
                                    self.last_time_status_changed = None
                                    self.last_time_status_down = None
                                    self.ldp_label_advertise_failed = None
                                    self.load_balance = None
                                    self.local_control_word = None
                                    self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self.local_label_failed = None
                                    self.local_pseudo_wire_type = None
                                    self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self.local_source_address = None
                                    self.mac_limit_oper_down = None
                                    self.mtu_mismatched = None
                                    self.not_supported_qinq = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.out_of_memory_state = None
                                    self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self.payload_bytes_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self.preferred_path_disable_fallback = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.primary_pw = None
                                    self.protocol = None
                                    self.pseudo_wire_id = None
                                    self.pseudo_wire_state = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.pw_class_name = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_redundancy_initial_delay = None
                                    self.pw_redundancy_one_way = None
                                    self.pw_status_use = None
                                    self.pwlsd_rewrite_failed = None
                                    self.remote_control_word = None
                                    self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self.remote_label_failed = None
                                    self.remote_pseudo_wire_type = None
                                    self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self.required_bw = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.rtp_mismatched = None
                                    self.sequencing_type = None
                                    self.shutdown = None
                                    self.sig_pkts_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self.table_policy_name = None
                                    self.tag_rewrite = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.time_elapsed_status_changed = None
                                    self.time_elapsed_status_down = None
                                    self.transport_lsp_down = None
                                    self.xconnect_id = None


                                class PeerId(object):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.internal_label = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.type = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.internal_label is not None:
                                            return True

                                        if self.ipv4_peer_id is not None:
                                            return True

                                        if self.ipv6_peer_id is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                                class EncapsulationInfo(object):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self.encapsulation = None
                                        self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self


                                    class Atom(object):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_pseudowire_headend = None
                                            self.is_sai_itype2 = None
                                            self.is_tai_itype2 = None
                                            self.ldp_label_advertisment_failed = None
                                            self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self.local_c_ctype = None
                                            self.local_ceid = None
                                            self.local_cv_type = None
                                            self.local_group_id = None
                                            self.local_label = None
                                            self.local_ldp_id = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.local_veid = None
                                            self.lsd_rewrite_failed = None
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self.rem_saii = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self.remote_c_ctype = None
                                            self.remote_ceid = None
                                            self.remote_cv_type = None
                                            self.remote_group_id = None
                                            self.remote_label = None
                                            self.remote_ldp_id = None
                                            self.remote_source_address = None
                                            self.remote_veid = None
                                            self.saii = None
                                            self.source_address = None
                                            self.taii = None


                                        class LocalAgi(object):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                        class RemoteAgi(object):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                        class MultiSegmentPseudowireStats(object):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.received_bytes = None
                                                self.received_packets = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.received_bytes is not None:
                                                    return True

                                                if self.received_packets is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_pseudowire_headend is not None:
                                                return True

                                            if self.is_sai_itype2 is not None:
                                                return True

                                            if self.is_tai_itype2 is not None:
                                                return True

                                            if self.ldp_label_advertisment_failed is not None:
                                                return True

                                            if self.local_agi is not None and self.local_agi._has_data():
                                                return True

                                            if self.local_c_ctype is not None:
                                                return True

                                            if self.local_ceid is not None:
                                                return True

                                            if self.local_cv_type is not None:
                                                return True

                                            if self.local_group_id is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_ldp_id is not None:
                                                return True

                                            if self.local_saii_gbl_id is not None:
                                                return True

                                            if self.local_saiiac_id is not None:
                                                return True

                                            if self.local_taii_gbl_id is not None:
                                                return True

                                            if self.local_taiiac_id is not None:
                                                return True

                                            if self.local_veid is not None:
                                                return True

                                            if self.lsd_rewrite_failed is not None:
                                                return True

                                            if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                return True

                                            if self.rem_saii is not None:
                                                return True

                                            if self.rem_saii_gbl_id is not None:
                                                return True

                                            if self.rem_saiiac_id is not None:
                                                return True

                                            if self.rem_taii is not None:
                                                return True

                                            if self.rem_taii_gbl_id is not None:
                                                return True

                                            if self.rem_taiiac_id is not None:
                                                return True

                                            if self.remote_agi is not None and self.remote_agi._has_data():
                                                return True

                                            if self.remote_c_ctype is not None:
                                                return True

                                            if self.remote_ceid is not None:
                                                return True

                                            if self.remote_cv_type is not None:
                                                return True

                                            if self.remote_group_id is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_ldp_id is not None:
                                                return True

                                            if self.remote_source_address is not None:
                                                return True

                                            if self.remote_veid is not None:
                                                return True

                                            if self.saii is not None:
                                                return True

                                            if self.source_address is not None:
                                                return True

                                            if self.taii is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                    class L2Tpv3(object):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dont_fragment_bit = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.l2tp_class_name = None
                                            self.local_cookie_high_value = None
                                            self.local_cookie_low_value = None
                                            self.local_cookie_size = None
                                            self.local_secondary_cookie_high_value = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_size = None
                                            self.local_session_id = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.remote_circuit_status_up = None
                                            self.remote_cookie_high_value = None
                                            self.remote_cookie_low_value = None
                                            self.remote_cookie_size = None
                                            self.remote_session_id = None
                                            self.tos = None
                                            self.tos_mode = None
                                            self.ttl = None
                                            self.tunnel_state = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dont_fragment_bit is not None:
                                                return True

                                            if self.ipv4_source_address is not None:
                                                return True

                                            if self.ipv6_source_address is not None:
                                                return True

                                            if self.l2tp_class_name is not None:
                                                return True

                                            if self.local_cookie_high_value is not None:
                                                return True

                                            if self.local_cookie_low_value is not None:
                                                return True

                                            if self.local_cookie_size is not None:
                                                return True

                                            if self.local_secondary_cookie_high_value is not None:
                                                return True

                                            if self.local_secondary_cookie_low_value is not None:
                                                return True

                                            if self.local_secondary_cookie_size is not None:
                                                return True

                                            if self.local_session_id is not None:
                                                return True

                                            if self.path_mtu_enabled is not None:
                                                return True

                                            if self.path_mtu_max_value is not None:
                                                return True

                                            if self.remote_circuit_status_up is not None:
                                                return True

                                            if self.remote_cookie_high_value is not None:
                                                return True

                                            if self.remote_cookie_low_value is not None:
                                                return True

                                            if self.remote_cookie_size is not None:
                                                return True

                                            if self.remote_session_id is not None:
                                                return True

                                            if self.tos is not None:
                                                return True

                                            if self.tos_mode is not None:
                                                return True

                                            if self.ttl is not None:
                                                return True

                                            if self.tunnel_state is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atom is not None and self.atom._has_data():
                                            return True

                                        if self.encapsulation is not None:
                                            return True

                                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                                class LocalInterface(object):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                                class RemoteInterface(object):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):

                                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                                class PreferredPath(object):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ip_tunnel_interface_number = None
                                        self.next_hop_ip = None
                                        self.option = None
                                        self.te_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ip_tunnel_interface_number is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        if self.option is not None:
                                            return True

                                        if self.te_tunnel_interface_number is not None:
                                            return True

                                        if self.tp_tunnel_interface_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                                class LocalSignalling(object):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                                class RemoteSignalling(object):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                                class P2MpPw(object):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local_available = None
                                        self.local_extended_tunnel_id = None
                                        self.local_flags = None
                                        self.local_label = None
                                        self.local_p2mp_id = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.remote_available = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_flags = None
                                        self.remote_label = None
                                        self.remote_p2mp_id = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local_available is not None:
                                            return True

                                        if self.local_extended_tunnel_id is not None:
                                            return True

                                        if self.local_flags is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_p2mp_id is not None:
                                            return True

                                        if self.local_ptree_type is not None:
                                            return True

                                        if self.local_tunnel_id is not None:
                                            return True

                                        if self.remote_available is not None:
                                            return True

                                        if self.remote_extended_tunnel_id is not None:
                                            return True

                                        if self.remote_flags is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_p2mp_id is not None:
                                            return True

                                        if self.remote_ptree_type is not None:
                                            return True

                                        if self.remote_tunnel_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_remote_down is not None:
                                        return True

                                    if self.admited_bw is not None:
                                        return True

                                    if self.auto_discovery is not None:
                                        return True

                                    if self.backup_active is not None:
                                        return True

                                    if self.backup_force_active is not None:
                                        return True

                                    if self.backup_pw is not None:
                                        return True

                                    if self.bitrate_mismatched is not None:
                                        return True

                                    if self.bridge_pw_type_mismatch is not None:
                                        return True

                                    if self.cas_mismatched is not None:
                                        return True

                                    if self.diff_ts_mismatched is not None:
                                        return True

                                    if self.disable_delay is not None:
                                        return True

                                    if self.disable_never is not None:
                                        return True

                                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                        return True

                                    if self.evpn_src_acid is not None:
                                        return True

                                    if self.fe_ctype is not None:
                                        return True

                                    if self.forward_class is not None:
                                        return True

                                    if self.freq_mismatched is not None:
                                        return True

                                    if self.illegal_control_word is not None:
                                        return True

                                    if self.imposed_vlan_id is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.ipv6_local_source_address is not None:
                                        return True

                                    if self.is_evpnvpws_type is not None:
                                        return True

                                    if self.is_flow_label_static is not None:
                                        return True

                                    if self.is_multi_segment_pseudowire is not None:
                                        return True

                                    if self.is_partially_programmed is not None:
                                        return True

                                    if self.is_pwr_type is not None:
                                        return True

                                    if self.is_vfi is not None:
                                        return True

                                    if self.last_time_status_changed is not None:
                                        return True

                                    if self.last_time_status_down is not None:
                                        return True

                                    if self.ldp_label_advertise_failed is not None:
                                        return True

                                    if self.load_balance is not None:
                                        return True

                                    if self.local_control_word is not None:
                                        return True

                                    if self.local_interface is not None and self.local_interface._has_data():
                                        return True

                                    if self.local_label_failed is not None:
                                        return True

                                    if self.local_pseudo_wire_type is not None:
                                        return True

                                    if self.local_signalling is not None and self.local_signalling._has_data():
                                        return True

                                    if self.local_source_address is not None:
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.not_supported_qinq is not None:
                                        return True

                                    if self.num_ma_cwithdraw_msg_received is not None:
                                        return True

                                    if self.number_ma_cwithdraw_message_sent is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                        return True

                                    if self.payload_bytes_mismatched is not None:
                                        return True

                                    if self.payload_type_mismatched is not None:
                                        return True

                                    if self.peer_id is not None and self.peer_id._has_data():
                                        return True

                                    if self.preferred_path is not None and self.preferred_path._has_data():
                                        return True

                                    if self.preferred_path_disable_fallback is not None:
                                        return True

                                    if self.primary_peer_id is not None:
                                        return True

                                    if self.primary_pseudo_wire_id is not None:
                                        return True

                                    if self.primary_pw is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    if self.pseudo_wire_id is not None:
                                        return True

                                    if self.pseudo_wire_state is not None:
                                        return True

                                    if self.pseudo_wire_type_mismatched is not None:
                                        return True

                                    if self.pw_class_name is not None:
                                        return True

                                    if self.pw_flow_label_code17_disabled is not None:
                                        return True

                                    if self.pw_flow_label_type is not None:
                                        return True

                                    if self.pw_flow_label_type_cfg is not None:
                                        return True

                                    if self.pw_redundancy_initial_delay is not None:
                                        return True

                                    if self.pw_redundancy_one_way is not None:
                                        return True

                                    if self.pw_status_use is not None:
                                        return True

                                    if self.pwlsd_rewrite_failed is not None:
                                        return True

                                    if self.remote_control_word is not None:
                                        return True

                                    if self.remote_interface is not None and self.remote_interface._has_data():
                                        return True

                                    if self.remote_label_failed is not None:
                                        return True

                                    if self.remote_pseudo_wire_type is not None:
                                        return True

                                    if self.remote_signalling is not None and self.remote_signalling._has_data():
                                        return True

                                    if self.required_bw is not None:
                                        return True

                                    if self.resync_enabled is not None:
                                        return True

                                    if self.resync_threshold is not None:
                                        return True

                                    if self.rtp_mismatched is not None:
                                        return True

                                    if self.sequencing_type is not None:
                                        return True

                                    if self.shutdown is not None:
                                        return True

                                    if self.sig_pkts_mismatched is not None:
                                        return True

                                    if self.ssrc_mismatched is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.table_policy_name is not None:
                                        return True

                                    if self.tag_rewrite is not None:
                                        return True

                                    if self.time_created is not None:
                                        return True

                                    if self.time_elapsed_creation is not None:
                                        return True

                                    if self.time_elapsed_status_changed is not None:
                                        return True

                                    if self.time_elapsed_status_down is not None:
                                        return True

                                    if self.transport_lsp_down is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_access is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.pseudowire is not None and self.pseudowire._has_data():
                                    return True

                                if self.pseudowire_id is not None:
                                    return True

                                if self.pw_type is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                if self.ve_id_vpls_id_0_3 is not None:
                                    return True

                                if self.vpls_id_4_7 is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_pw is not None:
                                for child_ref in self.bridge_pw:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_pws is not None and self.bridge_pws._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable']['meta_info']


                class BridgeAcs(object):
                    """
                    VPLS Bridge Domain Attachment Circuit Table
                    
                    .. attribute:: bridge_ac
                    
                    	VPLS Bridge Domain Attachment Circuit
                    	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_ac = YList()
                        self.bridge_ac.parent = self
                        self.bridge_ac.name = 'bridge_ac'


                    class BridgeAc(object):
                        """
                        VPLS Bridge Domain Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                        
                        .. attribute:: bvi_mac_index
                        
                        	MyMac Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: bvimac
                        
                        	BVI MAC addresses
                        	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.attachment_circuit = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self.bvi_mac_index = None
                            self.bvimac = YList()
                            self.bvimac.parent = self
                            self.bvimac.name = 'bvimac'
                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                            self.security_parameters.parent = self
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'


                        class AttachmentCircuit(object):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit']['meta_info']


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac']['meta_info']


                        class Bvimac(object):
                            """
                            BVI MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bvimac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac']['meta_info']

                        @property
                        def _common_path(self):
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-acs/Cisco-IOS-XR-l2vpn-oper:bridge-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            if self.bvi_mac_index is not None:
                                return True

                            if self.bvimac is not None:
                                for child_ref in self.bvimac:
                                    if child_ref._has_data():
                                        return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-acs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_ac is not None:
                            for child_ref in self.bridge_ac:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs']['meta_info']


                class BridgeAccessPws(object):
                    """
                    VPLS Bridge Domain Access Pseudowire Table
                    
                    .. attribute:: bridge_access_pw
                    
                    	VPLS Bridge Domain Access Pseudowire
                    	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_access_pw = YList()
                        self.bridge_access_pw.parent = self
                        self.bridge_access_pw.name = 'bridge_access_pw'


                    class BridgeAccessPw(object):
                        """
                        VPLS Bridge Domain Access Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.is_access = None
                            self.neighbor = None
                            self.pseudowire = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                            self.pseudowire.parent = self
                            self.pseudowire_id = None
                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                            self.security_parameters.parent = self
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'


                        class Pseudowire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire']['meta_info']


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.is_access is not None:
                                return True

                            if self.neighbor is not None:
                                return True

                            if self.pseudowire is not None and self.pseudowire._has_data():
                                return True

                            if self.pseudowire_id is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_access_pw is not None:
                            for child_ref in self.bridge_access_pw:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws']['meta_info']


                class BridgeDomainInfo(object):
                    """
                    VPLS Bridge Domain Information
                    
                    .. attribute:: acpwup
                    
                    	Number of bridge ports (AC,PW) which are up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: as_
                    
                    	BGP AS number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_access_vfi
                    
                    	Access Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                    
                    .. attribute:: bridge_coupled_state
                    
                    	Bridge\-domain coupled state
                    	**type**\:   :py:class:`L2VpnBridgeCoupledStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledStateEnum>`
                    
                    .. attribute:: bridge_description
                    
                    	Human\-readable bridge\-domain description
                    	**type**\:  str
                    
                    .. attribute:: bridge_domain_id
                    
                    	Identification number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_internal_msti
                    
                    	Bridge\-domain internal msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_msti
                    
                    	Bridge\-domain msti
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_mtu
                    
                    	Maximum transmission unit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge\-domain name
                    	**type**\:  str
                    
                    .. attribute:: bridge_shg_id
                    
                    	Bridge\-domain shgid
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_state
                    
                    	Bridge\-domain state
                    	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                    
                    .. attribute:: bridge_type
                    
                    	Bridge\-domain type
                    	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                    
                    .. attribute:: bridge_vfi
                    
                    	Virtual Forwarding Interfaces
                    	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                    
                    .. attribute:: configured
                    
                    	Bridge\-domain is configured
                    	**type**\:  bool
                    
                    .. attribute:: disposition_bytecount
                    
                    	EVPN Disposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_pkt_count
                    
                    	EVPN Disposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_parameters
                    
                    	EVPN parameters
                    	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                    
                    .. attribute:: flodd_group_id_down
                    
                    	Oper down because no FGID
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: imposition_byte_count
                    
                    	EVPN Imposition Byte Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: imposition_pkt_count
                    
                    	EVPN Imposition Packet Count
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: is_bridge_partially_programmed
                    
                    	Bridge is partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_rd_configured
                    
                    	Config or Auto
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the bridge domain status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: mac_filter
                    
                    	MAC addresses for filtering
                    	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                    
                    .. attribute:: mac_limit_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw
                    
                    	MAC withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_access
                    
                    	MAC Access PW withdraw enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_withdraw_option
                    
                    	Event on which MAC withdraw is sent
                    	**type**\:   :py:class:`L2VpnBagMacWithdrawOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOptionEnum>`
                    
                    .. attribute:: mac_withdraw_relay
                    
                    	MAC Access PW withdraw relaying from access to access enabled
                    	**type**\:  bool
                    
                    .. attribute:: num_vn_is
                    
                    	Number of VNIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_vn_is_up
                    
                    	Number of VNIs up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_access_vf_is
                    
                    	Number of Access VFIs
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pb_bs
                    
                    	Number of pbbs
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pb_bs_up
                    
                    	Number of pbbs up
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_vf_is
                    
                    	Number of virtual forwarding interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                    
                    	nV Satellite Offload IPv4 Multicast Disabled
                    	**type**\:  bool
                    
                    .. attribute:: p2mp_enabled
                    
                    	P2MP Enabled on this Bridge Domain
                    	**type**\:  bool
                    
                    .. attribute:: partially_programmed_a_cs
                    
                    	Number of attachment circuits partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_pseudowires
                    
                    	Number of pseudowires partially programmed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_parameters
                    
                    	PBB parameters
                    	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                    
                    .. attribute:: rd
                    
                    	Route Distinguisher
                    	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                    
                    .. attribute:: security_parameters
                    
                    	Security parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                    
                    .. attribute:: shutdown
                    
                    	Administratively disabled
                    	**type**\:  bool
                    
                    .. attribute:: standby_pseudowires
                    
                    	Number of pseudowires standby
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_created
                    
                    	Time when the bridge domain was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: vine_fsm_state
                    
                    	VNI, IRB, Native\-Evpn state
                    	**type**\:  str
                    
                    .. attribute:: vni_parameters
                    
                    	VNI parameters
                    	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.acpwup = None
                        self.as_ = None
                        self.bridge_access_vfi = YList()
                        self.bridge_access_vfi.parent = self
                        self.bridge_access_vfi.name = 'bridge_access_vfi'
                        self.bridge_coupled_state = None
                        self.bridge_description = None
                        self.bridge_domain_id = None
                        self.bridge_internal_msti = None
                        self.bridge_msti = None
                        self.bridge_mtu = None
                        self.bridge_name = None
                        self.bridge_shg_id = None
                        self.bridge_state = None
                        self.bridge_type = None
                        self.bridge_vfi = YList()
                        self.bridge_vfi.parent = self
                        self.bridge_vfi.name = 'bridge_vfi'
                        self.configured = None
                        self.disposition_bytecount = None
                        self.disposition_pkt_count = None
                        self.evi = None
                        self.evpn_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                        self.evpn_parameters.parent = self
                        self.flodd_group_id_down = None
                        self.group_name = None
                        self.imposition_byte_count = None
                        self.imposition_pkt_count = None
                        self.is_bridge_partially_programmed = None
                        self.is_rd_configured = None
                        self.last_time_status_changed = None
                        self.load_balance = None
                        self.mac_filter = YList()
                        self.mac_filter.parent = self
                        self.mac_filter.name = 'mac_filter'
                        self.mac_limit_down = None
                        self.mac_withdraw = None
                        self.mac_withdraw_access = None
                        self.mac_withdraw_option = None
                        self.mac_withdraw_relay = None
                        self.num_vn_is = None
                        self.num_vn_is_up = None
                        self.number_a_cs = None
                        self.number_a_cs_up = None
                        self.number_access_vf_is = None
                        self.number_p_ws_up = None
                        self.number_pb_bs = None
                        self.number_pb_bs_up = None
                        self.number_pseudowires = None
                        self.number_vf_is = None
                        self.nv_satellite_offload_ipv4_multicast_disabled = None
                        self.p2mp_enabled = None
                        self.partially_programmed_a_cs = None
                        self.partially_programmed_pseudowires = None
                        self.pbb_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                        self.pbb_parameters.parent = self
                        self.rd = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                        self.rd.parent = self
                        self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                        self.security_parameters.parent = self
                        self.shutdown = None
                        self.standby_pseudowires = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.vine_fsm_state = None
                        self.vni_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                        self.vni_parameters.parent = self


                    class SecurityParameters(object):
                        """
                        Security parameters
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: dai_address_validation_mask
                        
                        	DAI Address Validation mask
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dhcpv4_profile_name
                        
                        	DHCPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: dhcpv4_snoop
                        
                        	DHCPv4 Snoop Status
                        	**type**\:  bool
                        
                        .. attribute:: flood_unknown_unicast_enabled
                        
                        	Flooding unknown unicast enabled
                        	**type**\:  bool
                        
                        .. attribute:: flood_uu_disabled_mac_limit_action
                        
                        	Flooding of unknown\-unicast disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_disabled
                        
                        	IGMPv4 Disabled
                        	**type**\:  bool
                        
                        .. attribute:: igm_pv4_profile_name
                        
                        	IGMPv4 Profile Name
                        	**type**\:  str
                        
                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                        
                        	Is DAI Dstination MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                        
                        	Is DAI IPv4 Addr Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                        
                        	Is DAI Source MAC Address Validation Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_enabled
                        
                        	Is Dynamic ARP Inspection Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_dai_logging_enabled
                        
                        	Is DAI Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_source_guard_enabled
                        
                        	Is IP Source Guard Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_ipsg_logging_enabled
                        
                        	Is IP Source Guard Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                        
                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_enabled
                        
                        	Is MAC Secure Enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_mac_secure_logging_enabled
                        
                        	Is MAC Secure Logging Enabled
                        	**type**\:  bool
                        
                        .. attribute:: learn_disabled_mac_limit_action
                        
                        	Learning disabled due to MAC limit action
                        	**type**\:  bool
                        
                        .. attribute:: mac_aging_mode
                        
                        	MAC Aging Mode
                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                        
                        .. attribute:: mac_aging_time
                        
                        	MAC aging time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: mac_flooding
                        
                        	MAC flooding enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_learning
                        
                        	MAC learning enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_limit
                        
                        	MAC address limit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_limit_action
                        
                        	MAC limit action
                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                        
                        .. attribute:: mac_limit_notification
                        
                        	MAC limit notification
                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                        
                        .. attribute:: mac_limit_reached
                        
                        	MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mac_port_down_flush_enabled
                        
                        	MAC Flush when port goes down
                        	**type**\:  bool
                        
                        .. attribute:: mac_secure_action
                        
                        	MAC Secure Action
                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                        
                        .. attribute:: mld_profile_name
                        
                        	MLD Profile Name
                        	**type**\:  str
                        
                        .. attribute:: mmrp_flood_optimization
                        
                        	MMRP Flood Optimization Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: split_horizon_group_id
                        
                        	Split Horizon Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.dai_address_validation_mask = None
                            self.dhcpv4_profile_name = None
                            self.dhcpv4_snoop = None
                            self.flood_unknown_unicast_enabled = None
                            self.flood_uu_disabled_mac_limit_action = None
                            self.igm_pv4_disabled = None
                            self.igm_pv4_profile_name = None
                            self.is_dai_addr_validate_destination_mac_enabled = None
                            self.is_dai_addr_validate_ipv4_enabled = None
                            self.is_dai_addr_validate_source_mac_enabled = None
                            self.is_dai_enabled = None
                            self.is_dai_logging_enabled = None
                            self.is_ip_source_guard_enabled = None
                            self.is_ipsg_logging_enabled = None
                            self.is_mac_secure_accept_shutdown_enabled = None
                            self.is_mac_secure_enabled = None
                            self.is_mac_secure_logging_enabled = None
                            self.learn_disabled_mac_limit_action = None
                            self.mac_aging_mode = None
                            self.mac_aging_time = None
                            self.mac_flooding = None
                            self.mac_learning = None
                            self.mac_limit = None
                            self.mac_limit_action = None
                            self.mac_limit_notification = None
                            self.mac_limit_reached = None
                            self.mac_port_down_flush_enabled = None
                            self.mac_secure_action = None
                            self.mld_profile_name = None
                            self.mmrp_flood_optimization = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_rate_unit = None
                            self.split_horizon_group_id = None
                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_rate_unit = None


                        class StormControl(object):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bd_policer = None
                                self.broadcast = None
                                self.multicast = None
                                self.unicast = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bd_policer is not None:
                                    return True

                                if self.broadcast is not None:
                                    return True

                                if self.multicast is not None:
                                    return True

                                if self.unicast is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.broadcast_storm_control_rate_unit is not None:
                                return True

                            if self.dai_address_validation_mask is not None:
                                return True

                            if self.dhcpv4_profile_name is not None:
                                return True

                            if self.dhcpv4_snoop is not None:
                                return True

                            if self.flood_unknown_unicast_enabled is not None:
                                return True

                            if self.flood_uu_disabled_mac_limit_action is not None:
                                return True

                            if self.igm_pv4_disabled is not None:
                                return True

                            if self.igm_pv4_profile_name is not None:
                                return True

                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                return True

                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                return True

                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                return True

                            if self.is_dai_enabled is not None:
                                return True

                            if self.is_dai_logging_enabled is not None:
                                return True

                            if self.is_ip_source_guard_enabled is not None:
                                return True

                            if self.is_ipsg_logging_enabled is not None:
                                return True

                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                return True

                            if self.is_mac_secure_enabled is not None:
                                return True

                            if self.is_mac_secure_logging_enabled is not None:
                                return True

                            if self.learn_disabled_mac_limit_action is not None:
                                return True

                            if self.mac_aging_mode is not None:
                                return True

                            if self.mac_aging_time is not None:
                                return True

                            if self.mac_flooding is not None:
                                return True

                            if self.mac_learning is not None:
                                return True

                            if self.mac_limit is not None:
                                return True

                            if self.mac_limit_action is not None:
                                return True

                            if self.mac_limit_notification is not None:
                                return True

                            if self.mac_limit_reached is not None:
                                return True

                            if self.mac_port_down_flush_enabled is not None:
                                return True

                            if self.mac_secure_action is not None:
                                return True

                            if self.mld_profile_name is not None:
                                return True

                            if self.mmrp_flood_optimization is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_rate_unit is not None:
                                return True

                            if self.split_horizon_group_id is not None:
                                return True

                            if self.storm_control is not None and self.storm_control._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            if self.unicast_storm_control_rate_unit is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters']['meta_info']


                    class PbbParameters(object):
                        """
                        PBB parameters
                        
                        .. attribute:: pbb_core
                        
                        	PBB Core
                        	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                        
                        .. attribute:: pbb_edge
                        
                        	PBB Edge
                        	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                        
                        .. attribute:: type
                        
                        	Type
                        	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pbb_core = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                            self.pbb_core.parent = self
                            self.pbb_edge = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                            self.pbb_edge.parent = self
                            self.type = None


                        class PbbEdge(object):
                            """
                            PBB Edge
                            
                            .. attribute:: core_bridge_name
                            
                            	Core Bridge Domain Name
                            	**type**\:  str
                            
                            .. attribute:: core_bridge_state
                            
                            	Core Bridge State
                            	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                            
                            .. attribute:: edge_port
                            
                            	PBB Edge Port
                            	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                            
                            .. attribute:: i_sid
                            
                            	SID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mirp_lite_protocol
                            
                            	MIRP\-lite protocol info
                            	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfoEnum>`
                            
                            .. attribute:: mirp_lite_status
                            
                            	MIRP\-lite Status
                            	**type**\:   :py:class:`L2VpnMirpLiteStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatusEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.core_bridge_name = None
                                self.core_bridge_state = None
                                self.edge_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                self.edge_port.parent = self
                                self.i_sid = None
                                self.mirp_lite_protocol = None
                                self.mirp_lite_status = None


                            class EdgePort(object):
                                """
                                PBB Edge Port
                                
                                .. attribute:: bmac_mapping
                                
                                	CMAC to BMAC Mapping
                                	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                
                                .. attribute:: edge_port_state
                                
                                	PBB Edge Port State
                                	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                
                                .. attribute:: unknown_unicast_mac
                                
                                	Unknown Unicast MAC
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: unknown_unicast_mac_set
                                
                                	Unknown Unicast MAC Configured
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bmac_mapping = YList()
                                    self.bmac_mapping.parent = self
                                    self.bmac_mapping.name = 'bmac_mapping'
                                    self.edge_port_state = None
                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                    self.statistics.parent = self
                                    self.unknown_unicast_mac = None
                                    self.unknown_unicast_mac_set = None
                                    self.xconnect_id = None


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics']['meta_info']


                                class BmacMapping(object):
                                    """
                                    CMAC to BMAC Mapping
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:bmac-mapping'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address is not None:
                                            return True

                                        if self.bmac is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bmac_mapping is not None:
                                        for child_ref in self.bmac_mapping:
                                            if child_ref._has_data():
                                                return True

                                    if self.edge_port_state is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.unknown_unicast_mac is not None:
                                        return True

                                    if self.unknown_unicast_mac_set is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.core_bridge_name is not None:
                                    return True

                                if self.core_bridge_state is not None:
                                    return True

                                if self.edge_port is not None and self.edge_port._has_data():
                                    return True

                                if self.i_sid is not None:
                                    return True

                                if self.mirp_lite_protocol is not None:
                                    return True

                                if self.mirp_lite_status is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge']['meta_info']


                        class PbbCore(object):
                            """
                            PBB Core
                            
                            .. attribute:: core_port
                            
                            	PBB Core Port
                            	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                            
                            .. attribute:: num_ass_edge
                            
                            	Number of Associated PBB Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.core_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                self.core_port.parent = self
                                self.num_ass_edge = None


                            class CorePort(object):
                                """
                                PBB Core Port
                                
                                .. attribute:: core_port_state
                                
                                	PBB Core Port State
                                	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                
                                .. attribute:: vlan_id
                                
                                	Vlan ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_port_state = None
                                    self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.vlan_id = None
                                    self.xconnect_id = None


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_port_state is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.vlan_id is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.core_port is not None and self.core_port._has_data():
                                    return True

                                if self.num_ass_edge is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pbb_core is not None and self.pbb_core._has_data():
                                return True

                            if self.pbb_edge is not None and self.pbb_edge._has_data():
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters']['meta_info']


                    class EvpnParameters(object):
                        """
                        EVPN parameters
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_port
                        
                        	EVPN Port
                        	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.evi = None
                            self.evpn_port = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                            self.evpn_port.parent = self


                        class EvpnPort(object):
                            """
                            EVPN Port
                            
                            .. attribute:: evpn_port_state
                            
                            	EVPN Port State
                            	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.evpn_port_state = None
                                self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                self.security_parameters.parent = self
                                self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                self.statistics.parent = self
                                self.xconnect_id = None


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.evpn_port_state is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.evi is not None:
                                return True

                            if self.evpn_port is not None and self.evpn_port._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters']['meta_info']


                    class VniParameters(object):
                        """
                        VNI parameters
                        
                        .. attribute:: anycast_mcast_group_addr
                        
                        	Anycast Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_vtep_ip_addr
                        
                        	Anycast VTEP IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_addr
                        
                        	Multicast Group Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: overlay
                        
                        	NVE Overlay
                        	**type**\:  str
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                        
                        .. attribute:: source_ip_addr
                        
                        	Source IP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                        
                        .. attribute:: udp_port
                        
                        	UDP Port
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni
                        
                        	VNI
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni_encap_type
                        
                        	VNI Encapsulation Type
                        	**type**\:   :py:class:`L2VpnVniEncapsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncapsEnum>`
                        
                        .. attribute:: vni_mode
                        
                        	VNI Mode
                        	**type**\:   :py:class:`L2VpnVniModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniModeEnum>`
                        
                        .. attribute:: vni_port_state
                        
                        	VNI Port State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.anycast_mcast_group_addr = None
                            self.anycast_vtep_ip_addr = None
                            self.multicast_group_addr = None
                            self.overlay = None
                            self.security_parameters = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                            self.security_parameters.parent = self
                            self.source_ip_addr = None
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'
                            self.statistics = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                            self.statistics.parent = self
                            self.udp_port = None
                            self.vni = None
                            self.vni_encap_type = None
                            self.vni_mode = None
                            self.vni_port_state = None
                            self.xconnect_id = None


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.anycast_mcast_group_addr is not None:
                                return True

                            if self.anycast_vtep_ip_addr is not None:
                                return True

                            if self.multicast_group_addr is not None:
                                return True

                            if self.overlay is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.source_ip_addr is not None:
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.udp_port is not None:
                                return True

                            if self.vni is not None:
                                return True

                            if self.vni_encap_type is not None:
                                return True

                            if self.vni_mode is not None:
                                return True

                            if self.vni_port_state is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters']['meta_info']


                    class Rd(object):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                            self.auto.parent = self
                            self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rd = None
                            self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                            self.v4_addr.parent = self


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto_index = None
                                self.router_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto_index is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rd is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd']['meta_info']


                    class MacFilter(object):
                        """
                        MAC addresses for filtering
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:mac-filter'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.bmac is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter']['meta_info']


                    class BridgeVfi(object):
                        """
                        Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.access = None
                            self.discovery_information = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self.number_pseudowires = None
                            self.p2mp_information = YList()
                            self.p2mp_information.parent = self
                            self.p2mp_information.name = 'p2mp_information'
                            self.shutdown = None
                            self.vfi_name = None
                            self.vfi_state = None


                        class DiscoveryInformation(object):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_signalling_method = None
                                self.as_number = None
                                self.export_route_policy = None
                                self.export_rt = YList()
                                self.export_rt.parent = self
                                self.export_rt.name = 'export_rt'
                                self.import_rt = YList()
                                self.import_rt.parent = self
                                self.import_rt.name = 'import_rt'
                                self.l2vpn_router_id = None
                                self.provisioned_ve_id = None
                                self.rd_value = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self.service_connected = None
                                self.ve_id = None
                                self.ve_range = None
                                self.vpls_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self.vpls_id_conflict = None
                                self.vpn_added = None
                                self.vpn_id = None


                            class RdValue(object):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rd = None
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto_index = None
                                        self.router_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto_index is not None:
                                            return True

                                        if self.router_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rd is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue']['meta_info']


                            class VplsId(object):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId']['meta_info']


                            class ImportRt(object):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt']['meta_info']


                            class ExportRt(object):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_signalling_method is not None:
                                    return True

                                if self.as_number is not None:
                                    return True

                                if self.export_route_policy is not None:
                                    return True

                                if self.export_rt is not None:
                                    for child_ref in self.export_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.import_rt is not None:
                                    for child_ref in self.import_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.l2vpn_router_id is not None:
                                    return True

                                if self.provisioned_ve_id is not None:
                                    return True

                                if self.rd_value is not None and self.rd_value._has_data():
                                    return True

                                if self.service_connected is not None:
                                    return True

                                if self.ve_id is not None:
                                    return True

                                if self.ve_range is not None:
                                    return True

                                if self.vpls_id is not None and self.vpls_id._has_data():
                                    return True

                                if self.vpls_id_conflict is not None:
                                    return True

                                if self.vpn_added is not None:
                                    return True

                                if self.vpn_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation']['meta_info']


                        class P2MpInformation(object):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.attribute_set_name = None
                                self.local_label = None
                                self.ptree_id = None
                                self.signaling = None
                                self.transport = None
                                self.transport_status = None
                                self.tunnel_interface = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attribute_set_name is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.ptree_id is not None:
                                    return True

                                if self.signaling is not None:
                                    return True

                                if self.transport is not None:
                                    return True

                                if self.transport_status is not None:
                                    return True

                                if self.tunnel_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.access is not None:
                                return True

                            if self.discovery_information is not None and self.discovery_information._has_data():
                                return True

                            if self.number_pseudowires is not None:
                                return True

                            if self.p2mp_information is not None:
                                for child_ref in self.p2mp_information:
                                    if child_ref._has_data():
                                        return True

                            if self.shutdown is not None:
                                return True

                            if self.vfi_name is not None:
                                return True

                            if self.vfi_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi']['meta_info']


                    class BridgeAccessVfi(object):
                        """
                        Access Virtual Forwarding Interfaces
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\:  bool
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\:  str
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.access = None
                            self.discovery_information = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self.number_pseudowires = None
                            self.p2mp_information = YList()
                            self.p2mp_information.parent = self
                            self.p2mp_information.name = 'p2mp_information'
                            self.shutdown = None
                            self.vfi_name = None
                            self.vfi_state = None


                        class DiscoveryInformation(object):
                            """
                            Auto Discovery information
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\:  str
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\:  bool
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\:  bool
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\:  bool
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_signalling_method = None
                                self.as_number = None
                                self.export_route_policy = None
                                self.export_rt = YList()
                                self.export_rt.parent = self
                                self.export_rt.name = 'export_rt'
                                self.import_rt = YList()
                                self.import_rt.parent = self
                                self.import_rt.name = 'import_rt'
                                self.l2vpn_router_id = None
                                self.provisioned_ve_id = None
                                self.rd_value = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self.service_connected = None
                                self.ve_id = None
                                self.ve_range = None
                                self.vpls_id = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self.vpls_id_conflict = None
                                self.vpn_added = None
                                self.vpn_id = None


                            class RdValue(object):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rd = None
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto_index = None
                                        self.router_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto_index is not None:
                                            return True

                                        if self.router_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rd is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue']['meta_info']


                            class VplsId(object):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId']['meta_info']


                            class ImportRt(object):
                                """
                                List of import route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt']['meta_info']


                            class ExportRt(object):
                                """
                                List of export route targets
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.es_import = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self.four_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self.rt = None
                                    self.two_byte_as = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                                class FourByteAs(object):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_as = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_as is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                                class EsImport(object):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.high_bytes = None
                                        self.low_bytes = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.high_bytes is not None:
                                            return True

                                        if self.low_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.es_import is not None and self.es_import._has_data():
                                        return True

                                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                                        return True

                                    if self.rt is not None:
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_signalling_method is not None:
                                    return True

                                if self.as_number is not None:
                                    return True

                                if self.export_route_policy is not None:
                                    return True

                                if self.export_rt is not None:
                                    for child_ref in self.export_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.import_rt is not None:
                                    for child_ref in self.import_rt:
                                        if child_ref._has_data():
                                            return True

                                if self.l2vpn_router_id is not None:
                                    return True

                                if self.provisioned_ve_id is not None:
                                    return True

                                if self.rd_value is not None and self.rd_value._has_data():
                                    return True

                                if self.service_connected is not None:
                                    return True

                                if self.ve_id is not None:
                                    return True

                                if self.ve_range is not None:
                                    return True

                                if self.vpls_id is not None and self.vpls_id._has_data():
                                    return True

                                if self.vpls_id_conflict is not None:
                                    return True

                                if self.vpn_added is not None:
                                    return True

                                if self.vpn_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation']['meta_info']


                        class P2MpInformation(object):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\:  str
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.attribute_set_name = None
                                self.local_label = None
                                self.ptree_id = None
                                self.signaling = None
                                self.transport = None
                                self.transport_status = None
                                self.tunnel_interface = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.attribute_set_name is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.ptree_id is not None:
                                    return True

                                if self.signaling is not None:
                                    return True

                                if self.transport is not None:
                                    return True

                                if self.transport_status is not None:
                                    return True

                                if self.tunnel_interface is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.access is not None:
                                return True

                            if self.discovery_information is not None and self.discovery_information._has_data():
                                return True

                            if self.number_pseudowires is not None:
                                return True

                            if self.p2mp_information is not None:
                                for child_ref in self.p2mp_information:
                                    if child_ref._has_data():
                                        return True

                            if self.shutdown is not None:
                                return True

                            if self.vfi_name is not None:
                                return True

                            if self.vfi_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.acpwup is not None:
                            return True

                        if self.as_ is not None:
                            return True

                        if self.bridge_access_vfi is not None:
                            for child_ref in self.bridge_access_vfi:
                                if child_ref._has_data():
                                    return True

                        if self.bridge_coupled_state is not None:
                            return True

                        if self.bridge_description is not None:
                            return True

                        if self.bridge_domain_id is not None:
                            return True

                        if self.bridge_internal_msti is not None:
                            return True

                        if self.bridge_msti is not None:
                            return True

                        if self.bridge_mtu is not None:
                            return True

                        if self.bridge_name is not None:
                            return True

                        if self.bridge_shg_id is not None:
                            return True

                        if self.bridge_state is not None:
                            return True

                        if self.bridge_type is not None:
                            return True

                        if self.bridge_vfi is not None:
                            for child_ref in self.bridge_vfi:
                                if child_ref._has_data():
                                    return True

                        if self.configured is not None:
                            return True

                        if self.disposition_bytecount is not None:
                            return True

                        if self.disposition_pkt_count is not None:
                            return True

                        if self.evi is not None:
                            return True

                        if self.evpn_parameters is not None and self.evpn_parameters._has_data():
                            return True

                        if self.flodd_group_id_down is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.imposition_byte_count is not None:
                            return True

                        if self.imposition_pkt_count is not None:
                            return True

                        if self.is_bridge_partially_programmed is not None:
                            return True

                        if self.is_rd_configured is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.mac_filter is not None:
                            for child_ref in self.mac_filter:
                                if child_ref._has_data():
                                    return True

                        if self.mac_limit_down is not None:
                            return True

                        if self.mac_withdraw is not None:
                            return True

                        if self.mac_withdraw_access is not None:
                            return True

                        if self.mac_withdraw_option is not None:
                            return True

                        if self.mac_withdraw_relay is not None:
                            return True

                        if self.num_vn_is is not None:
                            return True

                        if self.num_vn_is_up is not None:
                            return True

                        if self.number_a_cs is not None:
                            return True

                        if self.number_a_cs_up is not None:
                            return True

                        if self.number_access_vf_is is not None:
                            return True

                        if self.number_p_ws_up is not None:
                            return True

                        if self.number_pb_bs is not None:
                            return True

                        if self.number_pb_bs_up is not None:
                            return True

                        if self.number_pseudowires is not None:
                            return True

                        if self.number_vf_is is not None:
                            return True

                        if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                            return True

                        if self.p2mp_enabled is not None:
                            return True

                        if self.partially_programmed_a_cs is not None:
                            return True

                        if self.partially_programmed_pseudowires is not None:
                            return True

                        if self.pbb_parameters is not None and self.pbb_parameters._has_data():
                            return True

                        if self.rd is not None and self.rd._has_data():
                            return True

                        if self.security_parameters is not None and self.security_parameters._has_data():
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.standby_pseudowires is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.vine_fsm_state is not None:
                            return True

                        if self.vni_parameters is not None and self.vni_parameters._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_access_pws is not None and self.bridge_access_pws._has_data():
                        return True

                    if self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table._has_data():
                        return True

                    if self.bridge_acs is not None and self.bridge_acs._has_data():
                        return True

                    if self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table._has_data():
                        return True

                    if self.bridge_domain_group_name is not None:
                        return True

                    if self.bridge_domain_info is not None and self.bridge_domain_info._has_data():
                        return True

                    if self.bridge_domain_name is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.BridgeDomains.BridgeDomain']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:bridge-domains'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bridge_domain is not None:
                    for child_ref in self.bridge_domain:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.BridgeDomains']['meta_info']


        class DiscoverySummary(object):
            """
            Discovery summary information
            
            .. attribute:: bgp_current_node_id
            
            	BGP current node id
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: bgp_ipc_transport_mode
            
            	IPC Transport mode with BGP
            	**type**\:   :py:class:`L2VpnIpcTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportModeEnum>`
            
            .. attribute:: bgp_stateon_active_rp
            
            	BGP state on the active RP
            	**type**\:  bool
            
            .. attribute:: bgp_stateon_standby_rp
            
            	BGP state on standby RP
            	**type**\:  bool
            
            .. attribute:: number_bridge_domainvpns
            
            	Number of BDs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_bridge_domain
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_xconnect
            
            	Number of local Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2m_pxconnect_vpns
            
            	Number of XCs registered
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_bridge_domain
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_xconnect
            
            	Number of NLRI
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_bridge_domain
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_xconnect
            
            	Number of Remote Edges
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpls_registered
            
            	Is the VPLS service registered
            	**type**\:  bool
            
            .. attribute:: vpws_registered
            
            	Is the VPWS service registered
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bgp_current_node_id = None
                self.bgp_ipc_transport_mode = None
                self.bgp_stateon_active_rp = None
                self.bgp_stateon_standby_rp = None
                self.number_bridge_domainvpns = None
                self.number_local_edges_bridge_domain = None
                self.number_local_edges_xconnect = None
                self.number_mp2m_pxconnect_vpns = None
                self.number_nlri_bridge_domain = None
                self.number_nlri_xconnect = None
                self.number_remote_edges_bridge_domain = None
                self.number_remote_edges_xconnect = None
                self.vpls_registered = None
                self.vpws_registered = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:discovery-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bgp_current_node_id is not None:
                    return True

                if self.bgp_ipc_transport_mode is not None:
                    return True

                if self.bgp_stateon_active_rp is not None:
                    return True

                if self.bgp_stateon_standby_rp is not None:
                    return True

                if self.number_bridge_domainvpns is not None:
                    return True

                if self.number_local_edges_bridge_domain is not None:
                    return True

                if self.number_local_edges_xconnect is not None:
                    return True

                if self.number_mp2m_pxconnect_vpns is not None:
                    return True

                if self.number_nlri_bridge_domain is not None:
                    return True

                if self.number_nlri_xconnect is not None:
                    return True

                if self.number_remote_edges_bridge_domain is not None:
                    return True

                if self.number_remote_edges_xconnect is not None:
                    return True

                if self.vpls_registered is not None:
                    return True

                if self.vpws_registered is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.DiscoverySummary']['meta_info']


        class G8032(object):
            """
            G8032 information
            
            .. attribute:: g8032_rings
            
            	G8032 Ring table
            	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.g8032_rings = L2Vpnv2.Active.G8032.G8032Rings()
                self.g8032_rings.parent = self


            class G8032Rings(object):
                """
                G8032 Ring table
                
                .. attribute:: g8032_ring
                
                	G8032 Ring
                	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.g8032_ring = YList()
                    self.g8032_ring.parent = self
                    self.g8032_ring.name = 'g8032_ring'


                class G8032Ring(object):
                    """
                    G8032 Ring
                    
                    .. attribute:: ring_name  <key>
                    
                    	Ring Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: g8032_ring_detail
                    
                    	G8032 Ring detailed information
                    	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                    
                    .. attribute:: g8032_ring_instance_details
                    
                    	G8032 Ring Instance detail table
                    	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                    
                    .. attribute:: g8032_ring_instance_summaries
                    
                    	G8032 Ring Instance summary table
                    	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                    
                    .. attribute:: g8032_ring_summary
                    
                    	G8032 Ring summary information
                    	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ring_name = None
                        self.g8032_ring_detail = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                        self.g8032_ring_detail.parent = self
                        self.g8032_ring_instance_details = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                        self.g8032_ring_instance_details.parent = self
                        self.g8032_ring_instance_summaries = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                        self.g8032_ring_instance_summaries.parent = self
                        self.g8032_ring_summary = L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                        self.g8032_ring_summary.parent = self


                    class G8032RingDetail(object):
                        """
                        G8032 Ring detailed information
                        
                        .. attribute:: excluded_vlan_id
                        
                        	Exclusion Vlan ids list 
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: is_open_ring
                        
                        	Flag open ring
                        	**type**\:  bool
                        
                        .. attribute:: is_provider_bridge
                        
                        	Operating mode Customer/Provider 
                        	**type**\:  bool
                        
                        .. attribute:: monitor0
                        
                        	Monitor port 0
                        	**type**\:  str
                        
                        .. attribute:: monitor1
                        
                        	Monitor port 1
                        	**type**\:  str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        .. attribute:: tcn_propagation
                        
                        	Global TCN propagation
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.excluded_vlan_id = YLeafList()
                            self.excluded_vlan_id.parent = self
                            self.excluded_vlan_id.name = 'excluded_vlan_id'
                            self.is_open_ring = None
                            self.is_provider_bridge = None
                            self.monitor0 = None
                            self.monitor1 = None
                            self.port0 = None
                            self.port1 = None
                            self.ring_name = None
                            self.tcn_propagation = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-detail'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.excluded_vlan_id is not None:
                                for child in self.excluded_vlan_id:
                                    if child is not None:
                                        return True

                            if self.is_open_ring is not None:
                                return True

                            if self.is_provider_bridge is not None:
                                return True

                            if self.monitor0 is not None:
                                return True

                            if self.monitor1 is not None:
                                return True

                            if self.port0 is not None:
                                return True

                            if self.port1 is not None:
                                return True

                            if self.ring_name is not None:
                                return True

                            if self.tcn_propagation is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail']['meta_info']


                    class G8032RingInstanceSummaries(object):
                        """
                        G8032 Ring Instance summary table
                        
                        .. attribute:: g8032_ring_instance_summary
                        
                        	G8032 Ring Instance summary information
                        	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.g8032_ring_instance_summary = YList()
                            self.g8032_ring_instance_summary.parent = self
                            self.g8032_ring_instance_summary.name = 'g8032_ring_instance_summary'


                        class G8032RingInstanceSummary(object):
                            """
                            G8032 Ring Instance summary information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.instance = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None
                                self.included_vlan_id = YLeafList()
                                self.included_vlan_id.parent = self
                                self.included_vlan_id.name = 'included_vlan_id'
                                self.ring_instance = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.instance is None:
                                    raise YPYModelError('Key property instance is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summary[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.instance is not None:
                                    return True

                                if self.aps_port0 is not None:
                                    return True

                                if self.aps_port1 is not None:
                                    return True

                                if self.config_state is not None:
                                    return True

                                if self.included_vlan_id is not None:
                                    for child in self.included_vlan_id:
                                        if child is not None:
                                            return True

                                if self.ring_instance is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summaries'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.g8032_ring_instance_summary is not None:
                                for child_ref in self.g8032_ring_instance_summary:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries']['meta_info']


                    class G8032RingSummary(object):
                        """
                        G8032 Ring summary information
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\:  str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\:  str
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.port0 = None
                            self.port1 = None
                            self.ring_name = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-summary'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.port0 is not None:
                                return True

                            if self.port1 is not None:
                                return True

                            if self.ring_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary']['meta_info']


                    class G8032RingInstanceDetails(object):
                        """
                        G8032 Ring Instance detail table
                        
                        .. attribute:: g8032_ring_instance_detail
                        
                        	G8032 Ring Instance detailed information
                        	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.g8032_ring_instance_detail = YList()
                            self.g8032_ring_instance_detail.parent = self
                            self.g8032_ring_instance_detail.name = 'g8032_ring_instance_detail'


                        class G8032RingInstanceDetail(object):
                            """
                            G8032 Ring Instance detailed information
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: aps_channel_level
                            
                            	APS channel level
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\:  str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\:  bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: ring_description
                            
                            	Ring description
                            	**type**\:  str
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_profile
                            
                            	Ring Profile
                            	**type**\:  str
                            
                            .. attribute:: rpl
                            
                            	RPL
                            	**type**\:   :py:class:`L2VpnG8032RplEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032RplEnum>`
                            
                            .. attribute:: unresolved_reason
                            
                            	Reason of unresolved state state
                            	**type**\:   :py:class:`L2VpnG8032UncfgReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReasonEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.instance = None
                                self.aps_channel_level = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None
                                self.included_vlan_id = YLeafList()
                                self.included_vlan_id.parent = self
                                self.included_vlan_id.name = 'included_vlan_id'
                                self.ring_description = None
                                self.ring_instance = None
                                self.ring_profile = None
                                self.rpl = None
                                self.unresolved_reason = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.instance is None:
                                    raise YPYModelError('Key property instance is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-detail[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.instance is not None:
                                    return True

                                if self.aps_channel_level is not None:
                                    return True

                                if self.aps_port0 is not None:
                                    return True

                                if self.aps_port1 is not None:
                                    return True

                                if self.config_state is not None:
                                    return True

                                if self.included_vlan_id is not None:
                                    for child in self.included_vlan_id:
                                        if child is not None:
                                            return True

                                if self.ring_description is not None:
                                    return True

                                if self.ring_instance is not None:
                                    return True

                                if self.ring_profile is not None:
                                    return True

                                if self.rpl is not None:
                                    return True

                                if self.unresolved_reason is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-details'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.g8032_ring_instance_detail is not None:
                                for child_ref in self.g8032_ring_instance_detail:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails']['meta_info']

                    @property
                    def _common_path(self):
                        if self.ring_name is None:
                            raise YPYModelError('Key property ring_name is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:g8032/Cisco-IOS-XR-l2vpn-oper:g8032-rings/Cisco-IOS-XR-l2vpn-oper:g8032-ring[Cisco-IOS-XR-l2vpn-oper:ring-name = ' + str(self.ring_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ring_name is not None:
                            return True

                        if self.g8032_ring_detail is not None and self.g8032_ring_detail._has_data():
                            return True

                        if self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details._has_data():
                            return True

                        if self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries._has_data():
                            return True

                        if self.g8032_ring_summary is not None and self.g8032_ring_summary._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings.G8032Ring']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:g8032/Cisco-IOS-XR-l2vpn-oper:g8032-rings'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.g8032_ring is not None:
                        for child_ref in self.g8032_ring:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.G8032.G8032Rings']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:g8032'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.g8032_rings is not None and self.g8032_rings._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.G8032']['meta_info']


        class PseudowireClasses(object):
            """
            List of pseudowire classes
            
            .. attribute:: pseudowire_class
            
            	Pseudowire class information
            	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.pseudowire_class = YList()
                self.pseudowire_class.parent = self
                self.pseudowire_class.name = 'pseudowire_class'


            class PseudowireClass(object):
                """
                Pseudowire class information
                
                .. attribute:: pseudowire_class_name  <key>
                
                	Pseudowire Class Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: backup_mac_withdraw
                
                	TRUE if MAC withdraw message is sent
                	**type**\:  bool
                
                .. attribute:: control_word
                
                	Control word
                	**type**\:   :py:class:`L2VpnPwClassControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWordEnum>`
                
                .. attribute:: disable_delay
                
                	Disable Deley
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: disable_never
                
                	TRUE if backup is not automatically disabled
                	**type**\:  bool
                
                .. attribute:: encapsulation_info
                
                	Encapsulation specific pseudowire information
                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                
                .. attribute:: is_flow_label_static
                
                	is flow label static
                	**type**\:  bool
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                
                .. attribute:: local_source_address
                
                	Local source address
                	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                
                .. attribute:: preferred_path
                
                	MPLS Preferred Path
                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath>`
                
                .. attribute:: preferred_path_disable_fallback
                
                	PreferredPathDisableFallback
                	**type**\:  bool
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                
                .. attribute:: pw_class_name
                
                	Pseudowire class name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: pw_flow_label_code17_disabled
                
                	Disable sending Code 17 TLV
                	**type**\:  bool
                
                .. attribute:: pw_flow_label_type_cfg
                
                	Configured pseudowire flow label type
                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                
                .. attribute:: resync_enabled
                
                	Resync if packets out of sequence
                	**type**\:  bool
                
                .. attribute:: resync_threshold
                
                	Number of Packets Out of Seqence to trigger resync
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sequencing_type
                
                	Sequencing Type
                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                
                .. attribute:: tag_rewrite
                
                	Static tag rewrite
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: transport_mode
                
                	Transport mode
                	**type**\:   :py:class:`L2VpnTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportModeEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.pseudowire_class_name = None
                    self.backup_mac_withdraw = None
                    self.control_word = None
                    self.disable_delay = None
                    self.disable_never = None
                    self.encapsulation_info = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                    self.encapsulation_info.parent = self
                    self.is_flow_label_static = None
                    self.load_balance = None
                    self.local_source_address = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                    self.local_source_address.parent = self
                    self.preferred_path = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath()
                    self.preferred_path.parent = self
                    self.preferred_path_disable_fallback = None
                    self.protocol = None
                    self.pw_class_name = None
                    self.pw_flow_label_code17_disabled = None
                    self.pw_flow_label_type_cfg = None
                    self.resync_enabled = None
                    self.resync_threshold = None
                    self.sequencing_type = None
                    self.tag_rewrite = None
                    self.transport_mode = None


                class EncapsulationInfo(object):
                    """
                    Encapsulation specific pseudowire information
                    
                    .. attribute:: encapsulation
                    
                    	Encapsulation
                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                    
                    .. attribute:: l2tpv3
                    
                    	l2tpv3
                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.encapsulation = None
                        self.l2tpv3 = L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                        self.l2tpv3.parent = self


                    class L2Tpv3(object):
                        """
                        l2tpv3
                        
                        .. attribute:: cookie_size
                        
                        	Cookie size\: 0, 4, or 8 bytes
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dont_fragment_bit
                        
                        	Don't Fragment Bit
                        	**type**\:  bool
                        
                        .. attribute:: ipv4_source_address
                        
                        	IPv4 source address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: l2tp_class_name
                        
                        	L2TPClassName
                        	**type**\:  str
                        
                        	**length:** 0..32
                        
                        .. attribute:: path_mtu_enabled
                        
                        	Path MTU enabled
                        	**type**\:  bool
                        
                        .. attribute:: path_mtu_max_value
                        
                        	Path MTU Maximum allowable session MTU
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: tos
                        
                        	Type Of Service Value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tos_mode
                        
                        	Type Of Service Mode
                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                        
                        .. attribute:: ttl
                        
                        	Time To Live value
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.cookie_size = None
                            self.dont_fragment_bit = None
                            self.ipv4_source_address = None
                            self.l2tp_class_name = None
                            self.path_mtu_enabled = None
                            self.path_mtu_max_value = None
                            self.tos = None
                            self.tos_mode = None
                            self.ttl = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.cookie_size is not None:
                                return True

                            if self.dont_fragment_bit is not None:
                                return True

                            if self.ipv4_source_address is not None:
                                return True

                            if self.l2tp_class_name is not None:
                                return True

                            if self.path_mtu_enabled is not None:
                                return True

                            if self.path_mtu_max_value is not None:
                                return True

                            if self.tos is not None:
                                return True

                            if self.tos_mode is not None:
                                return True

                            if self.ttl is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.encapsulation is not None:
                            return True

                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo']['meta_info']


                class PreferredPath(object):
                    """
                    MPLS Preferred Path
                    
                    .. attribute:: ip_tunnel_interface_number
                    
                    	IPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: next_hop_ip
                    
                    	NextHopIP
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: option
                    
                    	Option
                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                    
                    .. attribute:: te_tunnel_interface_number
                    
                    	TETunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tp_tunnel_interface_number
                    
                    	TPTunnelInterfaceNumber
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ip_tunnel_interface_number = None
                        self.next_hop_ip = None
                        self.option = None
                        self.te_tunnel_interface_number = None
                        self.tp_tunnel_interface_number = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ip_tunnel_interface_number is not None:
                            return True

                        if self.next_hop_ip is not None:
                            return True

                        if self.option is not None:
                            return True

                        if self.te_tunnel_interface_number is not None:
                            return True

                        if self.tp_tunnel_interface_number is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath']['meta_info']


                class LocalSourceAddress(object):
                    """
                    Local source address
                    
                    .. attribute:: address
                    
                    	Local source address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: configuration
                    
                    	Configuration
                    	**type**\:   :py:class:`L2VpnSrcAddressSetEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSetEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.configuration = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-source-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.configuration is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress']['meta_info']

                @property
                def _common_path(self):
                    if self.pseudowire_class_name is None:
                        raise YPYModelError('Key property pseudowire_class_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes/Cisco-IOS-XR-l2vpn-oper:pseudowire-class[Cisco-IOS-XR-l2vpn-oper:pseudowire-class-name = ' + str(self.pseudowire_class_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.pseudowire_class_name is not None:
                        return True

                    if self.backup_mac_withdraw is not None:
                        return True

                    if self.control_word is not None:
                        return True

                    if self.disable_delay is not None:
                        return True

                    if self.disable_never is not None:
                        return True

                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                        return True

                    if self.is_flow_label_static is not None:
                        return True

                    if self.load_balance is not None:
                        return True

                    if self.local_source_address is not None and self.local_source_address._has_data():
                        return True

                    if self.preferred_path is not None and self.preferred_path._has_data():
                        return True

                    if self.preferred_path_disable_fallback is not None:
                        return True

                    if self.protocol is not None:
                        return True

                    if self.pw_class_name is not None:
                        return True

                    if self.pw_flow_label_code17_disabled is not None:
                        return True

                    if self.pw_flow_label_type_cfg is not None:
                        return True

                    if self.resync_enabled is not None:
                        return True

                    if self.resync_threshold is not None:
                        return True

                    if self.sequencing_type is not None:
                        return True

                    if self.tag_rewrite is not None:
                        return True

                    if self.transport_mode is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.PseudowireClasses.PseudowireClass']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.pseudowire_class is not None:
                    for child_ref in self.pseudowire_class:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.PseudowireClasses']['meta_info']


        class L2VpnCollaborators(object):
            """
            L2VPN collaborator information
            
            .. attribute:: collaborator_statistics
            
            	Collaborator Statistics
            	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.collaborator_statistics = L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics()
                self.collaborator_statistics.parent = self


            class CollaboratorStatistics(object):
                """
                Collaborator Statistics
                
                .. attribute:: count
                
                	count
                	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.count = YList()
                    self.count.parent = self
                    self.count.name = 'count'


                class Count(object):
                    """
                    count
                    
                    .. attribute:: collaborator_name
                    
                    	Collaborator Name
                    	**type**\:  str
                    
                    .. attribute:: down
                    
                    	Down
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_up
                    
                    	Is up
                    	**type**\:  bool
                    
                    .. attribute:: up
                    
                    	Up
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.collaborator_name = None
                        self.down = None
                        self.is_up = None
                        self.up = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics/Cisco-IOS-XR-l2vpn-oper:count'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.collaborator_name is not None:
                            return True

                        if self.down is not None:
                            return True

                        if self.is_up is not None:
                            return True

                        if self.up is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics.Count']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.count is not None:
                        for child_ref in self.count:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.L2VpnCollaborators.CollaboratorStatistics']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.collaborator_statistics is not None and self.collaborator_statistics._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.L2VpnCollaborators']['meta_info']


        class Mvrp(object):
            """
            MVRP
            
            .. attribute:: mvrp_main_ports
            
            	MVRP Main Port Table
            	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mvrp_main_ports = L2Vpnv2.Active.Mvrp.MvrpMainPorts()
                self.mvrp_main_ports.parent = self


            class MvrpMainPorts(object):
                """
                MVRP Main Port Table
                
                .. attribute:: mvrp_main_port
                
                	MVRP Main Port
                	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mvrp_main_port = YList()
                    self.mvrp_main_port.parent = self
                    self.mvrp_main_port.name = 'mvrp_main_port'


                class MvrpMainPort(object):
                    """
                    MVRP Main Port
                    
                    .. attribute:: main_port_interface_name  <key>
                    
                    	Main Port interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: mvrp_bridge_ports
                    
                    	MVRP Bridge Port Table
                    	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                    
                    .. attribute:: mvrp_main_port_info
                    
                    	MVRP Main Port Information
                    	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.main_port_interface_name = None
                        self.mvrp_bridge_ports = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                        self.mvrp_bridge_ports.parent = self
                        self.mvrp_main_port_info = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                        self.mvrp_main_port_info.parent = self


                    class MvrpMainPortInfo(object):
                        """
                        MVRP Main Port Information
                        
                        .. attribute:: default_bridge_port
                        
                        	Trunk or default Bridge Port
                        	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                        
                        .. attribute:: is_default_encap
                        
                        	Is default encap set
                        	**type**\:  bool
                        
                        .. attribute:: is_trunk
                        
                        	Is main port a trunk
                        	**type**\:  bool
                        
                        .. attribute:: main_port_interface_name
                        
                        	Main Port Interface name
                        	**type**\:  str
                        
                        .. attribute:: number_of_bridge_ports
                        
                        	Number of Bridge Ports
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.default_bridge_port = L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                            self.default_bridge_port.parent = self
                            self.is_default_encap = None
                            self.is_trunk = None
                            self.main_port_interface_name = None
                            self.number_of_bridge_ports = None


                        class DefaultBridgePort(object):
                            """
                            Trunk or default Bridge Port
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None
                                self.vlan_range = YList()
                                self.vlan_range.parent = self
                                self.vlan_range.name = 'vlan_range'


                            class VlanRange(object):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lower = None
                                    self.upper = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lower is not None:
                                        return True

                                    if self.upper is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:default-bridge-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bridge_port_interface_name is not None:
                                    return True

                                if self.bridge_port_xconnect_id is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.vlan_range is not None:
                                    for child_ref in self.vlan_range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.default_bridge_port is not None and self.default_bridge_port._has_data():
                                return True

                            if self.is_default_encap is not None:
                                return True

                            if self.is_trunk is not None:
                                return True

                            if self.main_port_interface_name is not None:
                                return True

                            if self.number_of_bridge_ports is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo']['meta_info']


                    class MvrpBridgePorts(object):
                        """
                        MVRP Bridge Port Table
                        
                        .. attribute:: mvrp_bridge_port
                        
                        	MVRP Bridge Port Information
                        	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mvrp_bridge_port = YList()
                            self.mvrp_bridge_port.parent = self
                            self.mvrp_bridge_port.name = 'mvrp_bridge_port'


                        class MvrpBridgePort(object):
                            """
                            MVRP Bridge Port Information
                            
                            .. attribute:: interface_name  <key>
                            
                            	Bridge Port Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\:  str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None
                                self.vlan_range = YList()
                                self.vlan_range.parent = self
                                self.vlan_range.name = 'vlan_range'


                            class VlanRange(object):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.lower = None
                                    self.upper = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.lower is not None:
                                        return True

                                    if self.upper is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-port[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.bridge_port_interface_name is not None:
                                    return True

                                if self.bridge_port_xconnect_id is not None:
                                    return True

                                if self.mvrp_sequence_number is not None:
                                    return True

                                if self.vlan_range is not None:
                                    for child_ref in self.vlan_range:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-ports'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mvrp_bridge_port is not None:
                                for child_ref in self.mvrp_bridge_port:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts']['meta_info']

                    @property
                    def _common_path(self):
                        if self.main_port_interface_name is None:
                            raise YPYModelError('Key property main_port_interface_name is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mvrp/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port[Cisco-IOS-XR-l2vpn-oper:main-port-interface-name = ' + str(self.main_port_interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.main_port_interface_name is not None:
                            return True

                        if self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports._has_data():
                            return True

                        if self.mvrp_main_port_info is not None and self.mvrp_main_port_info._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mvrp/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mvrp_main_port is not None:
                        for child_ref in self.mvrp_main_port:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.Mvrp.MvrpMainPorts']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mvrp'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mvrp_main_ports is not None and self.mvrp_main_ports._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.Mvrp']['meta_info']


        class GenericInterfaces(object):
            """
            L2VPN generic interface list Table
            
            .. attribute:: generic_interface
            
            	Generic Interface List information
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.generic_interface = YList()
                self.generic_interface.parent = self
                self.generic_interface.name = 'generic_interface'


            class GenericInterface(object):
                """
                Generic Interface List information
                
                .. attribute:: interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_list_name = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.interface_list_id = None
                    self.interface_list_name_xr = None
                    self.items = None
                    self.number_of_interfaces = None


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.GenericInterfaces.GenericInterface.Interface']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_list_name is None:
                        raise YPYModelError('Key property interface_list_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:generic-interfaces/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_list_name is not None:
                        return True

                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.interface_list_id is not None:
                        return True

                    if self.interface_list_name_xr is not None:
                        return True

                    if self.items is not None:
                        return True

                    if self.number_of_interfaces is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.GenericInterfaces.GenericInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.generic_interface is not None:
                    for child_ref in self.generic_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.GenericInterfaces']['meta_info']


        class MstpVlans(object):
            """
            L2VPN MSTP VLAN Table
            
            .. attribute:: mstp_vlan
            
            	L2VPN MSTP VLAN information
            	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpVlans.MstpVlan>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mstp_vlan = YList()
                self.mstp_vlan.parent = self
                self.mstp_vlan.name = 'mstp_vlan'


            class MstpVlan(object):
                """
                L2VPN MSTP VLAN information
                
                .. attribute:: vlan_id  <key>
                
                	vlan id
                	**type**\:  int
                
                	**range:** 0..4098
                
                .. attribute:: msti_id
                
                	MSTI id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_count
                
                	Port Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_interface
                
                	Sub interfaces
                	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface>`
                
                .. attribute:: vlan_id_xr
                
                	Vlan id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.vlan_id = None
                    self.msti_id = None
                    self.port_count = None
                    self.sub_interface = YList()
                    self.sub_interface.parent = self
                    self.sub_interface.name = 'sub_interface'
                    self.vlan_id_xr = None


                class SubInterface(object):
                    """
                    Sub interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sub-interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.MstpVlans.MstpVlan.SubInterface']['meta_info']

                @property
                def _common_path(self):
                    if self.vlan_id is None:
                        raise YPYModelError('Key property vlan_id is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mstp-vlans/Cisco-IOS-XR-l2vpn-oper:mstp-vlan[Cisco-IOS-XR-l2vpn-oper:vlan-id = ' + str(self.vlan_id) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.vlan_id is not None:
                        return True

                    if self.msti_id is not None:
                        return True

                    if self.port_count is not None:
                        return True

                    if self.sub_interface is not None:
                        for child_ref in self.sub_interface:
                            if child_ref._has_data():
                                return True

                    if self.vlan_id_xr is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.MstpVlans.MstpVlan']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:mstp-vlans'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mstp_vlan is not None:
                    for child_ref in self.mstp_vlan:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.MstpVlans']['meta_info']


        class L2VpnPbbBsa(object):
            """
            L2VPN PBB Backbone Source MAC information
            
            .. attribute:: bmac_sa
            
            	BMAC SA
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: chassis_is_provisioned
            
            	Chassis MAC is configured
            	**type**\:  bool
            
            .. attribute:: chassis_mac
            
            	Chassis MAC
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: provisioned
            
            	BMAC SA configured
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bmac_sa = None
                self.chassis_is_provisioned = None
                self.chassis_mac = None
                self.provisioned = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:l2vpn-pbb-bsa'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bmac_sa is not None:
                    return True

                if self.chassis_is_provisioned is not None:
                    return True

                if self.chassis_mac is not None:
                    return True

                if self.provisioned is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.L2VpnPbbBsa']['meta_info']


        class FlexibleXconnectServices(object):
            """
            Flexible XConnect Service Table
            
            .. attribute:: flexible_xconnect_service
            
            	Flexible XConnect Service Information
            	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.flexible_xconnect_service = YList()
                self.flexible_xconnect_service.parent = self
                self.flexible_xconnect_service.name = 'flexible_xconnect_service'


            class FlexibleXconnectService(object):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name  <key>
                
                	Flexible XConnect Service Name
                	**type**\:  str
                
                	**length:** 1..23
                
                .. attribute:: flexible_xconnect_service_acs
                
                	Flexible XConnect Service Attachment Circuit Table
                	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                
                .. attribute:: flexible_xconnect_service_info
                
                	Flexible XConnect Service Information
                	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.flexible_xconnect_service_acs = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                    self.flexible_xconnect_service_acs.parent = self
                    self.flexible_xconnect_service_info = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                    self.flexible_xconnect_service_info.parent = self


                class FlexibleXconnectServiceAcs(object):
                    """
                    Flexible XConnect Service Attachment Circuit
                    Table
                    
                    .. attribute:: flexible_xconnect_service_ac
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.flexible_xconnect_service_ac = YList()
                        self.flexible_xconnect_service_ac.parent = self
                        self.flexible_xconnect_service_ac.name = 'flexible_xconnect_service_ac'


                    class FlexibleXconnectServiceAc(object):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: attachment_circuit
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.attachment_circuit = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self


                        class AttachmentCircuit(object):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-acs'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.flexible_xconnect_service_ac is not None:
                            for child_ref in self.flexible_xconnect_service_ac:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs']['meta_info']


                class FlexibleXconnectServiceInfo(object):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: name
                    
                    	Flexible XConnect Service Name
                    	**type**\:  str
                    
                    .. attribute:: num_p_ws
                    
                    	Number of Pseudowires in Pseudowire List
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: pseudowire
                    
                    	Flexible XConnect Service Pseudowire List
                    	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                    
                    .. attribute:: state
                    
                    	State of the Flexible XConnect Service
                    	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.num_p_ws = None
                        self.pseudowire = YList()
                        self.pseudowire.parent = self
                        self.pseudowire.name = 'pseudowire'
                        self.state = None


                    class Pseudowire(object):
                        """
                        Flexible XConnect Service Pseudowire List
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.num_p_ws is not None:
                            return True

                        if self.pseudowire is not None:
                            for child_ref in self.pseudowire:
                                if child_ref._has_data():
                                    return True

                        if self.state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo']['meta_info']

                @property
                def _common_path(self):
                    if self.name is None:
                        raise YPYModelError('Key property name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service[Cisco-IOS-XR-l2vpn-oper:name = ' + str(self.name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs._has_data():
                        return True

                    if self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.flexible_xconnect_service is not None:
                    for child_ref in self.flexible_xconnect_service:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.FlexibleXconnectServices']['meta_info']


        class XconnectBrief(object):
            """
            XConnect brief information
            
            .. attribute:: encapsulation_report_matrix
            
            	Encapsulation report counters matrix
            	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix>`
            
            .. attribute:: encapsulation_total
            
            	Total summary
            	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationTotal>`
            
            .. attribute:: main_total_down
            
            	Total Number of non\-active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_unresolved
            
            	Total Number of unresolved Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_up
            
            	Total Number of active Cross\-Conections with valid encaps
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: memory_state
            
            	L2VPN memory state
            	**type**\:   :py:class:`L2VpnMemoryStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryStateEnum>`
            
            .. attribute:: undefined_xc
            
            	Undefined xc including PW\-PW
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.encapsulation_report_matrix = YList()
                self.encapsulation_report_matrix.parent = self
                self.encapsulation_report_matrix.name = 'encapsulation_report_matrix'
                self.encapsulation_total = YList()
                self.encapsulation_total.parent = self
                self.encapsulation_total.name = 'encapsulation_total'
                self.main_total_down = None
                self.main_total_unresolved = None
                self.main_total_up = None
                self.memory_state = None
                self.undefined_xc = None


            class EncapsulationReportMatrix(object):
                """
                Encapsulation report counters matrix
                
                .. attribute:: ac1
                
                	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ac1 = YList()
                    self.ac1.parent = self
                    self.ac1.name = 'ac1'


                class Ac1(object):
                    """
                    Array of l2vpn\_xc\_brief\_first layer indexed by
                    the AC1 encapsulation type
                    
                    .. attribute:: ac2
                    
                    	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                    	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac2 = YList()
                        self.ac2.parent = self
                        self.ac2.name = 'ac2'


                    class Ac2(object):
                        """
                        Array of l2vpn\_xc\_brief\_line indexed by the AC2
                        encapsulation type plus one type for PW
                        
                        .. attribute:: ac1_encapsulation
                        
                        	AC1 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                        
                        .. attribute:: ac2_encapsulation
                        
                        	AC2 encapsulation
                        	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                        
                        .. attribute:: down_count
                        
                        	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unresolved_count
                        
                        	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: up_count
                        
                        	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                        	**type**\:  list of int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac1_encapsulation = None
                            self.ac2_encapsulation = None
                            self.down_count = YLeafList()
                            self.down_count.parent = self
                            self.down_count.name = 'down_count'
                            self.unresolved_count = YLeafList()
                            self.unresolved_count.parent = self
                            self.unresolved_count.name = 'unresolved_count'
                            self.up_count = YLeafList()
                            self.up_count.parent = self
                            self.up_count.name = 'up_count'

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix/Cisco-IOS-XR-l2vpn-oper:ac1/Cisco-IOS-XR-l2vpn-oper:ac2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac1_encapsulation is not None:
                                return True

                            if self.ac2_encapsulation is not None:
                                return True

                            if self.down_count is not None:
                                for child in self.down_count:
                                    if child is not None:
                                        return True

                            if self.unresolved_count is not None:
                                for child in self.unresolved_count:
                                    if child is not None:
                                        return True

                            if self.up_count is not None:
                                for child in self.up_count:
                                    if child is not None:
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix/Cisco-IOS-XR-l2vpn-oper:ac1'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac2 is not None:
                            for child_ref in self.ac2:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ac1 is not None:
                        for child_ref in self.ac1:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.XconnectBrief.EncapsulationReportMatrix']['meta_info']


            class EncapsulationTotal(object):
                """
                Total summary
                
                .. attribute:: ac1_encapsulation
                
                	AC1 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                
                .. attribute:: ac2_encapsulation
                
                	AC2 encapsulation
                	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                
                .. attribute:: down_count
                
                	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_count
                
                	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ac1_encapsulation = None
                    self.ac2_encapsulation = None
                    self.down_count = YLeafList()
                    self.down_count.parent = self
                    self.down_count.name = 'down_count'
                    self.unresolved_count = YLeafList()
                    self.unresolved_count.parent = self
                    self.unresolved_count.name = 'unresolved_count'
                    self.up_count = YLeafList()
                    self.up_count.parent = self
                    self.up_count.name = 'up_count'

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-total'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ac1_encapsulation is not None:
                        return True

                    if self.ac2_encapsulation is not None:
                        return True

                    if self.down_count is not None:
                        for child in self.down_count:
                            if child is not None:
                                return True

                    if self.unresolved_count is not None:
                        for child in self.unresolved_count:
                            if child is not None:
                                return True

                    if self.up_count is not None:
                        for child in self.up_count:
                            if child is not None:
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Active.XconnectBrief.EncapsulationTotal']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:xconnect-brief'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.encapsulation_report_matrix is not None:
                    for child_ref in self.encapsulation_report_matrix:
                        if child_ref._has_data():
                            return True

                if self.encapsulation_total is not None:
                    for child_ref in self.encapsulation_total:
                        if child_ref._has_data():
                            return True

                if self.main_total_down is not None:
                    return True

                if self.main_total_unresolved is not None:
                    return True

                if self.main_total_up is not None:
                    return True

                if self.memory_state is not None:
                    return True

                if self.undefined_xc is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Active.XconnectBrief']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:active'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.bridge_domains is not None and self.bridge_domains._has_data():
                return True

            if self.bridge_summary is not None and self.bridge_summary._has_data():
                return True

            if self.discoveries is not None and self.discoveries._has_data():
                return True

            if self.discovery_summary is not None and self.discovery_summary._has_data():
                return True

            if self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary._has_data():
                return True

            if self.flexible_xconnect_services is not None and self.flexible_xconnect_services._has_data():
                return True

            if self.g8032 is not None and self.g8032._has_data():
                return True

            if self.generic_interface_list_details is not None and self.generic_interface_list_details._has_data():
                return True

            if self.generic_interfaces is not None and self.generic_interfaces._has_data():
                return True

            if self.global_settings is not None and self.global_settings._has_data():
                return True

            if self.iccp_sm is not None and self.iccp_sm._has_data():
                return True

            if self.indexes is not None and self.indexes._has_data():
                return True

            if self.l2vpn_collaborators is not None and self.l2vpn_collaborators._has_data():
                return True

            if self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa._has_data():
                return True

            if self.l2vpn_resource_state is not None and self.l2vpn_resource_state._has_data():
                return True

            if self.main_interfaces is not None and self.main_interfaces._has_data():
                return True

            if self.mstp_ports is not None and self.mstp_ports._has_data():
                return True

            if self.mstp_vlans is not None and self.mstp_vlans._has_data():
                return True

            if self.mvrp is not None and self.mvrp._has_data():
                return True

            if self.nsr is not None and self.nsr._has_data():
                return True

            if self.proc_fsm is not None and self.proc_fsm._has_data():
                return True

            if self.pseudowire_classes is not None and self.pseudowire_classes._has_data():
                return True

            if self.pwr is not None and self.pwr._has_data():
                return True

            if self.xconnect_brief is not None and self.xconnect_brief._has_data():
                return True

            if self.xconnect_groups is not None and self.xconnect_groups._has_data():
                return True

            if self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces._has_data():
                return True

            if self.xconnect_mp2mps is not None and self.xconnect_mp2mps._has_data():
                return True

            if self.xconnect_summary is not None and self.xconnect_summary._has_data():
                return True

            if self.xconnects is not None and self.xconnects._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpnv2.Active']['meta_info']


    class Nodes(object):
        """
        Table of L2VPN operational data for a particular
        node
        
        .. attribute:: node
        
        	L2VPN operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.node = YList()
            self.node.parent = self
            self.node.name = 'node'


        class Node(object):
            """
            L2VPN operational data for a particular node
            
            .. attribute:: node_id  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: bridge_domains
            
            	VPLS Bridge Domain Information
            	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains>`
            
            .. attribute:: bridge_summary
            
            	Bridge Domain summary information
            	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeSummary>`
            
            .. attribute:: discoveries
            
            	Discovery Table
            	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries>`
            
            .. attribute:: discovery_summary
            
            	Discovery summary information
            	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.DiscoverySummary>`
            
            .. attribute:: flexible_xconnect_service_summary
            
            	Flexible XConnect Service summary information
            	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary>`
            
            .. attribute:: flexible_xconnect_services
            
            	Flexible XConnect Service Table
            	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices>`
            
            .. attribute:: g8032
            
            	G8032 information
            	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032>`
            
            .. attribute:: generic_interface_list_details
            
            	L2VPN generic interface list Detail Table
            	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails>`
            
            .. attribute:: generic_interfaces
            
            	L2VPN generic interface list Table
            	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaces>`
            
            .. attribute:: global_settings
            
            	L2VPN global settings
            	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GlobalSettings>`
            
            .. attribute:: iccp_sm
            
            	ICCP\-based Service Multi\-homing operational data
            	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm>`
            
            .. attribute:: indexes
            
            	ID Manager Index Table
            	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Indexes>`
            
            .. attribute:: l2vpn_collaborators
            
            	L2VPN collaborator information
            	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnCollaborators>`
            
            .. attribute:: l2vpn_pbb_bsa
            
            	L2VPN PBB Backbone Source MAC information
            	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnPbbBsa>`
            
            .. attribute:: l2vpn_resource_state
            
            	L2VPN resource state information
            	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnResourceState>`
            
            .. attribute:: main_interfaces
            
            	Main Interface
            	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces>`
            
            .. attribute:: mstp_ports
            
            	L2VPN MSTP Port Table
            	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts>`
            
            .. attribute:: mstp_vlans
            
            	L2VPN MSTP VLAN Table
            	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpVlans>`
            
            .. attribute:: mvrp
            
            	MVRP
            	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp>`
            
            .. attribute:: nsr
            
            	L2VPN NSR information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr>`
            
            .. attribute:: proc_fsm
            
            	L2VPN Process FSM information
            	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm>`
            
            .. attribute:: pseudowire_classes
            
            	List of pseudowire classes
            	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses>`
            
            .. attribute:: pwr
            
            	Pseudowire Routing Table
            	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr>`
            
            .. attribute:: xconnect_brief
            
            	XConnect brief information
            	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief>`
            
            .. attribute:: xconnect_groups
            
            	XConnect group Table
            	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectGroups>`
            
            .. attribute:: xconnect_mp2mp_ce2ces
            
            	XConnect MP2MP CE2CE Table
            	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces>`
            
            .. attribute:: xconnect_mp2mps
            
            	XConnect MP2MP Table
            	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps>`
            
            .. attribute:: xconnect_summary
            
            	XConnect summary information
            	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectSummary>`
            
            .. attribute:: xconnects
            
            	XConnect Table
            	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.node_id = None
                self.bridge_domains = L2Vpnv2.Nodes.Node.BridgeDomains()
                self.bridge_domains.parent = self
                self.bridge_summary = L2Vpnv2.Nodes.Node.BridgeSummary()
                self.bridge_summary.parent = self
                self.discoveries = L2Vpnv2.Nodes.Node.Discoveries()
                self.discoveries.parent = self
                self.discovery_summary = L2Vpnv2.Nodes.Node.DiscoverySummary()
                self.discovery_summary.parent = self
                self.flexible_xconnect_service_summary = L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary()
                self.flexible_xconnect_service_summary.parent = self
                self.flexible_xconnect_services = L2Vpnv2.Nodes.Node.FlexibleXconnectServices()
                self.flexible_xconnect_services.parent = self
                self.g8032 = L2Vpnv2.Nodes.Node.G8032()
                self.g8032.parent = self
                self.generic_interface_list_details = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails()
                self.generic_interface_list_details.parent = self
                self.generic_interfaces = L2Vpnv2.Nodes.Node.GenericInterfaces()
                self.generic_interfaces.parent = self
                self.global_settings = L2Vpnv2.Nodes.Node.GlobalSettings()
                self.global_settings.parent = self
                self.iccp_sm = L2Vpnv2.Nodes.Node.IccpSm()
                self.iccp_sm.parent = self
                self.indexes = L2Vpnv2.Nodes.Node.Indexes()
                self.indexes.parent = self
                self.l2vpn_collaborators = L2Vpnv2.Nodes.Node.L2VpnCollaborators()
                self.l2vpn_collaborators.parent = self
                self.l2vpn_pbb_bsa = L2Vpnv2.Nodes.Node.L2VpnPbbBsa()
                self.l2vpn_pbb_bsa.parent = self
                self.l2vpn_resource_state = L2Vpnv2.Nodes.Node.L2VpnResourceState()
                self.l2vpn_resource_state.parent = self
                self.main_interfaces = L2Vpnv2.Nodes.Node.MainInterfaces()
                self.main_interfaces.parent = self
                self.mstp_ports = L2Vpnv2.Nodes.Node.MstpPorts()
                self.mstp_ports.parent = self
                self.mstp_vlans = L2Vpnv2.Nodes.Node.MstpVlans()
                self.mstp_vlans.parent = self
                self.mvrp = L2Vpnv2.Nodes.Node.Mvrp()
                self.mvrp.parent = self
                self.nsr = L2Vpnv2.Nodes.Node.Nsr()
                self.nsr.parent = self
                self.proc_fsm = L2Vpnv2.Nodes.Node.ProcFsm()
                self.proc_fsm.parent = self
                self.pseudowire_classes = L2Vpnv2.Nodes.Node.PseudowireClasses()
                self.pseudowire_classes.parent = self
                self.pwr = L2Vpnv2.Nodes.Node.Pwr()
                self.pwr.parent = self
                self.xconnect_brief = L2Vpnv2.Nodes.Node.XconnectBrief()
                self.xconnect_brief.parent = self
                self.xconnect_groups = L2Vpnv2.Nodes.Node.XconnectGroups()
                self.xconnect_groups.parent = self
                self.xconnect_mp2mp_ce2ces = L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces()
                self.xconnect_mp2mp_ce2ces.parent = self
                self.xconnect_mp2mps = L2Vpnv2.Nodes.Node.XconnectMp2Mps()
                self.xconnect_mp2mps.parent = self
                self.xconnect_summary = L2Vpnv2.Nodes.Node.XconnectSummary()
                self.xconnect_summary.parent = self
                self.xconnects = L2Vpnv2.Nodes.Node.Xconnects()
                self.xconnects.parent = self


            class Discoveries(object):
                """
                Discovery Table
                
                .. attribute:: discovery
                
                	VPLS Discovery information
                	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.discovery = YList()
                    self.discovery.parent = self
                    self.discovery.name = 'discovery'


                class Discovery(object):
                    """
                    VPLS Discovery information
                    
                    .. attribute:: group_name
                    
                    	Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: is_service_connected
                    
                    	Is the service connected
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatch_ignore
                    
                    	Ignore MTU Mismatch
                    	**type**\:  bool
                    
                    .. attribute:: number_vpn
                    
                    	Number of vpns
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: service_name
                    
                    	Service type
                    	**type**\:   :py:class:`L2VpnServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnServiceEnum>`
                    
                    .. attribute:: service_name_xr
                    
                    	Service Type
                    	**type**\:  str
                    
                    .. attribute:: signalling_info
                    
                    	Info about signalling protocol
                    	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo>`
                    
                    .. attribute:: vpn_id
                    
                    	VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_name
                    
                    	VPN Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    .. attribute:: vpn_name_xr
                    
                    	VPN instance name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_name = None
                        self.group_name_xr = None
                        self.is_service_connected = None
                        self.mtu_mismatch_ignore = None
                        self.number_vpn = None
                        self.service_name = None
                        self.service_name_xr = None
                        self.signalling_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo()
                        self.signalling_info.parent = self
                        self.vpn_id = None
                        self.vpn_name = None
                        self.vpn_name_xr = None


                    class SignallingInfo(object):
                        """
                        Info about signalling protocol
                        
                        .. attribute:: ad_signalling_method
                        
                        	ADSignallingMethod
                        	**type**\:   :py:class:`L2VpnAdSigMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethodEnum>`
                        
                        .. attribute:: bgp_sig_info
                        
                        	bgp sig info
                        	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                        
                        .. attribute:: ldp_sig_info
                        
                        	ldp sig info
                        	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_signalling_method = None
                            self.bgp_sig_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                            self.bgp_sig_info.parent = self
                            self.ldp_sig_info = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                            self.ldp_sig_info.parent = self


                        class BgpSigInfo(object):
                            """
                            bgp sig info
                            
                            .. attribute:: edge
                            
                            	List of edge ids
                            	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                            
                            .. attribute:: number_edges
                            
                            	Number of Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_remote_edges
                            
                            	Number of remote Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redge
                            
                            	List of edge ids
                            	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.edge = YList()
                                self.edge.parent = self
                                self.edge.name = 'edge'
                                self.number_edges = None
                                self.number_remote_edges = None
                                self.redge = YList()
                                self.redge.parent = self
                                self.redge.name = 'redge'


                            class Edge(object):
                                """
                                List of edge ids
                                
                                .. attribute:: edge_id
                                
                                	Edge ids
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_block
                                
                                	List of label blocks
                                	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                                
                                .. attribute:: label_count
                                
                                	Number of label blocks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.edge_id = None
                                    self.label_block = YList()
                                    self.label_block.parent = self
                                    self.label_block.name = 'label_block'
                                    self.label_count = None


                                class LabelBlock(object):
                                    """
                                    List of label blocks
                                    
                                    .. attribute:: block_offset
                                    
                                    	Block offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_size
                                    
                                    	Block size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_base
                                    
                                    	Label Base
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_error
                                    
                                    	Label Error
                                    	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                                    
                                    .. attribute:: label_time_created
                                    
                                    	Creation time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_edge_id
                                    
                                    	Local edge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	 Peer id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: status_vector
                                    
                                    	Status Vector
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.block_offset = None
                                        self.block_size = None
                                        self.label_base = None
                                        self.label_error = None
                                        self.label_time_created = None
                                        self.local_edge_id = None
                                        self.next_hop = None
                                        self.status_vector = YLeafList()
                                        self.status_vector.parent = self
                                        self.status_vector.name = 'status_vector'

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:label-block'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.block_offset is not None:
                                            return True

                                        if self.block_size is not None:
                                            return True

                                        if self.label_base is not None:
                                            return True

                                        if self.label_error is not None:
                                            return True

                                        if self.label_time_created is not None:
                                            return True

                                        if self.local_edge_id is not None:
                                            return True

                                        if self.next_hop is not None:
                                            return True

                                        if self.status_vector is not None:
                                            for child in self.status_vector:
                                                if child is not None:
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.edge_id is not None:
                                        return True

                                    if self.label_block is not None:
                                        for child_ref in self.label_block:
                                            if child_ref._has_data():
                                                return True

                                    if self.label_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge']['meta_info']


                            class Redge(object):
                                """
                                List of edge ids
                                
                                .. attribute:: edge_id
                                
                                	Edge ids
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_block
                                
                                	List of label blocks
                                	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                                
                                .. attribute:: label_count
                                
                                	Number of label blocks
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.edge_id = None
                                    self.label_block = YList()
                                    self.label_block.parent = self
                                    self.label_block.name = 'label_block'
                                    self.label_count = None


                                class LabelBlock(object):
                                    """
                                    List of label blocks
                                    
                                    .. attribute:: block_offset
                                    
                                    	Block offset
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_size
                                    
                                    	Block size
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_base
                                    
                                    	Label Base
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_error
                                    
                                    	Label Error
                                    	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                                    
                                    .. attribute:: label_time_created
                                    
                                    	Creation time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_edge_id
                                    
                                    	Local edge ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	 Peer id
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: status_vector
                                    
                                    	Status Vector
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.block_offset = None
                                        self.block_size = None
                                        self.label_base = None
                                        self.label_error = None
                                        self.label_time_created = None
                                        self.local_edge_id = None
                                        self.next_hop = None
                                        self.status_vector = YLeafList()
                                        self.status_vector.parent = self
                                        self.status_vector.name = 'status_vector'

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:label-block'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.block_offset is not None:
                                            return True

                                        if self.block_size is not None:
                                            return True

                                        if self.label_base is not None:
                                            return True

                                        if self.label_error is not None:
                                            return True

                                        if self.label_time_created is not None:
                                            return True

                                        if self.local_edge_id is not None:
                                            return True

                                        if self.next_hop is not None:
                                            return True

                                        if self.status_vector is not None:
                                            for child in self.status_vector:
                                                if child is not None:
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:redge'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.edge_id is not None:
                                        return True

                                    if self.label_block is not None:
                                        for child_ref in self.label_block:
                                            if child_ref._has_data():
                                                return True

                                    if self.label_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.edge is not None:
                                    for child_ref in self.edge:
                                        if child_ref._has_data():
                                            return True

                                if self.number_edges is not None:
                                    return True

                                if self.number_remote_edges is not None:
                                    return True

                                if self.redge is not None:
                                    for child_ref in self.redge:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo']['meta_info']


                        class LdpSigInfo(object):
                            """
                            ldp sig info
                            
                            .. attribute:: local_l2_router_id
                            
                            	Local L2VPN Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_vpls_id
                            
                            	Local VPLS\-ID
                            	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                            
                            .. attribute:: number_remote_edges
                            
                            	Number of remote Edges
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_nlri
                            
                            	List of NLRIs
                            	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_l2_router_id = None
                                self.local_vpls_id = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                self.local_vpls_id.parent = self
                                self.number_remote_edges = None
                                self.remote_nlri = YList()
                                self.remote_nlri.parent = self
                                self.remote_nlri.name = 'remote_nlri'


                            class LocalVplsId(object):
                                """
                                Local VPLS\-ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-vpls-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId']['meta_info']


                            class RemoteNlri(object):
                                """
                                List of NLRIs
                                
                                .. attribute:: local_address
                                
                                	Local BGP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: nlri_time_created
                                
                                	NLRI creation time
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote BGP Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_l2_router_id
                                
                                	Remote L2VPN Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_address = None
                                    self.nlri_time_created = None
                                    self.remote_address = None
                                    self.remote_l2_router_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-nlri'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_address is not None:
                                        return True

                                    if self.nlri_time_created is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    if self.remote_l2_router_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_l2_router_id is not None:
                                    return True

                                if self.local_vpls_id is not None and self.local_vpls_id._has_data():
                                    return True

                                if self.number_remote_edges is not None:
                                    return True

                                if self.remote_nlri is not None:
                                    for child_ref in self.remote_nlri:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:signalling-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_signalling_method is not None:
                                return True

                            if self.bgp_sig_info is not None and self.bgp_sig_info._has_data():
                                return True

                            if self.ldp_sig_info is not None and self.ldp_sig_info._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:discovery'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_name is not None:
                            return True

                        if self.group_name_xr is not None:
                            return True

                        if self.is_service_connected is not None:
                            return True

                        if self.mtu_mismatch_ignore is not None:
                            return True

                        if self.number_vpn is not None:
                            return True

                        if self.service_name is not None:
                            return True

                        if self.service_name_xr is not None:
                            return True

                        if self.signalling_info is not None and self.signalling_info._has_data():
                            return True

                        if self.vpn_id is not None:
                            return True

                        if self.vpn_name is not None:
                            return True

                        if self.vpn_name_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries.Discovery']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:discoveries'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.discovery is not None:
                        for child_ref in self.discovery:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.Discoveries']['meta_info']


            class FlexibleXconnectServiceSummary(object):
                """
                Flexible XConnect Service summary information
                
                .. attribute:: number_fxc
                
                	Number of flexible xconnect services
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_fxc_down
                
                	Number of flexible xconnect services whose state is down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_fxc_up
                
                	Number of flexible xconnect services whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.number_fxc = None
                    self.number_fxc_down = None
                    self.number_fxc_up = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.number_fxc is not None:
                        return True

                    if self.number_fxc_down is not None:
                        return True

                    if self.number_fxc_up is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServiceSummary']['meta_info']


            class MainInterfaces(object):
                """
                Main Interface
                
                .. attribute:: main_interface
                
                	Main Interface Table
                	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.main_interface = YList()
                    self.main_interface.parent = self
                    self.main_interface.name = 'main_interface'


                class MainInterface(object):
                    """
                    Main Interface Table
                    
                    .. attribute:: interface_name  <key>
                    
                    	Main interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: main_interface_info
                    
                    	Main Interface info
                    	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo>`
                    
                    .. attribute:: main_interface_instances
                    
                    	Main Interface Instance table
                    	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.main_interface_info = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo()
                        self.main_interface_info.parent = self
                        self.main_interface_instances = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances()
                        self.main_interface_instances.parent = self


                    class MainInterfaceInstances(object):
                        """
                        Main Interface Instance table
                        
                        .. attribute:: main_interface_instance
                        
                        	Main Interface Instance
                        	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.main_interface_instance = YList()
                            self.main_interface_instance.parent = self
                            self.main_interface_instance.name = 'main_interface_instance'


                        class MainInterfaceInstance(object):
                            """
                            Main Interface Instance
                            
                            .. attribute:: instance  <key>
                            
                            	Instance
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: main_interface_instance_bridge_ports
                            
                            	Main Interface Instance Bridge Port table
                            	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                            
                            .. attribute:: main_interface_instance_info
                            
                            	Main Interface Instance info
                            	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.instance = None
                                self.main_interface_instance_bridge_ports = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                self.main_interface_instance_bridge_ports.parent = self
                                self.main_interface_instance_info = L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                self.main_interface_instance_info.parent = self


                            class MainInterfaceInstanceInfo(object):
                                """
                                Main Interface Instance info
                                
                                .. attribute:: configured_instance
                                
                                	Configured Instance
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flush_count
                                
                                	Flush count 
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_flags
                                
                                	Instance Flags
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_state
                                
                                	Instance State
                                	**type**\:   :py:class:`L2VpnMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceStateEnum>`
                                
                                .. attribute:: interface_count
                                
                                	Interface count
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.configured_instance = None
                                    self.flush_count = None
                                    self.instance_flags = None
                                    self.instance_id = None
                                    self.instance_state = None
                                    self.interface_count = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.configured_instance is not None:
                                        return True

                                    if self.flush_count is not None:
                                        return True

                                    if self.instance_flags is not None:
                                        return True

                                    if self.instance_id is not None:
                                        return True

                                    if self.instance_state is not None:
                                        return True

                                    if self.interface_count is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo']['meta_info']


                            class MainInterfaceInstanceBridgePorts(object):
                                """
                                Main Interface Instance Bridge Port table
                                
                                .. attribute:: main_interface_instance_bridge_port
                                
                                	Main Interface Bridge Port info
                                	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.main_interface_instance_bridge_port = YList()
                                    self.main_interface_instance_bridge_port.parent = self
                                    self.main_interface_instance_bridge_port.name = 'main_interface_instance_bridge_port'


                                class MainInterfaceInstanceBridgePort(object):
                                    """
                                    Main Interface Bridge Port info
                                    
                                    .. attribute:: bridge_port  <key>
                                    
                                    	Bridge Port
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: bridge_port_xr
                                    
                                    	Bridge port ifhandle
                                    	**type**\:  str
                                    
                                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                    
                                    .. attribute:: instance_id
                                    
                                    	Instance ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bridge_port = None
                                        self.bridge_port_xr = None
                                        self.instance_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')
                                        if self.bridge_port is None:
                                            raise YPYModelError('Key property bridge_port is None')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-port[Cisco-IOS-XR-l2vpn-oper:bridge-port = ' + str(self.bridge_port) + ']'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bridge_port is not None:
                                            return True

                                        if self.bridge_port_xr is not None:
                                            return True

                                        if self.instance_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-ports'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.main_interface_instance_bridge_port is not None:
                                        for child_ref in self.main_interface_instance_bridge_port:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.instance is None:
                                    raise YPYModelError('Key property instance is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.instance is not None:
                                    return True

                                if self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports._has_data():
                                    return True

                                if self.main_interface_instance_info is not None and self.main_interface_instance_info._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instances'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.main_interface_instance is not None:
                                for child_ref in self.main_interface_instance:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances']['meta_info']


                    class MainInterfaceInfo(object):
                        """
                        Main Interface info
                        
                        .. attribute:: interface_count
                        
                        	Sub Interface Count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: main_interface_handle
                        
                        	Main Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: protected
                        
                        	Protected
                        	**type**\:   :py:class:`L2VpnMainIfProtectectedEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectectedEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_count = None
                            self.main_interface_handle = None
                            self.protected = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_count is not None:
                                return True

                            if self.main_interface_handle is not None:
                                return True

                            if self.protected is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.main_interface_info is not None and self.main_interface_info._has_data():
                            return True

                        if self.main_interface_instances is not None and self.main_interface_instances._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces.MainInterface']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.main_interface is not None:
                        for child_ref in self.main_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.MainInterfaces']['meta_info']


            class IccpSm(object):
                """
                ICCP\-based Service Multi\-homing operational data
                
                .. attribute:: iccp_groups
                
                	ICCP Group Table
                	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups>`
                
                .. attribute:: iccp_sm_summary
                
                	ICCP\-based Service Multi\-homing database summary
                	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.iccp_groups = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups()
                    self.iccp_groups.parent = self
                    self.iccp_sm_summary = L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary()
                    self.iccp_sm_summary.parent = self


                class IccpSmSummary(object):
                    """
                    ICCP\-based Service Multi\-homing database
                    summary
                    
                    .. attribute:: connected_groups
                    
                    	Number of Connected Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: connecting_groups
                    
                    	Number of Connecting Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: failed_ports
                    
                    	Number of Failed Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groups
                    
                    	Total Number of Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: operational_ports
                    
                    	Number of Operational Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ports
                    
                    	Total Number of Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: provisioned_groups
                    
                    	Number of Provisioned Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reverting_ports
                    
                    	Number of Reverting Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: synchronized_groups
                    
                    	Number of Synchronized Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: synchronizing_groups
                    
                    	Number of Synchronizing Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unconfigured_ports
                    
                    	Number of Unconfigured Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unknown_ports
                    
                    	Number of Unknown Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unresolved_groups
                    
                    	Number of Unresolved Groups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsynchronized_ports
                    
                    	Number of Unsynchronized Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.connected_groups = None
                        self.connecting_groups = None
                        self.failed_ports = None
                        self.groups = None
                        self.operational_ports = None
                        self.ports = None
                        self.provisioned_groups = None
                        self.reverting_ports = None
                        self.synchronized_groups = None
                        self.synchronizing_groups = None
                        self.unconfigured_ports = None
                        self.unknown_ports = None
                        self.unresolved_groups = None
                        self.unsynchronized_ports = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-sm-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.connected_groups is not None:
                            return True

                        if self.connecting_groups is not None:
                            return True

                        if self.failed_ports is not None:
                            return True

                        if self.groups is not None:
                            return True

                        if self.operational_ports is not None:
                            return True

                        if self.ports is not None:
                            return True

                        if self.provisioned_groups is not None:
                            return True

                        if self.reverting_ports is not None:
                            return True

                        if self.synchronized_groups is not None:
                            return True

                        if self.synchronizing_groups is not None:
                            return True

                        if self.unconfigured_ports is not None:
                            return True

                        if self.unknown_ports is not None:
                            return True

                        if self.unresolved_groups is not None:
                            return True

                        if self.unsynchronized_ports is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpSmSummary']['meta_info']


                class IccpGroups(object):
                    """
                    ICCP Group Table
                    
                    .. attribute:: iccp_group
                    
                    	ICCP Group
                    	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.iccp_group = YList()
                        self.iccp_group.parent = self
                        self.iccp_group.name = 'iccp_group'


                    class IccpGroup(object):
                        """
                        ICCP Group
                        
                        .. attribute:: group_id  <key>
                        
                        	Group ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: iccp_group_info
                        
                        	ICCP Group Information
                        	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                        
                        .. attribute:: iccp_ports
                        
                        	ICCP Port Table
                        	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.group_id = None
                            self.iccp_group_info = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                            self.iccp_group_info.parent = self
                            self.iccp_ports = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                            self.iccp_ports.parent = self


                        class IccpGroupInfo(object):
                            """
                            ICCP Group Information
                            
                            .. attribute:: group_id
                            
                            	Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: iccp_member_up
                            
                            	ICCP Member Up
                            	**type**\:  bool
                            
                            .. attribute:: iccp_transport_up
                            
                            	ICCP Transport Up
                            	**type**\:  bool
                            
                            .. attribute:: local_node_id
                            
                            	Local Node ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ports
                            
                            	List of ports in the group
                            	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                            
                            .. attribute:: remote_node_id
                            
                            	Remote Node ID
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`IccpSmStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.group_id = None
                                self.iccp_member_up = None
                                self.iccp_transport_up = None
                                self.local_node_id = None
                                self.ports = YList()
                                self.ports.parent = self
                                self.ports.name = 'ports'
                                self.remote_node_id = None
                                self.state = None


                            class Ports(object):
                                """
                                List of ports in the group
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: local_port
                                
                                	Local port info
                                	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                                
                                .. attribute:: mac_flush_tcn
                                
                                	Is MAC flush through STP\-TCN?
                                	**type**\:  bool
                                
                                .. attribute:: remote_port
                                
                                	Remote port info
                                	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.local_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                    self.local_port.parent = self
                                    self.mac_flush_tcn = None
                                    self.remote_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                    self.remote_port.parent = self


                                class LocalPort(object):
                                    """
                                    Local port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fsm_state = None
                                        self.port_fail_code = None
                                        self.port_state = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self.vlan_state = None
                                        self.vlan_vector = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fsm_state is not None:
                                            return True

                                        if self.port_fail_code is not None:
                                            return True

                                        if self.port_state is not None:
                                            return True

                                        if self.reversion_time is not None:
                                            return True

                                        if self.reversion_time_remaining is not None:
                                            return True

                                        if self.vlan_state is not None:
                                            return True

                                        if self.vlan_vector is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort']['meta_info']


                                class RemotePort(object):
                                    """
                                    Remote port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fsm_state = None
                                        self.port_fail_code = None
                                        self.port_state = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self.vlan_state = None
                                        self.vlan_vector = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fsm_state is not None:
                                            return True

                                        if self.port_fail_code is not None:
                                            return True

                                        if self.port_state is not None:
                                            return True

                                        if self.reversion_time is not None:
                                            return True

                                        if self.reversion_time_remaining is not None:
                                            return True

                                        if self.vlan_state is not None:
                                            return True

                                        if self.vlan_vector is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ports'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.local_port is not None and self.local_port._has_data():
                                        return True

                                    if self.mac_flush_tcn is not None:
                                        return True

                                    if self.remote_port is not None and self.remote_port._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-group-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.group_id is not None:
                                    return True

                                if self.iccp_member_up is not None:
                                    return True

                                if self.iccp_transport_up is not None:
                                    return True

                                if self.local_node_id is not None:
                                    return True

                                if self.ports is not None:
                                    for child_ref in self.ports:
                                        if child_ref._has_data():
                                            return True

                                if self.remote_node_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo']['meta_info']


                        class IccpPorts(object):
                            """
                            ICCP Port Table
                            
                            .. attribute:: iccp_port
                            
                            	ICCP Port
                            	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.iccp_port = YList()
                                self.iccp_port.parent = self
                                self.iccp_port.name = 'iccp_port'


                            class IccpPort(object):
                                """
                                ICCP Port
                                
                                .. attribute:: interface  <key>
                                
                                	Interface
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: local_port
                                
                                	Local port info
                                	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                                
                                .. attribute:: mac_flush_tcn
                                
                                	Is MAC flush through STP\-TCN?
                                	**type**\:  bool
                                
                                .. attribute:: remote_port
                                
                                	Remote port info
                                	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface = None
                                    self.interface_name = None
                                    self.local_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                    self.local_port.parent = self
                                    self.mac_flush_tcn = None
                                    self.remote_port = L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                    self.remote_port.parent = self


                                class LocalPort(object):
                                    """
                                    Local port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fsm_state = None
                                        self.port_fail_code = None
                                        self.port_state = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self.vlan_state = None
                                        self.vlan_vector = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fsm_state is not None:
                                            return True

                                        if self.port_fail_code is not None:
                                            return True

                                        if self.port_state is not None:
                                            return True

                                        if self.reversion_time is not None:
                                            return True

                                        if self.reversion_time_remaining is not None:
                                            return True

                                        if self.vlan_state is not None:
                                            return True

                                        if self.vlan_vector is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort']['meta_info']


                                class RemotePort(object):
                                    """
                                    Remote port info
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\:  str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.fsm_state = None
                                        self.port_fail_code = None
                                        self.port_state = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self.vlan_state = None
                                        self.vlan_vector = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.fsm_state is not None:
                                            return True

                                        if self.port_fail_code is not None:
                                            return True

                                        if self.port_state is not None:
                                            return True

                                        if self.reversion_time is not None:
                                            return True

                                        if self.reversion_time_remaining is not None:
                                            return True

                                        if self.vlan_state is not None:
                                            return True

                                        if self.vlan_vector is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface is None:
                                        raise YPYModelError('Key property interface is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface is not None:
                                        return True

                                    if self.interface_name is not None:
                                        return True

                                    if self.local_port is not None and self.local_port._has_data():
                                        return True

                                    if self.mac_flush_tcn is not None:
                                        return True

                                    if self.remote_port is not None and self.remote_port._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-ports'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.iccp_port is not None:
                                    for child_ref in self.iccp_port:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.group_id is None:
                                raise YPYModelError('Key property group_id is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-group[Cisco-IOS-XR-l2vpn-oper:group-id = ' + str(self.group_id) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.group_id is not None:
                                return True

                            if self.iccp_group_info is not None and self.iccp_group_info._has_data():
                                return True

                            if self.iccp_ports is not None and self.iccp_ports._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-groups'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.iccp_group is not None:
                            for child_ref in self.iccp_group:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm.IccpGroups']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-sm'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.iccp_groups is not None and self.iccp_groups._has_data():
                        return True

                    if self.iccp_sm_summary is not None and self.iccp_sm_summary._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.IccpSm']['meta_info']


            class BridgeSummary(object):
                """
                Bridge Domain summary information
                
                .. attribute:: num_vn_is
                
                	Number of VNIs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_down
                
                	Number of VNIs down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_unresolved
                
                	Number of VNIs unresolved
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_up
                
                	Number of VNIs up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains
                
                	Number of bridge\-domains
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains_shut
                
                	Number of bridge\-domains admin disabled
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains_up
                
                	Number of bridge\-domains up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_default_bridge_doamins
                
                	Number of default bridge\-domains
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_groups
                
                	Number of groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp
                
                	Number of P2MPs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp_down
                
                	Number of P2MPs whose state is down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp_up
                
                	Number of P2MPs whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pbb_core
                
                	Number of PBB Core
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pbb_edge
                
                	Number of PBB Edge
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_a_cs
                
                	Number of partially programmed attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_bridges
                
                	Number of partially programmed bridge\-domains
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_pseudowires
                
                	Number of partially programmed pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_pseudowires
                
                	Number of pseudowires whose state is standby
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.num_vn_is = None
                    self.num_vn_is_down = None
                    self.num_vn_is_unresolved = None
                    self.num_vn_is_up = None
                    self.number_a_cs = None
                    self.number_a_cs_up = None
                    self.number_bridge_domains = None
                    self.number_bridge_domains_shut = None
                    self.number_bridge_domains_up = None
                    self.number_default_bridge_doamins = None
                    self.number_groups = None
                    self.number_p2mp = None
                    self.number_p2mp_down = None
                    self.number_p2mp_up = None
                    self.number_p_ws_up = None
                    self.number_pbb_core = None
                    self.number_pbb_edge = None
                    self.number_pseudowires = None
                    self.out_of_memory_state = None
                    self.partially_programmed_a_cs = None
                    self.partially_programmed_bridges = None
                    self.partially_programmed_pseudowires = None
                    self.standby_pseudowires = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.num_vn_is is not None:
                        return True

                    if self.num_vn_is_down is not None:
                        return True

                    if self.num_vn_is_unresolved is not None:
                        return True

                    if self.num_vn_is_up is not None:
                        return True

                    if self.number_a_cs is not None:
                        return True

                    if self.number_a_cs_up is not None:
                        return True

                    if self.number_bridge_domains is not None:
                        return True

                    if self.number_bridge_domains_shut is not None:
                        return True

                    if self.number_bridge_domains_up is not None:
                        return True

                    if self.number_default_bridge_doamins is not None:
                        return True

                    if self.number_groups is not None:
                        return True

                    if self.number_p2mp is not None:
                        return True

                    if self.number_p2mp_down is not None:
                        return True

                    if self.number_p2mp_up is not None:
                        return True

                    if self.number_p_ws_up is not None:
                        return True

                    if self.number_pbb_core is not None:
                        return True

                    if self.number_pbb_edge is not None:
                        return True

                    if self.number_pseudowires is not None:
                        return True

                    if self.out_of_memory_state is not None:
                        return True

                    if self.partially_programmed_a_cs is not None:
                        return True

                    if self.partially_programmed_bridges is not None:
                        return True

                    if self.partially_programmed_pseudowires is not None:
                        return True

                    if self.standby_pseudowires is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeSummary']['meta_info']


            class Nsr(object):
                """
                L2VPN NSR information
                
                .. attribute:: event_history
                
                	L2VPN Process event history
                	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.EventHistory>`
                
                .. attribute:: failover_status
                
                	L2VPN failover status
                	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.FailoverStatus>`
                
                .. attribute:: issu_status
                
                	L2VPN ISSU Status and timestamp
                	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.IssuStatus>`
                
                .. attribute:: nsr_status
                
                	L2VPN NSR status and timestamp
                	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.NsrStatus>`
                
                .. attribute:: process_role
                
                	Current Process Role
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_state
                
                	Current Process State
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: report_card
                
                	L2VPN Collaborator report card
                	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.ReportCard>`
                
                .. attribute:: state_transition_time
                
                	Transition time for all states
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: sw_install_in_progress
                
                	Is s/w install currently in progress?
                	**type**\:  bool
                
                .. attribute:: sync_flags
                
                	Sync complete flags
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xid_info
                
                	XID information
                	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.XidInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_history = YList()
                    self.event_history.parent = self
                    self.event_history.name = 'event_history'
                    self.failover_status = L2Vpnv2.Nodes.Node.Nsr.FailoverStatus()
                    self.failover_status.parent = self
                    self.issu_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus()
                    self.issu_status.parent = self
                    self.nsr_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus()
                    self.nsr_status.parent = self
                    self.process_role = None
                    self.process_state = None
                    self.report_card = YList()
                    self.report_card.parent = self
                    self.report_card.name = 'report_card'
                    self.state_transition_time = YLeafList()
                    self.state_transition_time.parent = self
                    self.state_transition_time.name = 'state_transition_time'
                    self.sw_install_in_progress = None
                    self.sync_flags = None
                    self.xid_info = YList()
                    self.xid_info.parent = self
                    self.xid_info.name = 'xid_info'


                class FailoverStatus(object):
                    """
                    L2VPN failover status
                    
                    .. attribute:: master_time
                    
                    	Master time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Start time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: triggered_time
                    
                    	Triggered time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.master_time = None
                        self.start_time = None
                        self.triggered_time = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:failover-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.master_time is not None:
                            return True

                        if self.start_time is not None:
                            return True

                        if self.triggered_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.FailoverStatus']['meta_info']


                class NsrStatus(object):
                    """
                    L2VPN NSR status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.idt_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self.role = None


                    class IdtStatus(object):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus']['meta_info']


                    class PreviOusIdtStatus(object):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:nsr-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.idt_status is not None and self.idt_status._has_data():
                            return True

                        if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                            return True

                        if self.role is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.NsrStatus']['meta_info']


                class IssuStatus(object):
                    """
                    L2VPN ISSU Status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.idt_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self.role = None


                    class IdtStatus(object):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus']['meta_info']


                    class PreviOusIdtStatus(object):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:issu-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.idt_status is not None and self.idt_status._has_data():
                            return True

                        if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                            return True

                        if self.role is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.IssuStatus']['meta_info']


                class XidInfo(object):
                    """
                    XID information
                    
                    .. attribute:: app_type
                    
                    	App type
                    	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                    
                    .. attribute:: sent_ids
                    
                    	Number of XIDs transferred
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.app_type = None
                        self.sent_ids = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xid-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.app_type is not None:
                            return True

                        if self.sent_ids is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.XidInfo']['meta_info']


                class ReportCard(object):
                    """
                    L2VPN Collaborator report card
                    
                    .. attribute:: collaborator_idt_done
                    
                    	Is IDT done for this collaborator
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_is_connected
                    
                    	Is the collaborator connected
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_skipped
                    
                    	Was this collaborator skipped for not connecting in time
                    	**type**\:  bool
                    
                    .. attribute:: connection_change_time
                    
                    	Time when connection state (UP/DOWN) changed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idt_time
                    
                    	Time when IDT was done
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.collaborator_idt_done = None
                        self.collaborator_is_connected = None
                        self.collaborator_skipped = None
                        self.connection_change_time = None
                        self.idt_time = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:report-card'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.collaborator_idt_done is not None:
                            return True

                        if self.collaborator_is_connected is not None:
                            return True

                        if self.collaborator_skipped is not None:
                            return True

                        if self.connection_change_time is not None:
                            return True

                        if self.idt_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.ReportCard']['meta_info']


                class EventHistory(object):
                    """
                    L2VPN Process event history
                    
                    .. attribute:: event_timestamp
                    
                    	Event timestamp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: new_state
                    
                    	New state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: previous_state
                    
                    	Previous state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_collaborator
                    
                    	Process collaborator
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: process_event
                    
                    	Process event
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.event_timestamp = None
                        self.new_state = None
                        self.previous_state = None
                        self.process_collaborator = None
                        self.process_event = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:event-history'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.event_timestamp is not None:
                            return True

                        if self.new_state is not None:
                            return True

                        if self.previous_state is not None:
                            return True

                        if self.process_collaborator is not None:
                            return True

                        if self.process_event is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr.EventHistory']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:nsr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_history is not None:
                        for child_ref in self.event_history:
                            if child_ref._has_data():
                                return True

                    if self.failover_status is not None and self.failover_status._has_data():
                        return True

                    if self.issu_status is not None and self.issu_status._has_data():
                        return True

                    if self.nsr_status is not None and self.nsr_status._has_data():
                        return True

                    if self.process_role is not None:
                        return True

                    if self.process_state is not None:
                        return True

                    if self.report_card is not None:
                        for child_ref in self.report_card:
                            if child_ref._has_data():
                                return True

                    if self.state_transition_time is not None:
                        for child in self.state_transition_time:
                            if child is not None:
                                return True

                    if self.sw_install_in_progress is not None:
                        return True

                    if self.sync_flags is not None:
                        return True

                    if self.xid_info is not None:
                        for child_ref in self.xid_info:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.Nsr']['meta_info']


            class GlobalSettings(object):
                """
                L2VPN global settings
                
                .. attribute:: going_active
                
                	transitioning to Active functional role
                	**type**\:  bool
                
                .. attribute:: ha_role
                
                	Node redundancy role
                	**type**\:  str
                
                .. attribute:: issu_role
                
                	Node ISSU role
                	**type**\:  str
                
                .. attribute:: logging_bd_enabled
                
                	Logging BD state changes enabled
                	**type**\:  bool
                
                .. attribute:: logging_df_election_enabled
                
                	Logging EVPN Designated Forwarder changes enabled
                	**type**\:  bool
                
                .. attribute:: logging_nsr_enabled
                
                	Logging NSR state changes enabled
                	**type**\:  bool
                
                .. attribute:: logging_pw_enabled
                
                	Logging PW enabled
                	**type**\:  bool
                
                .. attribute:: logging_vfi_enabled
                
                	Logging VFI state changes enabled
                	**type**\:  bool
                
                .. attribute:: process_fsm
                
                	Current L2VPN FSM role
                	**type**\:  str
                
                .. attribute:: pw_grouping_enabled
                
                	PW Grouping enabled
                	**type**\:  bool
                
                .. attribute:: pw_oam_refresh_transmit_time
                
                	PW OAM refresh transmit (seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: pw_status_enabled
                
                	PW Status enabled
                	**type**\:  bool
                
                .. attribute:: tcn_propagation_enabled
                
                	TCN propagation enabled
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.going_active = None
                    self.ha_role = None
                    self.issu_role = None
                    self.logging_bd_enabled = None
                    self.logging_df_election_enabled = None
                    self.logging_nsr_enabled = None
                    self.logging_pw_enabled = None
                    self.logging_vfi_enabled = None
                    self.process_fsm = None
                    self.pw_grouping_enabled = None
                    self.pw_oam_refresh_transmit_time = None
                    self.pw_status_enabled = None
                    self.tcn_propagation_enabled = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:global-settings'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.going_active is not None:
                        return True

                    if self.ha_role is not None:
                        return True

                    if self.issu_role is not None:
                        return True

                    if self.logging_bd_enabled is not None:
                        return True

                    if self.logging_df_election_enabled is not None:
                        return True

                    if self.logging_nsr_enabled is not None:
                        return True

                    if self.logging_pw_enabled is not None:
                        return True

                    if self.logging_vfi_enabled is not None:
                        return True

                    if self.process_fsm is not None:
                        return True

                    if self.pw_grouping_enabled is not None:
                        return True

                    if self.pw_oam_refresh_transmit_time is not None:
                        return True

                    if self.pw_status_enabled is not None:
                        return True

                    if self.tcn_propagation_enabled is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.GlobalSettings']['meta_info']


            class Pwr(object):
                """
                Pseudowire Routing Table
                
                .. attribute:: summary
                
                	L2VPN Pseudowire Routing Summary
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.summary = L2Vpnv2.Nodes.Node.Pwr.Summary()
                    self.summary.parent = self


                class Summary(object):
                    """
                    L2VPN Pseudowire Routing Summary
                    
                    .. attribute:: bgp_as
                    
                    	BGP AS number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bgp_router_id
                    
                    	BGP Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cfg_global_id
                    
                    	Configured Global ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: cfg_router_id
                    
                    	Configured Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: l2vpn_has_bgp_eod
                    
                    	L2VPN got BGP EOD
                    	**type**\:  bool
                    
                    .. attribute:: rd_auto
                    
                    	Automatic Route Distingtuisher
                    	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto>`
                    
                    .. attribute:: rd_configured
                    
                    	Configured Route Distinguisher
                    	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bgp_as = None
                        self.bgp_router_id = None
                        self.cfg_global_id = None
                        self.cfg_router_id = None
                        self.l2vpn_has_bgp_eod = None
                        self.rd_auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto()
                        self.rd_auto.parent = self
                        self.rd_configured = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured()
                        self.rd_configured.parent = self


                    class RdAuto(object):
                        """
                        Automatic Route Distingtuisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto()
                            self.auto.parent = self
                            self.four_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rd = None
                            self.two_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr()
                            self.v4_addr.parent = self


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto_index = None
                                self.router_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto_index is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:rd-auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rd is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdAuto']['meta_info']


                    class RdConfigured(object):
                        """
                        Configured Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto()
                            self.auto.parent = self
                            self.four_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs()
                            self.four_byte_as.parent = self
                            self.rd = None
                            self.two_byte_as = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr()
                            self.v4_addr.parent = self


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto_index = None
                                self.router_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto_index is not None:
                                    return True

                                if self.router_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs']['meta_info']


                        class FourByteAs(object):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_as = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_as is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:rd-configured'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.four_byte_as is not None and self.four_byte_as._has_data():
                                return True

                            if self.rd is not None:
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary.RdConfigured']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bgp_as is not None:
                            return True

                        if self.bgp_router_id is not None:
                            return True

                        if self.cfg_global_id is not None:
                            return True

                        if self.cfg_router_id is not None:
                            return True

                        if self.l2vpn_has_bgp_eod is not None:
                            return True

                        if self.rd_auto is not None and self.rd_auto._has_data():
                            return True

                        if self.rd_configured is not None and self.rd_configured._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr.Summary']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pwr'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.summary is not None and self.summary._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.Pwr']['meta_info']


            class XconnectMp2MpCe2Ces(object):
                """
                XConnect MP2MP CE2CE Table
                
                .. attribute:: xconnect_mp2mp_ce2ce
                
                	XConnect MP2MP CE2CE information
                	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.xconnect_mp2mp_ce2ce = YList()
                    self.xconnect_mp2mp_ce2ce.parent = self
                    self.xconnect_mp2mp_ce2ce.name = 'xconnect_mp2mp_ce2ce'


                class XconnectMp2MpCe2Ce(object):
                    """
                    XConnect MP2MP CE2CE information
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\:  bool
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: local_ceid
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: mp2_mp_name
                    
                    	Mp2Mp Name
                    	**type**\:  str
                    
                    	**length:** 1..26
                    
                    .. attribute:: remote_ceid
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ce_added = None
                        self.group_name = None
                        self.local_ceid = None
                        self.local_customer_edge_id = None
                        self.mp2_mp_name = None
                        self.remote_ceid = None
                        self.remote_customer_edge_id = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ce'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ce_added is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.local_ceid is not None:
                            return True

                        if self.local_customer_edge_id is not None:
                            return True

                        if self.mp2_mp_name is not None:
                            return True

                        if self.remote_ceid is not None:
                            return True

                        if self.remote_customer_edge_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.xconnect_mp2mp_ce2ce is not None:
                        for child_ref in self.xconnect_mp2mp_ce2ce:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2MpCe2Ces']['meta_info']


            class Xconnects(object):
                """
                XConnect Table
                
                .. attribute:: xconnect
                
                	XConnect information
                	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.xconnect = YList()
                    self.xconnect.parent = self
                    self.xconnect.name = 'xconnect'


                class Xconnect(object):
                    """
                    XConnect information
                    
                    .. attribute:: backup
                    
                    	LCR backup
                    	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup>`
                    
                    .. attribute:: backup_segment
                    
                    	Backup Segment
                    	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment>`
                    
                    .. attribute:: ce2ce
                    
                    	CE2CE
                    	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce>`
                    
                    .. attribute:: description
                    
                    	P2P Description
                    	**type**\:  str
                    
                    .. attribute:: diag_mask
                    
                    	Mask indicating what if anything is missing before the XC can be provisioned
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: is_mp2mp
                    
                    	xconnect is mp2mp
                    	**type**\:  bool
                    
                    .. attribute:: number_of_backup_p_ws
                    
                    	Number of backups
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: segment1
                    
                    	Segment 1
                    	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment 2
                    	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2>`
                    
                    .. attribute:: state
                    
                    	State of the xconnect
                    	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                    
                    .. attribute:: xconnect_name
                    
                    	XConnect Name
                    	**type**\:  str
                    
                    	**length:** 1..38
                    
                    .. attribute:: xconnect_name_xr
                    
                    	XConnect name
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.backup = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup()
                        self.backup.parent = self
                        self.backup_segment = YList()
                        self.backup_segment.parent = self
                        self.backup_segment.name = 'backup_segment'
                        self.ce2ce = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce()
                        self.ce2ce.parent = self
                        self.description = None
                        self.diag_mask = None
                        self.group_name = None
                        self.group_name_xr = None
                        self.interworking = None
                        self.is_mp2mp = None
                        self.number_of_backup_p_ws = None
                        self.segment1 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1()
                        self.segment1.parent = self
                        self.segment2 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2()
                        self.segment2.parent = self
                        self.state = None
                        self.xconnect_name = None
                        self.xconnect_name_xr = None


                    class Backup(object):
                        """
                        LCR backup
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire()
                            self.pseudo_wire.parent = self
                            self.segment_type = None


                        class AttachmentCircuit(object):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit']['meta_info']


                        class PseudoWire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                                return True

                            if self.segment_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Backup']['meta_info']


                    class Segment1(object):
                        """
                        Segment 1
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire()
                            self.pseudo_wire.parent = self
                            self.segment_type = None


                        class AttachmentCircuit(object):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit']['meta_info']


                        class PseudoWire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                                return True

                            if self.segment_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1']['meta_info']


                    class Segment2(object):
                        """
                        Segment 2
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire()
                            self.pseudo_wire.parent = self
                            self.segment_type = None


                        class AttachmentCircuit(object):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit']['meta_info']


                        class PseudoWire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:segment2'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                                return True

                            if self.segment_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2']['meta_info']


                    class Ce2Ce(object):
                        """
                        CE2CE
                        
                        .. attribute:: ce_added
                        
                        	CE2CE Advertised
                        	**type**\:  bool
                        
                        .. attribute:: local_customer_edge_id
                        
                        	Local CE ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: remote_customer_edge_id
                        
                        	Remote CE ID
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ce_added = None
                            self.local_customer_edge_id = None
                            self.remote_customer_edge_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ce2ce'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ce_added is not None:
                                return True

                            if self.local_customer_edge_id is not None:
                                return True

                            if self.remote_customer_edge_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2Ce']['meta_info']


                    class BackupSegment(object):
                        """
                        Backup Segment
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.attachment_circuit = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self.pseudo_wire = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire()
                            self.pseudo_wire.parent = self
                            self.segment_type = None


                        class AttachmentCircuit(object):
                            """
                            Attachment Circuit
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\:  bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\:  bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\:  str
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\:  bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\:  str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\:  bool
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\:  str
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\:  str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_error = None
                                self.encapsulation_mismatched = None
                                self.evpn_internal_label = None
                                self.interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self.interface_handle = None
                                self.internal_ms_ti = None
                                self.interworking = None
                                self.is_ac_partially_programmed = None
                                self.l2vpn_protection = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                                self.l2vpn_protection.parent = self
                                self.mac_limit_oper_down = None
                                self.ms_ti_mismatch = None
                                self.msti = None
                                self.msti_mismatch_down = None
                                self.mtu_mismatched = None
                                self.node_id = None
                                self.out_of_memory_state = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self.tdm_media_mismatched = None
                                self.xconnect_id = None


                            class Interface(object):
                                """
                                Interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface_(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics']['meta_info']


                            class L2VpnProtection(object):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\:  bool
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\:  str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.active = None
                                    self.protected_name = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protection_type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.active is not None:
                                        return True

                                    if self.protected_name is not None:
                                        return True

                                    if self.protection_configured is not None:
                                        return True

                                    if self.protection_name is not None:
                                        return True

                                    if self.protection_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bvi_mac_conflict is not None:
                                    return True

                                if self.bvi_no_port_up is not None:
                                    return True

                                if self.control_word_mismatched is not None:
                                    return True

                                if self.encapsulation_error is not None:
                                    return True

                                if self.encapsulation_mismatched is not None:
                                    return True

                                if self.evpn_internal_label is not None:
                                    return True

                                if self.interface is not None and self.interface._has_data():
                                    return True

                                if self.interface_handle is not None:
                                    return True

                                if self.internal_ms_ti is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.is_ac_partially_programmed is not None:
                                    return True

                                if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.ms_ti_mismatch is not None:
                                    return True

                                if self.msti is not None:
                                    return True

                                if self.msti_mismatch_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.node_id is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.redundancy_group_id is not None:
                                    return True

                                if self.redundancy_group_state is not None:
                                    return True

                                if self.redundancy_object_id is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.tdm_media_mismatched is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit']['meta_info']


                        class PseudoWire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:backup-segment'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                return True

                            if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                                return True

                            if self.segment_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.backup is not None and self.backup._has_data():
                            return True

                        if self.backup_segment is not None:
                            for child_ref in self.backup_segment:
                                if child_ref._has_data():
                                    return True

                        if self.ce2ce is not None and self.ce2ce._has_data():
                            return True

                        if self.description is not None:
                            return True

                        if self.diag_mask is not None:
                            return True

                        if self.group_name is not None:
                            return True

                        if self.group_name_xr is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.is_mp2mp is not None:
                            return True

                        if self.number_of_backup_p_ws is not None:
                            return True

                        if self.segment1 is not None and self.segment1._has_data():
                            return True

                        if self.segment2 is not None and self.segment2._has_data():
                            return True

                        if self.state is not None:
                            return True

                        if self.xconnect_name is not None:
                            return True

                        if self.xconnect_name_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects.Xconnect']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnects'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.xconnect is not None:
                        for child_ref in self.xconnect:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.Xconnects']['meta_info']


            class XconnectGroups(object):
                """
                XConnect group Table
                
                .. attribute:: xconnect_group
                
                	XConnect group information
                	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.xconnect_group = YList()
                    self.xconnect_group.parent = self
                    self.xconnect_group.name = 'xconnect_group'


                class XconnectGroup(object):
                    """
                    XConnect group information
                    
                    .. attribute:: group_name  <key>
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: number_xconnects
                    
                    	Number of xconnects
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_name = None
                        self.group_name_xr = None
                        self.number_xconnects = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.group_name is None:
                            raise YPYModelError('Key property group_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-group[Cisco-IOS-XR-l2vpn-oper:group-name = ' + str(self.group_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_name is not None:
                            return True

                        if self.group_name_xr is not None:
                            return True

                        if self.number_xconnects is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectGroups.XconnectGroup']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-groups'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.xconnect_group is not None:
                        for child_ref in self.xconnect_group:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectGroups']['meta_info']


            class XconnectMp2Mps(object):
                """
                XConnect MP2MP Table
                
                .. attribute:: xconnect_mp2mp
                
                	XConnect MP2MP information
                	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.xconnect_mp2mp = YList()
                    self.xconnect_mp2mp.parent = self
                    self.xconnect_mp2mp.name = 'xconnect_mp2mp'


                class XconnectMp2Mp(object):
                    """
                    XConnect MP2MP information
                    
                    .. attribute:: discovery
                    
                    	l2vpn xc auto discovery info
                    	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\:  str
                    
                    .. attribute:: l2_encapsulation
                    
                    	L2 Encapsulation
                    	**type**\:   :py:class:`L2VpnBagAdEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncapEnum>`
                    
                    .. attribute:: mp2_mp_name
                    
                    	Mp2Mp Name
                    	**type**\:  str
                    
                    	**length:** 1..26
                    
                    .. attribute:: mp2mp_name
                    
                    	MP2MP name
                    	**type**\:  str
                    
                    .. attribute:: mp2mpid
                    
                    	Identification Number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_id
                    
                    	Vpn ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_mtu
                    
                    	VPN MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_shutdown
                    
                    	Administratively disabled
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.discovery = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                        self.discovery.parent = self
                        self.group_name = None
                        self.group_name_xr = None
                        self.l2_encapsulation = None
                        self.mp2_mp_name = None
                        self.mp2mp_name = None
                        self.mp2mpid = None
                        self.vpn_id = None
                        self.vpn_mtu = None
                        self.xconnect_shutdown = None


                    class Discovery(object):
                        """
                        l2vpn xc auto discovery info
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery Method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_service_connected
                        
                        	Service Connected
                        	**type**\:  bool
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling Protocol
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ce_range
                        
                        	CE Range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\:  str
                        
                        .. attribute:: export_rt
                        
                        	Export Route Targets
                        	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                        
                        .. attribute:: import_rt
                        
                        	Import Route Targets
                        	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                        
                        .. attribute:: number_a_cs
                        
                        	Number of attachment circuits
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs_up
                        
                        	Number of attachment circuits up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ce2c_es
                        
                        	Number of ce2ce
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ce2ce_advertised
                        
                        	Number of ce2ce Advertised
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_p_ws_up
                        
                        	Number of pseudowires up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                        
                        .. attribute:: vpn_added
                        
                        	VPN Added
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_service_connected = None
                            self.ad_signalling_method = None
                            self.ce_range = None
                            self.export_route_policy = None
                            self.export_rt = YList()
                            self.export_rt.parent = self
                            self.export_rt.name = 'export_rt'
                            self.import_rt = YList()
                            self.import_rt.parent = self
                            self.import_rt.name = 'import_rt'
                            self.number_a_cs = None
                            self.number_a_cs_up = None
                            self.number_ce2c_es = None
                            self.number_ce2ce_advertised = None
                            self.number_p_ws_up = None
                            self.number_pseudowires = None
                            self.rd_value = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                            self.rd_value.parent = self
                            self.vpn_added = None


                        class RdValue(object):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                                self.auto.parent = self
                                self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rd = None
                                self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                                self.v4_addr.parent = self


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto_index = None
                                    self.router_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto_index is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:rd-value'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rd is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue']['meta_info']


                        class ImportRt(object):
                            """
                            Import Route Targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.es_import = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                                self.es_import.parent = self
                                self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rt = None
                                self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                                self.v4_addr.parent = self


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr']['meta_info']


                            class EsImport(object):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.high_bytes = None
                                    self.low_bytes = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:es-import'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.high_bytes is not None:
                                        return True

                                    if self.low_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:import-rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.es_import is not None and self.es_import._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rt is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt']['meta_info']


                        class ExportRt(object):
                            """
                            Export Route Targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.es_import = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                                self.es_import.parent = self
                                self.four_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rt = None
                                self.two_byte_as = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                                self.v4_addr.parent = self


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr']['meta_info']


                            class EsImport(object):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.high_bytes = None
                                    self.low_bytes = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:es-import'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.high_bytes is not None:
                                        return True

                                    if self.low_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:export-rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.es_import is not None and self.es_import._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rt is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:discovery'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_service_connected is not None:
                                return True

                            if self.ad_signalling_method is not None:
                                return True

                            if self.ce_range is not None:
                                return True

                            if self.export_route_policy is not None:
                                return True

                            if self.export_rt is not None:
                                for child_ref in self.export_rt:
                                    if child_ref._has_data():
                                        return True

                            if self.import_rt is not None:
                                for child_ref in self.import_rt:
                                    if child_ref._has_data():
                                        return True

                            if self.number_a_cs is not None:
                                return True

                            if self.number_a_cs_up is not None:
                                return True

                            if self.number_ce2c_es is not None:
                                return True

                            if self.number_ce2ce_advertised is not None:
                                return True

                            if self.number_p_ws_up is not None:
                                return True

                            if self.number_pseudowires is not None:
                                return True

                            if self.rd_value is not None and self.rd_value._has_data():
                                return True

                            if self.vpn_added is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp.Discovery']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.discovery is not None and self.discovery._has_data():
                            return True

                        if self.group_name is not None:
                            return True

                        if self.group_name_xr is not None:
                            return True

                        if self.l2_encapsulation is not None:
                            return True

                        if self.mp2_mp_name is not None:
                            return True

                        if self.mp2mp_name is not None:
                            return True

                        if self.mp2mpid is not None:
                            return True

                        if self.vpn_id is not None:
                            return True

                        if self.vpn_mtu is not None:
                            return True

                        if self.xconnect_shutdown is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps.XconnectMp2Mp']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.xconnect_mp2mp is not None:
                        for child_ref in self.xconnect_mp2mp:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectMp2Mps']['meta_info']


            class Indexes(object):
                """
                ID Manager Index Table
                
                .. attribute:: index
                
                	ID Manager Index Pool
                	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Indexes.Index>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.index = YList()
                    self.index.parent = self
                    self.index.name = 'index'


                class Index(object):
                    """
                    ID Manager Index Pool
                    
                    .. attribute:: pool_id  <key>
                    
                    	Pool ID
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: allocated_ids
                    
                    	Number of IDs allocated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: application_type
                    
                    	Application Type
                    	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                    
                    .. attribute:: max_num_id_mgr
                    
                    	Maximum number of pool extensions
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_id_mgr_in_use
                    
                    	ID mgr instances in use
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pool_id_xr
                    
                    	Pool Id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pool_size
                    
                    	Pool size
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: zombied_ids
                    
                    	Number of IDs allocated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.pool_id = None
                        self.allocated_ids = None
                        self.application_type = None
                        self.max_num_id_mgr = None
                        self.num_id_mgr_in_use = None
                        self.pool_id_xr = None
                        self.pool_size = None
                        self.zombied_ids = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.pool_id is None:
                            raise YPYModelError('Key property pool_id is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:index[Cisco-IOS-XR-l2vpn-oper:pool-id = ' + str(self.pool_id) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.pool_id is not None:
                            return True

                        if self.allocated_ids is not None:
                            return True

                        if self.application_type is not None:
                            return True

                        if self.max_num_id_mgr is not None:
                            return True

                        if self.num_id_mgr_in_use is not None:
                            return True

                        if self.pool_id_xr is not None:
                            return True

                        if self.pool_size is not None:
                            return True

                        if self.zombied_ids is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Indexes.Index']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:indexes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.index is not None:
                        for child_ref in self.index:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.Indexes']['meta_info']


            class XconnectSummary(object):
                """
                XConnect summary information
                
                .. attribute:: admin_down_backup_interface_xconnects
                
                	Number of XCs with backup interface in admin down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: admin_down_backup_xconnects
                
                	Number of XCs with backup PW in admin down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: down_backup_interface_xconnects
                
                	Number of XCs with backup interface in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: down_backup_xconnects
                
                	Number of XCs with backup PW in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2_ceconnections
                
                	Number of Ce2Ce connections
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_advertized
                
                	Number of CE2CE connections that have been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_not_advertized
                
                	Number of CE2CE connections that have not been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_groups
                
                	Number of groups
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects
                
                	Number of mp2mp xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_advertised
                
                	Number of Mp2mp XCs that have been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_down
                
                	Number of Mp2mp XCs that have ben admined down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_up
                
                	Number of Mp2mp XCs that have been admined up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnectss_not_advertised
                
                	Number of Mp2mp XCs that have not been advertized
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_administratively_down
                
                	Number of xconnects with segments in admin down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_currently_using_backup
                
                	Number of XCs currently using backup PW (UP state)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_currently_using_backup_interface
                
                	Number of XCs currently using backup interface (UP state)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_down
                
                	Number of xconnects whose state is down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_locally_switched
                
                	Number of locally switched xconnects
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
                
                	Number of xconnects of type attachment circuit to pseudowire
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
                
                	Number of xconnects of type monitor session to pseudowire
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
                
                	Number of xconnects of type PseudoWire To PseudoWire
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_unresolved
                
                	Number of xconnects whose state is unresolved
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_up
                
                	Numxber of xconnects whose state is up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_with_backup_interface
                
                	Number of XCs configured with backup interface
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_with_backup_pw
                
                	Number of XCs configured with backup PW
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_xconnects
                
                	Number of cross\-connects partially programmed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_backup_interface_xconnects
                
                	Number of XCs with backup interface in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_backup_xconnects
                
                	Number of XCs with backup PW in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_ready_backup_xconnects
                
                	Number of XCs with backup PW in standby ready state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_backup_interface_xconnects
                
                	Number of XCs with backup interface in unresolved state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_backup_xconnects
                
                	Number of XCs with backup PW in unresolved state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.admin_down_backup_interface_xconnects = None
                    self.admin_down_backup_xconnects = None
                    self.down_backup_interface_xconnects = None
                    self.down_backup_xconnects = None
                    self.number_ce2_ceconnections = None
                    self.number_ce2ce_advertized = None
                    self.number_ce2ce_not_advertized = None
                    self.number_groups = None
                    self.number_mp2mp_xconnects = None
                    self.number_mp2mp_xconnects_advertised = None
                    self.number_mp2mp_xconnects_down = None
                    self.number_mp2mp_xconnects_up = None
                    self.number_mp2mp_xconnectss_not_advertised = None
                    self.number_xconnects = None
                    self.number_xconnects_administratively_down = None
                    self.number_xconnects_currently_using_backup = None
                    self.number_xconnects_currently_using_backup_interface = None
                    self.number_xconnects_down = None
                    self.number_xconnects_locally_switched = None
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
                    self.number_xconnects_type_monitor_session_to_pseudo_wire = None
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
                    self.number_xconnects_unresolved = None
                    self.number_xconnects_up = None
                    self.number_xconnects_with_backup_interface = None
                    self.number_xconnects_with_backup_pw = None
                    self.out_of_memory_state = None
                    self.partially_programmed_xconnects = None
                    self.standby_backup_interface_xconnects = None
                    self.standby_backup_xconnects = None
                    self.standby_ready_backup_xconnects = None
                    self.unresolved_backup_interface_xconnects = None
                    self.unresolved_backup_xconnects = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.admin_down_backup_interface_xconnects is not None:
                        return True

                    if self.admin_down_backup_xconnects is not None:
                        return True

                    if self.down_backup_interface_xconnects is not None:
                        return True

                    if self.down_backup_xconnects is not None:
                        return True

                    if self.number_ce2_ceconnections is not None:
                        return True

                    if self.number_ce2ce_advertized is not None:
                        return True

                    if self.number_ce2ce_not_advertized is not None:
                        return True

                    if self.number_groups is not None:
                        return True

                    if self.number_mp2mp_xconnects is not None:
                        return True

                    if self.number_mp2mp_xconnects_advertised is not None:
                        return True

                    if self.number_mp2mp_xconnects_down is not None:
                        return True

                    if self.number_mp2mp_xconnects_up is not None:
                        return True

                    if self.number_mp2mp_xconnectss_not_advertised is not None:
                        return True

                    if self.number_xconnects is not None:
                        return True

                    if self.number_xconnects_administratively_down is not None:
                        return True

                    if self.number_xconnects_currently_using_backup is not None:
                        return True

                    if self.number_xconnects_currently_using_backup_interface is not None:
                        return True

                    if self.number_xconnects_down is not None:
                        return True

                    if self.number_xconnects_locally_switched is not None:
                        return True

                    if self.number_xconnects_type_attachment_circuit_to_pseudo_wire is not None:
                        return True

                    if self.number_xconnects_type_monitor_session_to_pseudo_wire is not None:
                        return True

                    if self.number_xconnects_type_pseudo_wire_to_pseudo_wire is not None:
                        return True

                    if self.number_xconnects_unresolved is not None:
                        return True

                    if self.number_xconnects_up is not None:
                        return True

                    if self.number_xconnects_with_backup_interface is not None:
                        return True

                    if self.number_xconnects_with_backup_pw is not None:
                        return True

                    if self.out_of_memory_state is not None:
                        return True

                    if self.partially_programmed_xconnects is not None:
                        return True

                    if self.standby_backup_interface_xconnects is not None:
                        return True

                    if self.standby_backup_xconnects is not None:
                        return True

                    if self.standby_ready_backup_xconnects is not None:
                        return True

                    if self.unresolved_backup_interface_xconnects is not None:
                        return True

                    if self.unresolved_backup_xconnects is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectSummary']['meta_info']


            class ProcFsm(object):
                """
                L2VPN Process FSM information
                
                .. attribute:: event_history
                
                	L2VPN Process event history
                	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.EventHistory>`
                
                .. attribute:: failover_status
                
                	L2VPN failover status
                	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus>`
                
                .. attribute:: issu_status
                
                	L2VPN ISSU Status and timestamp
                	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus>`
                
                .. attribute:: nsr_status
                
                	L2VPN NSR status and timestamp
                	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus>`
                
                .. attribute:: process_role
                
                	Current Process Role
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: process_state
                
                	Current Process State
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: report_card
                
                	L2VPN Collaborator report card
                	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.ReportCard>`
                
                .. attribute:: state_transition_time
                
                	Transition time for all states
                	**type**\:  list of int
                
                	**range:** 0..4294967295
                
                .. attribute:: sw_install_in_progress
                
                	Is s/w install currently in progress?
                	**type**\:  bool
                
                .. attribute:: sync_flags
                
                	Sync complete flags
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: xid_info
                
                	XID information
                	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.XidInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.event_history = YList()
                    self.event_history.parent = self
                    self.event_history.name = 'event_history'
                    self.failover_status = L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus()
                    self.failover_status.parent = self
                    self.issu_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus()
                    self.issu_status.parent = self
                    self.nsr_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus()
                    self.nsr_status.parent = self
                    self.process_role = None
                    self.process_state = None
                    self.report_card = YList()
                    self.report_card.parent = self
                    self.report_card.name = 'report_card'
                    self.state_transition_time = YLeafList()
                    self.state_transition_time.parent = self
                    self.state_transition_time.name = 'state_transition_time'
                    self.sw_install_in_progress = None
                    self.sync_flags = None
                    self.xid_info = YList()
                    self.xid_info.parent = self
                    self.xid_info.name = 'xid_info'


                class FailoverStatus(object):
                    """
                    L2VPN failover status
                    
                    .. attribute:: master_time
                    
                    	Master time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Start time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: triggered_time
                    
                    	Triggered time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.master_time = None
                        self.start_time = None
                        self.triggered_time = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:failover-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.master_time is not None:
                            return True

                        if self.start_time is not None:
                            return True

                        if self.triggered_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.FailoverStatus']['meta_info']


                class NsrStatus(object):
                    """
                    L2VPN NSR status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.idt_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self.role = None


                    class IdtStatus(object):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus']['meta_info']


                    class PreviOusIdtStatus(object):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:nsr-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.idt_status is not None and self.idt_status._has_data():
                            return True

                        if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                            return True

                        if self.role is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.NsrStatus']['meta_info']


                class IssuStatus(object):
                    """
                    L2VPN ISSU Status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.idt_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self.previ_ous_idt_status = L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self.role = None


                    class IdtStatus(object):
                        """
                        IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus']['meta_info']


                    class PreviOusIdtStatus(object):
                        """
                        Previous IDT status
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.declare_time = None
                            self.idt_end_time = None
                            self.idt_start_time = None
                            self.not_ready_reason = None
                            self.sync_status = None
                            self.withdraw_time = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.declare_time is not None:
                                return True

                            if self.idt_end_time is not None:
                                return True

                            if self.idt_start_time is not None:
                                return True

                            if self.not_ready_reason is not None:
                                return True

                            if self.sync_status is not None:
                                return True

                            if self.withdraw_time is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:issu-status'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.idt_status is not None and self.idt_status._has_data():
                            return True

                        if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                            return True

                        if self.role is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.IssuStatus']['meta_info']


                class XidInfo(object):
                    """
                    XID information
                    
                    .. attribute:: app_type
                    
                    	App type
                    	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
                    
                    .. attribute:: sent_ids
                    
                    	Number of XIDs transferred
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.app_type = None
                        self.sent_ids = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xid-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.app_type is not None:
                            return True

                        if self.sent_ids is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.XidInfo']['meta_info']


                class ReportCard(object):
                    """
                    L2VPN Collaborator report card
                    
                    .. attribute:: collaborator_idt_done
                    
                    	Is IDT done for this collaborator
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_is_connected
                    
                    	Is the collaborator connected
                    	**type**\:  bool
                    
                    .. attribute:: collaborator_skipped
                    
                    	Was this collaborator skipped for not connecting in time
                    	**type**\:  bool
                    
                    .. attribute:: connection_change_time
                    
                    	Time when connection state (UP/DOWN) changed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: idt_time
                    
                    	Time when IDT was done
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.collaborator_idt_done = None
                        self.collaborator_is_connected = None
                        self.collaborator_skipped = None
                        self.connection_change_time = None
                        self.idt_time = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:report-card'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.collaborator_idt_done is not None:
                            return True

                        if self.collaborator_is_connected is not None:
                            return True

                        if self.collaborator_skipped is not None:
                            return True

                        if self.connection_change_time is not None:
                            return True

                        if self.idt_time is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.ReportCard']['meta_info']


                class EventHistory(object):
                    """
                    L2VPN Process event history
                    
                    .. attribute:: event_timestamp
                    
                    	Event timestamp
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: new_state
                    
                    	New state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: previous_state
                    
                    	Previous state
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_collaborator
                    
                    	Process collaborator
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: process_event
                    
                    	Process event
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.event_timestamp = None
                        self.new_state = None
                        self.previous_state = None
                        self.process_collaborator = None
                        self.process_event = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:event-history'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.event_timestamp is not None:
                            return True

                        if self.new_state is not None:
                            return True

                        if self.previous_state is not None:
                            return True

                        if self.process_collaborator is not None:
                            return True

                        if self.process_event is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm.EventHistory']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:proc-fsm'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.event_history is not None:
                        for child_ref in self.event_history:
                            if child_ref._has_data():
                                return True

                    if self.failover_status is not None and self.failover_status._has_data():
                        return True

                    if self.issu_status is not None and self.issu_status._has_data():
                        return True

                    if self.nsr_status is not None and self.nsr_status._has_data():
                        return True

                    if self.process_role is not None:
                        return True

                    if self.process_state is not None:
                        return True

                    if self.report_card is not None:
                        for child_ref in self.report_card:
                            if child_ref._has_data():
                                return True

                    if self.state_transition_time is not None:
                        for child in self.state_transition_time:
                            if child is not None:
                                return True

                    if self.sw_install_in_progress is not None:
                        return True

                    if self.sync_flags is not None:
                        return True

                    if self.xid_info is not None:
                        for child_ref in self.xid_info:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.ProcFsm']['meta_info']


            class MstpPorts(object):
                """
                L2VPN MSTP Port Table
                
                .. attribute:: mstp_port
                
                	MSTP Port information
                	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts.MstpPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mstp_port = YList()
                    self.mstp_port.parent = self
                    self.mstp_port.name = 'mstp_port'


                class MstpPort(object):
                    """
                    MSTP Port information
                    
                    .. attribute:: interface  <key>
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: msti_entry
                    
                    	MSTI
                    	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry>`
                    
                    .. attribute:: mstp_interface_handle
                    
                    	Interface handle
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:  bool
                    
                    .. attribute:: reference_count
                    
                    	Reference Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface = None
                        self.interface_name = None
                        self.msti_entry = YList()
                        self.msti_entry.parent = self
                        self.msti_entry.name = 'msti_entry'
                        self.mstp_interface_handle = None
                        self.protected = None
                        self.reference_count = None


                    class MstiEntry(object):
                        """
                        MSTI
                        
                        .. attribute:: ack_count
                        
                        	Ack count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bd_count
                        
                        	BD count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bd_entry
                        
                        	BD entries
                        	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                        
                        .. attribute:: cfg_ms_ti
                        
                        	 Configured MSTi
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flush_count
                        
                        	Flush count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_count
                        
                        	Interface count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_flags
                        
                        	Msti Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_state
                        
                        	Msti State
                        	**type**\:   :py:class:`L2VpnMstiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiStateEnum>`
                        
                        .. attribute:: nack_count
                        
                        	Nack count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rcv_count
                        
                        	Receive count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ack_count = None
                            self.bd_count = None
                            self.bd_entry = YList()
                            self.bd_entry.parent = self
                            self.bd_entry.name = 'bd_entry'
                            self.cfg_ms_ti = None
                            self.flush_count = None
                            self.interface_count = None
                            self.msti_flags = None
                            self.msti_state = None
                            self.nack_count = None
                            self.rcv_count = None


                        class BdEntry(object):
                            """
                            BD entries
                            
                            .. attribute:: bdid
                            
                            	BD ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bdif_count
                            
                            	BD Intf Count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bdid = None
                                self.bdif_count = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bd-entry'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bdid is not None:
                                    return True

                                if self.bdif_count is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:msti-entry'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ack_count is not None:
                                return True

                            if self.bd_count is not None:
                                return True

                            if self.bd_entry is not None:
                                for child_ref in self.bd_entry:
                                    if child_ref._has_data():
                                        return True

                            if self.cfg_ms_ti is not None:
                                return True

                            if self.flush_count is not None:
                                return True

                            if self.interface_count is not None:
                                return True

                            if self.msti_flags is not None:
                                return True

                            if self.msti_state is not None:
                                return True

                            if self.nack_count is not None:
                                return True

                            if self.rcv_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface is None:
                            raise YPYModelError('Key property interface is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mstp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface is not None:
                            return True

                        if self.interface_name is not None:
                            return True

                        if self.msti_entry is not None:
                            for child_ref in self.msti_entry:
                                if child_ref._has_data():
                                    return True

                        if self.mstp_interface_handle is not None:
                            return True

                        if self.protected is not None:
                            return True

                        if self.reference_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.MstpPorts.MstpPort']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mstp-ports'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mstp_port is not None:
                        for child_ref in self.mstp_port:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.MstpPorts']['meta_info']


            class GenericInterfaceListDetails(object):
                """
                L2VPN generic interface list Detail Table
                
                .. attribute:: generic_interface_list_detail
                
                	Generic Interface List detail information
                	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.generic_interface_list_detail = YList()
                    self.generic_interface_list_detail.parent = self
                    self.generic_interface_list_detail.name = 'generic_interface_list_detail'


                class GenericInterfaceListDetail(object):
                    """
                    Generic Interface List detail information
                    
                    .. attribute:: interface_list_name  <key>
                    
                    	Generic Interface List Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                    
                    .. attribute:: is_provisioned
                    
                    	Is Provisioned
                    	**type**\:  bool
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: psedowire_ether_items
                    
                    	Number PW Ether Items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pseudowire_ether_range
                    
                    	PW\-Ether ranges
                    	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                    
                    .. attribute:: pseudowire_iw_items
                    
                    	Number PW IW Items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pseudowire_iw_range
                    
                    	PW\-IW ranges
                    	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                    
                    .. attribute:: summary
                    
                    	Summary information
                    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_list_name = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'
                        self.is_provisioned = None
                        self.items = None
                        self.psedowire_ether_items = None
                        self.pseudowire_ether_range = YList()
                        self.pseudowire_ether_range.parent = self
                        self.pseudowire_ether_range.name = 'pseudowire_ether_range'
                        self.pseudowire_iw_items = None
                        self.pseudowire_iw_range = YList()
                        self.pseudowire_iw_range.parent = self
                        self.pseudowire_iw_range.name = 'pseudowire_iw_range'
                        self.summary = L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                        self.summary.parent = self


                    class Summary(object):
                        """
                        Summary information
                        
                        .. attribute:: interface
                        
                        	Interfaces
                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                        
                        .. attribute:: interface_list_id
                        
                        	Interface internal ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_list_name_xr
                        
                        	Interface\-list name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: items
                        
                        	Number of items
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_interfaces
                        
                        	Number of interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface = YList()
                            self.interface.parent = self
                            self.interface.name = 'interface'
                            self.interface_list_id = None
                            self.interface_list_name_xr = None
                            self.items = None
                            self.number_of_interfaces = None


                        class Interface(object):
                            """
                            Interfaces
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\:  str
                            
                            .. attribute:: is_fib_downloaded
                            
                            	Is interface downloaded to FIB
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_replications
                            
                            	Number of replications failed because unsupported
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pending_replications
                            
                            	Number of pending replications
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.is_fib_downloaded = None
                                self.not_supported_replications = None
                                self.pending_replications = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.is_fib_downloaded is not None:
                                    return True

                                if self.not_supported_replications is not None:
                                    return True

                                if self.pending_replications is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:summary'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface is not None:
                                for child_ref in self.interface:
                                    if child_ref._has_data():
                                        return True

                            if self.interface_list_id is not None:
                                return True

                            if self.interface_list_name_xr is not None:
                                return True

                            if self.items is not None:
                                return True

                            if self.number_of_interfaces is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary']['meta_info']


                    class Interface(object):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_fib_downloaded = None
                            self.not_supported_replications = None
                            self.pending_replications = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_fib_downloaded is not None:
                                return True

                            if self.not_supported_replications is not None:
                                return True

                            if self.pending_replications is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface']['meta_info']


                    class PseudowireEtherRange(object):
                        """
                        PW\-Ether ranges
                        
                        .. attribute:: lower
                        
                        	lower range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: upper
                        
                        	upper range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lower = None
                            self.upper = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lower is not None:
                                return True

                            if self.upper is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange']['meta_info']


                    class PseudowireIwRange(object):
                        """
                        PW\-IW ranges
                        
                        .. attribute:: lower
                        
                        	lower range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: upper
                        
                        	upper range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.lower = None
                            self.upper = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw-range'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.lower is not None:
                                return True

                            if self.upper is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_list_name is None:
                            raise YPYModelError('Key property interface_list_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-detail[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_list_name is not None:
                            return True

                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        if self.is_provisioned is not None:
                            return True

                        if self.items is not None:
                            return True

                        if self.psedowire_ether_items is not None:
                            return True

                        if self.pseudowire_ether_range is not None:
                            for child_ref in self.pseudowire_ether_range:
                                if child_ref._has_data():
                                    return True

                        if self.pseudowire_iw_items is not None:
                            return True

                        if self.pseudowire_iw_range is not None:
                            for child_ref in self.pseudowire_iw_range:
                                if child_ref._has_data():
                                    return True

                        if self.summary is not None and self.summary._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.generic_interface_list_detail is not None:
                        for child_ref in self.generic_interface_list_detail:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaceListDetails']['meta_info']


            class L2VpnResourceState(object):
                """
                L2VPN resource state information
                
                .. attribute:: resource_out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.resource_out_of_memory_state = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-resource-state'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.resource_out_of_memory_state is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.L2VpnResourceState']['meta_info']


            class BridgeDomains(object):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: bridge_domain
                
                	VPLS Bridge Domain Information
                	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_domain = YList()
                    self.bridge_domain.parent = self
                    self.bridge_domain.name = 'bridge_domain'


                class BridgeDomain(object):
                    """
                    VPLS Bridge Domain Information
                    
                    .. attribute:: bridge_access_pws
                    
                    	VPLS Bridge Domain Access Pseudowire Table
                    	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                    
                    .. attribute:: bridge_access_vfi_table
                    
                    	Bridge Domain Access VFI Table
                    	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                    
                    .. attribute:: bridge_acs
                    
                    	VPLS Bridge Domain Attachment Circuit Table
                    	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs>`
                    
                    .. attribute:: bridge_core_vfi_table
                    
                    	Bridge Domain Core VFI Table
                    	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                    
                    .. attribute:: bridge_domain_group_name
                    
                    	Bridge Domain Group Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bridge_domain_info
                    
                    	VPLS Bridge Domain Information
                    	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Domain Name
                    	**type**\:  str
                    
                    	**length:** 1..27
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_access_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws()
                        self.bridge_access_pws.parent = self
                        self.bridge_access_vfi_table = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                        self.bridge_access_vfi_table.parent = self
                        self.bridge_acs = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs()
                        self.bridge_acs.parent = self
                        self.bridge_core_vfi_table = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                        self.bridge_core_vfi_table.parent = self
                        self.bridge_domain_group_name = None
                        self.bridge_domain_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                        self.bridge_domain_info.parent = self
                        self.bridge_domain_name = None


                    class BridgeAccessVfiTable(object):
                        """
                        Bridge Domain Access VFI Table
                        
                        .. attribute:: bridge_pws
                        
                        	Bridge Domain Access/Core Pseudowire Table
                        	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                            self.bridge_pws.parent = self


                        class BridgePws(object):
                            """
                            Bridge Domain Access/Core Pseudowire Table
                            
                            .. attribute:: bridge_pw
                            
                            	VPLS Bridge Domain Pseudowire
                            	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bridge_pw = YList()
                                self.bridge_pw.parent = self
                                self.bridge_pw.name = 'bridge_pw'


                            class BridgePw(object):
                                """
                                VPLS Bridge Domain Pseudowire
                                
                                .. attribute:: is_access
                                
                                	Is Access PW
                                	**type**\:  bool
                                
                                .. attribute:: neighbor
                                
                                	Neighbor IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire
                                	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                                
                                .. attribute:: pseudowire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_type
                                
                                	PW Type
                                	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                                
                                .. attribute:: static_mac
                                
                                	Static MAC addresses
                                	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                                
                                .. attribute:: ve_id_vpls_id_0_3
                                
                                	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vpls_id_4_7
                                
                                	Zero or Last 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_access = None
                                    self.neighbor = None
                                    self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self.pseudowire_id = None
                                    self.pw_type = None
                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.static_mac = YList()
                                    self.static_mac.parent = self
                                    self.static_mac.name = 'static_mac'
                                    self.ve_id_vpls_id_0_3 = None
                                    self.vpls_id_4_7 = None


                                class Pseudowire(object):
                                    """
                                    Pseudowire
                                    
                                    .. attribute:: ad_method
                                    
                                    	Autodiscovery method
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ad_remote_down
                                    
                                    	Auto\-Discovered PW remote state down
                                    	**type**\:  bool
                                    
                                    .. attribute:: admited_bw
                                    
                                    	Admited Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auto_discovery
                                    
                                    	Is autodiscovery
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_active
                                    
                                    	TRUE if backup is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_force_active
                                    
                                    	TRUE if backup is active due to switchover
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_pw
                                    
                                    	TRUE if PW is a backup PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: bitrate_mismatched
                                    
                                    	Bitrate mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: bridge_pw_type_mismatch
                                    
                                    	Oper down because Bridge has mismatched PW Types
                                    	**type**\:  bool
                                    
                                    .. attribute:: cas_mismatched
                                    
                                    	CAS mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: diff_ts_mismatched
                                    
                                    	Differential timestamp mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_delay
                                    
                                    	Backup disable delay
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: disable_never
                                    
                                    	TRUE if backup is not automatically disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_info
                                    
                                    	Encapsulation specific pseudowire information
                                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                    
                                    .. attribute:: evpn_src_acid
                                    
                                    	EVPN VPWS Source AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fe_ctype
                                    
                                    	Pseudowire FEC type
                                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                    
                                    .. attribute:: forward_class
                                    
                                    	Forward Class attribute
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: freq_mismatched
                                    
                                    	Frequency mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: illegal_control_word
                                    
                                    	Illegal control word
                                    	**type**\:  bool
                                    
                                    .. attribute:: imposed_vlan_id
                                    
                                    	Imposed vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interworking
                                    
                                    	Interworking type
                                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                    
                                    .. attribute:: ipv6_local_source_address
                                    
                                    	Local IPv6 Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_evpnvpws_type
                                    
                                    	is EVPN VPWS
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_flow_label_static
                                    
                                    	is flow label static
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_multi_segment_pseudowire
                                    
                                    	Is Multi\-Segment Pseudowire
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_partially_programmed
                                    
                                    	Is Pseudowire partially programmed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pwr_type
                                    
                                    	is Pseudowire\-routed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vfi
                                    
                                    	Is VFI interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_time_status_changed
                                    
                                    	Last time the pseudowire status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_down
                                    
                                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: ldp_label_advertise_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: load_balance
                                    
                                    	Load Balance Type
                                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                    
                                    .. attribute:: local_control_word
                                    
                                    	Local control word
                                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                    
                                    .. attribute:: local_interface
                                    
                                    	Local interface
                                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                    
                                    .. attribute:: local_label_failed
                                    
                                    	Failed to set BGP advertised local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_pseudo_wire_type
                                    
                                    	Local pseudowire type
                                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                    
                                    .. attribute:: local_signalling
                                    
                                    	Local signalling
                                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                    
                                    .. attribute:: local_source_address
                                    
                                    	Local Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mac_limit_oper_down
                                    
                                    	Oper down because MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mtu_mismatched
                                    
                                    	MTU mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: not_supported_qinq
                                    
                                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_ma_cwithdraw_msg_received
                                    
                                    	Num MW messages received over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_ma_cwithdraw_message_sent
                                    
                                    	Num MW messages sent over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_of_memory_state
                                    
                                    	L2VPN Out of memory state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: p2mp_pw
                                    
                                    	P2MP Pseudowire Information
                                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                    
                                    .. attribute:: payload_bytes_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: payload_type_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer
                                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                    
                                    .. attribute:: preferred_path
                                    
                                    	MPLS Preferred Path
                                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                    
                                    .. attribute:: preferred_path_disable_fallback
                                    
                                    	Prefpath fallback enable/disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_peer_id
                                    
                                    	Primary Peer IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary_pseudo_wire_id
                                    
                                    	Primary Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: primary_pw
                                    
                                    	TRUE if PW is a primary PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol
                                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                    
                                    .. attribute:: pseudo_wire_id
                                    
                                    	Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: pseudo_wire_state
                                    
                                    	Pseudowire state
                                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                    
                                    .. attribute:: pseudo_wire_type_mismatched
                                    
                                    	Pseudowire type mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_class_name
                                    
                                    	Pseudowire class name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: pw_flow_label_code17_disabled
                                    
                                    	Disable sending Code 17 TLV
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_flow_label_type
                                    
                                    	Negotiated pseudowire flow label type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                    
                                    .. attribute:: pw_flow_label_type_cfg
                                    
                                    	Configured pseudowire flow label Type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                    
                                    .. attribute:: pw_redundancy_initial_delay
                                    
                                    	Initial delay for redundant PW in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pw_redundancy_one_way
                                    
                                    	Force one\-way PW redundancy behaviour in Redundancy Group
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_status_use
                                    
                                    	PW status in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: pwlsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_control_word
                                    
                                    	Remote control word
                                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                    
                                    .. attribute:: remote_interface
                                    
                                    	Remote interface
                                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                    
                                    .. attribute:: remote_label_failed
                                    
                                    	Failed to set BGP advertised remote label
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_pseudo_wire_type
                                    
                                    	Remote pseudowire type
                                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                    
                                    .. attribute:: remote_signalling
                                    
                                    	Remote signalling
                                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                    
                                    .. attribute:: required_bw
                                    
                                    	Required Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: resync_enabled
                                    
                                    	Resync if packets out of sequence
                                    	**type**\:  bool
                                    
                                    .. attribute:: resync_threshold
                                    
                                    	Number of Packets Out of Seqence to trigger resync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rtp_mismatched
                                    
                                    	RTP mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequencing_type
                                    
                                    	Sequencing Type
                                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown
                                    	**type**\:  bool
                                    
                                    .. attribute:: sig_pkts_mismatched
                                    
                                    	Signalling packets mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: ssrc_mismatched
                                    
                                    	SSRC mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                    
                                    .. attribute:: table_policy_name
                                    
                                    	Table\-policy Name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag_rewrite
                                    
                                    	StaticTagRewrite
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: time_created
                                    
                                    	Time when the pseudowire was created
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_creation
                                    
                                    	Time elapsed since creation
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_changed
                                    
                                    	Time elapsed since status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_down
                                    
                                    	Time elapsed since last status down in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transport_lsp_down
                                    
                                    	Oper down due to Transport LSP down
                                    	**type**\:  bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	XConnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ad_method = None
                                        self.ad_remote_down = None
                                        self.admited_bw = None
                                        self.auto_discovery = None
                                        self.backup_active = None
                                        self.backup_force_active = None
                                        self.backup_pw = None
                                        self.bitrate_mismatched = None
                                        self.bridge_pw_type_mismatch = None
                                        self.cas_mismatched = None
                                        self.diff_ts_mismatched = None
                                        self.disable_delay = None
                                        self.disable_never = None
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self.evpn_src_acid = None
                                        self.fe_ctype = None
                                        self.forward_class = None
                                        self.freq_mismatched = None
                                        self.illegal_control_word = None
                                        self.imposed_vlan_id = None
                                        self.interworking = None
                                        self.ipv6_local_source_address = None
                                        self.is_evpnvpws_type = None
                                        self.is_flow_label_static = None
                                        self.is_multi_segment_pseudowire = None
                                        self.is_partially_programmed = None
                                        self.is_pwr_type = None
                                        self.is_vfi = None
                                        self.last_time_status_changed = None
                                        self.last_time_status_down = None
                                        self.ldp_label_advertise_failed = None
                                        self.load_balance = None
                                        self.local_control_word = None
                                        self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self.local_label_failed = None
                                        self.local_pseudo_wire_type = None
                                        self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self.local_source_address = None
                                        self.mac_limit_oper_down = None
                                        self.mtu_mismatched = None
                                        self.not_supported_qinq = None
                                        self.num_ma_cwithdraw_msg_received = None
                                        self.number_ma_cwithdraw_message_sent = None
                                        self.out_of_memory_state = None
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self.payload_bytes_mismatched = None
                                        self.payload_type_mismatched = None
                                        self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self.preferred_path_disable_fallback = None
                                        self.primary_peer_id = None
                                        self.primary_pseudo_wire_id = None
                                        self.primary_pw = None
                                        self.protocol = None
                                        self.pseudo_wire_id = None
                                        self.pseudo_wire_state = None
                                        self.pseudo_wire_type_mismatched = None
                                        self.pw_class_name = None
                                        self.pw_flow_label_code17_disabled = None
                                        self.pw_flow_label_type = None
                                        self.pw_flow_label_type_cfg = None
                                        self.pw_redundancy_initial_delay = None
                                        self.pw_redundancy_one_way = None
                                        self.pw_status_use = None
                                        self.pwlsd_rewrite_failed = None
                                        self.remote_control_word = None
                                        self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self.remote_label_failed = None
                                        self.remote_pseudo_wire_type = None
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self.required_bw = None
                                        self.resync_enabled = None
                                        self.resync_threshold = None
                                        self.rtp_mismatched = None
                                        self.sequencing_type = None
                                        self.shutdown = None
                                        self.sig_pkts_mismatched = None
                                        self.ssrc_mismatched = None
                                        self.state = None
                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self.table_policy_name = None
                                        self.tag_rewrite = None
                                        self.time_created = None
                                        self.time_elapsed_creation = None
                                        self.time_elapsed_status_changed = None
                                        self.time_elapsed_status_down = None
                                        self.transport_lsp_down = None
                                        self.xconnect_id = None


                                    class PeerId(object):
                                        """
                                        Peer
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ipv4_peer_id
                                        
                                        	Peer IPv4 address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_peer_id
                                        
                                        	Peer IPv6 address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.internal_label = None
                                            self.ipv4_peer_id = None
                                            self.ipv6_peer_id = None
                                            self.type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.internal_label is not None:
                                                return True

                                            if self.ipv4_peer_id is not None:
                                                return True

                                            if self.ipv6_peer_id is not None:
                                                return True

                                            if self.type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                                    class EncapsulationInfo(object):
                                        """
                                        Encapsulation specific pseudowire information
                                        
                                        .. attribute:: atom
                                        
                                        	atom
                                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                        
                                        .. attribute:: encapsulation
                                        
                                        	Encapsulation
                                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                        
                                        .. attribute:: l2tpv3
                                        
                                        	l2tpv3
                                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self.encapsulation = None
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self


                                        class Atom(object):
                                            """
                                            atom
                                            
                                            .. attribute:: is_pseudowire_headend
                                            
                                            	Is this connected to a PW\-HE AC
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_sai_itype2
                                            
                                            	Is SAII FEC129 Type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tai_itype2
                                            
                                            	Is TAII type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: ldp_label_advertisment_failed
                                            
                                            	LDP label advertisment failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_agi
                                            
                                            	Local Attachment Group Identifier
                                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                            
                                            .. attribute:: local_c_ctype
                                            
                                            	Local VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_ceid
                                            
                                            	Local CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cv_type
                                            
                                            	Local VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_group_id
                                            
                                            	Local group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_ldp_id
                                            
                                            	Local LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: local_saii_gbl_id
                                            
                                            	Local SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_saiiac_id
                                            
                                            	Local SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taii_gbl_id
                                            
                                            	Local TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taiiac_id
                                            
                                            	Local TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_veid
                                            
                                            	Local VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsd_rewrite_failed
                                            
                                            	LSD rewrite failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: multi_segment_pseudowire_stats
                                            
                                            	Multisegment pseudowire statistics
                                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                            
                                            .. attribute:: rem_saii
                                            
                                            	Remote Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_saii_gbl_id
                                            
                                            	Remote SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saiiac_id
                                            
                                            	Remote SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taii
                                            
                                            	Remote Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_taii_gbl_id
                                            
                                            	Remote TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taiiac_id
                                            
                                            	Remote TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_agi
                                            
                                            	Remote Attachment Group Identifier
                                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                            
                                            .. attribute:: remote_c_ctype
                                            
                                            	Remote VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_ceid
                                            
                                            	Remote CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cv_type
                                            
                                            	Remote VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_group_id
                                            
                                            	Remote group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_label
                                            
                                            	Remote label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_ldp_id
                                            
                                            	Remote LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_source_address
                                            
                                            	Remote BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_veid
                                            
                                            	Remote VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: saii
                                            
                                            	Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_address
                                            
                                            	Local BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: taii
                                            
                                            	Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_pseudowire_headend = None
                                                self.is_sai_itype2 = None
                                                self.is_tai_itype2 = None
                                                self.ldp_label_advertisment_failed = None
                                                self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self.local_c_ctype = None
                                                self.local_ceid = None
                                                self.local_cv_type = None
                                                self.local_group_id = None
                                                self.local_label = None
                                                self.local_ldp_id = None
                                                self.local_saii_gbl_id = None
                                                self.local_saiiac_id = None
                                                self.local_taii_gbl_id = None
                                                self.local_taiiac_id = None
                                                self.local_veid = None
                                                self.lsd_rewrite_failed = None
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self.rem_saii = None
                                                self.rem_saii_gbl_id = None
                                                self.rem_saiiac_id = None
                                                self.rem_taii = None
                                                self.rem_taii_gbl_id = None
                                                self.rem_taiiac_id = None
                                                self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self.remote_c_ctype = None
                                                self.remote_ceid = None
                                                self.remote_cv_type = None
                                                self.remote_group_id = None
                                                self.remote_label = None
                                                self.remote_ldp_id = None
                                                self.remote_source_address = None
                                                self.remote_veid = None
                                                self.saii = None
                                                self.source_address = None
                                                self.taii = None


                                            class LocalAgi(object):
                                                """
                                                Local Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self.vpls_id_type = None


                                                class Auto(object):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.asn = None
                                                        self.vpn_id = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.asn is not None:
                                                            return True

                                                        if self.vpn_id is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                                class TwoByteAs(object):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.four_byte_index = None
                                                        self.two_byte_as = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.four_byte_index is not None:
                                                            return True

                                                        if self.two_byte_as is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                                class V4Addr(object):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.two_byte_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.auto is not None and self.auto._has_data():
                                                        return True

                                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                        return True

                                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                                        return True

                                                    if self.vpls_id_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                            class RemoteAgi(object):
                                                """
                                                Remote Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self.vpls_id_type = None


                                                class Auto(object):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.asn = None
                                                        self.vpn_id = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.asn is not None:
                                                            return True

                                                        if self.vpn_id is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                                class TwoByteAs(object):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.four_byte_index = None
                                                        self.two_byte_as = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.four_byte_index is not None:
                                                            return True

                                                        if self.two_byte_as is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                                class V4Addr(object):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.two_byte_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.auto is not None and self.auto._has_data():
                                                        return True

                                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                        return True

                                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                                        return True

                                                    if self.vpls_id_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                            class MultiSegmentPseudowireStats(object):
                                                """
                                                Multisegment pseudowire statistics
                                                
                                                .. attribute:: received_bytes
                                                
                                                	Bytes received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: received_packets
                                                
                                                	Packets received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.received_bytes = None
                                                    self.received_packets = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.received_bytes is not None:
                                                        return True

                                                    if self.received_packets is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_pseudowire_headend is not None:
                                                    return True

                                                if self.is_sai_itype2 is not None:
                                                    return True

                                                if self.is_tai_itype2 is not None:
                                                    return True

                                                if self.ldp_label_advertisment_failed is not None:
                                                    return True

                                                if self.local_agi is not None and self.local_agi._has_data():
                                                    return True

                                                if self.local_c_ctype is not None:
                                                    return True

                                                if self.local_ceid is not None:
                                                    return True

                                                if self.local_cv_type is not None:
                                                    return True

                                                if self.local_group_id is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_ldp_id is not None:
                                                    return True

                                                if self.local_saii_gbl_id is not None:
                                                    return True

                                                if self.local_saiiac_id is not None:
                                                    return True

                                                if self.local_taii_gbl_id is not None:
                                                    return True

                                                if self.local_taiiac_id is not None:
                                                    return True

                                                if self.local_veid is not None:
                                                    return True

                                                if self.lsd_rewrite_failed is not None:
                                                    return True

                                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                    return True

                                                if self.rem_saii is not None:
                                                    return True

                                                if self.rem_saii_gbl_id is not None:
                                                    return True

                                                if self.rem_saiiac_id is not None:
                                                    return True

                                                if self.rem_taii is not None:
                                                    return True

                                                if self.rem_taii_gbl_id is not None:
                                                    return True

                                                if self.rem_taiiac_id is not None:
                                                    return True

                                                if self.remote_agi is not None and self.remote_agi._has_data():
                                                    return True

                                                if self.remote_c_ctype is not None:
                                                    return True

                                                if self.remote_ceid is not None:
                                                    return True

                                                if self.remote_cv_type is not None:
                                                    return True

                                                if self.remote_group_id is not None:
                                                    return True

                                                if self.remote_label is not None:
                                                    return True

                                                if self.remote_ldp_id is not None:
                                                    return True

                                                if self.remote_source_address is not None:
                                                    return True

                                                if self.remote_veid is not None:
                                                    return True

                                                if self.saii is not None:
                                                    return True

                                                if self.source_address is not None:
                                                    return True

                                                if self.taii is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                        class L2Tpv3(object):
                                            """
                                            l2tpv3
                                            
                                            .. attribute:: dont_fragment_bit
                                            
                                            	Don't Fragment Bit
                                            	**type**\:  bool
                                            
                                            .. attribute:: ipv4_source_address
                                            
                                            	IPv4 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_source_address
                                            
                                            	IPv6 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tp_class_name
                                            
                                            	L2TPClassName
                                            	**type**\:  str
                                            
                                            	**length:** 0..32
                                            
                                            .. attribute:: local_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_size
                                            
                                            	Local cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_secondary_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_size
                                            
                                            	Local secondary cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_session_id
                                            
                                            	Local session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_mtu_enabled
                                            
                                            	Path MTU enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_mtu_max_value
                                            
                                            	Path MTU Maximum allowable session MTU
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: remote_circuit_status_up
                                            
                                            	RemoteCircuitStatusUp
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_size
                                            
                                            	Remote cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_session_id
                                            
                                            	Remote session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tos
                                            
                                            	Type Of Service Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tos_mode
                                            
                                            	Type Of Service Mode
                                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                            
                                            .. attribute:: ttl
                                            
                                            	Time To Live value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tunnel_state
                                            
                                            	L2TP tunnel state
                                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dont_fragment_bit = None
                                                self.ipv4_source_address = None
                                                self.ipv6_source_address = None
                                                self.l2tp_class_name = None
                                                self.local_cookie_high_value = None
                                                self.local_cookie_low_value = None
                                                self.local_cookie_size = None
                                                self.local_secondary_cookie_high_value = None
                                                self.local_secondary_cookie_low_value = None
                                                self.local_secondary_cookie_size = None
                                                self.local_session_id = None
                                                self.path_mtu_enabled = None
                                                self.path_mtu_max_value = None
                                                self.remote_circuit_status_up = None
                                                self.remote_cookie_high_value = None
                                                self.remote_cookie_low_value = None
                                                self.remote_cookie_size = None
                                                self.remote_session_id = None
                                                self.tos = None
                                                self.tos_mode = None
                                                self.ttl = None
                                                self.tunnel_state = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dont_fragment_bit is not None:
                                                    return True

                                                if self.ipv4_source_address is not None:
                                                    return True

                                                if self.ipv6_source_address is not None:
                                                    return True

                                                if self.l2tp_class_name is not None:
                                                    return True

                                                if self.local_cookie_high_value is not None:
                                                    return True

                                                if self.local_cookie_low_value is not None:
                                                    return True

                                                if self.local_cookie_size is not None:
                                                    return True

                                                if self.local_secondary_cookie_high_value is not None:
                                                    return True

                                                if self.local_secondary_cookie_low_value is not None:
                                                    return True

                                                if self.local_secondary_cookie_size is not None:
                                                    return True

                                                if self.local_session_id is not None:
                                                    return True

                                                if self.path_mtu_enabled is not None:
                                                    return True

                                                if self.path_mtu_max_value is not None:
                                                    return True

                                                if self.remote_circuit_status_up is not None:
                                                    return True

                                                if self.remote_cookie_high_value is not None:
                                                    return True

                                                if self.remote_cookie_low_value is not None:
                                                    return True

                                                if self.remote_cookie_size is not None:
                                                    return True

                                                if self.remote_session_id is not None:
                                                    return True

                                                if self.tos is not None:
                                                    return True

                                                if self.tos_mode is not None:
                                                    return True

                                                if self.ttl is not None:
                                                    return True

                                                if self.tunnel_state is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atom is not None and self.atom._has_data():
                                                return True

                                            if self.encapsulation is not None:
                                                return True

                                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                                    class LocalInterface(object):
                                        """
                                        Local interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.mtu = None
                                            self.name = None
                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self.payload_bytes = None


                                        class Parameters(object):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self.type = None
                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self


                                            class Ethernet(object):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.xconnect_tags = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                            class Vlan(object):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None
                                                    self.rewrite_tag = YLeafList()
                                                    self.rewrite_tag.parent = self
                                                    self.rewrite_tag.name = 'rewrite_tag'
                                                    self.simple_efp = None
                                                    self.vlan_range = YList()
                                                    self.vlan_range.parent = self
                                                    self.vlan_range.name = 'vlan_range'
                                                    self.vlan_rewrite_tag = None
                                                    self.xconnect_tags = None


                                                class VlanRange(object):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.lower = None
                                                        self.upper = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.lower is not None:
                                                            return True

                                                        if self.upper is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.encapsulation_type is not None:
                                                        return True

                                                    if self.outer_tag is not None:
                                                        return True

                                                    if self.rewrite_tag is not None:
                                                        for child in self.rewrite_tag:
                                                            if child is not None:
                                                                return True

                                                    if self.simple_efp is not None:
                                                        return True

                                                    if self.vlan_range is not None:
                                                        for child_ref in self.vlan_range:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.vlan_rewrite_tag is not None:
                                                        return True

                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                            class Tdm(object):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tdm_mode = None
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None


                                                class TdmOptions(object):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.bit_rate = None
                                                        self.cas = None
                                                        self.payload_bytes = None
                                                        self.rtp = None
                                                        self.rtp_header_payload_type = None
                                                        self.signalling_packets = None
                                                        self.ssrc = None
                                                        self.timestamp_clock_freq = None
                                                        self.timestamp_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.bit_rate is not None:
                                                            return True

                                                        if self.cas is not None:
                                                            return True

                                                        if self.payload_bytes is not None:
                                                            return True

                                                        if self.rtp is not None:
                                                            return True

                                                        if self.rtp_header_payload_type is not None:
                                                            return True

                                                        if self.signalling_packets is not None:
                                                            return True

                                                        if self.ssrc is not None:
                                                            return True

                                                        if self.timestamp_clock_freq is not None:
                                                            return True

                                                        if self.timestamp_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tdm_mode is not None:
                                                        return True

                                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                                        return True

                                                    if self.timeslot_group is not None:
                                                        return True

                                                    if self.timeslot_rate is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                            class Atm(object):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.atm_mode = None
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.vci = None
                                                    self.vpi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.atm_mode is not None:
                                                        return True

                                                    if self.maximum_number_cells_packed is not None:
                                                        return True

                                                    if self.maximum_number_cells_un_packed is not None:
                                                        return True

                                                    if self.vci is not None:
                                                        return True

                                                    if self.vpi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                            class Fr(object):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.dlci = None
                                                    self.fr_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.dlci is not None:
                                                        return True

                                                    if self.fr_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                            class PseudowireEther(object):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                            class PseudowireIw(object):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm is not None and self.atm._has_data():
                                                    return True

                                                if self.ethernet is not None and self.ethernet._has_data():
                                                    return True

                                                if self.fr is not None and self.fr._has_data():
                                                    return True

                                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                    return True

                                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                    return True

                                                if self.tdm is not None and self.tdm._has_data():
                                                    return True

                                                if self.type is not None:
                                                    return True

                                                if self.vlan is not None and self.vlan._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.mtu is not None:
                                                return True

                                            if self.name is not None:
                                                return True

                                            if self.parameters is not None and self.parameters._has_data():
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                                    class RemoteInterface(object):
                                        """
                                        Remote interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.mtu = None
                                            self.name = None
                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self.payload_bytes = None


                                        class Parameters(object):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self.type = None
                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self


                                            class Ethernet(object):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.xconnect_tags = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                            class Vlan(object):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None
                                                    self.rewrite_tag = YLeafList()
                                                    self.rewrite_tag.parent = self
                                                    self.rewrite_tag.name = 'rewrite_tag'
                                                    self.simple_efp = None
                                                    self.vlan_range = YList()
                                                    self.vlan_range.parent = self
                                                    self.vlan_range.name = 'vlan_range'
                                                    self.vlan_rewrite_tag = None
                                                    self.xconnect_tags = None


                                                class VlanRange(object):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.lower = None
                                                        self.upper = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.lower is not None:
                                                            return True

                                                        if self.upper is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.encapsulation_type is not None:
                                                        return True

                                                    if self.outer_tag is not None:
                                                        return True

                                                    if self.rewrite_tag is not None:
                                                        for child in self.rewrite_tag:
                                                            if child is not None:
                                                                return True

                                                    if self.simple_efp is not None:
                                                        return True

                                                    if self.vlan_range is not None:
                                                        for child_ref in self.vlan_range:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.vlan_rewrite_tag is not None:
                                                        return True

                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                            class Tdm(object):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tdm_mode = None
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None


                                                class TdmOptions(object):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.bit_rate = None
                                                        self.cas = None
                                                        self.payload_bytes = None
                                                        self.rtp = None
                                                        self.rtp_header_payload_type = None
                                                        self.signalling_packets = None
                                                        self.ssrc = None
                                                        self.timestamp_clock_freq = None
                                                        self.timestamp_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.bit_rate is not None:
                                                            return True

                                                        if self.cas is not None:
                                                            return True

                                                        if self.payload_bytes is not None:
                                                            return True

                                                        if self.rtp is not None:
                                                            return True

                                                        if self.rtp_header_payload_type is not None:
                                                            return True

                                                        if self.signalling_packets is not None:
                                                            return True

                                                        if self.ssrc is not None:
                                                            return True

                                                        if self.timestamp_clock_freq is not None:
                                                            return True

                                                        if self.timestamp_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tdm_mode is not None:
                                                        return True

                                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                                        return True

                                                    if self.timeslot_group is not None:
                                                        return True

                                                    if self.timeslot_rate is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                            class Atm(object):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.atm_mode = None
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.vci = None
                                                    self.vpi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.atm_mode is not None:
                                                        return True

                                                    if self.maximum_number_cells_packed is not None:
                                                        return True

                                                    if self.maximum_number_cells_un_packed is not None:
                                                        return True

                                                    if self.vci is not None:
                                                        return True

                                                    if self.vpi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                            class Fr(object):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.dlci = None
                                                    self.fr_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.dlci is not None:
                                                        return True

                                                    if self.fr_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                            class PseudowireEther(object):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                            class PseudowireIw(object):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm is not None and self.atm._has_data():
                                                    return True

                                                if self.ethernet is not None and self.ethernet._has_data():
                                                    return True

                                                if self.fr is not None and self.fr._has_data():
                                                    return True

                                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                    return True

                                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                    return True

                                                if self.tdm is not None and self.tdm._has_data():
                                                    return True

                                                if self.type is not None:
                                                    return True

                                                if self.vlan is not None and self.vlan._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.mtu is not None:
                                                return True

                                            if self.name is not None:
                                                return True

                                            if self.parameters is not None and self.parameters._has_data():
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                                    class PreferredPath(object):
                                        """
                                        MPLS Preferred Path
                                        
                                        .. attribute:: ip_tunnel_interface_number
                                        
                                        	IPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	NextHopIP
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: option
                                        
                                        	Option
                                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                        
                                        .. attribute:: te_tunnel_interface_number
                                        
                                        	TETunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tp_tunnel_interface_number
                                        
                                        	TPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ip_tunnel_interface_number = None
                                            self.next_hop_ip = None
                                            self.option = None
                                            self.te_tunnel_interface_number = None
                                            self.tp_tunnel_interface_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ip_tunnel_interface_number is not None:
                                                return True

                                            if self.next_hop_ip is not None:
                                                return True

                                            if self.option is not None:
                                                return True

                                            if self.te_tunnel_interface_number is not None:
                                                return True

                                            if self.tp_tunnel_interface_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                                    class LocalSignalling(object):
                                        """
                                        Local signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.pw_status = None
                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self.tlv = YList()
                                            self.tlv.parent = self
                                            self.tlv.name = 'tlv'


                                        class StatusTlv(object):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                        class Tlv(object):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.pw_status is not None:
                                                return True

                                            if self.status_tlv is not None and self.status_tlv._has_data():
                                                return True

                                            if self.tlv is not None:
                                                for child_ref in self.tlv:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                                    class RemoteSignalling(object):
                                        """
                                        Remote signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.pw_status = None
                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self.tlv = YList()
                                            self.tlv.parent = self
                                            self.tlv.name = 'tlv'


                                        class StatusTlv(object):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                        class Tlv(object):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.pw_status is not None:
                                                return True

                                            if self.status_tlv is not None and self.status_tlv._has_data():
                                                return True

                                            if self.tlv is not None:
                                                for child_ref in self.tlv:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                                    class Statistics(object):
                                        """
                                        Statistics
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self


                                        class ImpostionStats(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self


                                            class ImpositionStat(object):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                            class ImpositionMtuDrop(object):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                            class ImpostionTailDrop(object):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                            class L2FsbiDrop(object):
                                                """
                                                rx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                            class Multicast(object):
                                                """
                                                Multicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                            class Broadcast(object):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                            class KnownUnicast(object):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                            class UnknownUnicast(object):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast is not None and self.broadcast._has_data():
                                                    return True

                                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                    return True

                                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                    return True

                                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                    return True

                                                if self.known_unicast is not None and self.known_unicast._has_data():
                                                    return True

                                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                    return True

                                                if self.multicast is not None and self.multicast._has_data():
                                                    return True

                                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                        class DispostionStats(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self


                                            class DispositionStat(object):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                            class DispositionMtuDrop(object):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                            class DispositionTailDrop(object):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                            class MulticastDrop(object):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                            class UnicastDrop(object):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                            class BroadcastDrop(object):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                            class ReceivedDrops(object):
                                                """
                                                tx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                            class DaiDrop(object):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                            class IpsgDrop(object):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                            class DispositionOoODrops(object):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                            class DispositionP2MpStats(object):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                            class KnownUnicast(object):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                            class MacMove(object):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                    return True

                                                if self.dai_drop is not None and self.dai_drop._has_data():
                                                    return True

                                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                    return True

                                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                    return True

                                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                    return True

                                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                    return True

                                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                    return True

                                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                    return True

                                                if self.known_unicast is not None and self.known_unicast._has_data():
                                                    return True

                                                if self.mac_move is not None and self.mac_move._has_data():
                                                    return True

                                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                    return True

                                                if self.received_drops is not None and self.received_drops._has_data():
                                                    return True

                                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                        class SequenceNumber(object):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bypassed_inbound_sequence_packet = None
                                                self.bypassed_out_sequence_packet = None
                                                self.sequence_number_expected = None
                                                self.sequence_number_sent = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bypassed_inbound_sequence_packet is not None:
                                                    return True

                                                if self.bypassed_out_sequence_packet is not None:
                                                    return True

                                                if self.sequence_number_expected is not None:
                                                    return True

                                                if self.sequence_number_sent is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                                return True

                                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                                return True

                                            if self.sequence_number is not None and self.sequence_number._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                                    class P2MpPw(object):
                                        """
                                        P2MP Pseudowire Information
                                        
                                        .. attribute:: local_available
                                        
                                        	Local LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_extended_tunnel_id
                                        
                                        	Local Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_flags
                                        
                                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_label
                                        
                                        	Local Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_p2mp_id
                                        
                                        	Local P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ptree_type
                                        
                                        	Local P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                        
                                        .. attribute:: local_tunnel_id
                                        
                                        	Local Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_available
                                        
                                        	Remote LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_extended_tunnel_id
                                        
                                        	Remote Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_flags
                                        
                                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_p2mp_id
                                        
                                        	Remote P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ptree_type
                                        
                                        	Remote P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                        
                                        .. attribute:: remote_tunnel_id
                                        
                                        	Remote Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.local_available = None
                                            self.local_extended_tunnel_id = None
                                            self.local_flags = None
                                            self.local_label = None
                                            self.local_p2mp_id = None
                                            self.local_ptree_type = None
                                            self.local_tunnel_id = None
                                            self.remote_available = None
                                            self.remote_extended_tunnel_id = None
                                            self.remote_flags = None
                                            self.remote_label = None
                                            self.remote_p2mp_id = None
                                            self.remote_ptree_type = None
                                            self.remote_tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.local_available is not None:
                                                return True

                                            if self.local_extended_tunnel_id is not None:
                                                return True

                                            if self.local_flags is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_p2mp_id is not None:
                                                return True

                                            if self.local_ptree_type is not None:
                                                return True

                                            if self.local_tunnel_id is not None:
                                                return True

                                            if self.remote_available is not None:
                                                return True

                                            if self.remote_extended_tunnel_id is not None:
                                                return True

                                            if self.remote_flags is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_p2mp_id is not None:
                                                return True

                                            if self.remote_ptree_type is not None:
                                                return True

                                            if self.remote_tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ad_method is not None:
                                            return True

                                        if self.ad_remote_down is not None:
                                            return True

                                        if self.admited_bw is not None:
                                            return True

                                        if self.auto_discovery is not None:
                                            return True

                                        if self.backup_active is not None:
                                            return True

                                        if self.backup_force_active is not None:
                                            return True

                                        if self.backup_pw is not None:
                                            return True

                                        if self.bitrate_mismatched is not None:
                                            return True

                                        if self.bridge_pw_type_mismatch is not None:
                                            return True

                                        if self.cas_mismatched is not None:
                                            return True

                                        if self.diff_ts_mismatched is not None:
                                            return True

                                        if self.disable_delay is not None:
                                            return True

                                        if self.disable_never is not None:
                                            return True

                                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                            return True

                                        if self.evpn_src_acid is not None:
                                            return True

                                        if self.fe_ctype is not None:
                                            return True

                                        if self.forward_class is not None:
                                            return True

                                        if self.freq_mismatched is not None:
                                            return True

                                        if self.illegal_control_word is not None:
                                            return True

                                        if self.imposed_vlan_id is not None:
                                            return True

                                        if self.interworking is not None:
                                            return True

                                        if self.ipv6_local_source_address is not None:
                                            return True

                                        if self.is_evpnvpws_type is not None:
                                            return True

                                        if self.is_flow_label_static is not None:
                                            return True

                                        if self.is_multi_segment_pseudowire is not None:
                                            return True

                                        if self.is_partially_programmed is not None:
                                            return True

                                        if self.is_pwr_type is not None:
                                            return True

                                        if self.is_vfi is not None:
                                            return True

                                        if self.last_time_status_changed is not None:
                                            return True

                                        if self.last_time_status_down is not None:
                                            return True

                                        if self.ldp_label_advertise_failed is not None:
                                            return True

                                        if self.load_balance is not None:
                                            return True

                                        if self.local_control_word is not None:
                                            return True

                                        if self.local_interface is not None and self.local_interface._has_data():
                                            return True

                                        if self.local_label_failed is not None:
                                            return True

                                        if self.local_pseudo_wire_type is not None:
                                            return True

                                        if self.local_signalling is not None and self.local_signalling._has_data():
                                            return True

                                        if self.local_source_address is not None:
                                            return True

                                        if self.mac_limit_oper_down is not None:
                                            return True

                                        if self.mtu_mismatched is not None:
                                            return True

                                        if self.not_supported_qinq is not None:
                                            return True

                                        if self.num_ma_cwithdraw_msg_received is not None:
                                            return True

                                        if self.number_ma_cwithdraw_message_sent is not None:
                                            return True

                                        if self.out_of_memory_state is not None:
                                            return True

                                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                            return True

                                        if self.payload_bytes_mismatched is not None:
                                            return True

                                        if self.payload_type_mismatched is not None:
                                            return True

                                        if self.peer_id is not None and self.peer_id._has_data():
                                            return True

                                        if self.preferred_path is not None and self.preferred_path._has_data():
                                            return True

                                        if self.preferred_path_disable_fallback is not None:
                                            return True

                                        if self.primary_peer_id is not None:
                                            return True

                                        if self.primary_pseudo_wire_id is not None:
                                            return True

                                        if self.primary_pw is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pseudo_wire_id is not None:
                                            return True

                                        if self.pseudo_wire_state is not None:
                                            return True

                                        if self.pseudo_wire_type_mismatched is not None:
                                            return True

                                        if self.pw_class_name is not None:
                                            return True

                                        if self.pw_flow_label_code17_disabled is not None:
                                            return True

                                        if self.pw_flow_label_type is not None:
                                            return True

                                        if self.pw_flow_label_type_cfg is not None:
                                            return True

                                        if self.pw_redundancy_initial_delay is not None:
                                            return True

                                        if self.pw_redundancy_one_way is not None:
                                            return True

                                        if self.pw_status_use is not None:
                                            return True

                                        if self.pwlsd_rewrite_failed is not None:
                                            return True

                                        if self.remote_control_word is not None:
                                            return True

                                        if self.remote_interface is not None and self.remote_interface._has_data():
                                            return True

                                        if self.remote_label_failed is not None:
                                            return True

                                        if self.remote_pseudo_wire_type is not None:
                                            return True

                                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                                            return True

                                        if self.required_bw is not None:
                                            return True

                                        if self.resync_enabled is not None:
                                            return True

                                        if self.resync_threshold is not None:
                                            return True

                                        if self.rtp_mismatched is not None:
                                            return True

                                        if self.sequencing_type is not None:
                                            return True

                                        if self.shutdown is not None:
                                            return True

                                        if self.sig_pkts_mismatched is not None:
                                            return True

                                        if self.ssrc_mismatched is not None:
                                            return True

                                        if self.state is not None:
                                            return True

                                        if self.statistics is not None and self.statistics._has_data():
                                            return True

                                        if self.table_policy_name is not None:
                                            return True

                                        if self.tag_rewrite is not None:
                                            return True

                                        if self.time_created is not None:
                                            return True

                                        if self.time_elapsed_creation is not None:
                                            return True

                                        if self.time_elapsed_status_changed is not None:
                                            return True

                                        if self.time_elapsed_status_down is not None:
                                            return True

                                        if self.transport_lsp_down is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                                class StaticMac(object):
                                    """
                                    Static MAC addresses
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address is not None:
                                            return True

                                        if self.bmac is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_access is not None:
                                        return True

                                    if self.neighbor is not None:
                                        return True

                                    if self.pseudowire is not None and self.pseudowire._has_data():
                                        return True

                                    if self.pseudowire_id is not None:
                                        return True

                                    if self.pw_type is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.static_mac is not None:
                                        for child_ref in self.static_mac:
                                            if child_ref._has_data():
                                                return True

                                    if self.ve_id_vpls_id_0_3 is not None:
                                        return True

                                    if self.vpls_id_4_7 is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bridge_pw is not None:
                                    for child_ref in self.bridge_pw:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_pws is not None and self.bridge_pws._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable']['meta_info']


                    class BridgeCoreVfiTable(object):
                        """
                        Bridge Domain Core VFI Table
                        
                        .. attribute:: bridge_pws
                        
                        	Bridge Domain Access/Core Pseudowire Table
                        	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_pws = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                            self.bridge_pws.parent = self


                        class BridgePws(object):
                            """
                            Bridge Domain Access/Core Pseudowire Table
                            
                            .. attribute:: bridge_pw
                            
                            	VPLS Bridge Domain Pseudowire
                            	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bridge_pw = YList()
                                self.bridge_pw.parent = self
                                self.bridge_pw.name = 'bridge_pw'


                            class BridgePw(object):
                                """
                                VPLS Bridge Domain Pseudowire
                                
                                .. attribute:: is_access
                                
                                	Is Access PW
                                	**type**\:  bool
                                
                                .. attribute:: neighbor
                                
                                	Neighbor IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire
                                	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                                
                                .. attribute:: pseudowire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: pw_type
                                
                                	PW Type
                                	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                                
                                .. attribute:: static_mac
                                
                                	Static MAC addresses
                                	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                                
                                .. attribute:: ve_id_vpls_id_0_3
                                
                                	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vpls_id_4_7
                                
                                	Zero or Last 4 bytes of VPLS\-ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_access = None
                                    self.neighbor = None
                                    self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self.pseudowire_id = None
                                    self.pw_type = None
                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.static_mac = YList()
                                    self.static_mac.parent = self
                                    self.static_mac.name = 'static_mac'
                                    self.ve_id_vpls_id_0_3 = None
                                    self.vpls_id_4_7 = None


                                class Pseudowire(object):
                                    """
                                    Pseudowire
                                    
                                    .. attribute:: ad_method
                                    
                                    	Autodiscovery method
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ad_remote_down
                                    
                                    	Auto\-Discovered PW remote state down
                                    	**type**\:  bool
                                    
                                    .. attribute:: admited_bw
                                    
                                    	Admited Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: auto_discovery
                                    
                                    	Is autodiscovery
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_active
                                    
                                    	TRUE if backup is active
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_force_active
                                    
                                    	TRUE if backup is active due to switchover
                                    	**type**\:  bool
                                    
                                    .. attribute:: backup_pw
                                    
                                    	TRUE if PW is a backup PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: bitrate_mismatched
                                    
                                    	Bitrate mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: bridge_pw_type_mismatch
                                    
                                    	Oper down because Bridge has mismatched PW Types
                                    	**type**\:  bool
                                    
                                    .. attribute:: cas_mismatched
                                    
                                    	CAS mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: diff_ts_mismatched
                                    
                                    	Differential timestamp mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: disable_delay
                                    
                                    	Backup disable delay
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: disable_never
                                    
                                    	TRUE if backup is not automatically disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: encapsulation_info
                                    
                                    	Encapsulation specific pseudowire information
                                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                    
                                    .. attribute:: evpn_src_acid
                                    
                                    	EVPN VPWS Source AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fe_ctype
                                    
                                    	Pseudowire FEC type
                                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                    
                                    .. attribute:: forward_class
                                    
                                    	Forward Class attribute
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: freq_mismatched
                                    
                                    	Frequency mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: illegal_control_word
                                    
                                    	Illegal control word
                                    	**type**\:  bool
                                    
                                    .. attribute:: imposed_vlan_id
                                    
                                    	Imposed vlan id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interworking
                                    
                                    	Interworking type
                                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                    
                                    .. attribute:: ipv6_local_source_address
                                    
                                    	Local IPv6 Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_evpnvpws_type
                                    
                                    	is EVPN VPWS
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_flow_label_static
                                    
                                    	is flow label static
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_multi_segment_pseudowire
                                    
                                    	Is Multi\-Segment Pseudowire
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_partially_programmed
                                    
                                    	Is Pseudowire partially programmed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_pwr_type
                                    
                                    	is Pseudowire\-routed
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_vfi
                                    
                                    	Is VFI interface
                                    	**type**\:  bool
                                    
                                    .. attribute:: last_time_status_changed
                                    
                                    	Last time the pseudowire status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_down
                                    
                                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: ldp_label_advertise_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: load_balance
                                    
                                    	Load Balance Type
                                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                    
                                    .. attribute:: local_control_word
                                    
                                    	Local control word
                                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                    
                                    .. attribute:: local_interface
                                    
                                    	Local interface
                                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                    
                                    .. attribute:: local_label_failed
                                    
                                    	Failed to set BGP advertised local label
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_pseudo_wire_type
                                    
                                    	Local pseudowire type
                                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                    
                                    .. attribute:: local_signalling
                                    
                                    	Local signalling
                                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                    
                                    .. attribute:: local_source_address
                                    
                                    	Local Source Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: mac_limit_oper_down
                                    
                                    	Oper down because MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mtu_mismatched
                                    
                                    	MTU mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: not_supported_qinq
                                    
                                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                    	**type**\:  bool
                                    
                                    .. attribute:: num_ma_cwithdraw_msg_received
                                    
                                    	Num MW messages received over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_ma_cwithdraw_message_sent
                                    
                                    	Num MW messages sent over PW
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_of_memory_state
                                    
                                    	L2VPN Out of memory state
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: p2mp_pw
                                    
                                    	P2MP Pseudowire Information
                                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                                    
                                    .. attribute:: payload_bytes_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: payload_type_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer
                                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                    
                                    .. attribute:: preferred_path
                                    
                                    	MPLS Preferred Path
                                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                    
                                    .. attribute:: preferred_path_disable_fallback
                                    
                                    	Prefpath fallback enable/disable
                                    	**type**\:  bool
                                    
                                    .. attribute:: primary_peer_id
                                    
                                    	Primary Peer IP address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary_pseudo_wire_id
                                    
                                    	Primary Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: primary_pw
                                    
                                    	TRUE if PW is a primary PW
                                    	**type**\:  bool
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol
                                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                    
                                    .. attribute:: pseudo_wire_id
                                    
                                    	Pseudowire ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: pseudo_wire_state
                                    
                                    	Pseudowire state
                                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                    
                                    .. attribute:: pseudo_wire_type_mismatched
                                    
                                    	Pseudowire type mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_class_name
                                    
                                    	Pseudowire class name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: pw_flow_label_code17_disabled
                                    
                                    	Disable sending Code 17 TLV
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_flow_label_type
                                    
                                    	Negotiated pseudowire flow label type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                    
                                    .. attribute:: pw_flow_label_type_cfg
                                    
                                    	Configured pseudowire flow label Type
                                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                    
                                    .. attribute:: pw_redundancy_initial_delay
                                    
                                    	Initial delay for redundant PW in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: pw_redundancy_one_way
                                    
                                    	Force one\-way PW redundancy behaviour in Redundancy Group
                                    	**type**\:  bool
                                    
                                    .. attribute:: pw_status_use
                                    
                                    	PW status in use
                                    	**type**\:  bool
                                    
                                    .. attribute:: pwlsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_control_word
                                    
                                    	Remote control word
                                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                    
                                    .. attribute:: remote_interface
                                    
                                    	Remote interface
                                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                    
                                    .. attribute:: remote_label_failed
                                    
                                    	Failed to set BGP advertised remote label
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_pseudo_wire_type
                                    
                                    	Remote pseudowire type
                                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                    
                                    .. attribute:: remote_signalling
                                    
                                    	Remote signalling
                                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                    
                                    .. attribute:: required_bw
                                    
                                    	Required Bandwidth
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: resync_enabled
                                    
                                    	Resync if packets out of sequence
                                    	**type**\:  bool
                                    
                                    .. attribute:: resync_threshold
                                    
                                    	Number of Packets Out of Seqence to trigger resync
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rtp_mismatched
                                    
                                    	RTP mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: sequencing_type
                                    
                                    	Sequencing Type
                                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown
                                    	**type**\:  bool
                                    
                                    .. attribute:: sig_pkts_mismatched
                                    
                                    	Signalling packets mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: ssrc_mismatched
                                    
                                    	SSRC mismatched
                                    	**type**\:  bool
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                    
                                    .. attribute:: table_policy_name
                                    
                                    	Table\-policy Name
                                    	**type**\:  str
                                    
                                    .. attribute:: tag_rewrite
                                    
                                    	StaticTagRewrite
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: time_created
                                    
                                    	Time when the pseudowire was created
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_creation
                                    
                                    	Time elapsed since creation
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_changed
                                    
                                    	Time elapsed since status changed
                                    	**type**\:  str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_down
                                    
                                    	Time elapsed since last status down in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: transport_lsp_down
                                    
                                    	Oper down due to Transport LSP down
                                    	**type**\:  bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	XConnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ad_method = None
                                        self.ad_remote_down = None
                                        self.admited_bw = None
                                        self.auto_discovery = None
                                        self.backup_active = None
                                        self.backup_force_active = None
                                        self.backup_pw = None
                                        self.bitrate_mismatched = None
                                        self.bridge_pw_type_mismatch = None
                                        self.cas_mismatched = None
                                        self.diff_ts_mismatched = None
                                        self.disable_delay = None
                                        self.disable_never = None
                                        self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self.evpn_src_acid = None
                                        self.fe_ctype = None
                                        self.forward_class = None
                                        self.freq_mismatched = None
                                        self.illegal_control_word = None
                                        self.imposed_vlan_id = None
                                        self.interworking = None
                                        self.ipv6_local_source_address = None
                                        self.is_evpnvpws_type = None
                                        self.is_flow_label_static = None
                                        self.is_multi_segment_pseudowire = None
                                        self.is_partially_programmed = None
                                        self.is_pwr_type = None
                                        self.is_vfi = None
                                        self.last_time_status_changed = None
                                        self.last_time_status_down = None
                                        self.ldp_label_advertise_failed = None
                                        self.load_balance = None
                                        self.local_control_word = None
                                        self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self.local_label_failed = None
                                        self.local_pseudo_wire_type = None
                                        self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self.local_source_address = None
                                        self.mac_limit_oper_down = None
                                        self.mtu_mismatched = None
                                        self.not_supported_qinq = None
                                        self.num_ma_cwithdraw_msg_received = None
                                        self.number_ma_cwithdraw_message_sent = None
                                        self.out_of_memory_state = None
                                        self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                        self.p2mp_pw.parent = self
                                        self.payload_bytes_mismatched = None
                                        self.payload_type_mismatched = None
                                        self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self.preferred_path_disable_fallback = None
                                        self.primary_peer_id = None
                                        self.primary_pseudo_wire_id = None
                                        self.primary_pw = None
                                        self.protocol = None
                                        self.pseudo_wire_id = None
                                        self.pseudo_wire_state = None
                                        self.pseudo_wire_type_mismatched = None
                                        self.pw_class_name = None
                                        self.pw_flow_label_code17_disabled = None
                                        self.pw_flow_label_type = None
                                        self.pw_flow_label_type_cfg = None
                                        self.pw_redundancy_initial_delay = None
                                        self.pw_redundancy_one_way = None
                                        self.pw_status_use = None
                                        self.pwlsd_rewrite_failed = None
                                        self.remote_control_word = None
                                        self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self.remote_label_failed = None
                                        self.remote_pseudo_wire_type = None
                                        self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self.required_bw = None
                                        self.resync_enabled = None
                                        self.resync_threshold = None
                                        self.rtp_mismatched = None
                                        self.sequencing_type = None
                                        self.shutdown = None
                                        self.sig_pkts_mismatched = None
                                        self.ssrc_mismatched = None
                                        self.state = None
                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self.table_policy_name = None
                                        self.tag_rewrite = None
                                        self.time_created = None
                                        self.time_elapsed_creation = None
                                        self.time_elapsed_status_changed = None
                                        self.time_elapsed_status_down = None
                                        self.transport_lsp_down = None
                                        self.xconnect_id = None


                                    class PeerId(object):
                                        """
                                        Peer
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ipv4_peer_id
                                        
                                        	Peer IPv4 address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_peer_id
                                        
                                        	Peer IPv6 address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.internal_label = None
                                            self.ipv4_peer_id = None
                                            self.ipv6_peer_id = None
                                            self.type = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.internal_label is not None:
                                                return True

                                            if self.ipv4_peer_id is not None:
                                                return True

                                            if self.ipv6_peer_id is not None:
                                                return True

                                            if self.type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                                    class EncapsulationInfo(object):
                                        """
                                        Encapsulation specific pseudowire information
                                        
                                        .. attribute:: atom
                                        
                                        	atom
                                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                        
                                        .. attribute:: encapsulation
                                        
                                        	Encapsulation
                                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                        
                                        .. attribute:: l2tpv3
                                        
                                        	l2tpv3
                                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self.encapsulation = None
                                            self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                            self.l2tpv3.parent = self


                                        class Atom(object):
                                            """
                                            atom
                                            
                                            .. attribute:: is_pseudowire_headend
                                            
                                            	Is this connected to a PW\-HE AC
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_sai_itype2
                                            
                                            	Is SAII FEC129 Type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_tai_itype2
                                            
                                            	Is TAII type 2
                                            	**type**\:  bool
                                            
                                            .. attribute:: ldp_label_advertisment_failed
                                            
                                            	LDP label advertisment failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: local_agi
                                            
                                            	Local Attachment Group Identifier
                                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                            
                                            .. attribute:: local_c_ctype
                                            
                                            	Local VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_ceid
                                            
                                            	Local CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cv_type
                                            
                                            	Local VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_group_id
                                            
                                            	Local group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_ldp_id
                                            
                                            	Local LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: local_saii_gbl_id
                                            
                                            	Local SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_saiiac_id
                                            
                                            	Local SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taii_gbl_id
                                            
                                            	Local TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taiiac_id
                                            
                                            	Local TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_veid
                                            
                                            	Local VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: lsd_rewrite_failed
                                            
                                            	LSD rewrite failed
                                            	**type**\:  bool
                                            
                                            .. attribute:: multi_segment_pseudowire_stats
                                            
                                            	Multisegment pseudowire statistics
                                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                            
                                            .. attribute:: rem_saii
                                            
                                            	Remote Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_saii_gbl_id
                                            
                                            	Remote SAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saiiac_id
                                            
                                            	Remote SAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taii
                                            
                                            	Remote Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_taii_gbl_id
                                            
                                            	Remote TAII Global ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taiiac_id
                                            
                                            	Remote TAII AC ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_agi
                                            
                                            	Remote Attachment Group Identifier
                                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                            
                                            .. attribute:: remote_c_ctype
                                            
                                            	Remote VCCV CC type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_ceid
                                            
                                            	Remote CE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cv_type
                                            
                                            	Remote VCCV CV type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_group_id
                                            
                                            	Remote group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_label
                                            
                                            	Remote label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_ldp_id
                                            
                                            	Remote LDP ID
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_source_address
                                            
                                            	Remote BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_veid
                                            
                                            	Remote VE ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: saii
                                            
                                            	Source Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: source_address
                                            
                                            	Local BGP source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: taii
                                            
                                            	Target Attachment Individual Identifer
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.is_pseudowire_headend = None
                                                self.is_sai_itype2 = None
                                                self.is_tai_itype2 = None
                                                self.ldp_label_advertisment_failed = None
                                                self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self.local_c_ctype = None
                                                self.local_ceid = None
                                                self.local_cv_type = None
                                                self.local_group_id = None
                                                self.local_label = None
                                                self.local_ldp_id = None
                                                self.local_saii_gbl_id = None
                                                self.local_saiiac_id = None
                                                self.local_taii_gbl_id = None
                                                self.local_taiiac_id = None
                                                self.local_veid = None
                                                self.lsd_rewrite_failed = None
                                                self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self.rem_saii = None
                                                self.rem_saii_gbl_id = None
                                                self.rem_saiiac_id = None
                                                self.rem_taii = None
                                                self.rem_taii_gbl_id = None
                                                self.rem_taiiac_id = None
                                                self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self.remote_c_ctype = None
                                                self.remote_ceid = None
                                                self.remote_cv_type = None
                                                self.remote_group_id = None
                                                self.remote_label = None
                                                self.remote_ldp_id = None
                                                self.remote_source_address = None
                                                self.remote_veid = None
                                                self.saii = None
                                                self.source_address = None
                                                self.taii = None


                                            class LocalAgi(object):
                                                """
                                                Local Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self.vpls_id_type = None


                                                class Auto(object):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.asn = None
                                                        self.vpn_id = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.asn is not None:
                                                            return True

                                                        if self.vpn_id is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                                class TwoByteAs(object):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.four_byte_index = None
                                                        self.two_byte_as = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.four_byte_index is not None:
                                                            return True

                                                        if self.two_byte_as is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                                class V4Addr(object):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.two_byte_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.auto is not None and self.auto._has_data():
                                                        return True

                                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                        return True

                                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                                        return True

                                                    if self.vpls_id_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                            class RemoteAgi(object):
                                                """
                                                Remote Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self.vpls_id_type = None


                                                class Auto(object):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.asn = None
                                                        self.vpn_id = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.asn is not None:
                                                            return True

                                                        if self.vpn_id is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                                class TwoByteAs(object):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.four_byte_index = None
                                                        self.two_byte_as = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.four_byte_index is not None:
                                                            return True

                                                        if self.two_byte_as is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                                class V4Addr(object):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.ipv4_address is not None:
                                                            return True

                                                        if self.two_byte_index is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.auto is not None and self.auto._has_data():
                                                        return True

                                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                        return True

                                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                                        return True

                                                    if self.vpls_id_type is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                            class MultiSegmentPseudowireStats(object):
                                                """
                                                Multisegment pseudowire statistics
                                                
                                                .. attribute:: received_bytes
                                                
                                                	Bytes received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: received_packets
                                                
                                                	Packets received
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.received_bytes = None
                                                    self.received_packets = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.received_bytes is not None:
                                                        return True

                                                    if self.received_packets is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.is_pseudowire_headend is not None:
                                                    return True

                                                if self.is_sai_itype2 is not None:
                                                    return True

                                                if self.is_tai_itype2 is not None:
                                                    return True

                                                if self.ldp_label_advertisment_failed is not None:
                                                    return True

                                                if self.local_agi is not None and self.local_agi._has_data():
                                                    return True

                                                if self.local_c_ctype is not None:
                                                    return True

                                                if self.local_ceid is not None:
                                                    return True

                                                if self.local_cv_type is not None:
                                                    return True

                                                if self.local_group_id is not None:
                                                    return True

                                                if self.local_label is not None:
                                                    return True

                                                if self.local_ldp_id is not None:
                                                    return True

                                                if self.local_saii_gbl_id is not None:
                                                    return True

                                                if self.local_saiiac_id is not None:
                                                    return True

                                                if self.local_taii_gbl_id is not None:
                                                    return True

                                                if self.local_taiiac_id is not None:
                                                    return True

                                                if self.local_veid is not None:
                                                    return True

                                                if self.lsd_rewrite_failed is not None:
                                                    return True

                                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                    return True

                                                if self.rem_saii is not None:
                                                    return True

                                                if self.rem_saii_gbl_id is not None:
                                                    return True

                                                if self.rem_saiiac_id is not None:
                                                    return True

                                                if self.rem_taii is not None:
                                                    return True

                                                if self.rem_taii_gbl_id is not None:
                                                    return True

                                                if self.rem_taiiac_id is not None:
                                                    return True

                                                if self.remote_agi is not None and self.remote_agi._has_data():
                                                    return True

                                                if self.remote_c_ctype is not None:
                                                    return True

                                                if self.remote_ceid is not None:
                                                    return True

                                                if self.remote_cv_type is not None:
                                                    return True

                                                if self.remote_group_id is not None:
                                                    return True

                                                if self.remote_label is not None:
                                                    return True

                                                if self.remote_ldp_id is not None:
                                                    return True

                                                if self.remote_source_address is not None:
                                                    return True

                                                if self.remote_veid is not None:
                                                    return True

                                                if self.saii is not None:
                                                    return True

                                                if self.source_address is not None:
                                                    return True

                                                if self.taii is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                        class L2Tpv3(object):
                                            """
                                            l2tpv3
                                            
                                            .. attribute:: dont_fragment_bit
                                            
                                            	Don't Fragment Bit
                                            	**type**\:  bool
                                            
                                            .. attribute:: ipv4_source_address
                                            
                                            	IPv4 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_source_address
                                            
                                            	IPv6 source address
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: l2tp_class_name
                                            
                                            	L2TPClassName
                                            	**type**\:  str
                                            
                                            	**length:** 0..32
                                            
                                            .. attribute:: local_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_size
                                            
                                            	Local cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_secondary_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local secondary cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_size
                                            
                                            	Local secondary cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_session_id
                                            
                                            	Local session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: path_mtu_enabled
                                            
                                            	Path MTU enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: path_mtu_max_value
                                            
                                            	Path MTU Maximum allowable session MTU
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: remote_circuit_status_up
                                            
                                            	RemoteCircuitStatusUp
                                            	**type**\:  bool
                                            
                                            .. attribute:: remote_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the remote cookie
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_size
                                            
                                            	Remote cookie size\: 0, 4, or 8 bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_session_id
                                            
                                            	Remote session id
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tos
                                            
                                            	Type Of Service Value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tos_mode
                                            
                                            	Type Of Service Mode
                                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                            
                                            .. attribute:: ttl
                                            
                                            	Time To Live value
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tunnel_state
                                            
                                            	L2TP tunnel state
                                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dont_fragment_bit = None
                                                self.ipv4_source_address = None
                                                self.ipv6_source_address = None
                                                self.l2tp_class_name = None
                                                self.local_cookie_high_value = None
                                                self.local_cookie_low_value = None
                                                self.local_cookie_size = None
                                                self.local_secondary_cookie_high_value = None
                                                self.local_secondary_cookie_low_value = None
                                                self.local_secondary_cookie_size = None
                                                self.local_session_id = None
                                                self.path_mtu_enabled = None
                                                self.path_mtu_max_value = None
                                                self.remote_circuit_status_up = None
                                                self.remote_cookie_high_value = None
                                                self.remote_cookie_low_value = None
                                                self.remote_cookie_size = None
                                                self.remote_session_id = None
                                                self.tos = None
                                                self.tos_mode = None
                                                self.ttl = None
                                                self.tunnel_state = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dont_fragment_bit is not None:
                                                    return True

                                                if self.ipv4_source_address is not None:
                                                    return True

                                                if self.ipv6_source_address is not None:
                                                    return True

                                                if self.l2tp_class_name is not None:
                                                    return True

                                                if self.local_cookie_high_value is not None:
                                                    return True

                                                if self.local_cookie_low_value is not None:
                                                    return True

                                                if self.local_cookie_size is not None:
                                                    return True

                                                if self.local_secondary_cookie_high_value is not None:
                                                    return True

                                                if self.local_secondary_cookie_low_value is not None:
                                                    return True

                                                if self.local_secondary_cookie_size is not None:
                                                    return True

                                                if self.local_session_id is not None:
                                                    return True

                                                if self.path_mtu_enabled is not None:
                                                    return True

                                                if self.path_mtu_max_value is not None:
                                                    return True

                                                if self.remote_circuit_status_up is not None:
                                                    return True

                                                if self.remote_cookie_high_value is not None:
                                                    return True

                                                if self.remote_cookie_low_value is not None:
                                                    return True

                                                if self.remote_cookie_size is not None:
                                                    return True

                                                if self.remote_session_id is not None:
                                                    return True

                                                if self.tos is not None:
                                                    return True

                                                if self.tos_mode is not None:
                                                    return True

                                                if self.ttl is not None:
                                                    return True

                                                if self.tunnel_state is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atom is not None and self.atom._has_data():
                                                return True

                                            if self.encapsulation is not None:
                                                return True

                                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                                    class LocalInterface(object):
                                        """
                                        Local interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.mtu = None
                                            self.name = None
                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self.payload_bytes = None


                                        class Parameters(object):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self.type = None
                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self


                                            class Ethernet(object):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.xconnect_tags = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                            class Vlan(object):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None
                                                    self.rewrite_tag = YLeafList()
                                                    self.rewrite_tag.parent = self
                                                    self.rewrite_tag.name = 'rewrite_tag'
                                                    self.simple_efp = None
                                                    self.vlan_range = YList()
                                                    self.vlan_range.parent = self
                                                    self.vlan_range.name = 'vlan_range'
                                                    self.vlan_rewrite_tag = None
                                                    self.xconnect_tags = None


                                                class VlanRange(object):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.lower = None
                                                        self.upper = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.lower is not None:
                                                            return True

                                                        if self.upper is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.encapsulation_type is not None:
                                                        return True

                                                    if self.outer_tag is not None:
                                                        return True

                                                    if self.rewrite_tag is not None:
                                                        for child in self.rewrite_tag:
                                                            if child is not None:
                                                                return True

                                                    if self.simple_efp is not None:
                                                        return True

                                                    if self.vlan_range is not None:
                                                        for child_ref in self.vlan_range:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.vlan_rewrite_tag is not None:
                                                        return True

                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                            class Tdm(object):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tdm_mode = None
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None


                                                class TdmOptions(object):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.bit_rate = None
                                                        self.cas = None
                                                        self.payload_bytes = None
                                                        self.rtp = None
                                                        self.rtp_header_payload_type = None
                                                        self.signalling_packets = None
                                                        self.ssrc = None
                                                        self.timestamp_clock_freq = None
                                                        self.timestamp_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.bit_rate is not None:
                                                            return True

                                                        if self.cas is not None:
                                                            return True

                                                        if self.payload_bytes is not None:
                                                            return True

                                                        if self.rtp is not None:
                                                            return True

                                                        if self.rtp_header_payload_type is not None:
                                                            return True

                                                        if self.signalling_packets is not None:
                                                            return True

                                                        if self.ssrc is not None:
                                                            return True

                                                        if self.timestamp_clock_freq is not None:
                                                            return True

                                                        if self.timestamp_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tdm_mode is not None:
                                                        return True

                                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                                        return True

                                                    if self.timeslot_group is not None:
                                                        return True

                                                    if self.timeslot_rate is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                            class Atm(object):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.atm_mode = None
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.vci = None
                                                    self.vpi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.atm_mode is not None:
                                                        return True

                                                    if self.maximum_number_cells_packed is not None:
                                                        return True

                                                    if self.maximum_number_cells_un_packed is not None:
                                                        return True

                                                    if self.vci is not None:
                                                        return True

                                                    if self.vpi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                            class Fr(object):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.dlci = None
                                                    self.fr_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.dlci is not None:
                                                        return True

                                                    if self.fr_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                            class PseudowireEther(object):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                            class PseudowireIw(object):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm is not None and self.atm._has_data():
                                                    return True

                                                if self.ethernet is not None and self.ethernet._has_data():
                                                    return True

                                                if self.fr is not None and self.fr._has_data():
                                                    return True

                                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                    return True

                                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                    return True

                                                if self.tdm is not None and self.tdm._has_data():
                                                    return True

                                                if self.type is not None:
                                                    return True

                                                if self.vlan is not None and self.vlan._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.mtu is not None:
                                                return True

                                            if self.name is not None:
                                                return True

                                            if self.parameters is not None and self.parameters._has_data():
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                                    class RemoteInterface(object):
                                        """
                                        Remote interface
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.mtu = None
                                            self.name = None
                                            self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self.payload_bytes = None


                                        class Parameters(object):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self.type = None
                                                self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self


                                            class Ethernet(object):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.xconnect_tags = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                            class Vlan(object):
                                                """
                                                VLAN
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\:  list of int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None
                                                    self.rewrite_tag = YLeafList()
                                                    self.rewrite_tag.parent = self
                                                    self.rewrite_tag.name = 'rewrite_tag'
                                                    self.simple_efp = None
                                                    self.vlan_range = YList()
                                                    self.vlan_range.parent = self
                                                    self.vlan_range.name = 'vlan_range'
                                                    self.vlan_rewrite_tag = None
                                                    self.xconnect_tags = None


                                                class VlanRange(object):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.lower = None
                                                        self.upper = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.lower is not None:
                                                            return True

                                                        if self.upper is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.encapsulation_type is not None:
                                                        return True

                                                    if self.outer_tag is not None:
                                                        return True

                                                    if self.rewrite_tag is not None:
                                                        for child in self.rewrite_tag:
                                                            if child is not None:
                                                                return True

                                                    if self.simple_efp is not None:
                                                        return True

                                                    if self.vlan_range is not None:
                                                        for child_ref in self.vlan_range:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.vlan_rewrite_tag is not None:
                                                        return True

                                                    if self.xconnect_tags is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                            class Tdm(object):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\:  str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.tdm_mode = None
                                                    self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None


                                                class TdmOptions(object):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.bit_rate = None
                                                        self.cas = None
                                                        self.payload_bytes = None
                                                        self.rtp = None
                                                        self.rtp_header_payload_type = None
                                                        self.signalling_packets = None
                                                        self.ssrc = None
                                                        self.timestamp_clock_freq = None
                                                        self.timestamp_mode = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.bit_rate is not None:
                                                            return True

                                                        if self.cas is not None:
                                                            return True

                                                        if self.payload_bytes is not None:
                                                            return True

                                                        if self.rtp is not None:
                                                            return True

                                                        if self.rtp_header_payload_type is not None:
                                                            return True

                                                        if self.signalling_packets is not None:
                                                            return True

                                                        if self.ssrc is not None:
                                                            return True

                                                        if self.timestamp_clock_freq is not None:
                                                            return True

                                                        if self.timestamp_mode is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.tdm_mode is not None:
                                                        return True

                                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                                        return True

                                                    if self.timeslot_group is not None:
                                                        return True

                                                    if self.timeslot_rate is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                            class Atm(object):
                                                """
                                                ATM
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.atm_mode = None
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.vci = None
                                                    self.vpi = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.atm_mode is not None:
                                                        return True

                                                    if self.maximum_number_cells_packed is not None:
                                                        return True

                                                    if self.maximum_number_cells_un_packed is not None:
                                                        return True

                                                    if self.vci is not None:
                                                        return True

                                                    if self.vpi is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                            class Fr(object):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.dlci = None
                                                    self.fr_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.dlci is not None:
                                                        return True

                                                    if self.fr_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                            class PseudowireEther(object):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                            class PseudowireIw(object):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self.internal_label = None
                                                    self.is_valid = None


                                                class InterfaceList(object):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\:  str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface = YList()
                                                        self.interface.parent = self
                                                        self.interface.name = 'interface'
                                                        self.interface_list_id = None
                                                        self.interface_list_name = None


                                                    class Interface(object):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            self.parent = None
                                                            self.interface_name = None
                                                            self.replicate_status = None

                                                        @property
                                                        def _common_path(self):
                                                            if self.parent is None:
                                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                        def is_config(self):
                                                            ''' Returns True if this instance represents config data else returns False '''
                                                            return False

                                                        def _has_data(self):
                                                            if not self.is_config():
                                                                return False
                                                            if self.interface_name is not None:
                                                                return True

                                                            if self.replicate_status is not None:
                                                                return True

                                                            return False

                                                        @staticmethod
                                                        def _meta_info():
                                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface is not None:
                                                            for child_ref in self.interface:
                                                                if child_ref._has_data():
                                                                    return True

                                                        if self.interface_list_id is not None:
                                                            return True

                                                        if self.interface_list_name is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_list is not None and self.interface_list._has_data():
                                                        return True

                                                    if self.internal_label is not None:
                                                        return True

                                                    if self.is_valid is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm is not None and self.atm._has_data():
                                                    return True

                                                if self.ethernet is not None and self.ethernet._has_data():
                                                    return True

                                                if self.fr is not None and self.fr._has_data():
                                                    return True

                                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                    return True

                                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                    return True

                                                if self.tdm is not None and self.tdm._has_data():
                                                    return True

                                                if self.type is not None:
                                                    return True

                                                if self.vlan is not None and self.vlan._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.mtu is not None:
                                                return True

                                            if self.name is not None:
                                                return True

                                            if self.parameters is not None and self.parameters._has_data():
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                                    class PreferredPath(object):
                                        """
                                        MPLS Preferred Path
                                        
                                        .. attribute:: ip_tunnel_interface_number
                                        
                                        	IPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	NextHopIP
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: option
                                        
                                        	Option
                                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                        
                                        .. attribute:: te_tunnel_interface_number
                                        
                                        	TETunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tp_tunnel_interface_number
                                        
                                        	TPTunnelInterfaceNumber
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ip_tunnel_interface_number = None
                                            self.next_hop_ip = None
                                            self.option = None
                                            self.te_tunnel_interface_number = None
                                            self.tp_tunnel_interface_number = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ip_tunnel_interface_number is not None:
                                                return True

                                            if self.next_hop_ip is not None:
                                                return True

                                            if self.option is not None:
                                                return True

                                            if self.te_tunnel_interface_number is not None:
                                                return True

                                            if self.tp_tunnel_interface_number is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                                    class LocalSignalling(object):
                                        """
                                        Local signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.pw_status = None
                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self.tlv = YList()
                                            self.tlv.parent = self
                                            self.tlv.name = 'tlv'


                                        class StatusTlv(object):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                        class Tlv(object):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.pw_status is not None:
                                                return True

                                            if self.status_tlv is not None and self.status_tlv._has_data():
                                                return True

                                            if self.tlv is not None:
                                                for child_ref in self.tlv:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                                    class RemoteSignalling(object):
                                        """
                                        Remote signalling
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.pw_status = None
                                            self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self.tlv = YList()
                                            self.tlv.parent = self
                                            self.tlv.name = 'tlv'


                                        class StatusTlv(object):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                        class Tlv(object):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\:  str
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.description = None
                                                self.local_address = None
                                                self.pw_id = None
                                                self.remote_address = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.description is not None:
                                                    return True

                                                if self.local_address is not None:
                                                    return True

                                                if self.pw_id is not None:
                                                    return True

                                                if self.remote_address is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.pw_status is not None:
                                                return True

                                            if self.status_tlv is not None and self.status_tlv._has_data():
                                                return True

                                            if self.tlv is not None:
                                                for child_ref in self.tlv:
                                                    if child_ref._has_data():
                                                        return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                                    class Statistics(object):
                                        """
                                        Statistics
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self


                                        class ImpostionStats(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self


                                            class ImpositionStat(object):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                            class ImpositionMtuDrop(object):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                            class ImpostionTailDrop(object):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                            class L2FsbiDrop(object):
                                                """
                                                rx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                            class Multicast(object):
                                                """
                                                Multicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                            class Broadcast(object):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                            class KnownUnicast(object):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                            class UnknownUnicast(object):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast is not None and self.broadcast._has_data():
                                                    return True

                                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                    return True

                                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                    return True

                                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                    return True

                                                if self.known_unicast is not None and self.known_unicast._has_data():
                                                    return True

                                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                    return True

                                                if self.multicast is not None and self.multicast._has_data():
                                                    return True

                                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                        class DispostionStats(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self


                                            class DispositionStat(object):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                            class DispositionMtuDrop(object):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                            class DispositionTailDrop(object):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                            class MulticastDrop(object):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                            class UnicastDrop(object):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                            class BroadcastDrop(object):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                            class ReceivedDrops(object):
                                                """
                                                tx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                            class DaiDrop(object):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                            class IpsgDrop(object):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                            class DispositionOoODrops(object):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                            class DispositionP2MpStats(object):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                            class KnownUnicast(object):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                            class MacMove(object):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                    return True

                                                if self.dai_drop is not None and self.dai_drop._has_data():
                                                    return True

                                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                    return True

                                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                    return True

                                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                    return True

                                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                    return True

                                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                    return True

                                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                    return True

                                                if self.known_unicast is not None and self.known_unicast._has_data():
                                                    return True

                                                if self.mac_move is not None and self.mac_move._has_data():
                                                    return True

                                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                    return True

                                                if self.received_drops is not None and self.received_drops._has_data():
                                                    return True

                                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                        class SequenceNumber(object):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bypassed_inbound_sequence_packet = None
                                                self.bypassed_out_sequence_packet = None
                                                self.sequence_number_expected = None
                                                self.sequence_number_sent = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bypassed_inbound_sequence_packet is not None:
                                                    return True

                                                if self.bypassed_out_sequence_packet is not None:
                                                    return True

                                                if self.sequence_number_expected is not None:
                                                    return True

                                                if self.sequence_number_sent is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                                return True

                                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                                return True

                                            if self.sequence_number is not None and self.sequence_number._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                                    class P2MpPw(object):
                                        """
                                        P2MP Pseudowire Information
                                        
                                        .. attribute:: local_available
                                        
                                        	Local LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_extended_tunnel_id
                                        
                                        	Local Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_flags
                                        
                                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_label
                                        
                                        	Local Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_p2mp_id
                                        
                                        	Local P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ptree_type
                                        
                                        	Local P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                        
                                        .. attribute:: local_tunnel_id
                                        
                                        	Local Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_available
                                        
                                        	Remote LSM info available
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_extended_tunnel_id
                                        
                                        	Remote Extended Tunnel ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_flags
                                        
                                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_p2mp_id
                                        
                                        	Remote P2MP ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ptree_type
                                        
                                        	Remote P\-Tree Type
                                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                        
                                        .. attribute:: remote_tunnel_id
                                        
                                        	Remote Tunnel ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.local_available = None
                                            self.local_extended_tunnel_id = None
                                            self.local_flags = None
                                            self.local_label = None
                                            self.local_p2mp_id = None
                                            self.local_ptree_type = None
                                            self.local_tunnel_id = None
                                            self.remote_available = None
                                            self.remote_extended_tunnel_id = None
                                            self.remote_flags = None
                                            self.remote_label = None
                                            self.remote_p2mp_id = None
                                            self.remote_ptree_type = None
                                            self.remote_tunnel_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.local_available is not None:
                                                return True

                                            if self.local_extended_tunnel_id is not None:
                                                return True

                                            if self.local_flags is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_p2mp_id is not None:
                                                return True

                                            if self.local_ptree_type is not None:
                                                return True

                                            if self.local_tunnel_id is not None:
                                                return True

                                            if self.remote_available is not None:
                                                return True

                                            if self.remote_extended_tunnel_id is not None:
                                                return True

                                            if self.remote_flags is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_p2mp_id is not None:
                                                return True

                                            if self.remote_ptree_type is not None:
                                                return True

                                            if self.remote_tunnel_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ad_method is not None:
                                            return True

                                        if self.ad_remote_down is not None:
                                            return True

                                        if self.admited_bw is not None:
                                            return True

                                        if self.auto_discovery is not None:
                                            return True

                                        if self.backup_active is not None:
                                            return True

                                        if self.backup_force_active is not None:
                                            return True

                                        if self.backup_pw is not None:
                                            return True

                                        if self.bitrate_mismatched is not None:
                                            return True

                                        if self.bridge_pw_type_mismatch is not None:
                                            return True

                                        if self.cas_mismatched is not None:
                                            return True

                                        if self.diff_ts_mismatched is not None:
                                            return True

                                        if self.disable_delay is not None:
                                            return True

                                        if self.disable_never is not None:
                                            return True

                                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                            return True

                                        if self.evpn_src_acid is not None:
                                            return True

                                        if self.fe_ctype is not None:
                                            return True

                                        if self.forward_class is not None:
                                            return True

                                        if self.freq_mismatched is not None:
                                            return True

                                        if self.illegal_control_word is not None:
                                            return True

                                        if self.imposed_vlan_id is not None:
                                            return True

                                        if self.interworking is not None:
                                            return True

                                        if self.ipv6_local_source_address is not None:
                                            return True

                                        if self.is_evpnvpws_type is not None:
                                            return True

                                        if self.is_flow_label_static is not None:
                                            return True

                                        if self.is_multi_segment_pseudowire is not None:
                                            return True

                                        if self.is_partially_programmed is not None:
                                            return True

                                        if self.is_pwr_type is not None:
                                            return True

                                        if self.is_vfi is not None:
                                            return True

                                        if self.last_time_status_changed is not None:
                                            return True

                                        if self.last_time_status_down is not None:
                                            return True

                                        if self.ldp_label_advertise_failed is not None:
                                            return True

                                        if self.load_balance is not None:
                                            return True

                                        if self.local_control_word is not None:
                                            return True

                                        if self.local_interface is not None and self.local_interface._has_data():
                                            return True

                                        if self.local_label_failed is not None:
                                            return True

                                        if self.local_pseudo_wire_type is not None:
                                            return True

                                        if self.local_signalling is not None and self.local_signalling._has_data():
                                            return True

                                        if self.local_source_address is not None:
                                            return True

                                        if self.mac_limit_oper_down is not None:
                                            return True

                                        if self.mtu_mismatched is not None:
                                            return True

                                        if self.not_supported_qinq is not None:
                                            return True

                                        if self.num_ma_cwithdraw_msg_received is not None:
                                            return True

                                        if self.number_ma_cwithdraw_message_sent is not None:
                                            return True

                                        if self.out_of_memory_state is not None:
                                            return True

                                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                            return True

                                        if self.payload_bytes_mismatched is not None:
                                            return True

                                        if self.payload_type_mismatched is not None:
                                            return True

                                        if self.peer_id is not None and self.peer_id._has_data():
                                            return True

                                        if self.preferred_path is not None and self.preferred_path._has_data():
                                            return True

                                        if self.preferred_path_disable_fallback is not None:
                                            return True

                                        if self.primary_peer_id is not None:
                                            return True

                                        if self.primary_pseudo_wire_id is not None:
                                            return True

                                        if self.primary_pw is not None:
                                            return True

                                        if self.protocol is not None:
                                            return True

                                        if self.pseudo_wire_id is not None:
                                            return True

                                        if self.pseudo_wire_state is not None:
                                            return True

                                        if self.pseudo_wire_type_mismatched is not None:
                                            return True

                                        if self.pw_class_name is not None:
                                            return True

                                        if self.pw_flow_label_code17_disabled is not None:
                                            return True

                                        if self.pw_flow_label_type is not None:
                                            return True

                                        if self.pw_flow_label_type_cfg is not None:
                                            return True

                                        if self.pw_redundancy_initial_delay is not None:
                                            return True

                                        if self.pw_redundancy_one_way is not None:
                                            return True

                                        if self.pw_status_use is not None:
                                            return True

                                        if self.pwlsd_rewrite_failed is not None:
                                            return True

                                        if self.remote_control_word is not None:
                                            return True

                                        if self.remote_interface is not None and self.remote_interface._has_data():
                                            return True

                                        if self.remote_label_failed is not None:
                                            return True

                                        if self.remote_pseudo_wire_type is not None:
                                            return True

                                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                                            return True

                                        if self.required_bw is not None:
                                            return True

                                        if self.resync_enabled is not None:
                                            return True

                                        if self.resync_threshold is not None:
                                            return True

                                        if self.rtp_mismatched is not None:
                                            return True

                                        if self.sequencing_type is not None:
                                            return True

                                        if self.shutdown is not None:
                                            return True

                                        if self.sig_pkts_mismatched is not None:
                                            return True

                                        if self.ssrc_mismatched is not None:
                                            return True

                                        if self.state is not None:
                                            return True

                                        if self.statistics is not None and self.statistics._has_data():
                                            return True

                                        if self.table_policy_name is not None:
                                            return True

                                        if self.tag_rewrite is not None:
                                            return True

                                        if self.time_created is not None:
                                            return True

                                        if self.time_elapsed_creation is not None:
                                            return True

                                        if self.time_elapsed_status_changed is not None:
                                            return True

                                        if self.time_elapsed_status_down is not None:
                                            return True

                                        if self.transport_lsp_down is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                                class StaticMac(object):
                                    """
                                    Static MAC addresses
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.address is not None:
                                            return True

                                        if self.bmac is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_access is not None:
                                        return True

                                    if self.neighbor is not None:
                                        return True

                                    if self.pseudowire is not None and self.pseudowire._has_data():
                                        return True

                                    if self.pseudowire_id is not None:
                                        return True

                                    if self.pw_type is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.static_mac is not None:
                                        for child_ref in self.static_mac:
                                            if child_ref._has_data():
                                                return True

                                    if self.ve_id_vpls_id_0_3 is not None:
                                        return True

                                    if self.vpls_id_4_7 is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bridge_pw is not None:
                                    for child_ref in self.bridge_pw:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_pws is not None and self.bridge_pws._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable']['meta_info']


                    class BridgeAcs(object):
                        """
                        VPLS Bridge Domain Attachment Circuit Table
                        
                        .. attribute:: bridge_ac
                        
                        	VPLS Bridge Domain Attachment Circuit
                        	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_ac = YList()
                            self.bridge_ac.parent = self
                            self.bridge_ac.name = 'bridge_ac'


                        class BridgeAc(object):
                            """
                            VPLS Bridge Domain Attachment Circuit
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: attachment_circuit
                            
                            	Attachment Circuit
                            	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                            
                            .. attribute:: bvi_mac_index
                            
                            	MyMac Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bvimac
                            
                            	BVI MAC addresses
                            	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.attachment_circuit = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self.bvi_mac_index = None
                                self.bvimac = YList()
                                self.bvimac.parent = self
                                self.bvimac.name = 'bvimac'
                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                self.security_parameters.parent = self
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'


                            class AttachmentCircuit(object):
                                """
                                Attachment Circuit
                                
                                .. attribute:: bvi_mac_conflict
                                
                                	BVI Mac Conflict
                                	**type**\:  bool
                                
                                .. attribute:: bvi_no_port_up
                                
                                	BVI no BP Up
                                	**type**\:  bool
                                
                                .. attribute:: control_word_mismatched
                                
                                	Control word mismatched
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_error
                                
                                	Encapsulation Error
                                	**type**\:  str
                                
                                .. attribute:: encapsulation_mismatched
                                
                                	Encapsulation mismatched
                                	**type**\:  bool
                                
                                .. attribute:: evpn_internal_label
                                
                                	EVPN Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface
                                
                                	Interface
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                                
                                .. attribute:: interface_handle
                                
                                	Interface Handler
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: internal_ms_ti
                                
                                	Internal MSTi
                                	**type**\:  str
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: is_ac_partially_programmed
                                
                                	Is attachment\-circuit partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: l2vpn_protection
                                
                                	Protection object used for this segment
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: ms_ti_mismatch
                                
                                	MSTi mismatch
                                	**type**\:  bool
                                
                                .. attribute:: msti
                                
                                	MSTi
                                	**type**\:  str
                                
                                .. attribute:: msti_mismatch_down
                                
                                	Oper down due to MSTI mismatch
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	Node ID
                                	**type**\:  str
                                
                                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_id
                                
                                	Redundancy Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_state
                                
                                	Redundancy Group State
                                	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                                
                                .. attribute:: redundancy_object_id
                                
                                	Redundancy Object ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                                
                                .. attribute:: tdm_media_mismatched
                                
                                	TDM media parms mismatched
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bvi_mac_conflict = None
                                    self.bvi_no_port_up = None
                                    self.control_word_mismatched = None
                                    self.encapsulation_error = None
                                    self.encapsulation_mismatched = None
                                    self.evpn_internal_label = None
                                    self.interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self.interface_handle = None
                                    self.internal_ms_ti = None
                                    self.interworking = None
                                    self.is_ac_partially_programmed = None
                                    self.l2vpn_protection = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self.mac_limit_oper_down = None
                                    self.ms_ti_mismatch = None
                                    self.msti = None
                                    self.msti_mismatch_down = None
                                    self.mtu_mismatched = None
                                    self.node_id = None
                                    self.out_of_memory_state = None
                                    self.redundancy_group_id = None
                                    self.redundancy_group_state = None
                                    self.redundancy_object_id = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self.tdm_media_mismatched = None
                                    self.xconnect_id = None


                                class Interface(object):
                                    """
                                    Interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface_(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface_(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics']['meta_info']


                                class L2VpnProtection(object):
                                    """
                                    Protection object used for this segment
                                    
                                    .. attribute:: active
                                    
                                    	Active
                                    	**type**\:  bool
                                    
                                    .. attribute:: protected_name
                                    
                                    	Name of the protected segment
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_configured
                                    
                                    	Protection configured
                                    	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                    
                                    .. attribute:: protection_name
                                    
                                    	Name of the segment acting as backup
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_type
                                    
                                    	Type of the protection
                                    	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.active = None
                                        self.protected_name = None
                                        self.protection_configured = None
                                        self.protection_name = None
                                        self.protection_type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active is not None:
                                            return True

                                        if self.protected_name is not None:
                                            return True

                                        if self.protection_configured is not None:
                                            return True

                                        if self.protection_name is not None:
                                            return True

                                        if self.protection_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bvi_mac_conflict is not None:
                                        return True

                                    if self.bvi_no_port_up is not None:
                                        return True

                                    if self.control_word_mismatched is not None:
                                        return True

                                    if self.encapsulation_error is not None:
                                        return True

                                    if self.encapsulation_mismatched is not None:
                                        return True

                                    if self.evpn_internal_label is not None:
                                        return True

                                    if self.interface is not None and self.interface._has_data():
                                        return True

                                    if self.interface_handle is not None:
                                        return True

                                    if self.internal_ms_ti is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.is_ac_partially_programmed is not None:
                                        return True

                                    if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.ms_ti_mismatch is not None:
                                        return True

                                    if self.msti is not None:
                                        return True

                                    if self.msti_mismatch_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.node_id is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.redundancy_group_id is not None:
                                        return True

                                    if self.redundancy_group_state is not None:
                                        return True

                                    if self.redundancy_object_id is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.tdm_media_mismatched is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit']['meta_info']


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac']['meta_info']


                            class Bvimac(object):
                                """
                                BVI MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bvimac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                    return True

                                if self.bvi_mac_index is not None:
                                    return True

                                if self.bvimac is not None:
                                    for child_ref in self.bvimac:
                                        if child_ref._has_data():
                                            return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-acs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_ac is not None:
                                for child_ref in self.bridge_ac:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs']['meta_info']


                    class BridgeAccessPws(object):
                        """
                        VPLS Bridge Domain Access Pseudowire Table
                        
                        .. attribute:: bridge_access_pw
                        
                        	VPLS Bridge Domain Access Pseudowire
                        	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_access_pw = YList()
                            self.bridge_access_pw.parent = self
                            self.bridge_access_pw.name = 'bridge_access_pw'


                        class BridgeAccessPw(object):
                            """
                            VPLS Bridge Domain Access Pseudowire
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\:  bool
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_access = None
                                self.neighbor = None
                                self.pseudowire = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                self.pseudowire.parent = self
                                self.pseudowire_id = None
                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                self.security_parameters.parent = self
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'


                            class Pseudowire(object):
                                """
                                Pseudowire
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\:  bool
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\:  bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\:  bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\:  bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\:  bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\:  bool
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\:  bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\:  bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\:  bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\:  bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\:  bool
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_evpnvpws_type
                                
                                	is EVPN VPWS
                                	**type**\:  bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\:  bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\:  bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\:  bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\:  bool
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\:  bool
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\:  bool
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\:  bool
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\:  bool
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\:  bool
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\:  bool
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\:  str
                                
                                	**length:** 0..33
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\:  bool
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\:  bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\:  bool
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\:  bool
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\:  bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\:  bool
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\:  bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\:  bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\:  bool
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\:  str
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\:  str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_remote_down = None
                                    self.admited_bw = None
                                    self.auto_discovery = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.backup_pw = None
                                    self.bitrate_mismatched = None
                                    self.bridge_pw_type_mismatch = None
                                    self.cas_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.disable_delay = None
                                    self.disable_never = None
                                    self.encapsulation_info = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self.evpn_src_acid = None
                                    self.fe_ctype = None
                                    self.forward_class = None
                                    self.freq_mismatched = None
                                    self.illegal_control_word = None
                                    self.imposed_vlan_id = None
                                    self.interworking = None
                                    self.ipv6_local_source_address = None
                                    self.is_evpnvpws_type = None
                                    self.is_flow_label_static = None
                                    self.is_multi_segment_pseudowire = None
                                    self.is_partially_programmed = None
                                    self.is_pwr_type = None
                                    self.is_vfi = None
                                    self.last_time_status_changed = None
                                    self.last_time_status_down = None
                                    self.ldp_label_advertise_failed = None
                                    self.load_balance = None
                                    self.local_control_word = None
                                    self.local_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self.local_label_failed = None
                                    self.local_pseudo_wire_type = None
                                    self.local_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self.local_source_address = None
                                    self.mac_limit_oper_down = None
                                    self.mtu_mismatched = None
                                    self.not_supported_qinq = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.out_of_memory_state = None
                                    self.p2mp_pw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                                    self.p2mp_pw.parent = self
                                    self.payload_bytes_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.peer_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self.preferred_path = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self.preferred_path_disable_fallback = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.primary_pw = None
                                    self.protocol = None
                                    self.pseudo_wire_id = None
                                    self.pseudo_wire_state = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.pw_class_name = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_redundancy_initial_delay = None
                                    self.pw_redundancy_one_way = None
                                    self.pw_status_use = None
                                    self.pwlsd_rewrite_failed = None
                                    self.remote_control_word = None
                                    self.remote_interface = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self.remote_label_failed = None
                                    self.remote_pseudo_wire_type = None
                                    self.remote_signalling = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self.required_bw = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.rtp_mismatched = None
                                    self.sequencing_type = None
                                    self.shutdown = None
                                    self.sig_pkts_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self.table_policy_name = None
                                    self.tag_rewrite = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.time_elapsed_status_changed = None
                                    self.time_elapsed_status_down = None
                                    self.transport_lsp_down = None
                                    self.xconnect_id = None


                                class PeerId(object):
                                    """
                                    Peer
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.internal_label = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.internal_label is not None:
                                            return True

                                        if self.ipv4_peer_id is not None:
                                            return True

                                        if self.ipv6_peer_id is not None:
                                            return True

                                        if self.type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId']['meta_info']


                                class EncapsulationInfo(object):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atom = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self.encapsulation = None
                                        self.l2tpv3 = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                        self.l2tpv3.parent = self


                                    class Atom(object):
                                        """
                                        atom
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\:  bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\:  bool
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.is_pseudowire_headend = None
                                            self.is_sai_itype2 = None
                                            self.is_tai_itype2 = None
                                            self.ldp_label_advertisment_failed = None
                                            self.local_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self.local_c_ctype = None
                                            self.local_ceid = None
                                            self.local_cv_type = None
                                            self.local_group_id = None
                                            self.local_label = None
                                            self.local_ldp_id = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.local_veid = None
                                            self.lsd_rewrite_failed = None
                                            self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self.rem_saii = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.remote_agi = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self.remote_c_ctype = None
                                            self.remote_ceid = None
                                            self.remote_cv_type = None
                                            self.remote_group_id = None
                                            self.remote_label = None
                                            self.remote_ldp_id = None
                                            self.remote_source_address = None
                                            self.remote_veid = None
                                            self.saii = None
                                            self.source_address = None
                                            self.taii = None


                                        class LocalAgi(object):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                        class RemoteAgi(object):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self.vpls_id_type = None


                                            class Auto(object):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.asn = None
                                                    self.vpn_id = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.asn is not None:
                                                        return True

                                                    if self.vpn_id is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                            class TwoByteAs(object):
                                                """
                                                two byte as
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.four_byte_index = None
                                                    self.two_byte_as = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.four_byte_index is not None:
                                                        return True

                                                    if self.two_byte_as is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                            class V4Addr(object):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.ipv4_address is not None:
                                                        return True

                                                    if self.two_byte_index is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.auto is not None and self.auto._has_data():
                                                    return True

                                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                    return True

                                                if self.v4_addr is not None and self.v4_addr._has_data():
                                                    return True

                                                if self.vpls_id_type is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                        class MultiSegmentPseudowireStats(object):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.received_bytes = None
                                                self.received_packets = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.received_bytes is not None:
                                                    return True

                                                if self.received_packets is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.is_pseudowire_headend is not None:
                                                return True

                                            if self.is_sai_itype2 is not None:
                                                return True

                                            if self.is_tai_itype2 is not None:
                                                return True

                                            if self.ldp_label_advertisment_failed is not None:
                                                return True

                                            if self.local_agi is not None and self.local_agi._has_data():
                                                return True

                                            if self.local_c_ctype is not None:
                                                return True

                                            if self.local_ceid is not None:
                                                return True

                                            if self.local_cv_type is not None:
                                                return True

                                            if self.local_group_id is not None:
                                                return True

                                            if self.local_label is not None:
                                                return True

                                            if self.local_ldp_id is not None:
                                                return True

                                            if self.local_saii_gbl_id is not None:
                                                return True

                                            if self.local_saiiac_id is not None:
                                                return True

                                            if self.local_taii_gbl_id is not None:
                                                return True

                                            if self.local_taiiac_id is not None:
                                                return True

                                            if self.local_veid is not None:
                                                return True

                                            if self.lsd_rewrite_failed is not None:
                                                return True

                                            if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                                return True

                                            if self.rem_saii is not None:
                                                return True

                                            if self.rem_saii_gbl_id is not None:
                                                return True

                                            if self.rem_saiiac_id is not None:
                                                return True

                                            if self.rem_taii is not None:
                                                return True

                                            if self.rem_taii_gbl_id is not None:
                                                return True

                                            if self.rem_taiiac_id is not None:
                                                return True

                                            if self.remote_agi is not None and self.remote_agi._has_data():
                                                return True

                                            if self.remote_c_ctype is not None:
                                                return True

                                            if self.remote_ceid is not None:
                                                return True

                                            if self.remote_cv_type is not None:
                                                return True

                                            if self.remote_group_id is not None:
                                                return True

                                            if self.remote_label is not None:
                                                return True

                                            if self.remote_ldp_id is not None:
                                                return True

                                            if self.remote_source_address is not None:
                                                return True

                                            if self.remote_veid is not None:
                                                return True

                                            if self.saii is not None:
                                                return True

                                            if self.source_address is not None:
                                                return True

                                            if self.taii is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                    class L2Tpv3(object):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\:  bool
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\:  str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\:  bool
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dont_fragment_bit = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.l2tp_class_name = None
                                            self.local_cookie_high_value = None
                                            self.local_cookie_low_value = None
                                            self.local_cookie_size = None
                                            self.local_secondary_cookie_high_value = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_size = None
                                            self.local_session_id = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.remote_circuit_status_up = None
                                            self.remote_cookie_high_value = None
                                            self.remote_cookie_low_value = None
                                            self.remote_cookie_size = None
                                            self.remote_session_id = None
                                            self.tos = None
                                            self.tos_mode = None
                                            self.ttl = None
                                            self.tunnel_state = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dont_fragment_bit is not None:
                                                return True

                                            if self.ipv4_source_address is not None:
                                                return True

                                            if self.ipv6_source_address is not None:
                                                return True

                                            if self.l2tp_class_name is not None:
                                                return True

                                            if self.local_cookie_high_value is not None:
                                                return True

                                            if self.local_cookie_low_value is not None:
                                                return True

                                            if self.local_cookie_size is not None:
                                                return True

                                            if self.local_secondary_cookie_high_value is not None:
                                                return True

                                            if self.local_secondary_cookie_low_value is not None:
                                                return True

                                            if self.local_secondary_cookie_size is not None:
                                                return True

                                            if self.local_session_id is not None:
                                                return True

                                            if self.path_mtu_enabled is not None:
                                                return True

                                            if self.path_mtu_max_value is not None:
                                                return True

                                            if self.remote_circuit_status_up is not None:
                                                return True

                                            if self.remote_cookie_high_value is not None:
                                                return True

                                            if self.remote_cookie_low_value is not None:
                                                return True

                                            if self.remote_cookie_size is not None:
                                                return True

                                            if self.remote_session_id is not None:
                                                return True

                                            if self.tos is not None:
                                                return True

                                            if self.tos_mode is not None:
                                                return True

                                            if self.ttl is not None:
                                                return True

                                            if self.tunnel_state is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atom is not None and self.atom._has_data():
                                            return True

                                        if self.encapsulation is not None:
                                            return True

                                        if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo']['meta_info']


                                class LocalInterface(object):
                                    """
                                    Local interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface']['meta_info']


                                class RemoteInterface(object):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface']['meta_info']


                                class PreferredPath(object):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ip_tunnel_interface_number = None
                                        self.next_hop_ip = None
                                        self.option = None
                                        self.te_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ip_tunnel_interface_number is not None:
                                            return True

                                        if self.next_hop_ip is not None:
                                            return True

                                        if self.option is not None:
                                            return True

                                        if self.te_tunnel_interface_number is not None:
                                            return True

                                        if self.tp_tunnel_interface_number is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath']['meta_info']


                                class LocalSignalling(object):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling']['meta_info']


                                class RemoteSignalling(object):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.pw_status = None
                                        self.status_tlv = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self.tlv = YList()
                                        self.tlv.parent = self
                                        self.tlv.name = 'tlv'


                                    class StatusTlv(object):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                    class Tlv(object):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\:  str
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.description = None
                                            self.local_address = None
                                            self.pw_id = None
                                            self.remote_address = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.description is not None:
                                                return True

                                            if self.local_address is not None:
                                                return True

                                            if self.pw_id is not None:
                                                return True

                                            if self.remote_address is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.pw_status is not None:
                                            return True

                                        if self.status_tlv is not None and self.status_tlv._has_data():
                                            return True

                                        if self.tlv is not None:
                                            for child_ref in self.tlv:
                                                if child_ref._has_data():
                                                    return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics']['meta_info']


                                class P2MpPw(object):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.local_available = None
                                        self.local_extended_tunnel_id = None
                                        self.local_flags = None
                                        self.local_label = None
                                        self.local_p2mp_id = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.remote_available = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_flags = None
                                        self.remote_label = None
                                        self.remote_p2mp_id = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.local_available is not None:
                                            return True

                                        if self.local_extended_tunnel_id is not None:
                                            return True

                                        if self.local_flags is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_p2mp_id is not None:
                                            return True

                                        if self.local_ptree_type is not None:
                                            return True

                                        if self.local_tunnel_id is not None:
                                            return True

                                        if self.remote_available is not None:
                                            return True

                                        if self.remote_extended_tunnel_id is not None:
                                            return True

                                        if self.remote_flags is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_p2mp_id is not None:
                                            return True

                                        if self.remote_ptree_type is not None:
                                            return True

                                        if self.remote_tunnel_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_remote_down is not None:
                                        return True

                                    if self.admited_bw is not None:
                                        return True

                                    if self.auto_discovery is not None:
                                        return True

                                    if self.backup_active is not None:
                                        return True

                                    if self.backup_force_active is not None:
                                        return True

                                    if self.backup_pw is not None:
                                        return True

                                    if self.bitrate_mismatched is not None:
                                        return True

                                    if self.bridge_pw_type_mismatch is not None:
                                        return True

                                    if self.cas_mismatched is not None:
                                        return True

                                    if self.diff_ts_mismatched is not None:
                                        return True

                                    if self.disable_delay is not None:
                                        return True

                                    if self.disable_never is not None:
                                        return True

                                    if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                        return True

                                    if self.evpn_src_acid is not None:
                                        return True

                                    if self.fe_ctype is not None:
                                        return True

                                    if self.forward_class is not None:
                                        return True

                                    if self.freq_mismatched is not None:
                                        return True

                                    if self.illegal_control_word is not None:
                                        return True

                                    if self.imposed_vlan_id is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.ipv6_local_source_address is not None:
                                        return True

                                    if self.is_evpnvpws_type is not None:
                                        return True

                                    if self.is_flow_label_static is not None:
                                        return True

                                    if self.is_multi_segment_pseudowire is not None:
                                        return True

                                    if self.is_partially_programmed is not None:
                                        return True

                                    if self.is_pwr_type is not None:
                                        return True

                                    if self.is_vfi is not None:
                                        return True

                                    if self.last_time_status_changed is not None:
                                        return True

                                    if self.last_time_status_down is not None:
                                        return True

                                    if self.ldp_label_advertise_failed is not None:
                                        return True

                                    if self.load_balance is not None:
                                        return True

                                    if self.local_control_word is not None:
                                        return True

                                    if self.local_interface is not None and self.local_interface._has_data():
                                        return True

                                    if self.local_label_failed is not None:
                                        return True

                                    if self.local_pseudo_wire_type is not None:
                                        return True

                                    if self.local_signalling is not None and self.local_signalling._has_data():
                                        return True

                                    if self.local_source_address is not None:
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.not_supported_qinq is not None:
                                        return True

                                    if self.num_ma_cwithdraw_msg_received is not None:
                                        return True

                                    if self.number_ma_cwithdraw_message_sent is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                        return True

                                    if self.payload_bytes_mismatched is not None:
                                        return True

                                    if self.payload_type_mismatched is not None:
                                        return True

                                    if self.peer_id is not None and self.peer_id._has_data():
                                        return True

                                    if self.preferred_path is not None and self.preferred_path._has_data():
                                        return True

                                    if self.preferred_path_disable_fallback is not None:
                                        return True

                                    if self.primary_peer_id is not None:
                                        return True

                                    if self.primary_pseudo_wire_id is not None:
                                        return True

                                    if self.primary_pw is not None:
                                        return True

                                    if self.protocol is not None:
                                        return True

                                    if self.pseudo_wire_id is not None:
                                        return True

                                    if self.pseudo_wire_state is not None:
                                        return True

                                    if self.pseudo_wire_type_mismatched is not None:
                                        return True

                                    if self.pw_class_name is not None:
                                        return True

                                    if self.pw_flow_label_code17_disabled is not None:
                                        return True

                                    if self.pw_flow_label_type is not None:
                                        return True

                                    if self.pw_flow_label_type_cfg is not None:
                                        return True

                                    if self.pw_redundancy_initial_delay is not None:
                                        return True

                                    if self.pw_redundancy_one_way is not None:
                                        return True

                                    if self.pw_status_use is not None:
                                        return True

                                    if self.pwlsd_rewrite_failed is not None:
                                        return True

                                    if self.remote_control_word is not None:
                                        return True

                                    if self.remote_interface is not None and self.remote_interface._has_data():
                                        return True

                                    if self.remote_label_failed is not None:
                                        return True

                                    if self.remote_pseudo_wire_type is not None:
                                        return True

                                    if self.remote_signalling is not None and self.remote_signalling._has_data():
                                        return True

                                    if self.required_bw is not None:
                                        return True

                                    if self.resync_enabled is not None:
                                        return True

                                    if self.resync_threshold is not None:
                                        return True

                                    if self.rtp_mismatched is not None:
                                        return True

                                    if self.sequencing_type is not None:
                                        return True

                                    if self.shutdown is not None:
                                        return True

                                    if self.sig_pkts_mismatched is not None:
                                        return True

                                    if self.ssrc_mismatched is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.table_policy_name is not None:
                                        return True

                                    if self.tag_rewrite is not None:
                                        return True

                                    if self.time_created is not None:
                                        return True

                                    if self.time_elapsed_creation is not None:
                                        return True

                                    if self.time_elapsed_status_changed is not None:
                                        return True

                                    if self.time_elapsed_status_down is not None:
                                        return True

                                    if self.transport_lsp_down is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire']['meta_info']


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_access is not None:
                                    return True

                                if self.neighbor is not None:
                                    return True

                                if self.pseudowire is not None and self.pseudowire._has_data():
                                    return True

                                if self.pseudowire_id is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_access_pw is not None:
                                for child_ref in self.bridge_access_pw:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws']['meta_info']


                    class BridgeDomainInfo(object):
                        """
                        VPLS Bridge Domain Information
                        
                        .. attribute:: acpwup
                        
                        	Number of bridge ports (AC,PW) which are up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_
                        
                        	BGP AS number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_access_vfi
                        
                        	Access Virtual Forwarding Interfaces
                        	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                        
                        .. attribute:: bridge_coupled_state
                        
                        	Bridge\-domain coupled state
                        	**type**\:   :py:class:`L2VpnBridgeCoupledStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledStateEnum>`
                        
                        .. attribute:: bridge_description
                        
                        	Human\-readable bridge\-domain description
                        	**type**\:  str
                        
                        .. attribute:: bridge_domain_id
                        
                        	Identification number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_internal_msti
                        
                        	Bridge\-domain internal msti
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_msti
                        
                        	Bridge\-domain msti
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_mtu
                        
                        	Maximum transmission unit
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_name
                        
                        	Bridge\-domain name
                        	**type**\:  str
                        
                        .. attribute:: bridge_shg_id
                        
                        	Bridge\-domain shgid
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_state
                        
                        	Bridge\-domain state
                        	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                        
                        .. attribute:: bridge_type
                        
                        	Bridge\-domain type
                        	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                        
                        .. attribute:: bridge_vfi
                        
                        	Virtual Forwarding Interfaces
                        	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                        
                        .. attribute:: configured
                        
                        	Bridge\-domain is configured
                        	**type**\:  bool
                        
                        .. attribute:: disposition_bytecount
                        
                        	EVPN Disposition Byte Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: disposition_pkt_count
                        
                        	EVPN Disposition Packet Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: evpn_parameters
                        
                        	EVPN parameters
                        	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                        
                        .. attribute:: flodd_group_id_down
                        
                        	Oper down because no FGID
                        	**type**\:  bool
                        
                        .. attribute:: group_name
                        
                        	Group name
                        	**type**\:  str
                        
                        .. attribute:: imposition_byte_count
                        
                        	EVPN Imposition Byte Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: imposition_pkt_count
                        
                        	EVPN Imposition Packet Count
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_bridge_partially_programmed
                        
                        	Bridge is partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_rd_configured
                        
                        	Config or Auto
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the bridge domain status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: mac_filter
                        
                        	MAC addresses for filtering
                        	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                        
                        .. attribute:: mac_limit_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mac_withdraw
                        
                        	MAC withdraw enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_withdraw_access
                        
                        	MAC Access PW withdraw enabled
                        	**type**\:  bool
                        
                        .. attribute:: mac_withdraw_option
                        
                        	Event on which MAC withdraw is sent
                        	**type**\:   :py:class:`L2VpnBagMacWithdrawOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOptionEnum>`
                        
                        .. attribute:: mac_withdraw_relay
                        
                        	MAC Access PW withdraw relaying from access to access enabled
                        	**type**\:  bool
                        
                        .. attribute:: num_vn_is
                        
                        	Number of VNIs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_vn_is_up
                        
                        	Number of VNIs up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs
                        
                        	Number of attachment circuits
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs_up
                        
                        	Number of attachment circuits up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_access_vf_is
                        
                        	Number of Access VFIs
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_p_ws_up
                        
                        	Number of pseudowires up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pb_bs
                        
                        	Number of pbbs
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: number_pb_bs_up
                        
                        	Number of pbbs up
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of pseudowires
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_vf_is
                        
                        	Number of virtual forwarding interfaces
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                        
                        	nV Satellite Offload IPv4 Multicast Disabled
                        	**type**\:  bool
                        
                        .. attribute:: p2mp_enabled
                        
                        	P2MP Enabled on this Bridge Domain
                        	**type**\:  bool
                        
                        .. attribute:: partially_programmed_a_cs
                        
                        	Number of attachment circuits partially programmed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: partially_programmed_pseudowires
                        
                        	Number of pseudowires partially programmed
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pbb_parameters
                        
                        	PBB parameters
                        	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                        
                        .. attribute:: rd
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                        
                        .. attribute:: security_parameters
                        
                        	Security parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                        
                        .. attribute:: shutdown
                        
                        	Administratively disabled
                        	**type**\:  bool
                        
                        .. attribute:: standby_pseudowires
                        
                        	Number of pseudowires standby
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the bridge domain was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: vine_fsm_state
                        
                        	VNI, IRB, Native\-Evpn state
                        	**type**\:  str
                        
                        .. attribute:: vni_parameters
                        
                        	VNI parameters
                        	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.acpwup = None
                            self.as_ = None
                            self.bridge_access_vfi = YList()
                            self.bridge_access_vfi.parent = self
                            self.bridge_access_vfi.name = 'bridge_access_vfi'
                            self.bridge_coupled_state = None
                            self.bridge_description = None
                            self.bridge_domain_id = None
                            self.bridge_internal_msti = None
                            self.bridge_msti = None
                            self.bridge_mtu = None
                            self.bridge_name = None
                            self.bridge_shg_id = None
                            self.bridge_state = None
                            self.bridge_type = None
                            self.bridge_vfi = YList()
                            self.bridge_vfi.parent = self
                            self.bridge_vfi.name = 'bridge_vfi'
                            self.configured = None
                            self.disposition_bytecount = None
                            self.disposition_pkt_count = None
                            self.evi = None
                            self.evpn_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                            self.evpn_parameters.parent = self
                            self.flodd_group_id_down = None
                            self.group_name = None
                            self.imposition_byte_count = None
                            self.imposition_pkt_count = None
                            self.is_bridge_partially_programmed = None
                            self.is_rd_configured = None
                            self.last_time_status_changed = None
                            self.load_balance = None
                            self.mac_filter = YList()
                            self.mac_filter.parent = self
                            self.mac_filter.name = 'mac_filter'
                            self.mac_limit_down = None
                            self.mac_withdraw = None
                            self.mac_withdraw_access = None
                            self.mac_withdraw_option = None
                            self.mac_withdraw_relay = None
                            self.num_vn_is = None
                            self.num_vn_is_up = None
                            self.number_a_cs = None
                            self.number_a_cs_up = None
                            self.number_access_vf_is = None
                            self.number_p_ws_up = None
                            self.number_pb_bs = None
                            self.number_pb_bs_up = None
                            self.number_pseudowires = None
                            self.number_vf_is = None
                            self.nv_satellite_offload_ipv4_multicast_disabled = None
                            self.p2mp_enabled = None
                            self.partially_programmed_a_cs = None
                            self.partially_programmed_pseudowires = None
                            self.pbb_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                            self.pbb_parameters.parent = self
                            self.rd = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                            self.rd.parent = self
                            self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                            self.security_parameters.parent = self
                            self.shutdown = None
                            self.standby_pseudowires = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.vine_fsm_state = None
                            self.vni_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                            self.vni_parameters.parent = self


                        class SecurityParameters(object):
                            """
                            Security parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dai_address_validation_mask = None
                                self.dhcpv4_profile_name = None
                                self.dhcpv4_snoop = None
                                self.flood_unknown_unicast_enabled = None
                                self.flood_uu_disabled_mac_limit_action = None
                                self.igm_pv4_disabled = None
                                self.igm_pv4_profile_name = None
                                self.is_dai_addr_validate_destination_mac_enabled = None
                                self.is_dai_addr_validate_ipv4_enabled = None
                                self.is_dai_addr_validate_source_mac_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_ip_source_guard_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_mac_secure_accept_shutdown_enabled = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.learn_disabled_mac_limit_action = None
                                self.mac_aging_mode = None
                                self.mac_aging_time = None
                                self.mac_flooding = None
                                self.mac_learning = None
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification = None
                                self.mac_limit_reached = None
                                self.mac_port_down_flush_enabled = None
                                self.mac_secure_action = None
                                self.mld_profile_name = None
                                self.mmrp_flood_optimization = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.split_horizon_group_id = None
                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dai_address_validation_mask is not None:
                                    return True

                                if self.dhcpv4_profile_name is not None:
                                    return True

                                if self.dhcpv4_snoop is not None:
                                    return True

                                if self.flood_unknown_unicast_enabled is not None:
                                    return True

                                if self.flood_uu_disabled_mac_limit_action is not None:
                                    return True

                                if self.igm_pv4_disabled is not None:
                                    return True

                                if self.igm_pv4_profile_name is not None:
                                    return True

                                if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_ipv4_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_source_mac_enabled is not None:
                                    return True

                                if self.is_dai_enabled is not None:
                                    return True

                                if self.is_dai_logging_enabled is not None:
                                    return True

                                if self.is_ip_source_guard_enabled is not None:
                                    return True

                                if self.is_ipsg_logging_enabled is not None:
                                    return True

                                if self.is_mac_secure_accept_shutdown_enabled is not None:
                                    return True

                                if self.is_mac_secure_enabled is not None:
                                    return True

                                if self.is_mac_secure_logging_enabled is not None:
                                    return True

                                if self.learn_disabled_mac_limit_action is not None:
                                    return True

                                if self.mac_aging_mode is not None:
                                    return True

                                if self.mac_aging_time is not None:
                                    return True

                                if self.mac_flooding is not None:
                                    return True

                                if self.mac_learning is not None:
                                    return True

                                if self.mac_limit is not None:
                                    return True

                                if self.mac_limit_action is not None:
                                    return True

                                if self.mac_limit_notification is not None:
                                    return True

                                if self.mac_limit_reached is not None:
                                    return True

                                if self.mac_port_down_flush_enabled is not None:
                                    return True

                                if self.mac_secure_action is not None:
                                    return True

                                if self.mld_profile_name is not None:
                                    return True

                                if self.mmrp_flood_optimization is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.split_horizon_group_id is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters']['meta_info']


                        class PbbParameters(object):
                            """
                            PBB parameters
                            
                            .. attribute:: pbb_core
                            
                            	PBB Core
                            	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                            
                            .. attribute:: pbb_edge
                            
                            	PBB Edge
                            	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pbb_core = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                self.pbb_core.parent = self
                                self.pbb_edge = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                self.pbb_edge.parent = self
                                self.type = None


                            class PbbEdge(object):
                                """
                                PBB Edge
                                
                                .. attribute:: core_bridge_name
                                
                                	Core Bridge Domain Name
                                	**type**\:  str
                                
                                .. attribute:: core_bridge_state
                                
                                	Core Bridge State
                                	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                                
                                .. attribute:: edge_port
                                
                                	PBB Edge Port
                                	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                                
                                .. attribute:: i_sid
                                
                                	SID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mirp_lite_protocol
                                
                                	MIRP\-lite protocol info
                                	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfoEnum>`
                                
                                .. attribute:: mirp_lite_status
                                
                                	MIRP\-lite Status
                                	**type**\:   :py:class:`L2VpnMirpLiteStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatusEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_bridge_name = None
                                    self.core_bridge_state = None
                                    self.edge_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                    self.edge_port.parent = self
                                    self.i_sid = None
                                    self.mirp_lite_protocol = None
                                    self.mirp_lite_status = None


                                class EdgePort(object):
                                    """
                                    PBB Edge Port
                                    
                                    .. attribute:: bmac_mapping
                                    
                                    	CMAC to BMAC Mapping
                                    	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                    
                                    .. attribute:: edge_port_state
                                    
                                    	PBB Edge Port State
                                    	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                    
                                    .. attribute:: security_parameters
                                    
                                    	Security Parameters
                                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                    
                                    .. attribute:: unknown_unicast_mac
                                    
                                    	Unknown Unicast MAC
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: unknown_unicast_mac_set
                                    
                                    	Unknown Unicast MAC Configured
                                    	**type**\:  bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bmac_mapping = YList()
                                        self.bmac_mapping.parent = self
                                        self.bmac_mapping.name = 'bmac_mapping'
                                        self.edge_port_state = None
                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                        self.statistics.parent = self
                                        self.unknown_unicast_mac = None
                                        self.unknown_unicast_mac_set = None
                                        self.xconnect_id = None


                                    class SecurityParameters(object):
                                        """
                                        Security Parameters
                                        
                                        .. attribute:: base
                                        
                                        	Basic Security Parameters
                                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dhcpv4_trust
                                        
                                        	DHCPv4 Trust Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dhcpv4_trust = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class Base(object):
                                            """
                                            Basic Security Parameters
                                            
                                            .. attribute:: broadcast_storm_control_kb_ps
                                            
                                            	Broadcast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: broadcast_storm_control_pps
                                            
                                            	Broadcast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: broadcast_storm_control_rate_unit
                                            
                                            	Broadcast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                            
                                            .. attribute:: dai_address_validation_mask
                                            
                                            	DAI Address Validation mask
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: dhcpv4_profile_name
                                            
                                            	DHCPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: dhcpv4_snoop
                                            
                                            	DHCPv4 Snoop Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Flooding unknown unicast enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_uu_disabled_mac_limit_action
                                            
                                            	Flooding of unknown\-unicast disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_disabled
                                            
                                            	IGMPv4 Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_profile_name
                                            
                                            	IGMPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                            
                                            	Is DAI Dstination MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                                            
                                            	Is DAI IPv4 Addr Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ip_source_guard_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                                            
                                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: learn_disabled_mac_limit_action
                                            
                                            	Learning disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_aging_mode
                                            
                                            	MAC Aging Mode
                                            	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: mac_flooding
                                            
                                            	MAC flooding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_learning
                                            
                                            	MAC learning enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC address limit
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                            
                                            .. attribute:: mac_limit_notification
                                            
                                            	MAC limit notification
                                            	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                            
                                            .. attribute:: mac_limit_reached
                                            
                                            	MAC limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_port_down_flush_enabled
                                            
                                            	MAC Flush when port goes down
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC Secure Action
                                            	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                            
                                            .. attribute:: mld_profile_name
                                            
                                            	MLD Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: mmrp_flood_optimization
                                            
                                            	MMRP Flood Optimization Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast_storm_control_kb_ps
                                            
                                            	Multicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: multicast_storm_control_pps
                                            
                                            	Multicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: multicast_storm_control_rate_unit
                                            
                                            	Multicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                            
                                            .. attribute:: split_horizon_group_id
                                            
                                            	Split Horizon Group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: storm_control
                                            
                                            	Storm Control Configuration
                                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                            
                                            .. attribute:: unicast_storm_control_kb_ps
                                            
                                            	Unicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: unicast_storm_control_pps
                                            
                                            	Unicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: unicast_storm_control_rate_unit
                                            
                                            	Unicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast_storm_control_kb_ps = None
                                                self.broadcast_storm_control_pps = None
                                                self.broadcast_storm_control_rate_unit = None
                                                self.dai_address_validation_mask = None
                                                self.dhcpv4_profile_name = None
                                                self.dhcpv4_snoop = None
                                                self.flood_unknown_unicast_enabled = None
                                                self.flood_uu_disabled_mac_limit_action = None
                                                self.igm_pv4_disabled = None
                                                self.igm_pv4_profile_name = None
                                                self.is_dai_addr_validate_destination_mac_enabled = None
                                                self.is_dai_addr_validate_ipv4_enabled = None
                                                self.is_dai_addr_validate_source_mac_enabled = None
                                                self.is_dai_enabled = None
                                                self.is_dai_logging_enabled = None
                                                self.is_ip_source_guard_enabled = None
                                                self.is_ipsg_logging_enabled = None
                                                self.is_mac_secure_accept_shutdown_enabled = None
                                                self.is_mac_secure_enabled = None
                                                self.is_mac_secure_logging_enabled = None
                                                self.learn_disabled_mac_limit_action = None
                                                self.mac_aging_mode = None
                                                self.mac_aging_time = None
                                                self.mac_flooding = None
                                                self.mac_learning = None
                                                self.mac_limit = None
                                                self.mac_limit_action = None
                                                self.mac_limit_notification = None
                                                self.mac_limit_reached = None
                                                self.mac_port_down_flush_enabled = None
                                                self.mac_secure_action = None
                                                self.mld_profile_name = None
                                                self.mmrp_flood_optimization = None
                                                self.multicast_storm_control_kb_ps = None
                                                self.multicast_storm_control_pps = None
                                                self.multicast_storm_control_rate_unit = None
                                                self.split_horizon_group_id = None
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self.unicast_storm_control_kb_ps = None
                                                self.unicast_storm_control_pps = None
                                                self.unicast_storm_control_rate_unit = None


                                            class StormControl(object):
                                                """
                                                Storm Control Configuration
                                                
                                                .. attribute:: bd_policer
                                                
                                                	Bridge Domain Policer
                                                	**type**\:  bool
                                                
                                                .. attribute:: broadcast
                                                
                                                	Broadcast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: multicast
                                                
                                                	Multicast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: unicast
                                                
                                                	Unknown\-unicast Storm Control
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bd_policer = None
                                                    self.broadcast = None
                                                    self.multicast = None
                                                    self.unicast = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bd_policer is not None:
                                                        return True

                                                    if self.broadcast is not None:
                                                        return True

                                                    if self.multicast is not None:
                                                        return True

                                                    if self.unicast is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast_storm_control_kb_ps is not None:
                                                    return True

                                                if self.broadcast_storm_control_pps is not None:
                                                    return True

                                                if self.broadcast_storm_control_rate_unit is not None:
                                                    return True

                                                if self.dai_address_validation_mask is not None:
                                                    return True

                                                if self.dhcpv4_profile_name is not None:
                                                    return True

                                                if self.dhcpv4_snoop is not None:
                                                    return True

                                                if self.flood_unknown_unicast_enabled is not None:
                                                    return True

                                                if self.flood_uu_disabled_mac_limit_action is not None:
                                                    return True

                                                if self.igm_pv4_disabled is not None:
                                                    return True

                                                if self.igm_pv4_profile_name is not None:
                                                    return True

                                                if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                    return True

                                                if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                    return True

                                                if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                    return True

                                                if self.is_dai_enabled is not None:
                                                    return True

                                                if self.is_dai_logging_enabled is not None:
                                                    return True

                                                if self.is_ip_source_guard_enabled is not None:
                                                    return True

                                                if self.is_ipsg_logging_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_logging_enabled is not None:
                                                    return True

                                                if self.learn_disabled_mac_limit_action is not None:
                                                    return True

                                                if self.mac_aging_mode is not None:
                                                    return True

                                                if self.mac_aging_time is not None:
                                                    return True

                                                if self.mac_flooding is not None:
                                                    return True

                                                if self.mac_learning is not None:
                                                    return True

                                                if self.mac_limit is not None:
                                                    return True

                                                if self.mac_limit_action is not None:
                                                    return True

                                                if self.mac_limit_notification is not None:
                                                    return True

                                                if self.mac_limit_reached is not None:
                                                    return True

                                                if self.mac_port_down_flush_enabled is not None:
                                                    return True

                                                if self.mac_secure_action is not None:
                                                    return True

                                                if self.mld_profile_name is not None:
                                                    return True

                                                if self.mmrp_flood_optimization is not None:
                                                    return True

                                                if self.multicast_storm_control_kb_ps is not None:
                                                    return True

                                                if self.multicast_storm_control_pps is not None:
                                                    return True

                                                if self.multicast_storm_control_rate_unit is not None:
                                                    return True

                                                if self.split_horizon_group_id is not None:
                                                    return True

                                                if self.storm_control is not None and self.storm_control._has_data():
                                                    return True

                                                if self.unicast_storm_control_kb_ps is not None:
                                                    return True

                                                if self.unicast_storm_control_pps is not None:
                                                    return True

                                                if self.unicast_storm_control_rate_unit is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base']['meta_info']


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.base is not None and self.base._has_data():
                                                return True

                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dhcpv4_trust is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters']['meta_info']


                                    class Statistics(object):
                                        """
                                        Statistics
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self


                                        class ImpostionStats(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self


                                            class ImpositionStat(object):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                            class ImpositionMtuDrop(object):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                            class ImpostionTailDrop(object):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                            class L2FsbiDrop(object):
                                                """
                                                rx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                            class Multicast(object):
                                                """
                                                Multicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast']['meta_info']


                                            class Broadcast(object):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                            class KnownUnicast(object):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                            class UnknownUnicast(object):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast is not None and self.broadcast._has_data():
                                                    return True

                                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                    return True

                                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                    return True

                                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                    return True

                                                if self.known_unicast is not None and self.known_unicast._has_data():
                                                    return True

                                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                    return True

                                                if self.multicast is not None and self.multicast._has_data():
                                                    return True

                                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats']['meta_info']


                                        class DispostionStats(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self


                                            class DispositionStat(object):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                            class DispositionMtuDrop(object):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                            class DispositionTailDrop(object):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                            class MulticastDrop(object):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                            class UnicastDrop(object):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                            class BroadcastDrop(object):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                            class ReceivedDrops(object):
                                                """
                                                tx discards
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                            class DaiDrop(object):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                            class IpsgDrop(object):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                            class DispositionOoODrops(object):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                            class DispositionP2MpStats(object):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                            class KnownUnicast(object):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                            class MacMove(object):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.byte_counts = None
                                                    self.packet_counts = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.byte_counts is not None:
                                                        return True

                                                    if self.packet_counts is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                    return True

                                                if self.dai_drop is not None and self.dai_drop._has_data():
                                                    return True

                                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                    return True

                                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                    return True

                                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                    return True

                                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                    return True

                                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                    return True

                                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                    return True

                                                if self.known_unicast is not None and self.known_unicast._has_data():
                                                    return True

                                                if self.mac_move is not None and self.mac_move._has_data():
                                                    return True

                                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                    return True

                                                if self.received_drops is not None and self.received_drops._has_data():
                                                    return True

                                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats']['meta_info']


                                        class SequenceNumber(object):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bypassed_inbound_sequence_packet = None
                                                self.bypassed_out_sequence_packet = None
                                                self.sequence_number_expected = None
                                                self.sequence_number_sent = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bypassed_inbound_sequence_packet is not None:
                                                    return True

                                                if self.bypassed_out_sequence_packet is not None:
                                                    return True

                                                if self.sequence_number_expected is not None:
                                                    return True

                                                if self.sequence_number_sent is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                                return True

                                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                                return True

                                            if self.sequence_number is not None and self.sequence_number._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics']['meta_info']


                                    class BmacMapping(object):
                                        """
                                        CMAC to BMAC Mapping
                                        
                                        .. attribute:: address
                                        
                                        	MAC address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: bmac
                                        
                                        	Backbone MAC address
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	Next Hop IP
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.address = None
                                            self.bmac = None
                                            self.next_hop_ip = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bmac-mapping'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.address is not None:
                                                return True

                                            if self.bmac is not None:
                                                return True

                                            if self.next_hop_ip is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:edge-port'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bmac_mapping is not None:
                                            for child_ref in self.bmac_mapping:
                                                if child_ref._has_data():
                                                    return True

                                        if self.edge_port_state is not None:
                                            return True

                                        if self.security_parameters is not None and self.security_parameters._has_data():
                                            return True

                                        if self.statistics is not None and self.statistics._has_data():
                                            return True

                                        if self.unknown_unicast_mac is not None:
                                            return True

                                        if self.unknown_unicast_mac_set is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-edge'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_bridge_name is not None:
                                        return True

                                    if self.core_bridge_state is not None:
                                        return True

                                    if self.edge_port is not None and self.edge_port._has_data():
                                        return True

                                    if self.i_sid is not None:
                                        return True

                                    if self.mirp_lite_protocol is not None:
                                        return True

                                    if self.mirp_lite_status is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge']['meta_info']


                            class PbbCore(object):
                                """
                                PBB Core
                                
                                .. attribute:: core_port
                                
                                	PBB Core Port
                                	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                                
                                .. attribute:: num_ass_edge
                                
                                	Number of Associated PBB Edges
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.core_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                    self.core_port.parent = self
                                    self.num_ass_edge = None


                                class CorePort(object):
                                    """
                                    PBB Core Port
                                    
                                    .. attribute:: core_port_state
                                    
                                    	PBB Core Port State
                                    	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                    
                                    .. attribute:: security_parameters
                                    
                                    	Security Parameters
                                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                    
                                    .. attribute:: vlan_id
                                    
                                    	Vlan ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.core_port_state = None
                                        self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self.vlan_id = None
                                        self.xconnect_id = None


                                    class SecurityParameters(object):
                                        """
                                        Security Parameters
                                        
                                        .. attribute:: base
                                        
                                        	Basic Security Parameters
                                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dhcpv4_trust
                                        
                                        	DHCPv4 Trust Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dhcpv4_trust = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class Base(object):
                                            """
                                            Basic Security Parameters
                                            
                                            .. attribute:: broadcast_storm_control_kb_ps
                                            
                                            	Broadcast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: broadcast_storm_control_pps
                                            
                                            	Broadcast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: broadcast_storm_control_rate_unit
                                            
                                            	Broadcast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                            
                                            .. attribute:: dai_address_validation_mask
                                            
                                            	DAI Address Validation mask
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: dhcpv4_profile_name
                                            
                                            	DHCPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: dhcpv4_snoop
                                            
                                            	DHCPv4 Snoop Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Flooding unknown unicast enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: flood_uu_disabled_mac_limit_action
                                            
                                            	Flooding of unknown\-unicast disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_disabled
                                            
                                            	IGMPv4 Disabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: igm_pv4_profile_name
                                            
                                            	IGMPv4 Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                            
                                            	Is DAI Dstination MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                                            
                                            	Is DAI IPv4 Addr Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ip_source_guard_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                                            
                                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: learn_disabled_mac_limit_action
                                            
                                            	Learning disabled due to MAC limit action
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_aging_mode
                                            
                                            	MAC Aging Mode
                                            	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in seconds
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: mac_flooding
                                            
                                            	MAC flooding enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_learning
                                            
                                            	MAC learning enabled
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC address limit
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                            
                                            .. attribute:: mac_limit_notification
                                            
                                            	MAC limit notification
                                            	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                            
                                            .. attribute:: mac_limit_reached
                                            
                                            	MAC limit reached
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_port_down_flush_enabled
                                            
                                            	MAC Flush when port goes down
                                            	**type**\:  bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC Secure Action
                                            	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                            
                                            .. attribute:: mld_profile_name
                                            
                                            	MLD Profile Name
                                            	**type**\:  str
                                            
                                            .. attribute:: mmrp_flood_optimization
                                            
                                            	MMRP Flood Optimization Status
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast_storm_control_kb_ps
                                            
                                            	Multicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: multicast_storm_control_pps
                                            
                                            	Multicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: multicast_storm_control_rate_unit
                                            
                                            	Multicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                            
                                            .. attribute:: split_horizon_group_id
                                            
                                            	Split Horizon Group ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: storm_control
                                            
                                            	Storm Control Configuration
                                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                            
                                            .. attribute:: unicast_storm_control_kb_ps
                                            
                                            	Unicast Storm Control KbPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: unicast_storm_control_pps
                                            
                                            	Unicast Storm Control PPS
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: unicast_storm_control_rate_unit
                                            
                                            	Unicast Storm Control Rate Unit
                                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.broadcast_storm_control_kb_ps = None
                                                self.broadcast_storm_control_pps = None
                                                self.broadcast_storm_control_rate_unit = None
                                                self.dai_address_validation_mask = None
                                                self.dhcpv4_profile_name = None
                                                self.dhcpv4_snoop = None
                                                self.flood_unknown_unicast_enabled = None
                                                self.flood_uu_disabled_mac_limit_action = None
                                                self.igm_pv4_disabled = None
                                                self.igm_pv4_profile_name = None
                                                self.is_dai_addr_validate_destination_mac_enabled = None
                                                self.is_dai_addr_validate_ipv4_enabled = None
                                                self.is_dai_addr_validate_source_mac_enabled = None
                                                self.is_dai_enabled = None
                                                self.is_dai_logging_enabled = None
                                                self.is_ip_source_guard_enabled = None
                                                self.is_ipsg_logging_enabled = None
                                                self.is_mac_secure_accept_shutdown_enabled = None
                                                self.is_mac_secure_enabled = None
                                                self.is_mac_secure_logging_enabled = None
                                                self.learn_disabled_mac_limit_action = None
                                                self.mac_aging_mode = None
                                                self.mac_aging_time = None
                                                self.mac_flooding = None
                                                self.mac_learning = None
                                                self.mac_limit = None
                                                self.mac_limit_action = None
                                                self.mac_limit_notification = None
                                                self.mac_limit_reached = None
                                                self.mac_port_down_flush_enabled = None
                                                self.mac_secure_action = None
                                                self.mld_profile_name = None
                                                self.mmrp_flood_optimization = None
                                                self.multicast_storm_control_kb_ps = None
                                                self.multicast_storm_control_pps = None
                                                self.multicast_storm_control_rate_unit = None
                                                self.split_horizon_group_id = None
                                                self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self.unicast_storm_control_kb_ps = None
                                                self.unicast_storm_control_pps = None
                                                self.unicast_storm_control_rate_unit = None


                                            class StormControl(object):
                                                """
                                                Storm Control Configuration
                                                
                                                .. attribute:: bd_policer
                                                
                                                	Bridge Domain Policer
                                                	**type**\:  bool
                                                
                                                .. attribute:: broadcast
                                                
                                                	Broadcast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: multicast
                                                
                                                	Multicast Storm Control
                                                	**type**\:  bool
                                                
                                                .. attribute:: unicast
                                                
                                                	Unknown\-unicast Storm Control
                                                	**type**\:  bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bd_policer = None
                                                    self.broadcast = None
                                                    self.multicast = None
                                                    self.unicast = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bd_policer is not None:
                                                        return True

                                                    if self.broadcast is not None:
                                                        return True

                                                    if self.multicast is not None:
                                                        return True

                                                    if self.unicast is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.broadcast_storm_control_kb_ps is not None:
                                                    return True

                                                if self.broadcast_storm_control_pps is not None:
                                                    return True

                                                if self.broadcast_storm_control_rate_unit is not None:
                                                    return True

                                                if self.dai_address_validation_mask is not None:
                                                    return True

                                                if self.dhcpv4_profile_name is not None:
                                                    return True

                                                if self.dhcpv4_snoop is not None:
                                                    return True

                                                if self.flood_unknown_unicast_enabled is not None:
                                                    return True

                                                if self.flood_uu_disabled_mac_limit_action is not None:
                                                    return True

                                                if self.igm_pv4_disabled is not None:
                                                    return True

                                                if self.igm_pv4_profile_name is not None:
                                                    return True

                                                if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                    return True

                                                if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                    return True

                                                if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                    return True

                                                if self.is_dai_enabled is not None:
                                                    return True

                                                if self.is_dai_logging_enabled is not None:
                                                    return True

                                                if self.is_ip_source_guard_enabled is not None:
                                                    return True

                                                if self.is_ipsg_logging_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_enabled is not None:
                                                    return True

                                                if self.is_mac_secure_logging_enabled is not None:
                                                    return True

                                                if self.learn_disabled_mac_limit_action is not None:
                                                    return True

                                                if self.mac_aging_mode is not None:
                                                    return True

                                                if self.mac_aging_time is not None:
                                                    return True

                                                if self.mac_flooding is not None:
                                                    return True

                                                if self.mac_learning is not None:
                                                    return True

                                                if self.mac_limit is not None:
                                                    return True

                                                if self.mac_limit_action is not None:
                                                    return True

                                                if self.mac_limit_notification is not None:
                                                    return True

                                                if self.mac_limit_reached is not None:
                                                    return True

                                                if self.mac_port_down_flush_enabled is not None:
                                                    return True

                                                if self.mac_secure_action is not None:
                                                    return True

                                                if self.mld_profile_name is not None:
                                                    return True

                                                if self.mmrp_flood_optimization is not None:
                                                    return True

                                                if self.multicast_storm_control_kb_ps is not None:
                                                    return True

                                                if self.multicast_storm_control_pps is not None:
                                                    return True

                                                if self.multicast_storm_control_rate_unit is not None:
                                                    return True

                                                if self.split_horizon_group_id is not None:
                                                    return True

                                                if self.storm_control is not None and self.storm_control._has_data():
                                                    return True

                                                if self.unicast_storm_control_kb_ps is not None:
                                                    return True

                                                if self.unicast_storm_control_pps is not None:
                                                    return True

                                                if self.unicast_storm_control_rate_unit is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base']['meta_info']


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.base is not None and self.base._has_data():
                                                return True

                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dhcpv4_trust is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:core-port'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.core_port_state is not None:
                                            return True

                                        if self.security_parameters is not None and self.security_parameters._has_data():
                                            return True

                                        if self.vlan_id is not None:
                                            return True

                                        if self.xconnect_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-core'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.core_port is not None and self.core_port._has_data():
                                        return True

                                    if self.num_ass_edge is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pbb-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pbb_core is not None and self.pbb_core._has_data():
                                    return True

                                if self.pbb_edge is not None and self.pbb_edge._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters']['meta_info']


                        class EvpnParameters(object):
                            """
                            EVPN parameters
                            
                            .. attribute:: evi
                            
                            	E\-VPN id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: evpn_port
                            
                            	EVPN Port
                            	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.evi = None
                                self.evpn_port = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                self.evpn_port.parent = self


                            class EvpnPort(object):
                                """
                                EVPN Port
                                
                                .. attribute:: evpn_port_state
                                
                                	EVPN Port State
                                	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.evpn_port_state = None
                                    self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                    self.statistics.parent = self
                                    self.xconnect_id = None


                                class SecurityParameters(object):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dhcpv4_trust = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class Base(object):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\:  bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\:  str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_profile_name = None
                                            self.dhcpv4_snoop = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.mac_aging_mode = None
                                            self.mac_aging_time = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_limit_reached = None
                                            self.mac_port_down_flush_enabled = None
                                            self.mac_secure_action = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.split_horizon_group_id = None
                                            self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self.unicast_storm_control_kb_ps = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_rate_unit = None


                                        class StormControl(object):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\:  bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\:  bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bd_policer = None
                                                self.broadcast = None
                                                self.multicast = None
                                                self.unicast = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bd_policer is not None:
                                                    return True

                                                if self.broadcast is not None:
                                                    return True

                                                if self.multicast is not None:
                                                    return True

                                                if self.unicast is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_storm_control_kb_ps is not None:
                                                return True

                                            if self.broadcast_storm_control_pps is not None:
                                                return True

                                            if self.broadcast_storm_control_rate_unit is not None:
                                                return True

                                            if self.dai_address_validation_mask is not None:
                                                return True

                                            if self.dhcpv4_profile_name is not None:
                                                return True

                                            if self.dhcpv4_snoop is not None:
                                                return True

                                            if self.flood_unknown_unicast_enabled is not None:
                                                return True

                                            if self.flood_uu_disabled_mac_limit_action is not None:
                                                return True

                                            if self.igm_pv4_disabled is not None:
                                                return True

                                            if self.igm_pv4_profile_name is not None:
                                                return True

                                            if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_ipv4_enabled is not None:
                                                return True

                                            if self.is_dai_addr_validate_source_mac_enabled is not None:
                                                return True

                                            if self.is_dai_enabled is not None:
                                                return True

                                            if self.is_dai_logging_enabled is not None:
                                                return True

                                            if self.is_ip_source_guard_enabled is not None:
                                                return True

                                            if self.is_ipsg_logging_enabled is not None:
                                                return True

                                            if self.is_mac_secure_accept_shutdown_enabled is not None:
                                                return True

                                            if self.is_mac_secure_enabled is not None:
                                                return True

                                            if self.is_mac_secure_logging_enabled is not None:
                                                return True

                                            if self.learn_disabled_mac_limit_action is not None:
                                                return True

                                            if self.mac_aging_mode is not None:
                                                return True

                                            if self.mac_aging_time is not None:
                                                return True

                                            if self.mac_flooding is not None:
                                                return True

                                            if self.mac_learning is not None:
                                                return True

                                            if self.mac_limit is not None:
                                                return True

                                            if self.mac_limit_action is not None:
                                                return True

                                            if self.mac_limit_notification is not None:
                                                return True

                                            if self.mac_limit_reached is not None:
                                                return True

                                            if self.mac_port_down_flush_enabled is not None:
                                                return True

                                            if self.mac_secure_action is not None:
                                                return True

                                            if self.mld_profile_name is not None:
                                                return True

                                            if self.mmrp_flood_optimization is not None:
                                                return True

                                            if self.multicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.multicast_storm_control_pps is not None:
                                                return True

                                            if self.multicast_storm_control_rate_unit is not None:
                                                return True

                                            if self.split_horizon_group_id is not None:
                                                return True

                                            if self.storm_control is not None and self.storm_control._has_data():
                                                return True

                                            if self.unicast_storm_control_kb_ps is not None:
                                                return True

                                            if self.unicast_storm_control_pps is not None:
                                                return True

                                            if self.unicast_storm_control_rate_unit is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base']['meta_info']


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.base is not None and self.base._has_data():
                                            return True

                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dhcpv4_trust is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.evpn_port_state is not None:
                                        return True

                                    if self.security_parameters is not None and self.security_parameters._has_data():
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:evpn-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.evi is not None:
                                    return True

                                if self.evpn_port is not None and self.evpn_port._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters']['meta_info']


                        class VniParameters(object):
                            """
                            VNI parameters
                            
                            .. attribute:: anycast_mcast_group_addr
                            
                            	Anycast Multicast Group Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_vtep_ip_addr
                            
                            	Anycast VTEP IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: multicast_group_addr
                            
                            	Multicast Group Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: overlay
                            
                            	NVE Overlay
                            	**type**\:  str
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                            
                            .. attribute:: source_ip_addr
                            
                            	Source IP Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vni
                            
                            	VNI
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vni_encap_type
                            
                            	VNI Encapsulation Type
                            	**type**\:   :py:class:`L2VpnVniEncapsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncapsEnum>`
                            
                            .. attribute:: vni_mode
                            
                            	VNI Mode
                            	**type**\:   :py:class:`L2VpnVniModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniModeEnum>`
                            
                            .. attribute:: vni_port_state
                            
                            	VNI Port State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.anycast_mcast_group_addr = None
                                self.anycast_vtep_ip_addr = None
                                self.multicast_group_addr = None
                                self.overlay = None
                                self.security_parameters = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                self.security_parameters.parent = self
                                self.source_ip_addr = None
                                self.static_mac = YList()
                                self.static_mac.parent = self
                                self.static_mac.name = 'static_mac'
                                self.statistics = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                self.statistics.parent = self
                                self.udp_port = None
                                self.vni = None
                                self.vni_encap_type = None
                                self.vni_mode = None
                                self.vni_port_state = None
                                self.xconnect_id = None


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics']['meta_info']


                            class StaticMac(object):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vni-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.anycast_mcast_group_addr is not None:
                                    return True

                                if self.anycast_vtep_ip_addr is not None:
                                    return True

                                if self.multicast_group_addr is not None:
                                    return True

                                if self.overlay is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.source_ip_addr is not None:
                                    return True

                                if self.static_mac is not None:
                                    for child_ref in self.static_mac:
                                        if child_ref._has_data():
                                            return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.udp_port is not None:
                                    return True

                                if self.vni is not None:
                                    return True

                                if self.vni_encap_type is not None:
                                    return True

                                if self.vni_mode is not None:
                                    return True

                                if self.vni_port_state is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters']['meta_info']


                        class Rd(object):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                self.auto.parent = self
                                self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rd = None
                                self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                self.v4_addr.parent = self


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto_index = None
                                    self.router_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto_index is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:rd'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rd is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd']['meta_info']


                        class MacFilter(object):
                            """
                            MAC addresses for filtering
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-filter'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter']['meta_info']


                        class BridgeVfi(object):
                            """
                            Virtual Forwarding Interfaces
                            
                            .. attribute:: access
                            
                            	VFI is an Access VFI
                            	**type**\:  bool
                            
                            .. attribute:: discovery_information
                            
                            	Auto Discovery information
                            	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                            
                            .. attribute:: number_pseudowires
                            
                            	Number of Pseudowires
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_information
                            
                            	Multicast P2MP information
                            	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: vfi_name
                            
                            	Virtual forwarding instance name
                            	**type**\:  str
                            
                            .. attribute:: vfi_state
                            
                            	VFI state
                            	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.access = None
                                self.discovery_information = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self.number_pseudowires = None
                                self.p2mp_information = YList()
                                self.p2mp_information.parent = self
                                self.p2mp_information.name = 'p2mp_information'
                                self.shutdown = None
                                self.vfi_name = None
                                self.vfi_state = None


                            class DiscoveryInformation(object):
                                """
                                Auto Discovery information
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_signalling_method
                                
                                	Signaling protocol
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_number
                                
                                	Autonomous System Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: export_route_policy
                                
                                	Export Route Policy
                                	**type**\:  str
                                
                                .. attribute:: export_rt
                                
                                	List of export route targets
                                	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                                
                                .. attribute:: import_rt
                                
                                	List of import route targets
                                	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                                
                                .. attribute:: l2vpn_router_id
                                
                                	L2PVN Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: provisioned_ve_id
                                
                                	Provisioned VPLS edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rd_value
                                
                                	Route Distinguisher
                                	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                                
                                .. attribute:: service_connected
                                
                                	Is the BGP service connected?
                                	**type**\:  bool
                                
                                .. attribute:: ve_id
                                
                                	VPLS Edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_range
                                
                                	VE range
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpls_id
                                
                                	VPLS ID
                                	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                                
                                .. attribute:: vpls_id_conflict
                                
                                	VPLS\-ID Conflict
                                	**type**\:  bool
                                
                                .. attribute:: vpn_added
                                
                                	Is VPN id configured
                                	**type**\:  bool
                                
                                .. attribute:: vpn_id
                                
                                	Vpn ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_signalling_method = None
                                    self.as_number = None
                                    self.export_route_policy = None
                                    self.export_rt = YList()
                                    self.export_rt.parent = self
                                    self.export_rt.name = 'export_rt'
                                    self.import_rt = YList()
                                    self.import_rt.parent = self
                                    self.import_rt.name = 'import_rt'
                                    self.l2vpn_router_id = None
                                    self.provisioned_ve_id = None
                                    self.rd_value = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self.service_connected = None
                                    self.ve_id = None
                                    self.ve_range = None
                                    self.vpls_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self.vpls_id_conflict = None
                                    self.vpn_added = None
                                    self.vpn_id = None


                                class RdValue(object):
                                    """
                                    Route Distinguisher
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                    
                                    .. attribute:: rd
                                    
                                    	RD
                                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self.rd = None
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: auto_index
                                        
                                        	Auto\-generated Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_id
                                        
                                        	BGP Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto_index = None
                                            self.router_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto_index is not None:
                                                return True

                                            if self.router_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                                    class FourByteAs(object):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_as = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_as is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:rd-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue']['meta_info']


                                class VplsId(object):
                                    """
                                    VPLS ID
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId']['meta_info']


                                class ImportRt(object):
                                    """
                                    List of import route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self.rt = None
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                                    class FourByteAs(object):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_as = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_as is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                                    class EsImport(object):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.high_bytes = None
                                            self.low_bytes = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:es-import'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.high_bytes is not None:
                                                return True

                                            if self.low_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:import-rt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.es_import is not None and self.es_import._has_data():
                                            return True

                                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                                            return True

                                        if self.rt is not None:
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt']['meta_info']


                                class ExportRt(object):
                                    """
                                    List of export route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self.rt = None
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                                    class FourByteAs(object):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_as = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_as is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                                    class EsImport(object):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.high_bytes = None
                                            self.low_bytes = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:es-import'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.high_bytes is not None:
                                                return True

                                            if self.low_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:export-rt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.es_import is not None and self.es_import._has_data():
                                            return True

                                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                                            return True

                                        if self.rt is not None:
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_signalling_method is not None:
                                        return True

                                    if self.as_number is not None:
                                        return True

                                    if self.export_route_policy is not None:
                                        return True

                                    if self.export_rt is not None:
                                        for child_ref in self.export_rt:
                                            if child_ref._has_data():
                                                return True

                                    if self.import_rt is not None:
                                        for child_ref in self.import_rt:
                                            if child_ref._has_data():
                                                return True

                                    if self.l2vpn_router_id is not None:
                                        return True

                                    if self.provisioned_ve_id is not None:
                                        return True

                                    if self.rd_value is not None and self.rd_value._has_data():
                                        return True

                                    if self.service_connected is not None:
                                        return True

                                    if self.ve_id is not None:
                                        return True

                                    if self.ve_range is not None:
                                        return True

                                    if self.vpls_id is not None and self.vpls_id._has_data():
                                        return True

                                    if self.vpls_id_conflict is not None:
                                        return True

                                    if self.vpn_added is not None:
                                        return True

                                    if self.vpn_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation']['meta_info']


                            class P2MpInformation(object):
                                """
                                Multicast P2MP information
                                
                                .. attribute:: attribute_set_name
                                
                                	TE Attribute Set Name
                                	**type**\:  str
                                
                                .. attribute:: local_label
                                
                                	P2MP Tunnel Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ptree_id
                                
                                	PTree ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: signaling
                                
                                	P2MP signaling
                                	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                                
                                .. attribute:: transport
                                
                                	P2MP transport
                                	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                                
                                .. attribute:: transport_status
                                
                                	Transport Status
                                	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                                
                                .. attribute:: tunnel_interface
                                
                                	P2MP Tunnel Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.attribute_set_name = None
                                    self.local_label = None
                                    self.ptree_id = None
                                    self.signaling = None
                                    self.transport = None
                                    self.transport_status = None
                                    self.tunnel_interface = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.attribute_set_name is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.ptree_id is not None:
                                        return True

                                    if self.signaling is not None:
                                        return True

                                    if self.transport is not None:
                                        return True

                                    if self.transport_status is not None:
                                        return True

                                    if self.tunnel_interface is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-vfi'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.access is not None:
                                    return True

                                if self.discovery_information is not None and self.discovery_information._has_data():
                                    return True

                                if self.number_pseudowires is not None:
                                    return True

                                if self.p2mp_information is not None:
                                    for child_ref in self.p2mp_information:
                                        if child_ref._has_data():
                                            return True

                                if self.shutdown is not None:
                                    return True

                                if self.vfi_name is not None:
                                    return True

                                if self.vfi_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi']['meta_info']


                        class BridgeAccessVfi(object):
                            """
                            Access Virtual Forwarding Interfaces
                            
                            .. attribute:: access
                            
                            	VFI is an Access VFI
                            	**type**\:  bool
                            
                            .. attribute:: discovery_information
                            
                            	Auto Discovery information
                            	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                            
                            .. attribute:: number_pseudowires
                            
                            	Number of Pseudowires
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_information
                            
                            	Multicast P2MP information
                            	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: vfi_name
                            
                            	Virtual forwarding instance name
                            	**type**\:  str
                            
                            .. attribute:: vfi_state
                            
                            	VFI state
                            	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.access = None
                                self.discovery_information = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self.number_pseudowires = None
                                self.p2mp_information = YList()
                                self.p2mp_information.parent = self
                                self.p2mp_information.name = 'p2mp_information'
                                self.shutdown = None
                                self.vfi_name = None
                                self.vfi_state = None


                            class DiscoveryInformation(object):
                                """
                                Auto Discovery information
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_signalling_method
                                
                                	Signaling protocol
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_number
                                
                                	Autonomous System Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: export_route_policy
                                
                                	Export Route Policy
                                	**type**\:  str
                                
                                .. attribute:: export_rt
                                
                                	List of export route targets
                                	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                                
                                .. attribute:: import_rt
                                
                                	List of import route targets
                                	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                                
                                .. attribute:: l2vpn_router_id
                                
                                	L2PVN Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: provisioned_ve_id
                                
                                	Provisioned VPLS edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rd_value
                                
                                	Route Distinguisher
                                	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                                
                                .. attribute:: service_connected
                                
                                	Is the BGP service connected?
                                	**type**\:  bool
                                
                                .. attribute:: ve_id
                                
                                	VPLS Edge ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_range
                                
                                	VE range
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpls_id
                                
                                	VPLS ID
                                	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                                
                                .. attribute:: vpls_id_conflict
                                
                                	VPLS\-ID Conflict
                                	**type**\:  bool
                                
                                .. attribute:: vpn_added
                                
                                	Is VPN id configured
                                	**type**\:  bool
                                
                                .. attribute:: vpn_id
                                
                                	Vpn ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ad_method = None
                                    self.ad_signalling_method = None
                                    self.as_number = None
                                    self.export_route_policy = None
                                    self.export_rt = YList()
                                    self.export_rt.parent = self
                                    self.export_rt.name = 'export_rt'
                                    self.import_rt = YList()
                                    self.import_rt.parent = self
                                    self.import_rt.name = 'import_rt'
                                    self.l2vpn_router_id = None
                                    self.provisioned_ve_id = None
                                    self.rd_value = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self.service_connected = None
                                    self.ve_id = None
                                    self.ve_range = None
                                    self.vpls_id = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self.vpls_id_conflict = None
                                    self.vpn_added = None
                                    self.vpn_id = None


                                class RdValue(object):
                                    """
                                    Route Distinguisher
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                    
                                    .. attribute:: rd
                                    
                                    	RD
                                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self.rd = None
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: auto_index
                                        
                                        	Auto\-generated Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: router_id
                                        
                                        	BGP Router ID
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto_index = None
                                            self.router_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto_index is not None:
                                                return True

                                            if self.router_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                                    class FourByteAs(object):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_as = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_as is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:rd-value'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                                            return True

                                        if self.rd is not None:
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue']['meta_info']


                                class VplsId(object):
                                    """
                                    VPLS ID
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId']['meta_info']


                                class ImportRt(object):
                                    """
                                    List of import route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self.rt = None
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                                    class FourByteAs(object):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_as = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_as is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                                    class EsImport(object):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.high_bytes = None
                                            self.low_bytes = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:es-import'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.high_bytes is not None:
                                                return True

                                            if self.low_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:import-rt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.es_import is not None and self.es_import._has_data():
                                            return True

                                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                                            return True

                                        if self.rt is not None:
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt']['meta_info']


                                class ExportRt(object):
                                    """
                                    List of export route targets
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.es_import = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self.four_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self.rt = None
                                        self.two_byte_as = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                                    class FourByteAs(object):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_as = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_as is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                                    class EsImport(object):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.high_bytes = None
                                            self.low_bytes = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:es-import'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.high_bytes is not None:
                                                return True

                                            if self.low_bytes is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:export-rt'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.es_import is not None and self.es_import._has_data():
                                            return True

                                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                                            return True

                                        if self.rt is not None:
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ad_method is not None:
                                        return True

                                    if self.ad_signalling_method is not None:
                                        return True

                                    if self.as_number is not None:
                                        return True

                                    if self.export_route_policy is not None:
                                        return True

                                    if self.export_rt is not None:
                                        for child_ref in self.export_rt:
                                            if child_ref._has_data():
                                                return True

                                    if self.import_rt is not None:
                                        for child_ref in self.import_rt:
                                            if child_ref._has_data():
                                                return True

                                    if self.l2vpn_router_id is not None:
                                        return True

                                    if self.provisioned_ve_id is not None:
                                        return True

                                    if self.rd_value is not None and self.rd_value._has_data():
                                        return True

                                    if self.service_connected is not None:
                                        return True

                                    if self.ve_id is not None:
                                        return True

                                    if self.ve_range is not None:
                                        return True

                                    if self.vpls_id is not None and self.vpls_id._has_data():
                                        return True

                                    if self.vpls_id_conflict is not None:
                                        return True

                                    if self.vpn_added is not None:
                                        return True

                                    if self.vpn_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation']['meta_info']


                            class P2MpInformation(object):
                                """
                                Multicast P2MP information
                                
                                .. attribute:: attribute_set_name
                                
                                	TE Attribute Set Name
                                	**type**\:  str
                                
                                .. attribute:: local_label
                                
                                	P2MP Tunnel Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ptree_id
                                
                                	PTree ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: signaling
                                
                                	P2MP signaling
                                	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                                
                                .. attribute:: transport
                                
                                	P2MP transport
                                	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                                
                                .. attribute:: transport_status
                                
                                	Transport Status
                                	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                                
                                .. attribute:: tunnel_interface
                                
                                	P2MP Tunnel Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.attribute_set_name = None
                                    self.local_label = None
                                    self.ptree_id = None
                                    self.signaling = None
                                    self.transport = None
                                    self.transport_status = None
                                    self.tunnel_interface = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.attribute_set_name is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.ptree_id is not None:
                                        return True

                                    if self.signaling is not None:
                                        return True

                                    if self.transport is not None:
                                        return True

                                    if self.transport_status is not None:
                                        return True

                                    if self.tunnel_interface is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.access is not None:
                                    return True

                                if self.discovery_information is not None and self.discovery_information._has_data():
                                    return True

                                if self.number_pseudowires is not None:
                                    return True

                                if self.p2mp_information is not None:
                                    for child_ref in self.p2mp_information:
                                        if child_ref._has_data():
                                            return True

                                if self.shutdown is not None:
                                    return True

                                if self.vfi_name is not None:
                                    return True

                                if self.vfi_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.acpwup is not None:
                                return True

                            if self.as_ is not None:
                                return True

                            if self.bridge_access_vfi is not None:
                                for child_ref in self.bridge_access_vfi:
                                    if child_ref._has_data():
                                        return True

                            if self.bridge_coupled_state is not None:
                                return True

                            if self.bridge_description is not None:
                                return True

                            if self.bridge_domain_id is not None:
                                return True

                            if self.bridge_internal_msti is not None:
                                return True

                            if self.bridge_msti is not None:
                                return True

                            if self.bridge_mtu is not None:
                                return True

                            if self.bridge_name is not None:
                                return True

                            if self.bridge_shg_id is not None:
                                return True

                            if self.bridge_state is not None:
                                return True

                            if self.bridge_type is not None:
                                return True

                            if self.bridge_vfi is not None:
                                for child_ref in self.bridge_vfi:
                                    if child_ref._has_data():
                                        return True

                            if self.configured is not None:
                                return True

                            if self.disposition_bytecount is not None:
                                return True

                            if self.disposition_pkt_count is not None:
                                return True

                            if self.evi is not None:
                                return True

                            if self.evpn_parameters is not None and self.evpn_parameters._has_data():
                                return True

                            if self.flodd_group_id_down is not None:
                                return True

                            if self.group_name is not None:
                                return True

                            if self.imposition_byte_count is not None:
                                return True

                            if self.imposition_pkt_count is not None:
                                return True

                            if self.is_bridge_partially_programmed is not None:
                                return True

                            if self.is_rd_configured is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.mac_filter is not None:
                                for child_ref in self.mac_filter:
                                    if child_ref._has_data():
                                        return True

                            if self.mac_limit_down is not None:
                                return True

                            if self.mac_withdraw is not None:
                                return True

                            if self.mac_withdraw_access is not None:
                                return True

                            if self.mac_withdraw_option is not None:
                                return True

                            if self.mac_withdraw_relay is not None:
                                return True

                            if self.num_vn_is is not None:
                                return True

                            if self.num_vn_is_up is not None:
                                return True

                            if self.number_a_cs is not None:
                                return True

                            if self.number_a_cs_up is not None:
                                return True

                            if self.number_access_vf_is is not None:
                                return True

                            if self.number_p_ws_up is not None:
                                return True

                            if self.number_pb_bs is not None:
                                return True

                            if self.number_pb_bs_up is not None:
                                return True

                            if self.number_pseudowires is not None:
                                return True

                            if self.number_vf_is is not None:
                                return True

                            if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                                return True

                            if self.p2mp_enabled is not None:
                                return True

                            if self.partially_programmed_a_cs is not None:
                                return True

                            if self.partially_programmed_pseudowires is not None:
                                return True

                            if self.pbb_parameters is not None and self.pbb_parameters._has_data():
                                return True

                            if self.rd is not None and self.rd._has_data():
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.standby_pseudowires is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.vine_fsm_state is not None:
                                return True

                            if self.vni_parameters is not None and self.vni_parameters._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-domain'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_access_pws is not None and self.bridge_access_pws._has_data():
                            return True

                        if self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table._has_data():
                            return True

                        if self.bridge_acs is not None and self.bridge_acs._has_data():
                            return True

                        if self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table._has_data():
                            return True

                        if self.bridge_domain_group_name is not None:
                            return True

                        if self.bridge_domain_info is not None and self.bridge_domain_info._has_data():
                            return True

                        if self.bridge_domain_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains.BridgeDomain']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bridge-domains'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_domain is not None:
                        for child_ref in self.bridge_domain:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.BridgeDomains']['meta_info']


            class DiscoverySummary(object):
                """
                Discovery summary information
                
                .. attribute:: bgp_current_node_id
                
                	BGP current node id
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: bgp_ipc_transport_mode
                
                	IPC Transport mode with BGP
                	**type**\:   :py:class:`L2VpnIpcTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportModeEnum>`
                
                .. attribute:: bgp_stateon_active_rp
                
                	BGP state on the active RP
                	**type**\:  bool
                
                .. attribute:: bgp_stateon_standby_rp
                
                	BGP state on standby RP
                	**type**\:  bool
                
                .. attribute:: number_bridge_domainvpns
                
                	Number of BDs registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_local_edges_bridge_domain
                
                	Number of local Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_local_edges_xconnect
                
                	Number of local Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2m_pxconnect_vpns
                
                	Number of XCs registered
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_nlri_bridge_domain
                
                	Number of NLRI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_nlri_xconnect
                
                	Number of NLRI
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_remote_edges_bridge_domain
                
                	Number of Remote Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_remote_edges_xconnect
                
                	Number of Remote Edges
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpls_registered
                
                	Is the VPLS service registered
                	**type**\:  bool
                
                .. attribute:: vpws_registered
                
                	Is the VPWS service registered
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bgp_current_node_id = None
                    self.bgp_ipc_transport_mode = None
                    self.bgp_stateon_active_rp = None
                    self.bgp_stateon_standby_rp = None
                    self.number_bridge_domainvpns = None
                    self.number_local_edges_bridge_domain = None
                    self.number_local_edges_xconnect = None
                    self.number_mp2m_pxconnect_vpns = None
                    self.number_nlri_bridge_domain = None
                    self.number_nlri_xconnect = None
                    self.number_remote_edges_bridge_domain = None
                    self.number_remote_edges_xconnect = None
                    self.vpls_registered = None
                    self.vpws_registered = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:discovery-summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bgp_current_node_id is not None:
                        return True

                    if self.bgp_ipc_transport_mode is not None:
                        return True

                    if self.bgp_stateon_active_rp is not None:
                        return True

                    if self.bgp_stateon_standby_rp is not None:
                        return True

                    if self.number_bridge_domainvpns is not None:
                        return True

                    if self.number_local_edges_bridge_domain is not None:
                        return True

                    if self.number_local_edges_xconnect is not None:
                        return True

                    if self.number_mp2m_pxconnect_vpns is not None:
                        return True

                    if self.number_nlri_bridge_domain is not None:
                        return True

                    if self.number_nlri_xconnect is not None:
                        return True

                    if self.number_remote_edges_bridge_domain is not None:
                        return True

                    if self.number_remote_edges_xconnect is not None:
                        return True

                    if self.vpls_registered is not None:
                        return True

                    if self.vpws_registered is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.DiscoverySummary']['meta_info']


            class G8032(object):
                """
                G8032 information
                
                .. attribute:: g8032_rings
                
                	G8032 Ring table
                	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.g8032_rings = L2Vpnv2.Nodes.Node.G8032.G8032Rings()
                    self.g8032_rings.parent = self


                class G8032Rings(object):
                    """
                    G8032 Ring table
                    
                    .. attribute:: g8032_ring
                    
                    	G8032 Ring
                    	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.g8032_ring = YList()
                        self.g8032_ring.parent = self
                        self.g8032_ring.name = 'g8032_ring'


                    class G8032Ring(object):
                        """
                        G8032 Ring
                        
                        .. attribute:: ring_name  <key>
                        
                        	Ring Name
                        	**type**\:  str
                        
                        	**length:** 1..32
                        
                        .. attribute:: g8032_ring_detail
                        
                        	G8032 Ring detailed information
                        	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                        
                        .. attribute:: g8032_ring_instance_details
                        
                        	G8032 Ring Instance detail table
                        	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                        
                        .. attribute:: g8032_ring_instance_summaries
                        
                        	G8032 Ring Instance summary table
                        	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                        
                        .. attribute:: g8032_ring_summary
                        
                        	G8032 Ring summary information
                        	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ring_name = None
                            self.g8032_ring_detail = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                            self.g8032_ring_detail.parent = self
                            self.g8032_ring_instance_details = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                            self.g8032_ring_instance_details.parent = self
                            self.g8032_ring_instance_summaries = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                            self.g8032_ring_instance_summaries.parent = self
                            self.g8032_ring_summary = L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                            self.g8032_ring_summary.parent = self


                        class G8032RingDetail(object):
                            """
                            G8032 Ring detailed information
                            
                            .. attribute:: excluded_vlan_id
                            
                            	Exclusion Vlan ids list 
                            	**type**\:  list of int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: is_open_ring
                            
                            	Flag open ring
                            	**type**\:  bool
                            
                            .. attribute:: is_provider_bridge
                            
                            	Operating mode Customer/Provider 
                            	**type**\:  bool
                            
                            .. attribute:: monitor0
                            
                            	Monitor port 0
                            	**type**\:  str
                            
                            .. attribute:: monitor1
                            
                            	Monitor port 1
                            	**type**\:  str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            .. attribute:: tcn_propagation
                            
                            	Global TCN propagation
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.excluded_vlan_id = YLeafList()
                                self.excluded_vlan_id.parent = self
                                self.excluded_vlan_id.name = 'excluded_vlan_id'
                                self.is_open_ring = None
                                self.is_provider_bridge = None
                                self.monitor0 = None
                                self.monitor1 = None
                                self.port0 = None
                                self.port1 = None
                                self.ring_name = None
                                self.tcn_propagation = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-detail'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.excluded_vlan_id is not None:
                                    for child in self.excluded_vlan_id:
                                        if child is not None:
                                            return True

                                if self.is_open_ring is not None:
                                    return True

                                if self.is_provider_bridge is not None:
                                    return True

                                if self.monitor0 is not None:
                                    return True

                                if self.monitor1 is not None:
                                    return True

                                if self.port0 is not None:
                                    return True

                                if self.port1 is not None:
                                    return True

                                if self.ring_name is not None:
                                    return True

                                if self.tcn_propagation is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail']['meta_info']


                        class G8032RingInstanceSummaries(object):
                            """
                            G8032 Ring Instance summary table
                            
                            .. attribute:: g8032_ring_instance_summary
                            
                            	G8032 Ring Instance summary information
                            	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.g8032_ring_instance_summary = YList()
                                self.g8032_ring_instance_summary.parent = self
                                self.g8032_ring_instance_summary.name = 'g8032_ring_instance_summary'


                            class G8032RingInstanceSummary(object):
                                """
                                G8032 Ring Instance summary information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: config_state
                                
                                	State of the instance
                                	**type**\:  bool
                                
                                .. attribute:: included_vlan_id
                                
                                	Inclusion list Vlan Ids
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.instance = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.config_state = None
                                    self.included_vlan_id = YLeafList()
                                    self.included_vlan_id.parent = self
                                    self.included_vlan_id.name = 'included_vlan_id'
                                    self.ring_instance = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.instance is None:
                                        raise YPYModelError('Key property instance is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summary[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.instance is not None:
                                        return True

                                    if self.aps_port0 is not None:
                                        return True

                                    if self.aps_port1 is not None:
                                        return True

                                    if self.config_state is not None:
                                        return True

                                    if self.included_vlan_id is not None:
                                        for child in self.included_vlan_id:
                                            if child is not None:
                                                return True

                                    if self.ring_instance is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summaries'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.g8032_ring_instance_summary is not None:
                                    for child_ref in self.g8032_ring_instance_summary:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries']['meta_info']


                        class G8032RingSummary(object):
                            """
                            G8032 Ring summary information
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\:  str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\:  str
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\:  str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.port0 = None
                                self.port1 = None
                                self.ring_name = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-summary'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.port0 is not None:
                                    return True

                                if self.port1 is not None:
                                    return True

                                if self.ring_name is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary']['meta_info']


                        class G8032RingInstanceDetails(object):
                            """
                            G8032 Ring Instance detail table
                            
                            .. attribute:: g8032_ring_instance_detail
                            
                            	G8032 Ring Instance detailed information
                            	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.g8032_ring_instance_detail = YList()
                                self.g8032_ring_instance_detail.parent = self
                                self.g8032_ring_instance_detail.name = 'g8032_ring_instance_detail'


                            class G8032RingInstanceDetail(object):
                                """
                                G8032 Ring Instance detailed information
                                
                                .. attribute:: instance  <key>
                                
                                	Instance
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: aps_channel_level
                                
                                	APS channel level
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\:  str
                                
                                .. attribute:: config_state
                                
                                	State of the instance
                                	**type**\:  bool
                                
                                .. attribute:: included_vlan_id
                                
                                	Inclusion list Vlan Ids
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ring_description
                                
                                	Ring description
                                	**type**\:  str
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_profile
                                
                                	Ring Profile
                                	**type**\:  str
                                
                                .. attribute:: rpl
                                
                                	RPL
                                	**type**\:   :py:class:`L2VpnG8032RplEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032RplEnum>`
                                
                                .. attribute:: unresolved_reason
                                
                                	Reason of unresolved state state
                                	**type**\:   :py:class:`L2VpnG8032UncfgReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReasonEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.instance = None
                                    self.aps_channel_level = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.config_state = None
                                    self.included_vlan_id = YLeafList()
                                    self.included_vlan_id.parent = self
                                    self.included_vlan_id.name = 'included_vlan_id'
                                    self.ring_description = None
                                    self.ring_instance = None
                                    self.ring_profile = None
                                    self.rpl = None
                                    self.unresolved_reason = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.instance is None:
                                        raise YPYModelError('Key property instance is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-detail[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.instance is not None:
                                        return True

                                    if self.aps_channel_level is not None:
                                        return True

                                    if self.aps_port0 is not None:
                                        return True

                                    if self.aps_port1 is not None:
                                        return True

                                    if self.config_state is not None:
                                        return True

                                    if self.included_vlan_id is not None:
                                        for child in self.included_vlan_id:
                                            if child is not None:
                                                return True

                                    if self.ring_description is not None:
                                        return True

                                    if self.ring_instance is not None:
                                        return True

                                    if self.ring_profile is not None:
                                        return True

                                    if self.rpl is not None:
                                        return True

                                    if self.unresolved_reason is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-details'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.g8032_ring_instance_detail is not None:
                                    for child_ref in self.g8032_ring_instance_detail:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.ring_name is None:
                                raise YPYModelError('Key property ring_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring[Cisco-IOS-XR-l2vpn-oper:ring-name = ' + str(self.ring_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ring_name is not None:
                                return True

                            if self.g8032_ring_detail is not None and self.g8032_ring_detail._has_data():
                                return True

                            if self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details._has_data():
                                return True

                            if self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries._has_data():
                                return True

                            if self.g8032_ring_summary is not None and self.g8032_ring_summary._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-rings'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.g8032_ring is not None:
                            for child_ref in self.g8032_ring:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.G8032.G8032Rings']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.g8032_rings is not None and self.g8032_rings._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.G8032']['meta_info']


            class PseudowireClasses(object):
                """
                List of pseudowire classes
                
                .. attribute:: pseudowire_class
                
                	Pseudowire class information
                	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.pseudowire_class = YList()
                    self.pseudowire_class.parent = self
                    self.pseudowire_class.name = 'pseudowire_class'


                class PseudowireClass(object):
                    """
                    Pseudowire class information
                    
                    .. attribute:: pseudowire_class_name  <key>
                    
                    	Pseudowire Class Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: backup_mac_withdraw
                    
                    	TRUE if MAC withdraw message is sent
                    	**type**\:  bool
                    
                    .. attribute:: control_word
                    
                    	Control word
                    	**type**\:   :py:class:`L2VpnPwClassControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWordEnum>`
                    
                    .. attribute:: disable_delay
                    
                    	Disable Deley
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: local_source_address
                    
                    	Local source address
                    	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	PreferredPathDisableFallback
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                    
                    .. attribute:: tag_rewrite
                    
                    	Static tag rewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: transport_mode
                    
                    	Transport mode
                    	**type**\:   :py:class:`L2VpnTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportModeEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.pseudowire_class_name = None
                        self.backup_mac_withdraw = None
                        self.control_word = None
                        self.disable_delay = None
                        self.disable_never = None
                        self.encapsulation_info = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self.is_flow_label_static = None
                        self.load_balance = None
                        self.local_source_address = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                        self.local_source_address.parent = self
                        self.preferred_path = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath()
                        self.preferred_path.parent = self
                        self.preferred_path_disable_fallback = None
                        self.protocol = None
                        self.pw_class_name = None
                        self.pw_flow_label_code17_disabled = None
                        self.pw_flow_label_type_cfg = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.sequencing_type = None
                        self.tag_rewrite = None
                        self.transport_mode = None


                    class EncapsulationInfo(object):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.encapsulation = None
                            self.l2tpv3 = L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self


                        class L2Tpv3(object):
                            """
                            l2tpv3
                            
                            .. attribute:: cookie_size
                            
                            	Cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.cookie_size = None
                                self.dont_fragment_bit = None
                                self.ipv4_source_address = None
                                self.l2tp_class_name = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.tos = None
                                self.tos_mode = None
                                self.ttl = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.cookie_size is not None:
                                    return True

                                if self.dont_fragment_bit is not None:
                                    return True

                                if self.ipv4_source_address is not None:
                                    return True

                                if self.l2tp_class_name is not None:
                                    return True

                                if self.path_mtu_enabled is not None:
                                    return True

                                if self.path_mtu_max_value is not None:
                                    return True

                                if self.tos is not None:
                                    return True

                                if self.tos_mode is not None:
                                    return True

                                if self.ttl is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.encapsulation is not None:
                                return True

                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo']['meta_info']


                    class PreferredPath(object):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ip_tunnel_interface_number = None
                            self.next_hop_ip = None
                            self.option = None
                            self.te_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ip_tunnel_interface_number is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            if self.option is not None:
                                return True

                            if self.te_tunnel_interface_number is not None:
                                return True

                            if self.tp_tunnel_interface_number is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath']['meta_info']


                    class LocalSourceAddress(object):
                        """
                        Local source address
                        
                        .. attribute:: address
                        
                        	Local source address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: configuration
                        
                        	Configuration
                        	**type**\:   :py:class:`L2VpnSrcAddressSetEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSetEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.configuration = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-source-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.configuration is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.pseudowire_class_name is None:
                            raise YPYModelError('Key property pseudowire_class_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-class[Cisco-IOS-XR-l2vpn-oper:pseudowire-class-name = ' + str(self.pseudowire_class_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.pseudowire_class_name is not None:
                            return True

                        if self.backup_mac_withdraw is not None:
                            return True

                        if self.control_word is not None:
                            return True

                        if self.disable_delay is not None:
                            return True

                        if self.disable_never is not None:
                            return True

                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                            return True

                        if self.is_flow_label_static is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.local_source_address is not None and self.local_source_address._has_data():
                            return True

                        if self.preferred_path is not None and self.preferred_path._has_data():
                            return True

                        if self.preferred_path_disable_fallback is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.pw_class_name is not None:
                            return True

                        if self.pw_flow_label_code17_disabled is not None:
                            return True

                        if self.pw_flow_label_type_cfg is not None:
                            return True

                        if self.resync_enabled is not None:
                            return True

                        if self.resync_threshold is not None:
                            return True

                        if self.sequencing_type is not None:
                            return True

                        if self.tag_rewrite is not None:
                            return True

                        if self.transport_mode is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.pseudowire_class is not None:
                        for child_ref in self.pseudowire_class:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.PseudowireClasses']['meta_info']


            class L2VpnCollaborators(object):
                """
                L2VPN collaborator information
                
                .. attribute:: collaborator_statistics
                
                	Collaborator Statistics
                	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.collaborator_statistics = L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics()
                    self.collaborator_statistics.parent = self


                class CollaboratorStatistics(object):
                    """
                    Collaborator Statistics
                    
                    .. attribute:: count
                    
                    	count
                    	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.count = YList()
                        self.count.parent = self
                        self.count.name = 'count'


                    class Count(object):
                        """
                        count
                        
                        .. attribute:: collaborator_name
                        
                        	Collaborator Name
                        	**type**\:  str
                        
                        .. attribute:: down
                        
                        	Down
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_up
                        
                        	Is up
                        	**type**\:  bool
                        
                        .. attribute:: up
                        
                        	Up
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.collaborator_name = None
                            self.down = None
                            self.is_up = None
                            self.up = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:count'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.collaborator_name is not None:
                                return True

                            if self.down is not None:
                                return True

                            if self.is_up is not None:
                                return True

                            if self.up is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics.Count']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.count is not None:
                            for child_ref in self.count:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.L2VpnCollaborators.CollaboratorStatistics']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.collaborator_statistics is not None and self.collaborator_statistics._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.L2VpnCollaborators']['meta_info']


            class Mvrp(object):
                """
                MVRP
                
                .. attribute:: mvrp_main_ports
                
                	MVRP Main Port Table
                	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mvrp_main_ports = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts()
                    self.mvrp_main_ports.parent = self


                class MvrpMainPorts(object):
                    """
                    MVRP Main Port Table
                    
                    .. attribute:: mvrp_main_port
                    
                    	MVRP Main Port
                    	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.mvrp_main_port = YList()
                        self.mvrp_main_port.parent = self
                        self.mvrp_main_port.name = 'mvrp_main_port'


                    class MvrpMainPort(object):
                        """
                        MVRP Main Port
                        
                        .. attribute:: main_port_interface_name  <key>
                        
                        	Main Port interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: mvrp_bridge_ports
                        
                        	MVRP Bridge Port Table
                        	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                        
                        .. attribute:: mvrp_main_port_info
                        
                        	MVRP Main Port Information
                        	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.main_port_interface_name = None
                            self.mvrp_bridge_ports = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                            self.mvrp_bridge_ports.parent = self
                            self.mvrp_main_port_info = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                            self.mvrp_main_port_info.parent = self


                        class MvrpMainPortInfo(object):
                            """
                            MVRP Main Port Information
                            
                            .. attribute:: default_bridge_port
                            
                            	Trunk or default Bridge Port
                            	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                            
                            .. attribute:: is_default_encap
                            
                            	Is default encap set
                            	**type**\:  bool
                            
                            .. attribute:: is_trunk
                            
                            	Is main port a trunk
                            	**type**\:  bool
                            
                            .. attribute:: main_port_interface_name
                            
                            	Main Port Interface name
                            	**type**\:  str
                            
                            .. attribute:: number_of_bridge_ports
                            
                            	Number of Bridge Ports
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.default_bridge_port = L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                self.default_bridge_port.parent = self
                                self.is_default_encap = None
                                self.is_trunk = None
                                self.main_port_interface_name = None
                                self.number_of_bridge_ports = None


                            class DefaultBridgePort(object):
                                """
                                Trunk or default Bridge Port
                                
                                .. attribute:: bridge_port_interface_name
                                
                                	Bridge port Interface name
                                	**type**\:  str
                                
                                .. attribute:: bridge_port_xconnect_id
                                
                                	Bridge port XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvrp_sequence_number
                                
                                	MVRP Sequence Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan_range
                                
                                	VLAN IDs
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bridge_port_interface_name = None
                                    self.bridge_port_xconnect_id = None
                                    self.mvrp_sequence_number = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'


                                class VlanRange(object):
                                    """
                                    VLAN IDs
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:default-bridge-port'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bridge_port_interface_name is not None:
                                        return True

                                    if self.bridge_port_xconnect_id is not None:
                                        return True

                                    if self.mvrp_sequence_number is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.default_bridge_port is not None and self.default_bridge_port._has_data():
                                    return True

                                if self.is_default_encap is not None:
                                    return True

                                if self.is_trunk is not None:
                                    return True

                                if self.main_port_interface_name is not None:
                                    return True

                                if self.number_of_bridge_ports is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo']['meta_info']


                        class MvrpBridgePorts(object):
                            """
                            MVRP Bridge Port Table
                            
                            .. attribute:: mvrp_bridge_port
                            
                            	MVRP Bridge Port Information
                            	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mvrp_bridge_port = YList()
                                self.mvrp_bridge_port.parent = self
                                self.mvrp_bridge_port.name = 'mvrp_bridge_port'


                            class MvrpBridgePort(object):
                                """
                                MVRP Bridge Port Information
                                
                                .. attribute:: interface_name  <key>
                                
                                	Bridge Port Interface Name
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: bridge_port_interface_name
                                
                                	Bridge port Interface name
                                	**type**\:  str
                                
                                .. attribute:: bridge_port_xconnect_id
                                
                                	Bridge port XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvrp_sequence_number
                                
                                	MVRP Sequence Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan_range
                                
                                	VLAN IDs
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_name = None
                                    self.bridge_port_interface_name = None
                                    self.bridge_port_xconnect_id = None
                                    self.mvrp_sequence_number = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'


                                class VlanRange(object):
                                    """
                                    VLAN IDs
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')
                                    if self.interface_name is None:
                                        raise YPYModelError('Key property interface_name is None')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-port[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_name is not None:
                                        return True

                                    if self.bridge_port_interface_name is not None:
                                        return True

                                    if self.bridge_port_xconnect_id is not None:
                                        return True

                                    if self.mvrp_sequence_number is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-ports'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mvrp_bridge_port is not None:
                                    for child_ref in self.mvrp_bridge_port:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.main_port_interface_name is None:
                                raise YPYModelError('Key property main_port_interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port[Cisco-IOS-XR-l2vpn-oper:main-port-interface-name = ' + str(self.main_port_interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.main_port_interface_name is not None:
                                return True

                            if self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports._has_data():
                                return True

                            if self.mvrp_main_port_info is not None and self.mvrp_main_port_info._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.mvrp_main_port is not None:
                            for child_ref in self.mvrp_main_port:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp.MvrpMainPorts']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mvrp_main_ports is not None and self.mvrp_main_ports._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.Mvrp']['meta_info']


            class GenericInterfaces(object):
                """
                L2VPN generic interface list Table
                
                .. attribute:: generic_interface
                
                	Generic Interface List information
                	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.generic_interface = YList()
                    self.generic_interface.parent = self
                    self.generic_interface.name = 'generic_interface'


                class GenericInterface(object):
                    """
                    Generic Interface List information
                    
                    .. attribute:: interface_list_name  <key>
                    
                    	Generic Interface List Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_list_name = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'
                        self.interface_list_id = None
                        self.interface_list_name_xr = None
                        self.items = None
                        self.number_of_interfaces = None


                    class Interface(object):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_fib_downloaded = None
                            self.not_supported_replications = None
                            self.pending_replications = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_fib_downloaded is not None:
                                return True

                            if self.not_supported_replications is not None:
                                return True

                            if self.pending_replications is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_list_name is None:
                            raise YPYModelError('Key property interface_list_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_list_name is not None:
                            return True

                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        if self.interface_list_id is not None:
                            return True

                        if self.interface_list_name_xr is not None:
                            return True

                        if self.items is not None:
                            return True

                        if self.number_of_interfaces is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaces.GenericInterface']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.generic_interface is not None:
                        for child_ref in self.generic_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.GenericInterfaces']['meta_info']


            class MstpVlans(object):
                """
                L2VPN MSTP VLAN Table
                
                .. attribute:: mstp_vlan
                
                	L2VPN MSTP VLAN information
                	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.mstp_vlan = YList()
                    self.mstp_vlan.parent = self
                    self.mstp_vlan.name = 'mstp_vlan'


                class MstpVlan(object):
                    """
                    L2VPN MSTP VLAN information
                    
                    .. attribute:: vlan_id  <key>
                    
                    	vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4098
                    
                    .. attribute:: msti_id
                    
                    	MSTI id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_count
                    
                    	Port Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sub_interface
                    
                    	Sub interfaces
                    	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface>`
                    
                    .. attribute:: vlan_id_xr
                    
                    	Vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.vlan_id = None
                        self.msti_id = None
                        self.port_count = None
                        self.sub_interface = YList()
                        self.sub_interface.parent = self
                        self.sub_interface.name = 'sub_interface'
                        self.vlan_id_xr = None


                    class SubInterface(object):
                        """
                        Sub interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sub-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.vlan_id is None:
                            raise YPYModelError('Key property vlan_id is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mstp-vlan[Cisco-IOS-XR-l2vpn-oper:vlan-id = ' + str(self.vlan_id) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.vlan_id is not None:
                            return True

                        if self.msti_id is not None:
                            return True

                        if self.port_count is not None:
                            return True

                        if self.sub_interface is not None:
                            for child_ref in self.sub_interface:
                                if child_ref._has_data():
                                    return True

                        if self.vlan_id_xr is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.MstpVlans.MstpVlan']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mstp-vlans'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.mstp_vlan is not None:
                        for child_ref in self.mstp_vlan:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.MstpVlans']['meta_info']


            class L2VpnPbbBsa(object):
                """
                L2VPN PBB Backbone Source MAC information
                
                .. attribute:: bmac_sa
                
                	BMAC SA
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: chassis_is_provisioned
                
                	Chassis MAC is configured
                	**type**\:  bool
                
                .. attribute:: chassis_mac
                
                	Chassis MAC
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: provisioned
                
                	BMAC SA configured
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bmac_sa = None
                    self.chassis_is_provisioned = None
                    self.chassis_mac = None
                    self.provisioned = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-pbb-bsa'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bmac_sa is not None:
                        return True

                    if self.chassis_is_provisioned is not None:
                        return True

                    if self.chassis_mac is not None:
                        return True

                    if self.provisioned is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.L2VpnPbbBsa']['meta_info']


            class FlexibleXconnectServices(object):
                """
                Flexible XConnect Service Table
                
                .. attribute:: flexible_xconnect_service
                
                	Flexible XConnect Service Information
                	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.flexible_xconnect_service = YList()
                    self.flexible_xconnect_service.parent = self
                    self.flexible_xconnect_service.name = 'flexible_xconnect_service'


                class FlexibleXconnectService(object):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: name  <key>
                    
                    	Flexible XConnect Service Name
                    	**type**\:  str
                    
                    	**length:** 1..23
                    
                    .. attribute:: flexible_xconnect_service_acs
                    
                    	Flexible XConnect Service Attachment Circuit Table
                    	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                    
                    .. attribute:: flexible_xconnect_service_info
                    
                    	Flexible XConnect Service Information
                    	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.name = None
                        self.flexible_xconnect_service_acs = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                        self.flexible_xconnect_service_acs.parent = self
                        self.flexible_xconnect_service_info = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                        self.flexible_xconnect_service_info.parent = self


                    class FlexibleXconnectServiceAcs(object):
                        """
                        Flexible XConnect Service Attachment Circuit
                        Table
                        
                        .. attribute:: flexible_xconnect_service_ac
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.flexible_xconnect_service_ac = YList()
                            self.flexible_xconnect_service_ac.parent = self
                            self.flexible_xconnect_service_ac.name = 'flexible_xconnect_service_ac'


                        class FlexibleXconnectServiceAc(object):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: interface_name  <key>
                            
                            	Interface Name
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: attachment_circuit
                            
                            	Flexible XConnect Service Attachment Circuit
                            	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.interface_name = None
                                self.attachment_circuit = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self


                            class AttachmentCircuit(object):
                                """
                                Flexible XConnect Service Attachment Circuit
                                
                                .. attribute:: bvi_mac_conflict
                                
                                	BVI Mac Conflict
                                	**type**\:  bool
                                
                                .. attribute:: bvi_no_port_up
                                
                                	BVI no BP Up
                                	**type**\:  bool
                                
                                .. attribute:: control_word_mismatched
                                
                                	Control word mismatched
                                	**type**\:  bool
                                
                                .. attribute:: encapsulation_error
                                
                                	Encapsulation Error
                                	**type**\:  str
                                
                                .. attribute:: encapsulation_mismatched
                                
                                	Encapsulation mismatched
                                	**type**\:  bool
                                
                                .. attribute:: evpn_internal_label
                                
                                	EVPN Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface
                                
                                	Interface
                                	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                                
                                .. attribute:: interface_handle
                                
                                	Interface Handler
                                	**type**\:  str
                                
                                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                                
                                .. attribute:: internal_ms_ti
                                
                                	Internal MSTi
                                	**type**\:  str
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                                
                                .. attribute:: is_ac_partially_programmed
                                
                                	Is attachment\-circuit partially programmed
                                	**type**\:  bool
                                
                                .. attribute:: l2vpn_protection
                                
                                	Protection object used for this segment
                                	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: ms_ti_mismatch
                                
                                	MSTi mismatch
                                	**type**\:  bool
                                
                                .. attribute:: msti
                                
                                	MSTi
                                	**type**\:  str
                                
                                .. attribute:: msti_mismatch_down
                                
                                	Oper down due to MSTI mismatch
                                	**type**\:  bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\:  bool
                                
                                .. attribute:: node_id
                                
                                	Node ID
                                	**type**\:  str
                                
                                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_id
                                
                                	Redundancy Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_state
                                
                                	Redundancy Group State
                                	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                                
                                .. attribute:: redundancy_object_id
                                
                                	Redundancy Object ID
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                                
                                .. attribute:: tdm_media_mismatched
                                
                                	TDM media parms mismatched
                                	**type**\:  bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bvi_mac_conflict = None
                                    self.bvi_no_port_up = None
                                    self.control_word_mismatched = None
                                    self.encapsulation_error = None
                                    self.encapsulation_mismatched = None
                                    self.evpn_internal_label = None
                                    self.interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self.interface_handle = None
                                    self.internal_ms_ti = None
                                    self.interworking = None
                                    self.is_ac_partially_programmed = None
                                    self.l2vpn_protection = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self.mac_limit_oper_down = None
                                    self.ms_ti_mismatch = None
                                    self.msti = None
                                    self.msti_mismatch_down = None
                                    self.mtu_mismatched = None
                                    self.node_id = None
                                    self.out_of_memory_state = None
                                    self.redundancy_group_id = None
                                    self.redundancy_group_state = None
                                    self.redundancy_object_id = None
                                    self.state = None
                                    self.statistics = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self.tdm_media_mismatched = None
                                    self.xconnect_id = None


                                class Interface(object):
                                    """
                                    Interface
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\:  str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.mtu = None
                                        self.name = None
                                        self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self.payload_bytes = None


                                    class Parameters(object):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self.type = None
                                            self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self


                                        class Ethernet(object):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.xconnect_tags = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                        class Vlan(object):
                                            """
                                            VLAN
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\:  list of int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None
                                                self.rewrite_tag = YLeafList()
                                                self.rewrite_tag.parent = self
                                                self.rewrite_tag.name = 'rewrite_tag'
                                                self.simple_efp = None
                                                self.vlan_range = YList()
                                                self.vlan_range.parent = self
                                                self.vlan_range.name = 'vlan_range'
                                                self.vlan_rewrite_tag = None
                                                self.xconnect_tags = None


                                            class VlanRange(object):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.lower = None
                                                    self.upper = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.lower is not None:
                                                        return True

                                                    if self.upper is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.encapsulation_type is not None:
                                                    return True

                                                if self.outer_tag is not None:
                                                    return True

                                                if self.rewrite_tag is not None:
                                                    for child in self.rewrite_tag:
                                                        if child is not None:
                                                            return True

                                                if self.simple_efp is not None:
                                                    return True

                                                if self.vlan_range is not None:
                                                    for child_ref in self.vlan_range:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.vlan_rewrite_tag is not None:
                                                    return True

                                                if self.xconnect_tags is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                        class Tdm(object):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\:  str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.tdm_mode = None
                                                self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self.timeslot_group = None
                                                self.timeslot_rate = None


                                            class TdmOptions(object):
                                                """
                                                TDM options
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.bit_rate = None
                                                    self.cas = None
                                                    self.payload_bytes = None
                                                    self.rtp = None
                                                    self.rtp_header_payload_type = None
                                                    self.signalling_packets = None
                                                    self.ssrc = None
                                                    self.timestamp_clock_freq = None
                                                    self.timestamp_mode = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.bit_rate is not None:
                                                        return True

                                                    if self.cas is not None:
                                                        return True

                                                    if self.payload_bytes is not None:
                                                        return True

                                                    if self.rtp is not None:
                                                        return True

                                                    if self.rtp_header_payload_type is not None:
                                                        return True

                                                    if self.signalling_packets is not None:
                                                        return True

                                                    if self.ssrc is not None:
                                                        return True

                                                    if self.timestamp_clock_freq is not None:
                                                        return True

                                                    if self.timestamp_mode is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.tdm_mode is not None:
                                                    return True

                                                if self.tdm_options is not None and self.tdm_options._has_data():
                                                    return True

                                                if self.timeslot_group is not None:
                                                    return True

                                                if self.timeslot_rate is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                        class Atm(object):
                                            """
                                            ATM
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.atm_mode = None
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.vci = None
                                                self.vpi = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.atm_mode is not None:
                                                    return True

                                                if self.maximum_number_cells_packed is not None:
                                                    return True

                                                if self.maximum_number_cells_un_packed is not None:
                                                    return True

                                                if self.vci is not None:
                                                    return True

                                                if self.vpi is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                        class Fr(object):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.dlci = None
                                                self.fr_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.dlci is not None:
                                                    return True

                                                if self.fr_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                        class PseudowireEther(object):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface_(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                        class PseudowireIw(object):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self.internal_label = None
                                                self.is_valid = None


                                            class InterfaceList(object):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\:  str
                                                
                                                	**length:** 0..33
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface = YList()
                                                    self.interface.parent = self
                                                    self.interface.name = 'interface'
                                                    self.interface_list_id = None
                                                    self.interface_list_name = None


                                                class Interface_(object):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        self.parent = None
                                                        self.interface_name = None
                                                        self.replicate_status = None

                                                    @property
                                                    def _common_path(self):
                                                        if self.parent is None:
                                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                    def is_config(self):
                                                        ''' Returns True if this instance represents config data else returns False '''
                                                        return False

                                                    def _has_data(self):
                                                        if not self.is_config():
                                                            return False
                                                        if self.interface_name is not None:
                                                            return True

                                                        if self.replicate_status is not None:
                                                            return True

                                                        return False

                                                    @staticmethod
                                                    def _meta_info():
                                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface is not None:
                                                        for child_ref in self.interface:
                                                            if child_ref._has_data():
                                                                return True

                                                    if self.interface_list_id is not None:
                                                        return True

                                                    if self.interface_list_name is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_list is not None and self.interface_list._has_data():
                                                    return True

                                                if self.internal_label is not None:
                                                    return True

                                                if self.is_valid is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm is not None and self.atm._has_data():
                                                return True

                                            if self.ethernet is not None and self.ethernet._has_data():
                                                return True

                                            if self.fr is not None and self.fr._has_data():
                                                return True

                                            if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                                return True

                                            if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                                return True

                                            if self.tdm is not None and self.tdm._has_data():
                                                return True

                                            if self.type is not None:
                                                return True

                                            if self.vlan is not None and self.vlan._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.mtu is not None:
                                            return True

                                        if self.name is not None:
                                            return True

                                        if self.parameters is not None and self.parameters._has_data():
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface']['meta_info']


                                class Statistics(object):
                                    """
                                    Statistics
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dispostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self.impostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self.sequence_number = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self


                                    class ImpostionStats(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self.imposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self.impostion_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.l2fsbi_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self.multicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self.unknown_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self


                                        class ImpositionStat(object):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                        class ImpositionMtuDrop(object):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                        class ImpostionTailDrop(object):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                        class L2FsbiDrop(object):
                                            """
                                            rx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                        class Multicast(object):
                                            """
                                            Multicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                        class Broadcast(object):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                        class UnknownUnicast(object):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast is not None and self.broadcast._has_data():
                                                return True

                                            if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                                return True

                                            if self.imposition_stat is not None and self.imposition_stat._has_data():
                                                return True

                                            if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                                return True

                                            if self.multicast is not None and self.multicast._has_data():
                                                return True

                                            if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                                    class DispostionStats(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.broadcast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self.dai_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self.disposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self.disposition_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self.ipsg_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self.mac_move = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self.multicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self.received_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self.unicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self


                                        class DispositionStat(object):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                        class DispositionMtuDrop(object):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                        class DispositionTailDrop(object):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                        class MulticastDrop(object):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                        class UnicastDrop(object):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                        class BroadcastDrop(object):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                        class ReceivedDrops(object):
                                            """
                                            tx discards
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                        class DaiDrop(object):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                        class IpsgDrop(object):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                        class DispositionOoODrops(object):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                        class DispositionP2MpStats(object):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                        class KnownUnicast(object):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                        class MacMove(object):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.byte_counts = None
                                                self.packet_counts = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.byte_counts is not None:
                                                    return True

                                                if self.packet_counts is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                                return True

                                            if self.dai_drop is not None and self.dai_drop._has_data():
                                                return True

                                            if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                                return True

                                            if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                                return True

                                            if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                                return True

                                            if self.disposition_stat is not None and self.disposition_stat._has_data():
                                                return True

                                            if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                                return True

                                            if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                                return True

                                            if self.known_unicast is not None and self.known_unicast._has_data():
                                                return True

                                            if self.mac_move is not None and self.mac_move._has_data():
                                                return True

                                            if self.multicast_drop is not None and self.multicast_drop._has_data():
                                                return True

                                            if self.received_drops is not None and self.received_drops._has_data():
                                                return True

                                            if self.unicast_drop is not None and self.unicast_drop._has_data():
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                                    class SequenceNumber(object):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self.sequence_number_expected = None
                                            self.sequence_number_sent = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bypassed_inbound_sequence_packet is not None:
                                                return True

                                            if self.bypassed_out_sequence_packet is not None:
                                                return True

                                            if self.sequence_number_expected is not None:
                                                return True

                                            if self.sequence_number_sent is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                            return True

                                        if self.impostion_stats is not None and self.impostion_stats._has_data():
                                            return True

                                        if self.sequence_number is not None and self.sequence_number._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics']['meta_info']


                                class L2VpnProtection(object):
                                    """
                                    Protection object used for this segment
                                    
                                    .. attribute:: active
                                    
                                    	Active
                                    	**type**\:  bool
                                    
                                    .. attribute:: protected_name
                                    
                                    	Name of the protected segment
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_configured
                                    
                                    	Protection configured
                                    	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                                    
                                    .. attribute:: protection_name
                                    
                                    	Name of the segment acting as backup
                                    	**type**\:  str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protection_type
                                    
                                    	Type of the protection
                                    	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.active = None
                                        self.protected_name = None
                                        self.protection_configured = None
                                        self.protection_name = None
                                        self.protection_type = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.active is not None:
                                            return True

                                        if self.protected_name is not None:
                                            return True

                                        if self.protection_configured is not None:
                                            return True

                                        if self.protection_name is not None:
                                            return True

                                        if self.protection_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bvi_mac_conflict is not None:
                                        return True

                                    if self.bvi_no_port_up is not None:
                                        return True

                                    if self.control_word_mismatched is not None:
                                        return True

                                    if self.encapsulation_error is not None:
                                        return True

                                    if self.encapsulation_mismatched is not None:
                                        return True

                                    if self.evpn_internal_label is not None:
                                        return True

                                    if self.interface is not None and self.interface._has_data():
                                        return True

                                    if self.interface_handle is not None:
                                        return True

                                    if self.internal_ms_ti is not None:
                                        return True

                                    if self.interworking is not None:
                                        return True

                                    if self.is_ac_partially_programmed is not None:
                                        return True

                                    if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                        return True

                                    if self.mac_limit_oper_down is not None:
                                        return True

                                    if self.ms_ti_mismatch is not None:
                                        return True

                                    if self.msti is not None:
                                        return True

                                    if self.msti_mismatch_down is not None:
                                        return True

                                    if self.mtu_mismatched is not None:
                                        return True

                                    if self.node_id is not None:
                                        return True

                                    if self.out_of_memory_state is not None:
                                        return True

                                    if self.redundancy_group_id is not None:
                                        return True

                                    if self.redundancy_group_state is not None:
                                        return True

                                    if self.redundancy_object_id is not None:
                                        return True

                                    if self.state is not None:
                                        return True

                                    if self.statistics is not None and self.statistics._has_data():
                                        return True

                                    if self.tdm_media_mismatched is not None:
                                        return True

                                    if self.xconnect_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.interface_name is None:
                                    raise YPYModelError('Key property interface_name is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.interface_name is not None:
                                    return True

                                if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-acs'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.flexible_xconnect_service_ac is not None:
                                for child_ref in self.flexible_xconnect_service_ac:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs']['meta_info']


                    class FlexibleXconnectServiceInfo(object):
                        """
                        Flexible XConnect Service Information
                        
                        .. attribute:: name
                        
                        	Flexible XConnect Service Name
                        	**type**\:  str
                        
                        .. attribute:: num_p_ws
                        
                        	Number of Pseudowires in Pseudowire List
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pseudowire
                        
                        	Flexible XConnect Service Pseudowire List
                        	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                        
                        .. attribute:: state
                        
                        	State of the Flexible XConnect Service
                        	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.name = None
                            self.num_p_ws = None
                            self.pseudowire = YList()
                            self.pseudowire.parent = self
                            self.pseudowire.name = 'pseudowire'
                            self.state = None


                        class Pseudowire(object):
                            """
                            Flexible XConnect Service Pseudowire List
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):
                                                    if self.parent is None:
                                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.name is not None:
                                return True

                            if self.num_p_ws is not None:
                                return True

                            if self.pseudowire is not None:
                                for child_ref in self.pseudowire:
                                    if child_ref._has_data():
                                        return True

                            if self.state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.name is None:
                            raise YPYModelError('Key property name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service[Cisco-IOS-XR-l2vpn-oper:name = ' + str(self.name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.name is not None:
                            return True

                        if self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs._has_data():
                            return True

                        if self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.flexible_xconnect_service is not None:
                        for child_ref in self.flexible_xconnect_service:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.FlexibleXconnectServices']['meta_info']


            class XconnectBrief(object):
                """
                XConnect brief information
                
                .. attribute:: encapsulation_report_matrix
                
                	Encapsulation report counters matrix
                	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix>`
                
                .. attribute:: encapsulation_total
                
                	Total summary
                	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal>`
                
                .. attribute:: main_total_down
                
                	Total Number of non\-active Cross\-Conections with valid encaps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_total_unresolved
                
                	Total Number of unresolved Cross\-Conections with valid encaps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_total_up
                
                	Total Number of active Cross\-Conections with valid encaps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: memory_state
                
                	L2VPN memory state
                	**type**\:   :py:class:`L2VpnMemoryStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryStateEnum>`
                
                .. attribute:: undefined_xc
                
                	Undefined xc including PW\-PW
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.encapsulation_report_matrix = YList()
                    self.encapsulation_report_matrix.parent = self
                    self.encapsulation_report_matrix.name = 'encapsulation_report_matrix'
                    self.encapsulation_total = YList()
                    self.encapsulation_total.parent = self
                    self.encapsulation_total.name = 'encapsulation_total'
                    self.main_total_down = None
                    self.main_total_unresolved = None
                    self.main_total_up = None
                    self.memory_state = None
                    self.undefined_xc = None


                class EncapsulationReportMatrix(object):
                    """
                    Encapsulation report counters matrix
                    
                    .. attribute:: ac1
                    
                    	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                    	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac1 = YList()
                        self.ac1.parent = self
                        self.ac1.name = 'ac1'


                    class Ac1(object):
                        """
                        Array of l2vpn\_xc\_brief\_first layer indexed by
                        the AC1 encapsulation type
                        
                        .. attribute:: ac2
                        
                        	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                        	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ac2 = YList()
                            self.ac2.parent = self
                            self.ac2.name = 'ac2'


                        class Ac2(object):
                            """
                            Array of l2vpn\_xc\_brief\_line indexed by the AC2
                            encapsulation type plus one type for PW
                            
                            .. attribute:: ac1_encapsulation
                            
                            	AC1 encapsulation
                            	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                            
                            .. attribute:: ac2_encapsulation
                            
                            	AC2 encapsulation
                            	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                            
                            .. attribute:: down_count
                            
                            	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: unresolved_count
                            
                            	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: up_count
                            
                            	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                            	**type**\:  list of int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ac1_encapsulation = None
                                self.ac2_encapsulation = None
                                self.down_count = YLeafList()
                                self.down_count.parent = self
                                self.down_count.name = 'down_count'
                                self.unresolved_count = YLeafList()
                                self.unresolved_count.parent = self
                                self.unresolved_count.name = 'unresolved_count'
                                self.up_count = YLeafList()
                                self.up_count.parent = self
                                self.up_count.name = 'up_count'

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac2'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ac1_encapsulation is not None:
                                    return True

                                if self.ac2_encapsulation is not None:
                                    return True

                                if self.down_count is not None:
                                    for child in self.down_count:
                                        if child is not None:
                                            return True

                                if self.unresolved_count is not None:
                                    for child in self.unresolved_count:
                                        if child is not None:
                                            return True

                                if self.up_count is not None:
                                    for child in self.up_count:
                                        if child is not None:
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ac1'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ac2 is not None:
                                for child_ref in self.ac2:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac1 is not None:
                            for child_ref in self.ac1:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix']['meta_info']


                class EncapsulationTotal(object):
                    """
                    Total summary
                    
                    .. attribute:: ac1_encapsulation
                    
                    	AC1 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                    
                    .. attribute:: ac2_encapsulation
                    
                    	AC2 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                    
                    .. attribute:: down_count
                    
                    	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unresolved_count
                    
                    	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: up_count
                    
                    	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac1_encapsulation = None
                        self.ac2_encapsulation = None
                        self.down_count = YLeafList()
                        self.down_count.parent = self
                        self.down_count.name = 'down_count'
                        self.unresolved_count = YLeafList()
                        self.unresolved_count.parent = self
                        self.unresolved_count.name = 'unresolved_count'
                        self.up_count = YLeafList()
                        self.up_count.parent = self
                        self.up_count.name = 'up_count'

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-total'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac1_encapsulation is not None:
                            return True

                        if self.ac2_encapsulation is not None:
                            return True

                        if self.down_count is not None:
                            for child in self.down_count:
                                if child is not None:
                                    return True

                        if self.unresolved_count is not None:
                            for child in self.unresolved_count:
                                if child is not None:
                                    return True

                        if self.up_count is not None:
                            for child in self.up_count:
                                if child is not None:
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:xconnect-brief'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.encapsulation_report_matrix is not None:
                        for child_ref in self.encapsulation_report_matrix:
                            if child_ref._has_data():
                                return True

                    if self.encapsulation_total is not None:
                        for child_ref in self.encapsulation_total:
                            if child_ref._has_data():
                                return True

                    if self.main_total_down is not None:
                        return True

                    if self.main_total_unresolved is not None:
                        return True

                    if self.main_total_up is not None:
                        return True

                    if self.memory_state is not None:
                        return True

                    if self.undefined_xc is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpnv2.Nodes.Node.XconnectBrief']['meta_info']

            @property
            def _common_path(self):
                if self.node_id is None:
                    raise YPYModelError('Key property node_id is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:nodes/Cisco-IOS-XR-l2vpn-oper:node[Cisco-IOS-XR-l2vpn-oper:node-id = ' + str(self.node_id) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.node_id is not None:
                    return True

                if self.bridge_domains is not None and self.bridge_domains._has_data():
                    return True

                if self.bridge_summary is not None and self.bridge_summary._has_data():
                    return True

                if self.discoveries is not None and self.discoveries._has_data():
                    return True

                if self.discovery_summary is not None and self.discovery_summary._has_data():
                    return True

                if self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary._has_data():
                    return True

                if self.flexible_xconnect_services is not None and self.flexible_xconnect_services._has_data():
                    return True

                if self.g8032 is not None and self.g8032._has_data():
                    return True

                if self.generic_interface_list_details is not None and self.generic_interface_list_details._has_data():
                    return True

                if self.generic_interfaces is not None and self.generic_interfaces._has_data():
                    return True

                if self.global_settings is not None and self.global_settings._has_data():
                    return True

                if self.iccp_sm is not None and self.iccp_sm._has_data():
                    return True

                if self.indexes is not None and self.indexes._has_data():
                    return True

                if self.l2vpn_collaborators is not None and self.l2vpn_collaborators._has_data():
                    return True

                if self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa._has_data():
                    return True

                if self.l2vpn_resource_state is not None and self.l2vpn_resource_state._has_data():
                    return True

                if self.main_interfaces is not None and self.main_interfaces._has_data():
                    return True

                if self.mstp_ports is not None and self.mstp_ports._has_data():
                    return True

                if self.mstp_vlans is not None and self.mstp_vlans._has_data():
                    return True

                if self.mvrp is not None and self.mvrp._has_data():
                    return True

                if self.nsr is not None and self.nsr._has_data():
                    return True

                if self.proc_fsm is not None and self.proc_fsm._has_data():
                    return True

                if self.pseudowire_classes is not None and self.pseudowire_classes._has_data():
                    return True

                if self.pwr is not None and self.pwr._has_data():
                    return True

                if self.xconnect_brief is not None and self.xconnect_brief._has_data():
                    return True

                if self.xconnect_groups is not None and self.xconnect_groups._has_data():
                    return True

                if self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces._has_data():
                    return True

                if self.xconnect_mp2mps is not None and self.xconnect_mp2mps._has_data():
                    return True

                if self.xconnect_summary is not None and self.xconnect_summary._has_data():
                    return True

                if self.xconnects is not None and self.xconnects._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpnv2.Nodes.Node']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2/Cisco-IOS-XR-l2vpn-oper:nodes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.node is not None:
                for child_ref in self.node:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpnv2.Nodes']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-l2vpn-oper:l2vpnv2'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.active is not None and self.active._has_data():
            return True

        if self.nodes is not None and self.nodes._has_data():
            return True

        if self.standby is not None and self.standby._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2Vpnv2']['meta_info']


class L2Vpn(object):
    """
    l2vpn
    
    .. attribute:: bridge_domains
    
    	VPLS Bridge Domain Information
    	**type**\:   :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains>`
    
    .. attribute:: bridge_summary
    
    	Bridge Domain summary information
    	**type**\:   :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeSummary>`
    
    .. attribute:: discoveries
    
    	Discovery Table
    	**type**\:   :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries>`
    
    .. attribute:: discovery_summary
    
    	Discovery summary information
    	**type**\:   :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.DiscoverySummary>`
    
    .. attribute:: flexible_xconnect_service_summary
    
    	Flexible XConnect Service summary information
    	**type**\:   :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServiceSummary>`
    
    .. attribute:: flexible_xconnect_services
    
    	Flexible XConnect Service Table
    	**type**\:   :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices>`
    
    .. attribute:: g8032
    
    	G8032 information
    	**type**\:   :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032>`
    
    .. attribute:: generic_interface_list_details
    
    	L2VPN generic interface list Detail Table
    	**type**\:   :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails>`
    
    .. attribute:: generic_interfaces
    
    	L2VPN generic interface list Table
    	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaces>`
    
    .. attribute:: global_settings
    
    	L2VPN global settings
    	**type**\:   :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GlobalSettings>`
    
    .. attribute:: iccp_sm
    
    	ICCP\-based Service Multi\-homing operational data
    	**type**\:   :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm>`
    
    .. attribute:: indexes
    
    	ID Manager Index Table
    	**type**\:   :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Indexes>`
    
    .. attribute:: l2vpn_collaborators
    
    	L2VPN collaborator information
    	**type**\:   :py:class:`L2VpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnCollaborators>`
    
    .. attribute:: l2vpn_pbb_bsa
    
    	L2VPN PBB Backbone Source MAC information
    	**type**\:   :py:class:`L2VpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnPbbBsa>`
    
    .. attribute:: l2vpn_resource_state
    
    	L2VPN resource state information
    	**type**\:   :py:class:`L2VpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnResourceState>`
    
    .. attribute:: main_interfaces
    
    	Main Interface
    	**type**\:   :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces>`
    
    .. attribute:: mstp_ports
    
    	L2VPN MSTP Port Table
    	**type**\:   :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts>`
    
    .. attribute:: mstp_vlans
    
    	L2VPN MSTP VLAN Table
    	**type**\:   :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpVlans>`
    
    .. attribute:: mvrp
    
    	MVRP
    	**type**\:   :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp>`
    
    .. attribute:: nsr
    
    	L2VPN NSR information
    	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr>`
    
    .. attribute:: proc_fsm
    
    	L2VPN Process FSM information
    	**type**\:   :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm>`
    
    .. attribute:: pseudowire_classes
    
    	List of pseudowire classes
    	**type**\:   :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses>`
    
    .. attribute:: pseudowire_headend
    
    	Pseudowire Headend related operational data
    	**type**\:   :py:class:`PseudowireHeadend <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend>`
    
    .. attribute:: pwr
    
    	Pseudowire Routing Table
    	**type**\:   :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr>`
    
    .. attribute:: xconnect_brief
    
    	XConnect brief information
    	**type**\:   :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief>`
    
    .. attribute:: xconnect_groups
    
    	XConnect group Table
    	**type**\:   :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectGroups>`
    
    .. attribute:: xconnect_mp2mp_ce2ces
    
    	XConnect MP2MP CE2CE Table
    	**type**\:   :py:class:`XconnectMp2MpCe2Ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2MpCe2Ces>`
    
    .. attribute:: xconnect_mp2mps
    
    	XConnect MP2MP Table
    	**type**\:   :py:class:`XconnectMp2Mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps>`
    
    .. attribute:: xconnect_summary
    
    	XConnect summary information
    	**type**\:   :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectSummary>`
    
    .. attribute:: xconnects
    
    	XConnect Table
    	**type**\:   :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.bridge_domains = L2Vpn.BridgeDomains()
        self.bridge_domains.parent = self
        self.bridge_summary = L2Vpn.BridgeSummary()
        self.bridge_summary.parent = self
        self.discoveries = L2Vpn.Discoveries()
        self.discoveries.parent = self
        self.discovery_summary = L2Vpn.DiscoverySummary()
        self.discovery_summary.parent = self
        self.flexible_xconnect_service_summary = L2Vpn.FlexibleXconnectServiceSummary()
        self.flexible_xconnect_service_summary.parent = self
        self.flexible_xconnect_services = L2Vpn.FlexibleXconnectServices()
        self.flexible_xconnect_services.parent = self
        self.g8032 = L2Vpn.G8032()
        self.g8032.parent = self
        self.generic_interface_list_details = L2Vpn.GenericInterfaceListDetails()
        self.generic_interface_list_details.parent = self
        self.generic_interfaces = L2Vpn.GenericInterfaces()
        self.generic_interfaces.parent = self
        self.global_settings = L2Vpn.GlobalSettings()
        self.global_settings.parent = self
        self.iccp_sm = L2Vpn.IccpSm()
        self.iccp_sm.parent = self
        self.indexes = L2Vpn.Indexes()
        self.indexes.parent = self
        self.l2vpn_collaborators = L2Vpn.L2VpnCollaborators()
        self.l2vpn_collaborators.parent = self
        self.l2vpn_pbb_bsa = L2Vpn.L2VpnPbbBsa()
        self.l2vpn_pbb_bsa.parent = self
        self.l2vpn_resource_state = L2Vpn.L2VpnResourceState()
        self.l2vpn_resource_state.parent = self
        self.main_interfaces = L2Vpn.MainInterfaces()
        self.main_interfaces.parent = self
        self.mstp_ports = L2Vpn.MstpPorts()
        self.mstp_ports.parent = self
        self.mstp_vlans = L2Vpn.MstpVlans()
        self.mstp_vlans.parent = self
        self.mvrp = L2Vpn.Mvrp()
        self.mvrp.parent = self
        self.nsr = L2Vpn.Nsr()
        self.nsr.parent = self
        self.proc_fsm = L2Vpn.ProcFsm()
        self.proc_fsm.parent = self
        self.pseudowire_classes = L2Vpn.PseudowireClasses()
        self.pseudowire_classes.parent = self
        self.pseudowire_headend = L2Vpn.PseudowireHeadend()
        self.pseudowire_headend.parent = self
        self.pwr = L2Vpn.Pwr()
        self.pwr.parent = self
        self.xconnect_brief = L2Vpn.XconnectBrief()
        self.xconnect_brief.parent = self
        self.xconnect_groups = L2Vpn.XconnectGroups()
        self.xconnect_groups.parent = self
        self.xconnect_mp2mp_ce2ces = L2Vpn.XconnectMp2MpCe2Ces()
        self.xconnect_mp2mp_ce2ces.parent = self
        self.xconnect_mp2mps = L2Vpn.XconnectMp2Mps()
        self.xconnect_mp2mps.parent = self
        self.xconnect_summary = L2Vpn.XconnectSummary()
        self.xconnect_summary.parent = self
        self.xconnects = L2Vpn.Xconnects()
        self.xconnects.parent = self


    class PseudowireHeadend(object):
        """
        Pseudowire Headend related operational data
        
        .. attribute:: detail_interfaces
        
        	PW\-HE Interfaces
        	**type**\:   :py:class:`DetailInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces>`
        
        .. attribute:: summary
        
        	PW\-HE interface summary
        	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.Summary>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.detail_interfaces = L2Vpn.PseudowireHeadend.DetailInterfaces()
            self.detail_interfaces.parent = self
            self.summary = L2Vpn.PseudowireHeadend.Summary()
            self.summary.parent = self


        class DetailInterfaces(object):
            """
            PW\-HE Interfaces
            
            .. attribute:: detail_interface
            
            	PW\-HE Interface detail
            	**type**\: list of    :py:class:`DetailInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.detail_interface = YList()
                self.detail_interface.parent = self
                self.detail_interface.name = 'detail_interface'


            class DetailInterface(object):
                """
                PW\-HE Interface detail
                
                .. attribute:: interface_name  <key>
                
                	PWHE Interface name
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: admin_state
                
                	Interface Admin Status
                	**type**\:   :py:class:`PwhePortImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PwhePortImStateEnum>`
                
                .. attribute:: bandwidth
                
                	Bandwidth (Kbps)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: kbit/s
                
                .. attribute:: control_word
                
                	Control Word
                	**type**\:  bool
                
                .. attribute:: generic_interface_list
                
                	Generic Interface List
                	**type**\:   :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList>`
                
                .. attribute:: interface_state
                
                	Interface Status
                	**type**\:   :py:class:`PwhePortImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PwhePortImStateEnum>`
                
                .. attribute:: l2_address
                
                	Layer2 Address
                	**type**\:   :py:class:`L2Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address>`
                
                .. attribute:: l2_overhead
                
                	L2 Overhead
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: label
                
                	Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: vctype
                
                	VC Type
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_name = None
                    self.admin_state = None
                    self.bandwidth = None
                    self.control_word = None
                    self.generic_interface_list = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList()
                    self.generic_interface_list.parent = self
                    self.interface_state = None
                    self.l2_address = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address()
                    self.l2_address.parent = self
                    self.l2_overhead = None
                    self.label = None
                    self.mtu = None
                    self.vctype = None


                class L2Address(object):
                    """
                    Layer2 Address
                    
                    .. attribute:: interface_type
                    
                    	InterfaceType
                    	**type**\:   :py:class:`L2VpnPwheIntfEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwheIntfEnum>`
                    
                    .. attribute:: mac_address
                    
                    	MAC address
                    	**type**\:   :py:class:`MacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_type = None
                        self.mac_address = L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress()
                        self.mac_address.parent = self


                    class MacAddress(object):
                        """
                        MAC address
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mac_address = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-address'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mac_address is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address.MacAddress']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2-address'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_type is not None:
                            return True

                        if self.mac_address is not None and self.mac_address._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.L2Address']['meta_info']


                class GenericInterfaceList(object):
                    """
                    Generic Interface List
                    
                    .. attribute:: generic_interface_list_name
                    
                    	Generic interface list name
                    	**type**\:  str
                    
                    .. attribute:: id
                    
                    	Generic interface list ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_detail
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`InterfaceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.generic_interface_list_name = None
                        self.id = None
                        self.interface_detail = YList()
                        self.interface_detail.parent = self
                        self.interface_detail.name = 'interface_detail'


                    class InterfaceDetail(object):
                        """
                        Interfaces
                        
                        .. attribute:: bundle_interface_name
                        
                        	Bundle Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_state
                        
                        	Interface Status
                        	**type**\:   :py:class:`PwhePortImStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PwhePortImStateEnum>`
                        
                        .. attribute:: misconfigured
                        
                        	Interface misconfigured
                        	**type**\:  bool
                        
                        .. attribute:: replicate_state
                        
                        	Replication status
                        	**type**\:   :py:class:`L2VpnPwheIflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwheIflistRepStatusEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bundle_interface_name = None
                            self.interface_name = None
                            self.interface_state = None
                            self.misconfigured = None
                            self.replicate_state = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-detail'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bundle_interface_name is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.interface_state is not None:
                                return True

                            if self.misconfigured is not None:
                                return True

                            if self.replicate_state is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList.InterfaceDetail']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interface-list'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.generic_interface_list_name is not None:
                            return True

                        if self.id is not None:
                            return True

                        if self.interface_detail is not None:
                            for child_ref in self.interface_detail:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface.GenericInterfaceList']['meta_info']

                @property
                def _common_path(self):
                    if self.interface_name is None:
                        raise YPYModelError('Key property interface_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pseudowire-headend/Cisco-IOS-XR-l2vpn-oper:detail-interfaces/Cisco-IOS-XR-l2vpn-oper:detail-interface[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_name is not None:
                        return True

                    if self.admin_state is not None:
                        return True

                    if self.bandwidth is not None:
                        return True

                    if self.control_word is not None:
                        return True

                    if self.generic_interface_list is not None and self.generic_interface_list._has_data():
                        return True

                    if self.interface_state is not None:
                        return True

                    if self.l2_address is not None and self.l2_address._has_data():
                        return True

                    if self.l2_overhead is not None:
                        return True

                    if self.label is not None:
                        return True

                    if self.mtu is not None:
                        return True

                    if self.vctype is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.PseudowireHeadend.DetailInterfaces.DetailInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pseudowire-headend/Cisco-IOS-XR-l2vpn-oper:detail-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.detail_interface is not None:
                    for child_ref in self.detail_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.PseudowireHeadend.DetailInterfaces']['meta_info']


        class Summary(object):
            """
            PW\-HE interface summary
            
            .. attribute:: admin_down_interfaces
            
            	Number of interfaces admin down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_pseudowire_ether_interfaces
            
            	Number of PW\-Ether interfaces admin down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces admin down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_interfaces
            
            	Number of interfaces down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_pseudowire_ether_interfaces
            
            	Number of PW\-Ether interfaces down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces down
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interfaces
            
            	Number of PW\-HE interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: psuedowire_ether_interfaces
            
            	Number of PW\-Ether interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_interfaces
            
            	Number of interfaces up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_pseudowire_iw_interfaces
            
            	Number of PW\-IW interfaces up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_psuedowire_ether_interfaces
            
            	Number of PW\-Ether interfaces up
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.admin_down_interfaces = None
                self.admin_down_pseudowire_ether_interfaces = None
                self.admin_down_pseudowire_iw_interfaces = None
                self.down_interfaces = None
                self.down_pseudowire_ether_interfaces = None
                self.down_pseudowire_iw_interfaces = None
                self.interfaces = None
                self.pseudowire_iw_interfaces = None
                self.psuedowire_ether_interfaces = None
                self.up_interfaces = None
                self.up_pseudowire_iw_interfaces = None
                self.up_psuedowire_ether_interfaces = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pseudowire-headend/Cisco-IOS-XR-l2vpn-oper:summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.admin_down_interfaces is not None:
                    return True

                if self.admin_down_pseudowire_ether_interfaces is not None:
                    return True

                if self.admin_down_pseudowire_iw_interfaces is not None:
                    return True

                if self.down_interfaces is not None:
                    return True

                if self.down_pseudowire_ether_interfaces is not None:
                    return True

                if self.down_pseudowire_iw_interfaces is not None:
                    return True

                if self.interfaces is not None:
                    return True

                if self.pseudowire_iw_interfaces is not None:
                    return True

                if self.psuedowire_ether_interfaces is not None:
                    return True

                if self.up_interfaces is not None:
                    return True

                if self.up_pseudowire_iw_interfaces is not None:
                    return True

                if self.up_psuedowire_ether_interfaces is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.PseudowireHeadend.Summary']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pseudowire-headend'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.detail_interfaces is not None and self.detail_interfaces._has_data():
                return True

            if self.summary is not None and self.summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.PseudowireHeadend']['meta_info']


    class Discoveries(object):
        """
        Discovery Table
        
        .. attribute:: discovery
        
        	VPLS Discovery information
        	**type**\: list of    :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.discovery = YList()
            self.discovery.parent = self
            self.discovery.name = 'discovery'


        class Discovery(object):
            """
            VPLS Discovery information
            
            .. attribute:: group_name
            
            	Group Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: is_service_connected
            
            	Is the service connected
            	**type**\:  bool
            
            .. attribute:: mtu_mismatch_ignore
            
            	Ignore MTU Mismatch
            	**type**\:  bool
            
            .. attribute:: number_vpn
            
            	Number of vpns
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: service_name
            
            	Service type
            	**type**\:   :py:class:`L2VpnServiceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnServiceEnum>`
            
            .. attribute:: service_name_xr
            
            	Service Type
            	**type**\:  str
            
            .. attribute:: signalling_info
            
            	Info about signalling protocol
            	**type**\:   :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo>`
            
            .. attribute:: vpn_id
            
            	VPN id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpn_name
            
            	VPN Name
            	**type**\:  str
            
            	**length:** 1..27
            
            .. attribute:: vpn_name_xr
            
            	VPN instance name
            	**type**\:  str
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.group_name = None
                self.group_name_xr = None
                self.is_service_connected = None
                self.mtu_mismatch_ignore = None
                self.number_vpn = None
                self.service_name = None
                self.service_name_xr = None
                self.signalling_info = L2Vpn.Discoveries.Discovery.SignallingInfo()
                self.signalling_info.parent = self
                self.vpn_id = None
                self.vpn_name = None
                self.vpn_name_xr = None


            class SignallingInfo(object):
                """
                Info about signalling protocol
                
                .. attribute:: ad_signalling_method
                
                	ADSignallingMethod
                	**type**\:   :py:class:`L2VpnAdSigMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdSigMethodEnum>`
                
                .. attribute:: bgp_sig_info
                
                	bgp sig info
                	**type**\:   :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                
                .. attribute:: ldp_sig_info
                
                	ldp sig info
                	**type**\:   :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ad_signalling_method = None
                    self.bgp_sig_info = L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                    self.bgp_sig_info.parent = self
                    self.ldp_sig_info = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                    self.ldp_sig_info.parent = self


                class BgpSigInfo(object):
                    """
                    bgp sig info
                    
                    .. attribute:: edge
                    
                    	List of edge ids
                    	**type**\: list of    :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                    
                    .. attribute:: number_edges
                    
                    	Number of Edges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_remote_edges
                    
                    	Number of remote Edges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redge
                    
                    	List of edge ids
                    	**type**\: list of    :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.edge = YList()
                        self.edge.parent = self
                        self.edge.name = 'edge'
                        self.number_edges = None
                        self.number_remote_edges = None
                        self.redge = YList()
                        self.redge.parent = self
                        self.redge.name = 'redge'


                    class Edge(object):
                        """
                        List of edge ids
                        
                        .. attribute:: edge_id
                        
                        	Edge ids
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: label_block
                        
                        	List of label blocks
                        	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                        
                        .. attribute:: label_count
                        
                        	Number of label blocks
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.edge_id = None
                            self.label_block = YList()
                            self.label_block.parent = self
                            self.label_block.name = 'label_block'
                            self.label_count = None


                        class LabelBlock(object):
                            """
                            List of label blocks
                            
                            .. attribute:: block_offset
                            
                            	Block offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: block_size
                            
                            	Block size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_base
                            
                            	Label Base
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_error
                            
                            	Label Error
                            	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                            
                            .. attribute:: label_time_created
                            
                            	Creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_edge_id
                            
                            	Local edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop
                            
                            	 Peer id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: status_vector
                            
                            	Status Vector
                            	**type**\:  list of int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.block_offset = None
                                self.block_size = None
                                self.label_base = None
                                self.label_error = None
                                self.label_time_created = None
                                self.local_edge_id = None
                                self.next_hop = None
                                self.status_vector = YLeafList()
                                self.status_vector.parent = self
                                self.status_vector.name = 'status_vector'

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:edge/Cisco-IOS-XR-l2vpn-oper:label-block'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.block_offset is not None:
                                    return True

                                if self.block_size is not None:
                                    return True

                                if self.label_base is not None:
                                    return True

                                if self.label_error is not None:
                                    return True

                                if self.label_time_created is not None:
                                    return True

                                if self.local_edge_id is not None:
                                    return True

                                if self.next_hop is not None:
                                    return True

                                if self.status_vector is not None:
                                    for child in self.status_vector:
                                        if child is not None:
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:edge'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.edge_id is not None:
                                return True

                            if self.label_block is not None:
                                for child_ref in self.label_block:
                                    if child_ref._has_data():
                                        return True

                            if self.label_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge']['meta_info']


                    class Redge(object):
                        """
                        List of edge ids
                        
                        .. attribute:: edge_id
                        
                        	Edge ids
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: label_block
                        
                        	List of label blocks
                        	**type**\: list of    :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                        
                        .. attribute:: label_count
                        
                        	Number of label blocks
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.edge_id = None
                            self.label_block = YList()
                            self.label_block.parent = self
                            self.label_block.name = 'label_block'
                            self.label_count = None


                        class LabelBlock(object):
                            """
                            List of label blocks
                            
                            .. attribute:: block_offset
                            
                            	Block offset
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: block_size
                            
                            	Block size
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_base
                            
                            	Label Base
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_error
                            
                            	Label Error
                            	**type**\:   :py:class:`L2VpnAdLsdErrEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdLsdErrEnum>`
                            
                            .. attribute:: label_time_created
                            
                            	Creation time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_edge_id
                            
                            	Local edge ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop
                            
                            	 Peer id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: status_vector
                            
                            	Status Vector
                            	**type**\:  list of int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.block_offset = None
                                self.block_size = None
                                self.label_base = None
                                self.label_error = None
                                self.label_time_created = None
                                self.local_edge_id = None
                                self.next_hop = None
                                self.status_vector = YLeafList()
                                self.status_vector.parent = self
                                self.status_vector.name = 'status_vector'

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:redge/Cisco-IOS-XR-l2vpn-oper:label-block'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.block_offset is not None:
                                    return True

                                if self.block_size is not None:
                                    return True

                                if self.label_base is not None:
                                    return True

                                if self.label_error is not None:
                                    return True

                                if self.label_time_created is not None:
                                    return True

                                if self.local_edge_id is not None:
                                    return True

                                if self.next_hop is not None:
                                    return True

                                if self.status_vector is not None:
                                    for child in self.status_vector:
                                        if child is not None:
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info/Cisco-IOS-XR-l2vpn-oper:redge'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.edge_id is not None:
                                return True

                            if self.label_block is not None:
                                for child_ref in self.label_block:
                                    if child_ref._has_data():
                                        return True

                            if self.label_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:bgp-sig-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.edge is not None:
                            for child_ref in self.edge:
                                if child_ref._has_data():
                                    return True

                        if self.number_edges is not None:
                            return True

                        if self.number_remote_edges is not None:
                            return True

                        if self.redge is not None:
                            for child_ref in self.redge:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.BgpSigInfo']['meta_info']


                class LdpSigInfo(object):
                    """
                    ldp sig info
                    
                    .. attribute:: local_l2_router_id
                    
                    	Local L2VPN Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: local_vpls_id
                    
                    	Local VPLS\-ID
                    	**type**\:   :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                    
                    .. attribute:: number_remote_edges
                    
                    	Number of remote Edges
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_nlri
                    
                    	List of NLRIs
                    	**type**\: list of    :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.local_l2_router_id = None
                        self.local_vpls_id = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                        self.local_vpls_id.parent = self
                        self.number_remote_edges = None
                        self.remote_nlri = YList()
                        self.remote_nlri.parent = self
                        self.remote_nlri.name = 'remote_nlri'


                    class LocalVplsId(object):
                        """
                        Local VPLS\-ID
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                        
                        .. attribute:: vpls_id_type
                        
                        	VPLS ID TYPE
                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                            self.auto.parent = self
                            self.two_byte_as = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                            self.two_byte_as.parent = self
                            self.v4_addr = L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                            self.v4_addr.parent = self
                            self.vpls_id_type = None


                        class Auto(object):
                            """
                            auto
                            
                            .. attribute:: asn
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vpn_id
                            
                            	VPN ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.asn = None
                                self.vpn_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.asn is not None:
                                    return True

                                if self.vpn_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto']['meta_info']


                        class TwoByteAs(object):
                            """
                            two byte as
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.four_byte_index = None
                                self.two_byte_as = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.four_byte_index is not None:
                                    return True

                                if self.two_byte_as is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs']['meta_info']


                        class V4Addr(object):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ipv4_address = None
                                self.two_byte_index = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ipv4_address is not None:
                                    return True

                                if self.two_byte_index is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:local-vpls-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto is not None and self.auto._has_data():
                                return True

                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                return True

                            if self.v4_addr is not None and self.v4_addr._has_data():
                                return True

                            if self.vpls_id_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId']['meta_info']


                    class RemoteNlri(object):
                        """
                        List of NLRIs
                        
                        .. attribute:: local_address
                        
                        	Local BGP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: nlri_time_created
                        
                        	NLRI creation time
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_address
                        
                        	Remote BGP Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_l2_router_id
                        
                        	Remote L2VPN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_address = None
                            self.nlri_time_created = None
                            self.remote_address = None
                            self.remote_l2_router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info/Cisco-IOS-XR-l2vpn-oper:remote-nlri'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_address is not None:
                                return True

                            if self.nlri_time_created is not None:
                                return True

                            if self.remote_address is not None:
                                return True

                            if self.remote_l2_router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info/Cisco-IOS-XR-l2vpn-oper:ldp-sig-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.local_l2_router_id is not None:
                            return True

                        if self.local_vpls_id is not None and self.local_vpls_id._has_data():
                            return True

                        if self.number_remote_edges is not None:
                            return True

                        if self.remote_nlri is not None:
                            for child_ref in self.remote_nlri:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo.LdpSigInfo']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:signalling-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ad_signalling_method is not None:
                        return True

                    if self.bgp_sig_info is not None and self.bgp_sig_info._has_data():
                        return True

                    if self.ldp_sig_info is not None and self.ldp_sig_info._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Discoveries.Discovery.SignallingInfo']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries/Cisco-IOS-XR-l2vpn-oper:discovery'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.group_name is not None:
                    return True

                if self.group_name_xr is not None:
                    return True

                if self.is_service_connected is not None:
                    return True

                if self.mtu_mismatch_ignore is not None:
                    return True

                if self.number_vpn is not None:
                    return True

                if self.service_name is not None:
                    return True

                if self.service_name_xr is not None:
                    return True

                if self.signalling_info is not None and self.signalling_info._has_data():
                    return True

                if self.vpn_id is not None:
                    return True

                if self.vpn_name is not None:
                    return True

                if self.vpn_name_xr is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Discoveries.Discovery']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discoveries'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.discovery is not None:
                for child_ref in self.discovery:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.Discoveries']['meta_info']


    class FlexibleXconnectServiceSummary(object):
        """
        Flexible XConnect Service summary information
        
        .. attribute:: number_fxc
        
        	Number of flexible xconnect services
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_fxc_down
        
        	Number of flexible xconnect services whose state is down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_fxc_up
        
        	Number of flexible xconnect services whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.number_fxc = None
            self.number_fxc_down = None
            self.number_fxc_up = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-summary'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.number_fxc is not None:
                return True

            if self.number_fxc_down is not None:
                return True

            if self.number_fxc_up is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.FlexibleXconnectServiceSummary']['meta_info']


    class MainInterfaces(object):
        """
        Main Interface
        
        .. attribute:: main_interface
        
        	Main Interface Table
        	**type**\: list of    :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.main_interface = YList()
            self.main_interface.parent = self
            self.main_interface.name = 'main_interface'


        class MainInterface(object):
            """
            Main Interface Table
            
            .. attribute:: interface_name  <key>
            
            	Main interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: main_interface_info
            
            	Main Interface info
            	**type**\:   :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo>`
            
            .. attribute:: main_interface_instances
            
            	Main Interface Instance table
            	**type**\:   :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_name = None
                self.main_interface_info = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo()
                self.main_interface_info.parent = self
                self.main_interface_instances = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances()
                self.main_interface_instances.parent = self


            class MainInterfaceInstances(object):
                """
                Main Interface Instance table
                
                .. attribute:: main_interface_instance
                
                	Main Interface Instance
                	**type**\: list of    :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.main_interface_instance = YList()
                    self.main_interface_instance.parent = self
                    self.main_interface_instance.name = 'main_interface_instance'


                class MainInterfaceInstance(object):
                    """
                    Main Interface Instance
                    
                    .. attribute:: instance  <key>
                    
                    	Instance
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: main_interface_instance_bridge_ports
                    
                    	Main Interface Instance Bridge Port table
                    	**type**\:   :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                    
                    .. attribute:: main_interface_instance_info
                    
                    	Main Interface Instance info
                    	**type**\:   :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.instance = None
                        self.main_interface_instance_bridge_ports = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                        self.main_interface_instance_bridge_ports.parent = self
                        self.main_interface_instance_info = L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                        self.main_interface_instance_info.parent = self


                    class MainInterfaceInstanceInfo(object):
                        """
                        Main Interface Instance info
                        
                        .. attribute:: configured_instance
                        
                        	Configured Instance
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flush_count
                        
                        	Flush count 
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_flags
                        
                        	Instance Flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_id
                        
                        	Instance ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_state
                        
                        	Instance State
                        	**type**\:   :py:class:`L2VpnMainIfInstanceStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfInstanceStateEnum>`
                        
                        .. attribute:: interface_count
                        
                        	Interface count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.configured_instance = None
                            self.flush_count = None
                            self.instance_flags = None
                            self.instance_id = None
                            self.instance_state = None
                            self.interface_count = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.configured_instance is not None:
                                return True

                            if self.flush_count is not None:
                                return True

                            if self.instance_flags is not None:
                                return True

                            if self.instance_id is not None:
                                return True

                            if self.instance_state is not None:
                                return True

                            if self.interface_count is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo']['meta_info']


                    class MainInterfaceInstanceBridgePorts(object):
                        """
                        Main Interface Instance Bridge Port table
                        
                        .. attribute:: main_interface_instance_bridge_port
                        
                        	Main Interface Bridge Port info
                        	**type**\: list of    :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.main_interface_instance_bridge_port = YList()
                            self.main_interface_instance_bridge_port.parent = self
                            self.main_interface_instance_bridge_port.name = 'main_interface_instance_bridge_port'


                        class MainInterfaceInstanceBridgePort(object):
                            """
                            Main Interface Bridge Port info
                            
                            .. attribute:: bridge_port  <key>
                            
                            	Bridge Port
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: bridge_port_xr
                            
                            	Bridge port ifhandle
                            	**type**\:  str
                            
                            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bridge_port = None
                                self.bridge_port_xr = None
                                self.instance_id = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')
                                if self.bridge_port is None:
                                    raise YPYModelError('Key property bridge_port is None')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-port[Cisco-IOS-XR-l2vpn-oper:bridge-port = ' + str(self.bridge_port) + ']'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bridge_port is not None:
                                    return True

                                if self.bridge_port_xr is not None:
                                    return True

                                if self.instance_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance-bridge-ports'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.main_interface_instance_bridge_port is not None:
                                for child_ref in self.main_interface_instance_bridge_port:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.instance is None:
                            raise YPYModelError('Key property instance is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instance[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.instance is not None:
                            return True

                        if self.main_interface_instance_bridge_ports is not None and self.main_interface_instance_bridge_ports._has_data():
                            return True

                        if self.main_interface_instance_info is not None and self.main_interface_instance_info._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-instances'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.main_interface_instance is not None:
                        for child_ref in self.main_interface_instance:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.MainInterfaces.MainInterface.MainInterfaceInstances']['meta_info']


            class MainInterfaceInfo(object):
                """
                Main Interface info
                
                .. attribute:: interface_count
                
                	Sub Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_interface_handle
                
                	Main Interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: protected
                
                	Protected
                	**type**\:   :py:class:`L2VpnMainIfProtectectedEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMainIfProtectectedEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_count = None
                    self.main_interface_handle = None
                    self.protected = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:main-interface-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_count is not None:
                        return True

                    if self.main_interface_handle is not None:
                        return True

                    if self.protected is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.MainInterfaces.MainInterface.MainInterfaceInfo']['meta_info']

            @property
            def _common_path(self):
                if self.interface_name is None:
                    raise YPYModelError('Key property interface_name is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:main-interfaces/Cisco-IOS-XR-l2vpn-oper:main-interface[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_name is not None:
                    return True

                if self.main_interface_info is not None and self.main_interface_info._has_data():
                    return True

                if self.main_interface_instances is not None and self.main_interface_instances._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.MainInterfaces.MainInterface']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:main-interfaces'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.main_interface is not None:
                for child_ref in self.main_interface:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.MainInterfaces']['meta_info']


    class IccpSm(object):
        """
        ICCP\-based Service Multi\-homing operational data
        
        .. attribute:: iccp_groups
        
        	ICCP Group Table
        	**type**\:   :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups>`
        
        .. attribute:: iccp_sm_summary
        
        	ICCP\-based Service Multi\-homing database summary
        	**type**\:   :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpSmSummary>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.iccp_groups = L2Vpn.IccpSm.IccpGroups()
            self.iccp_groups.parent = self
            self.iccp_sm_summary = L2Vpn.IccpSm.IccpSmSummary()
            self.iccp_sm_summary.parent = self


        class IccpSmSummary(object):
            """
            ICCP\-based Service Multi\-homing database
            summary
            
            .. attribute:: connected_groups
            
            	Number of Connected Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: connecting_groups
            
            	Number of Connecting Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: failed_ports
            
            	Number of Failed Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: groups
            
            	Total Number of Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: operational_ports
            
            	Number of Operational Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ports
            
            	Total Number of Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: provisioned_groups
            
            	Number of Provisioned Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: reverting_ports
            
            	Number of Reverting Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: synchronized_groups
            
            	Number of Synchronized Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: synchronizing_groups
            
            	Number of Synchronizing Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unconfigured_ports
            
            	Number of Unconfigured Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_ports
            
            	Number of Unknown Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_groups
            
            	Number of Unresolved Groups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unsynchronized_ports
            
            	Number of Unsynchronized Ports
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.connected_groups = None
                self.connecting_groups = None
                self.failed_ports = None
                self.groups = None
                self.operational_ports = None
                self.ports = None
                self.provisioned_groups = None
                self.reverting_ports = None
                self.synchronized_groups = None
                self.synchronizing_groups = None
                self.unconfigured_ports = None
                self.unknown_ports = None
                self.unresolved_groups = None
                self.unsynchronized_ports = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-sm-summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.connected_groups is not None:
                    return True

                if self.connecting_groups is not None:
                    return True

                if self.failed_ports is not None:
                    return True

                if self.groups is not None:
                    return True

                if self.operational_ports is not None:
                    return True

                if self.ports is not None:
                    return True

                if self.provisioned_groups is not None:
                    return True

                if self.reverting_ports is not None:
                    return True

                if self.synchronized_groups is not None:
                    return True

                if self.synchronizing_groups is not None:
                    return True

                if self.unconfigured_ports is not None:
                    return True

                if self.unknown_ports is not None:
                    return True

                if self.unresolved_groups is not None:
                    return True

                if self.unsynchronized_ports is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.IccpSm.IccpSmSummary']['meta_info']


        class IccpGroups(object):
            """
            ICCP Group Table
            
            .. attribute:: iccp_group
            
            	ICCP Group
            	**type**\: list of    :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.iccp_group = YList()
                self.iccp_group.parent = self
                self.iccp_group.name = 'iccp_group'


            class IccpGroup(object):
                """
                ICCP Group
                
                .. attribute:: group_id  <key>
                
                	Group ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: iccp_group_info
                
                	ICCP Group Information
                	**type**\:   :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                
                .. attribute:: iccp_ports
                
                	ICCP Port Table
                	**type**\:   :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.group_id = None
                    self.iccp_group_info = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                    self.iccp_group_info.parent = self
                    self.iccp_ports = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                    self.iccp_ports.parent = self


                class IccpGroupInfo(object):
                    """
                    ICCP Group Information
                    
                    .. attribute:: group_id
                    
                    	Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: iccp_member_up
                    
                    	ICCP Member Up
                    	**type**\:  bool
                    
                    .. attribute:: iccp_transport_up
                    
                    	ICCP Transport Up
                    	**type**\:  bool
                    
                    .. attribute:: local_node_id
                    
                    	Local Node ID
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ports
                    
                    	List of ports in the group
                    	**type**\: list of    :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                    
                    .. attribute:: remote_node_id
                    
                    	Remote Node ID
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`IccpSmStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmStateEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.group_id = None
                        self.iccp_member_up = None
                        self.iccp_transport_up = None
                        self.local_node_id = None
                        self.ports = YList()
                        self.ports.parent = self
                        self.ports.name = 'ports'
                        self.remote_node_id = None
                        self.state = None


                    class Ports(object):
                        """
                        List of ports in the group
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: local_port
                        
                        	Local port info
                        	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                        
                        .. attribute:: mac_flush_tcn
                        
                        	Is MAC flush through STP\-TCN?
                        	**type**\:  bool
                        
                        .. attribute:: remote_port
                        
                        	Remote port info
                        	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.local_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                            self.local_port.parent = self
                            self.mac_flush_tcn = None
                            self.remote_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                            self.remote_port.parent = self


                        class LocalPort(object):
                            """
                            Local port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fsm_state = None
                                self.port_fail_code = None
                                self.port_state = None
                                self.reversion_time = None
                                self.reversion_time_remaining = None
                                self.vlan_state = None
                                self.vlan_vector = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fsm_state is not None:
                                    return True

                                if self.port_fail_code is not None:
                                    return True

                                if self.port_state is not None:
                                    return True

                                if self.reversion_time is not None:
                                    return True

                                if self.reversion_time_remaining is not None:
                                    return True

                                if self.vlan_state is not None:
                                    return True

                                if self.vlan_vector is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort']['meta_info']


                        class RemotePort(object):
                            """
                            Remote port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fsm_state = None
                                self.port_fail_code = None
                                self.port_state = None
                                self.reversion_time = None
                                self.reversion_time_remaining = None
                                self.vlan_state = None
                                self.vlan_vector = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fsm_state is not None:
                                    return True

                                if self.port_fail_code is not None:
                                    return True

                                if self.port_state is not None:
                                    return True

                                if self.reversion_time is not None:
                                    return True

                                if self.reversion_time_remaining is not None:
                                    return True

                                if self.vlan_state is not None:
                                    return True

                                if self.vlan_vector is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ports'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.local_port is not None and self.local_port._has_data():
                                return True

                            if self.mac_flush_tcn is not None:
                                return True

                            if self.remote_port is not None and self.remote_port._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-group-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.group_id is not None:
                            return True

                        if self.iccp_member_up is not None:
                            return True

                        if self.iccp_transport_up is not None:
                            return True

                        if self.local_node_id is not None:
                            return True

                        if self.ports is not None:
                            for child_ref in self.ports:
                                if child_ref._has_data():
                                    return True

                        if self.remote_node_id is not None:
                            return True

                        if self.state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo']['meta_info']


                class IccpPorts(object):
                    """
                    ICCP Port Table
                    
                    .. attribute:: iccp_port
                    
                    	ICCP Port
                    	**type**\: list of    :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.iccp_port = YList()
                        self.iccp_port.parent = self
                        self.iccp_port.name = 'iccp_port'


                    class IccpPort(object):
                        """
                        ICCP Port
                        
                        .. attribute:: interface  <key>
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: local_port
                        
                        	Local port info
                        	**type**\:   :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                        
                        .. attribute:: mac_flush_tcn
                        
                        	Is MAC flush through STP\-TCN?
                        	**type**\:  bool
                        
                        .. attribute:: remote_port
                        
                        	Remote port info
                        	**type**\:   :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface = None
                            self.interface_name = None
                            self.local_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                            self.local_port.parent = self
                            self.mac_flush_tcn = None
                            self.remote_port = L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                            self.remote_port.parent = self


                        class LocalPort(object):
                            """
                            Local port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fsm_state = None
                                self.port_fail_code = None
                                self.port_state = None
                                self.reversion_time = None
                                self.reversion_time_remaining = None
                                self.vlan_state = None
                                self.vlan_vector = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fsm_state is not None:
                                    return True

                                if self.port_fail_code is not None:
                                    return True

                                if self.port_state is not None:
                                    return True

                                if self.reversion_time is not None:
                                    return True

                                if self.reversion_time_remaining is not None:
                                    return True

                                if self.vlan_state is not None:
                                    return True

                                if self.vlan_vector is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort']['meta_info']


                        class RemotePort(object):
                            """
                            Remote port info
                            
                            .. attribute:: fsm_state
                            
                            	FSM state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_fail_code
                            
                            	Port fail code
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: port_state
                            
                            	Port state
                            	**type**\:   :py:class:`IccpSmPortStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortStateEnum>`
                            
                            .. attribute:: reversion_time
                            
                            	Reversion Time
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: reversion_time_remaining
                            
                            	Reversion Time Remaining
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vlan_state
                            
                            	VLAN state
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: vlan_vector
                            
                            	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                            	**type**\:  str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.fsm_state = None
                                self.port_fail_code = None
                                self.port_state = None
                                self.reversion_time = None
                                self.reversion_time_remaining = None
                                self.vlan_state = None
                                self.vlan_vector = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.fsm_state is not None:
                                    return True

                                if self.port_fail_code is not None:
                                    return True

                                if self.port_state is not None:
                                    return True

                                if self.reversion_time is not None:
                                    return True

                                if self.reversion_time_remaining is not None:
                                    return True

                                if self.vlan_state is not None:
                                    return True

                                if self.vlan_vector is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface is None:
                                raise YPYModelError('Key property interface is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface is not None:
                                return True

                            if self.interface_name is not None:
                                return True

                            if self.local_port is not None and self.local_port._has_data():
                                return True

                            if self.mac_flush_tcn is not None:
                                return True

                            if self.remote_port is not None and self.remote_port._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:iccp-ports'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.iccp_port is not None:
                            for child_ref in self.iccp_port:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup.IccpPorts']['meta_info']

                @property
                def _common_path(self):
                    if self.group_id is None:
                        raise YPYModelError('Key property group_id is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-groups/Cisco-IOS-XR-l2vpn-oper:iccp-group[Cisco-IOS-XR-l2vpn-oper:group-id = ' + str(self.group_id) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.group_id is not None:
                        return True

                    if self.iccp_group_info is not None and self.iccp_group_info._has_data():
                        return True

                    if self.iccp_ports is not None and self.iccp_ports._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.IccpSm.IccpGroups.IccpGroup']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:iccp-sm/Cisco-IOS-XR-l2vpn-oper:iccp-groups'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.iccp_group is not None:
                    for child_ref in self.iccp_group:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.IccpSm.IccpGroups']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:iccp-sm'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.iccp_groups is not None and self.iccp_groups._has_data():
                return True

            if self.iccp_sm_summary is not None and self.iccp_sm_summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.IccpSm']['meta_info']


    class BridgeSummary(object):
        """
        Bridge Domain summary information
        
        .. attribute:: num_vn_is
        
        	Number of VNIs
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: num_vn_is_down
        
        	Number of VNIs down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: num_vn_is_unresolved
        
        	Number of VNIs unresolved
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: num_vn_is_up
        
        	Number of VNIs up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_a_cs
        
        	Number of attachment circuits
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_a_cs_up
        
        	Number of attachment circuits whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_bridge_domains
        
        	Number of bridge\-domains
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_bridge_domains_shut
        
        	Number of bridge\-domains admin disabled
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_bridge_domains_up
        
        	Number of bridge\-domains up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_default_bridge_doamins
        
        	Number of default bridge\-domains
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_groups
        
        	Number of groups
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p2mp
        
        	Number of P2MPs
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p2mp_down
        
        	Number of P2MPs whose state is down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p2mp_up
        
        	Number of P2MPs whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_p_ws_up
        
        	Number of pseudowires whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_pbb_core
        
        	Number of PBB Core
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_pbb_edge
        
        	Number of PBB Edge
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_pseudowires
        
        	Number of pseudowires
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: out_of_memory_state
        
        	L2VPN Out of memory state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_a_cs
        
        	Number of partially programmed attachment circuits
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_bridges
        
        	Number of partially programmed bridge\-domains
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_pseudowires
        
        	Number of partially programmed pseudowires
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_pseudowires
        
        	Number of pseudowires whose state is standby
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.num_vn_is = None
            self.num_vn_is_down = None
            self.num_vn_is_unresolved = None
            self.num_vn_is_up = None
            self.number_a_cs = None
            self.number_a_cs_up = None
            self.number_bridge_domains = None
            self.number_bridge_domains_shut = None
            self.number_bridge_domains_up = None
            self.number_default_bridge_doamins = None
            self.number_groups = None
            self.number_p2mp = None
            self.number_p2mp_down = None
            self.number_p2mp_up = None
            self.number_p_ws_up = None
            self.number_pbb_core = None
            self.number_pbb_edge = None
            self.number_pseudowires = None
            self.out_of_memory_state = None
            self.partially_programmed_a_cs = None
            self.partially_programmed_bridges = None
            self.partially_programmed_pseudowires = None
            self.standby_pseudowires = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-summary'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.num_vn_is is not None:
                return True

            if self.num_vn_is_down is not None:
                return True

            if self.num_vn_is_unresolved is not None:
                return True

            if self.num_vn_is_up is not None:
                return True

            if self.number_a_cs is not None:
                return True

            if self.number_a_cs_up is not None:
                return True

            if self.number_bridge_domains is not None:
                return True

            if self.number_bridge_domains_shut is not None:
                return True

            if self.number_bridge_domains_up is not None:
                return True

            if self.number_default_bridge_doamins is not None:
                return True

            if self.number_groups is not None:
                return True

            if self.number_p2mp is not None:
                return True

            if self.number_p2mp_down is not None:
                return True

            if self.number_p2mp_up is not None:
                return True

            if self.number_p_ws_up is not None:
                return True

            if self.number_pbb_core is not None:
                return True

            if self.number_pbb_edge is not None:
                return True

            if self.number_pseudowires is not None:
                return True

            if self.out_of_memory_state is not None:
                return True

            if self.partially_programmed_a_cs is not None:
                return True

            if self.partially_programmed_bridges is not None:
                return True

            if self.partially_programmed_pseudowires is not None:
                return True

            if self.standby_pseudowires is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.BridgeSummary']['meta_info']


    class Nsr(object):
        """
        L2VPN NSR information
        
        .. attribute:: event_history
        
        	L2VPN Process event history
        	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.EventHistory>`
        
        .. attribute:: failover_status
        
        	L2VPN failover status
        	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.FailoverStatus>`
        
        .. attribute:: issu_status
        
        	L2VPN ISSU Status and timestamp
        	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.IssuStatus>`
        
        .. attribute:: nsr_status
        
        	L2VPN NSR status and timestamp
        	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.NsrStatus>`
        
        .. attribute:: process_role
        
        	Current Process Role
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: process_state
        
        	Current Process State
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: report_card
        
        	L2VPN Collaborator report card
        	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.ReportCard>`
        
        .. attribute:: state_transition_time
        
        	Transition time for all states
        	**type**\:  list of int
        
        	**range:** 0..4294967295
        
        .. attribute:: sw_install_in_progress
        
        	Is s/w install currently in progress?
        	**type**\:  bool
        
        .. attribute:: sync_flags
        
        	Sync complete flags
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: xid_info
        
        	XID information
        	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.XidInfo>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.event_history = YList()
            self.event_history.parent = self
            self.event_history.name = 'event_history'
            self.failover_status = L2Vpn.Nsr.FailoverStatus()
            self.failover_status.parent = self
            self.issu_status = L2Vpn.Nsr.IssuStatus()
            self.issu_status.parent = self
            self.nsr_status = L2Vpn.Nsr.NsrStatus()
            self.nsr_status.parent = self
            self.process_role = None
            self.process_state = None
            self.report_card = YList()
            self.report_card.parent = self
            self.report_card.name = 'report_card'
            self.state_transition_time = YLeafList()
            self.state_transition_time.parent = self
            self.state_transition_time.name = 'state_transition_time'
            self.sw_install_in_progress = None
            self.sync_flags = None
            self.xid_info = YList()
            self.xid_info.parent = self
            self.xid_info.name = 'xid_info'


        class FailoverStatus(object):
            """
            L2VPN failover status
            
            .. attribute:: master_time
            
            	Master time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_time
            
            	Start time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: triggered_time
            
            	Triggered time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.master_time = None
                self.start_time = None
                self.triggered_time = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:failover-status'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.master_time is not None:
                    return True

                if self.start_time is not None:
                    return True

                if self.triggered_time is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Nsr.FailoverStatus']['meta_info']


        class NsrStatus(object):
            """
            L2VPN NSR status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.NsrStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.idt_status = L2Vpn.Nsr.NsrStatus.IdtStatus()
                self.idt_status.parent = self
                self.previ_ous_idt_status = L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self.role = None


            class IdtStatus(object):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Nsr.NsrStatus.IdtStatus']['meta_info']


            class PreviOusIdtStatus(object):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Nsr.NsrStatus.PreviOusIdtStatus']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:nsr-status'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.idt_status is not None and self.idt_status._has_data():
                    return True

                if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                    return True

                if self.role is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Nsr.NsrStatus']['meta_info']


        class IssuStatus(object):
            """
            L2VPN ISSU Status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.IssuStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.idt_status = L2Vpn.Nsr.IssuStatus.IdtStatus()
                self.idt_status.parent = self
                self.previ_ous_idt_status = L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self.role = None


            class IdtStatus(object):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Nsr.IssuStatus.IdtStatus']['meta_info']


            class PreviOusIdtStatus(object):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Nsr.IssuStatus.PreviOusIdtStatus']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:issu-status'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.idt_status is not None and self.idt_status._has_data():
                    return True

                if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                    return True

                if self.role is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Nsr.IssuStatus']['meta_info']


        class XidInfo(object):
            """
            XID information
            
            .. attribute:: app_type
            
            	App type
            	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
            
            .. attribute:: sent_ids
            
            	Number of XIDs transferred
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.app_type = None
                self.sent_ids = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:xid-info'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.app_type is not None:
                    return True

                if self.sent_ids is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Nsr.XidInfo']['meta_info']


        class ReportCard(object):
            """
            L2VPN Collaborator report card
            
            .. attribute:: collaborator_idt_done
            
            	Is IDT done for this collaborator
            	**type**\:  bool
            
            .. attribute:: collaborator_is_connected
            
            	Is the collaborator connected
            	**type**\:  bool
            
            .. attribute:: collaborator_skipped
            
            	Was this collaborator skipped for not connecting in time
            	**type**\:  bool
            
            .. attribute:: connection_change_time
            
            	Time when connection state (UP/DOWN) changed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: idt_time
            
            	Time when IDT was done
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.collaborator_idt_done = None
                self.collaborator_is_connected = None
                self.collaborator_skipped = None
                self.connection_change_time = None
                self.idt_time = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:report-card'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.collaborator_idt_done is not None:
                    return True

                if self.collaborator_is_connected is not None:
                    return True

                if self.collaborator_skipped is not None:
                    return True

                if self.connection_change_time is not None:
                    return True

                if self.idt_time is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Nsr.ReportCard']['meta_info']


        class EventHistory(object):
            """
            L2VPN Process event history
            
            .. attribute:: event_timestamp
            
            	Event timestamp
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: new_state
            
            	New state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: previous_state
            
            	Previous state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_collaborator
            
            	Process collaborator
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: process_event
            
            	Process event
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.event_timestamp = None
                self.new_state = None
                self.previous_state = None
                self.process_collaborator = None
                self.process_event = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr/Cisco-IOS-XR-l2vpn-oper:event-history'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.event_timestamp is not None:
                    return True

                if self.new_state is not None:
                    return True

                if self.previous_state is not None:
                    return True

                if self.process_collaborator is not None:
                    return True

                if self.process_event is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Nsr.EventHistory']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:nsr'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.event_history is not None:
                for child_ref in self.event_history:
                    if child_ref._has_data():
                        return True

            if self.failover_status is not None and self.failover_status._has_data():
                return True

            if self.issu_status is not None and self.issu_status._has_data():
                return True

            if self.nsr_status is not None and self.nsr_status._has_data():
                return True

            if self.process_role is not None:
                return True

            if self.process_state is not None:
                return True

            if self.report_card is not None:
                for child_ref in self.report_card:
                    if child_ref._has_data():
                        return True

            if self.state_transition_time is not None:
                for child in self.state_transition_time:
                    if child is not None:
                        return True

            if self.sw_install_in_progress is not None:
                return True

            if self.sync_flags is not None:
                return True

            if self.xid_info is not None:
                for child_ref in self.xid_info:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.Nsr']['meta_info']


    class GlobalSettings(object):
        """
        L2VPN global settings
        
        .. attribute:: going_active
        
        	transitioning to Active functional role
        	**type**\:  bool
        
        .. attribute:: ha_role
        
        	Node redundancy role
        	**type**\:  str
        
        .. attribute:: issu_role
        
        	Node ISSU role
        	**type**\:  str
        
        .. attribute:: logging_bd_enabled
        
        	Logging BD state changes enabled
        	**type**\:  bool
        
        .. attribute:: logging_df_election_enabled
        
        	Logging EVPN Designated Forwarder changes enabled
        	**type**\:  bool
        
        .. attribute:: logging_nsr_enabled
        
        	Logging NSR state changes enabled
        	**type**\:  bool
        
        .. attribute:: logging_pw_enabled
        
        	Logging PW enabled
        	**type**\:  bool
        
        .. attribute:: logging_vfi_enabled
        
        	Logging VFI state changes enabled
        	**type**\:  bool
        
        .. attribute:: process_fsm
        
        	Current L2VPN FSM role
        	**type**\:  str
        
        .. attribute:: pw_grouping_enabled
        
        	PW Grouping enabled
        	**type**\:  bool
        
        .. attribute:: pw_oam_refresh_transmit_time
        
        	PW OAM refresh transmit (seconds)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: second
        
        .. attribute:: pw_status_enabled
        
        	PW Status enabled
        	**type**\:  bool
        
        .. attribute:: tcn_propagation_enabled
        
        	TCN propagation enabled
        	**type**\:  bool
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.going_active = None
            self.ha_role = None
            self.issu_role = None
            self.logging_bd_enabled = None
            self.logging_df_election_enabled = None
            self.logging_nsr_enabled = None
            self.logging_pw_enabled = None
            self.logging_vfi_enabled = None
            self.process_fsm = None
            self.pw_grouping_enabled = None
            self.pw_oam_refresh_transmit_time = None
            self.pw_status_enabled = None
            self.tcn_propagation_enabled = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:global-settings'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.going_active is not None:
                return True

            if self.ha_role is not None:
                return True

            if self.issu_role is not None:
                return True

            if self.logging_bd_enabled is not None:
                return True

            if self.logging_df_election_enabled is not None:
                return True

            if self.logging_nsr_enabled is not None:
                return True

            if self.logging_pw_enabled is not None:
                return True

            if self.logging_vfi_enabled is not None:
                return True

            if self.process_fsm is not None:
                return True

            if self.pw_grouping_enabled is not None:
                return True

            if self.pw_oam_refresh_transmit_time is not None:
                return True

            if self.pw_status_enabled is not None:
                return True

            if self.tcn_propagation_enabled is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.GlobalSettings']['meta_info']


    class Pwr(object):
        """
        Pseudowire Routing Table
        
        .. attribute:: summary
        
        	L2VPN Pseudowire Routing Summary
        	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.summary = L2Vpn.Pwr.Summary()
            self.summary.parent = self


        class Summary(object):
            """
            L2VPN Pseudowire Routing Summary
            
            .. attribute:: bgp_as
            
            	BGP AS number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: bgp_router_id
            
            	BGP Router ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: cfg_global_id
            
            	Configured Global ID
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: cfg_router_id
            
            	Configured Router ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: l2vpn_has_bgp_eod
            
            	L2VPN got BGP EOD
            	**type**\:  bool
            
            .. attribute:: rd_auto
            
            	Automatic Route Distingtuisher
            	**type**\:   :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto>`
            
            .. attribute:: rd_configured
            
            	Configured Route Distinguisher
            	**type**\:   :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bgp_as = None
                self.bgp_router_id = None
                self.cfg_global_id = None
                self.cfg_router_id = None
                self.l2vpn_has_bgp_eod = None
                self.rd_auto = L2Vpn.Pwr.Summary.RdAuto()
                self.rd_auto.parent = self
                self.rd_configured = L2Vpn.Pwr.Summary.RdConfigured()
                self.rd_configured.parent = self


            class RdAuto(object):
                """
                Automatic Route Distingtuisher
                
                .. attribute:: auto
                
                	auto
                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.Auto>`
                
                .. attribute:: four_byte_as
                
                	four byte as
                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.FourByteAs>`
                
                .. attribute:: rd
                
                	RD
                	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                
                .. attribute:: two_byte_as
                
                	two byte as
                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.TwoByteAs>`
                
                .. attribute:: v4_addr
                
                	v4 addr
                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdAuto.V4Addr>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.auto = L2Vpn.Pwr.Summary.RdAuto.Auto()
                    self.auto.parent = self
                    self.four_byte_as = L2Vpn.Pwr.Summary.RdAuto.FourByteAs()
                    self.four_byte_as.parent = self
                    self.rd = None
                    self.two_byte_as = L2Vpn.Pwr.Summary.RdAuto.TwoByteAs()
                    self.two_byte_as.parent = self
                    self.v4_addr = L2Vpn.Pwr.Summary.RdAuto.V4Addr()
                    self.v4_addr.parent = self


                class Auto(object):
                    """
                    auto
                    
                    .. attribute:: auto_index
                    
                    	Auto\-generated Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: router_id
                    
                    	BGP Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto_index = None
                        self.router_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:auto'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto_index is not None:
                            return True

                        if self.router_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdAuto.Auto']['meta_info']


                class TwoByteAs(object):
                    """
                    two byte as
                    
                    .. attribute:: four_byte_index
                    
                    	4 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_as
                    
                    	2 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.four_byte_index = None
                        self.two_byte_as = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.four_byte_index is not None:
                            return True

                        if self.two_byte_as is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdAuto.TwoByteAs']['meta_info']


                class FourByteAs(object):
                    """
                    four byte as
                    
                    .. attribute:: four_byte_as
                    
                    	4 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.four_byte_as = None
                        self.two_byte_index = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.four_byte_as is not None:
                            return True

                        if self.two_byte_index is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdAuto.FourByteAs']['meta_info']


                class V4Addr(object):
                    """
                    v4 addr
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ipv4_address = None
                        self.two_byte_index = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ipv4_address is not None:
                            return True

                        if self.two_byte_index is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdAuto.V4Addr']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-auto'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.auto is not None and self.auto._has_data():
                        return True

                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                        return True

                    if self.rd is not None:
                        return True

                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                        return True

                    if self.v4_addr is not None and self.v4_addr._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Pwr.Summary.RdAuto']['meta_info']


            class RdConfigured(object):
                """
                Configured Route Distinguisher
                
                .. attribute:: auto
                
                	auto
                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.Auto>`
                
                .. attribute:: four_byte_as
                
                	four byte as
                	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.FourByteAs>`
                
                .. attribute:: rd
                
                	RD
                	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                
                .. attribute:: two_byte_as
                
                	two byte as
                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs>`
                
                .. attribute:: v4_addr
                
                	v4 addr
                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Pwr.Summary.RdConfigured.V4Addr>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.auto = L2Vpn.Pwr.Summary.RdConfigured.Auto()
                    self.auto.parent = self
                    self.four_byte_as = L2Vpn.Pwr.Summary.RdConfigured.FourByteAs()
                    self.four_byte_as.parent = self
                    self.rd = None
                    self.two_byte_as = L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs()
                    self.two_byte_as.parent = self
                    self.v4_addr = L2Vpn.Pwr.Summary.RdConfigured.V4Addr()
                    self.v4_addr.parent = self


                class Auto(object):
                    """
                    auto
                    
                    .. attribute:: auto_index
                    
                    	Auto\-generated Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: router_id
                    
                    	BGP Router ID
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto_index = None
                        self.router_id = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:auto'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto_index is not None:
                            return True

                        if self.router_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdConfigured.Auto']['meta_info']


                class TwoByteAs(object):
                    """
                    two byte as
                    
                    .. attribute:: four_byte_index
                    
                    	4 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_as
                    
                    	2 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.four_byte_index = None
                        self.two_byte_as = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.four_byte_index is not None:
                            return True

                        if self.two_byte_as is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdConfigured.TwoByteAs']['meta_info']


                class FourByteAs(object):
                    """
                    four byte as
                    
                    .. attribute:: four_byte_as
                    
                    	4 Byte AS Number
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.four_byte_as = None
                        self.two_byte_index = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.four_byte_as is not None:
                            return True

                        if self.two_byte_index is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdConfigured.FourByteAs']['meta_info']


                class V4Addr(object):
                    """
                    v4 addr
                    
                    .. attribute:: ipv4_address
                    
                    	IPv4 Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: two_byte_index
                    
                    	2 Byte Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ipv4_address = None
                        self.two_byte_index = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ipv4_address is not None:
                            return True

                        if self.two_byte_index is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Pwr.Summary.RdConfigured.V4Addr']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary/Cisco-IOS-XR-l2vpn-oper:rd-configured'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.auto is not None and self.auto._has_data():
                        return True

                    if self.four_byte_as is not None and self.four_byte_as._has_data():
                        return True

                    if self.rd is not None:
                        return True

                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                        return True

                    if self.v4_addr is not None and self.v4_addr._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Pwr.Summary.RdConfigured']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr/Cisco-IOS-XR-l2vpn-oper:summary'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bgp_as is not None:
                    return True

                if self.bgp_router_id is not None:
                    return True

                if self.cfg_global_id is not None:
                    return True

                if self.cfg_router_id is not None:
                    return True

                if self.l2vpn_has_bgp_eod is not None:
                    return True

                if self.rd_auto is not None and self.rd_auto._has_data():
                    return True

                if self.rd_configured is not None and self.rd_configured._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Pwr.Summary']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pwr'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.summary is not None and self.summary._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.Pwr']['meta_info']


    class XconnectMp2MpCe2Ces(object):
        """
        XConnect MP2MP CE2CE Table
        
        .. attribute:: xconnect_mp2mp_ce2ce
        
        	XConnect MP2MP CE2CE information
        	**type**\: list of    :py:class:`XconnectMp2MpCe2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.xconnect_mp2mp_ce2ce = YList()
            self.xconnect_mp2mp_ce2ce.parent = self
            self.xconnect_mp2mp_ce2ce.name = 'xconnect_mp2mp_ce2ce'


        class XconnectMp2MpCe2Ce(object):
            """
            XConnect MP2MP CE2CE information
            
            .. attribute:: ce_added
            
            	CE2CE Advertised
            	**type**\:  bool
            
            .. attribute:: group_name
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: local_ceid
            
            	Local CE ID
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: local_customer_edge_id
            
            	Local CE ID
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: mp2_mp_name
            
            	Mp2Mp Name
            	**type**\:  str
            
            	**length:** 1..26
            
            .. attribute:: remote_ceid
            
            	Remote CE ID
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: remote_customer_edge_id
            
            	Remote CE ID
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.ce_added = None
                self.group_name = None
                self.local_ceid = None
                self.local_customer_edge_id = None
                self.mp2_mp_name = None
                self.remote_ceid = None
                self.remote_customer_edge_id = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ce'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.ce_added is not None:
                    return True

                if self.group_name is not None:
                    return True

                if self.local_ceid is not None:
                    return True

                if self.local_customer_edge_id is not None:
                    return True

                if self.mp2_mp_name is not None:
                    return True

                if self.remote_ceid is not None:
                    return True

                if self.remote_customer_edge_id is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.XconnectMp2MpCe2Ces.XconnectMp2MpCe2Ce']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp-ce2ces'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.xconnect_mp2mp_ce2ce is not None:
                for child_ref in self.xconnect_mp2mp_ce2ce:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.XconnectMp2MpCe2Ces']['meta_info']


    class Xconnects(object):
        """
        XConnect Table
        
        .. attribute:: xconnect
        
        	XConnect information
        	**type**\: list of    :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.xconnect = YList()
            self.xconnect.parent = self
            self.xconnect.name = 'xconnect'


        class Xconnect(object):
            """
            XConnect information
            
            .. attribute:: backup
            
            	LCR backup
            	**type**\:   :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup>`
            
            .. attribute:: backup_segment
            
            	Backup Segment
            	**type**\: list of    :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment>`
            
            .. attribute:: ce2ce
            
            	CE2CE
            	**type**\:   :py:class:`Ce2Ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Ce2Ce>`
            
            .. attribute:: description
            
            	P2P Description
            	**type**\:  str
            
            .. attribute:: diag_mask
            
            	Mask indicating what if anything is missing before the XC can be provisioned
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: group_name
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: interworking
            
            	Interworking type
            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
            
            .. attribute:: is_mp2mp
            
            	xconnect is mp2mp
            	**type**\:  bool
            
            .. attribute:: number_of_backup_p_ws
            
            	Number of backups
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: segment1
            
            	Segment 1
            	**type**\:   :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1>`
            
            .. attribute:: segment2
            
            	Segment 2
            	**type**\:   :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2>`
            
            .. attribute:: state
            
            	State of the xconnect
            	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
            
            .. attribute:: xconnect_name
            
            	XConnect Name
            	**type**\:  str
            
            	**length:** 1..38
            
            .. attribute:: xconnect_name_xr
            
            	XConnect name
            	**type**\:  str
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.backup = L2Vpn.Xconnects.Xconnect.Backup()
                self.backup.parent = self
                self.backup_segment = YList()
                self.backup_segment.parent = self
                self.backup_segment.name = 'backup_segment'
                self.ce2ce = L2Vpn.Xconnects.Xconnect.Ce2Ce()
                self.ce2ce.parent = self
                self.description = None
                self.diag_mask = None
                self.group_name = None
                self.group_name_xr = None
                self.interworking = None
                self.is_mp2mp = None
                self.number_of_backup_p_ws = None
                self.segment1 = L2Vpn.Xconnects.Xconnect.Segment1()
                self.segment1.parent = self
                self.segment2 = L2Vpn.Xconnects.Xconnect.Segment2()
                self.segment2.parent = self
                self.state = None
                self.xconnect_name = None
                self.xconnect_name_xr = None


            class Backup(object):
                """
                LCR backup
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire()
                    self.pseudo_wire.parent = self
                    self.segment_type = None


                class AttachmentCircuit(object):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bvi_mac_conflict = None
                        self.bvi_no_port_up = None
                        self.control_word_mismatched = None
                        self.encapsulation_error = None
                        self.encapsulation_mismatched = None
                        self.evpn_internal_label = None
                        self.interface = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self.interface_handle = None
                        self.internal_ms_ti = None
                        self.interworking = None
                        self.is_ac_partially_programmed = None
                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self.mac_limit_oper_down = None
                        self.ms_ti_mismatch = None
                        self.msti = None
                        self.msti_mismatch_down = None
                        self.mtu_mismatched = None
                        self.node_id = None
                        self.out_of_memory_state = None
                        self.redundancy_group_id = None
                        self.redundancy_group_state = None
                        self.redundancy_object_id = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self.tdm_media_mismatched = None
                        self.xconnect_id = None


                    class Interface(object):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics']['meta_info']


                    class L2VpnProtection(object):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active = None
                            self.protected_name = None
                            self.protection_configured = None
                            self.protection_name = None
                            self.protection_type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active is not None:
                                return True

                            if self.protected_name is not None:
                                return True

                            if self.protection_configured is not None:
                                return True

                            if self.protection_name is not None:
                                return True

                            if self.protection_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit.L2VpnProtection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bvi_mac_conflict is not None:
                            return True

                        if self.bvi_no_port_up is not None:
                            return True

                        if self.control_word_mismatched is not None:
                            return True

                        if self.encapsulation_error is not None:
                            return True

                        if self.encapsulation_mismatched is not None:
                            return True

                        if self.evpn_internal_label is not None:
                            return True

                        if self.interface is not None and self.interface._has_data():
                            return True

                        if self.interface_handle is not None:
                            return True

                        if self.internal_ms_ti is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.is_ac_partially_programmed is not None:
                            return True

                        if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.ms_ti_mismatch is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.msti_mismatch_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.redundancy_group_id is not None:
                            return True

                        if self.redundancy_group_state is not None:
                            return True

                        if self.redundancy_object_id is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.tdm_media_mismatched is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.AttachmentCircuit']['meta_info']


                class PseudoWire(object):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_remote_down = None
                        self.admited_bw = None
                        self.auto_discovery = None
                        self.backup_active = None
                        self.backup_force_active = None
                        self.backup_pw = None
                        self.bitrate_mismatched = None
                        self.bridge_pw_type_mismatch = None
                        self.cas_mismatched = None
                        self.diff_ts_mismatched = None
                        self.disable_delay = None
                        self.disable_never = None
                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self.evpn_src_acid = None
                        self.fe_ctype = None
                        self.forward_class = None
                        self.freq_mismatched = None
                        self.illegal_control_word = None
                        self.imposed_vlan_id = None
                        self.interworking = None
                        self.ipv6_local_source_address = None
                        self.is_evpnvpws_type = None
                        self.is_flow_label_static = None
                        self.is_multi_segment_pseudowire = None
                        self.is_partially_programmed = None
                        self.is_pwr_type = None
                        self.is_vfi = None
                        self.last_time_status_changed = None
                        self.last_time_status_down = None
                        self.ldp_label_advertise_failed = None
                        self.load_balance = None
                        self.local_control_word = None
                        self.local_interface = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self.local_label_failed = None
                        self.local_pseudo_wire_type = None
                        self.local_signalling = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self.local_source_address = None
                        self.mac_limit_oper_down = None
                        self.mtu_mismatched = None
                        self.not_supported_qinq = None
                        self.num_ma_cwithdraw_msg_received = None
                        self.number_ma_cwithdraw_message_sent = None
                        self.out_of_memory_state = None
                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self.payload_bytes_mismatched = None
                        self.payload_type_mismatched = None
                        self.peer_id = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self.preferred_path = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self.preferred_path_disable_fallback = None
                        self.primary_peer_id = None
                        self.primary_pseudo_wire_id = None
                        self.primary_pw = None
                        self.protocol = None
                        self.pseudo_wire_id = None
                        self.pseudo_wire_state = None
                        self.pseudo_wire_type_mismatched = None
                        self.pw_class_name = None
                        self.pw_flow_label_code17_disabled = None
                        self.pw_flow_label_type = None
                        self.pw_flow_label_type_cfg = None
                        self.pw_redundancy_initial_delay = None
                        self.pw_redundancy_one_way = None
                        self.pw_status_use = None
                        self.pwlsd_rewrite_failed = None
                        self.remote_control_word = None
                        self.remote_interface = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self.remote_label_failed = None
                        self.remote_pseudo_wire_type = None
                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self.required_bw = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.rtp_mismatched = None
                        self.sequencing_type = None
                        self.shutdown = None
                        self.sig_pkts_mismatched = None
                        self.ssrc_mismatched = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self.table_policy_name = None
                        self.tag_rewrite = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.time_elapsed_status_down = None
                        self.transport_lsp_down = None
                        self.xconnect_id = None


                    class PeerId(object):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.internal_label = None
                            self.ipv4_peer_id = None
                            self.ipv6_peer_id = None
                            self.type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.internal_label is not None:
                                return True

                            if self.ipv4_peer_id is not None:
                                return True

                            if self.ipv6_peer_id is not None:
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PeerId']['meta_info']


                    class EncapsulationInfo(object):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.atom = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self.encapsulation = None
                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self


                        class Atom(object):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_pseudowire_headend = None
                                self.is_sai_itype2 = None
                                self.is_tai_itype2 = None
                                self.ldp_label_advertisment_failed = None
                                self.local_agi = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self.local_c_ctype = None
                                self.local_ceid = None
                                self.local_cv_type = None
                                self.local_group_id = None
                                self.local_label = None
                                self.local_ldp_id = None
                                self.local_saii_gbl_id = None
                                self.local_saiiac_id = None
                                self.local_taii_gbl_id = None
                                self.local_taiiac_id = None
                                self.local_veid = None
                                self.lsd_rewrite_failed = None
                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self.rem_saii = None
                                self.rem_saii_gbl_id = None
                                self.rem_saiiac_id = None
                                self.rem_taii = None
                                self.rem_taii_gbl_id = None
                                self.rem_taiiac_id = None
                                self.remote_agi = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self.remote_c_ctype = None
                                self.remote_ceid = None
                                self.remote_cv_type = None
                                self.remote_group_id = None
                                self.remote_label = None
                                self.remote_ldp_id = None
                                self.remote_source_address = None
                                self.remote_veid = None
                                self.saii = None
                                self.source_address = None
                                self.taii = None


                            class LocalAgi(object):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                            class RemoteAgi(object):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                            class MultiSegmentPseudowireStats(object):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.received_bytes = None
                                    self.received_packets = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.received_bytes is not None:
                                        return True

                                    if self.received_packets is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_pseudowire_headend is not None:
                                    return True

                                if self.is_sai_itype2 is not None:
                                    return True

                                if self.is_tai_itype2 is not None:
                                    return True

                                if self.ldp_label_advertisment_failed is not None:
                                    return True

                                if self.local_agi is not None and self.local_agi._has_data():
                                    return True

                                if self.local_c_ctype is not None:
                                    return True

                                if self.local_ceid is not None:
                                    return True

                                if self.local_cv_type is not None:
                                    return True

                                if self.local_group_id is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_ldp_id is not None:
                                    return True

                                if self.local_saii_gbl_id is not None:
                                    return True

                                if self.local_saiiac_id is not None:
                                    return True

                                if self.local_taii_gbl_id is not None:
                                    return True

                                if self.local_taiiac_id is not None:
                                    return True

                                if self.local_veid is not None:
                                    return True

                                if self.lsd_rewrite_failed is not None:
                                    return True

                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                    return True

                                if self.rem_saii is not None:
                                    return True

                                if self.rem_saii_gbl_id is not None:
                                    return True

                                if self.rem_saiiac_id is not None:
                                    return True

                                if self.rem_taii is not None:
                                    return True

                                if self.rem_taii_gbl_id is not None:
                                    return True

                                if self.rem_taiiac_id is not None:
                                    return True

                                if self.remote_agi is not None and self.remote_agi._has_data():
                                    return True

                                if self.remote_c_ctype is not None:
                                    return True

                                if self.remote_ceid is not None:
                                    return True

                                if self.remote_cv_type is not None:
                                    return True

                                if self.remote_group_id is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_ldp_id is not None:
                                    return True

                                if self.remote_source_address is not None:
                                    return True

                                if self.remote_veid is not None:
                                    return True

                                if self.saii is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.taii is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                        class L2Tpv3(object):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dont_fragment_bit = None
                                self.ipv4_source_address = None
                                self.ipv6_source_address = None
                                self.l2tp_class_name = None
                                self.local_cookie_high_value = None
                                self.local_cookie_low_value = None
                                self.local_cookie_size = None
                                self.local_secondary_cookie_high_value = None
                                self.local_secondary_cookie_low_value = None
                                self.local_secondary_cookie_size = None
                                self.local_session_id = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.remote_circuit_status_up = None
                                self.remote_cookie_high_value = None
                                self.remote_cookie_low_value = None
                                self.remote_cookie_size = None
                                self.remote_session_id = None
                                self.tos = None
                                self.tos_mode = None
                                self.ttl = None
                                self.tunnel_state = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dont_fragment_bit is not None:
                                    return True

                                if self.ipv4_source_address is not None:
                                    return True

                                if self.ipv6_source_address is not None:
                                    return True

                                if self.l2tp_class_name is not None:
                                    return True

                                if self.local_cookie_high_value is not None:
                                    return True

                                if self.local_cookie_low_value is not None:
                                    return True

                                if self.local_cookie_size is not None:
                                    return True

                                if self.local_secondary_cookie_high_value is not None:
                                    return True

                                if self.local_secondary_cookie_low_value is not None:
                                    return True

                                if self.local_secondary_cookie_size is not None:
                                    return True

                                if self.local_session_id is not None:
                                    return True

                                if self.path_mtu_enabled is not None:
                                    return True

                                if self.path_mtu_max_value is not None:
                                    return True

                                if self.remote_circuit_status_up is not None:
                                    return True

                                if self.remote_cookie_high_value is not None:
                                    return True

                                if self.remote_cookie_low_value is not None:
                                    return True

                                if self.remote_cookie_size is not None:
                                    return True

                                if self.remote_session_id is not None:
                                    return True

                                if self.tos is not None:
                                    return True

                                if self.tos_mode is not None:
                                    return True

                                if self.ttl is not None:
                                    return True

                                if self.tunnel_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.atom is not None and self.atom._has_data():
                                return True

                            if self.encapsulation is not None:
                                return True

                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo']['meta_info']


                    class LocalInterface(object):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface']['meta_info']


                    class RemoteInterface(object):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface']['meta_info']


                    class PreferredPath(object):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ip_tunnel_interface_number = None
                            self.next_hop_ip = None
                            self.option = None
                            self.te_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ip_tunnel_interface_number is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            if self.option is not None:
                                return True

                            if self.te_tunnel_interface_number is not None:
                                return True

                            if self.tp_tunnel_interface_number is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath']['meta_info']


                    class LocalSignalling(object):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling']['meta_info']


                    class RemoteSignalling(object):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.Statistics']['meta_info']


                    class P2MpPw(object):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_available = None
                            self.local_extended_tunnel_id = None
                            self.local_flags = None
                            self.local_label = None
                            self.local_p2mp_id = None
                            self.local_ptree_type = None
                            self.local_tunnel_id = None
                            self.remote_available = None
                            self.remote_extended_tunnel_id = None
                            self.remote_flags = None
                            self.remote_label = None
                            self.remote_p2mp_id = None
                            self.remote_ptree_type = None
                            self.remote_tunnel_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_available is not None:
                                return True

                            if self.local_extended_tunnel_id is not None:
                                return True

                            if self.local_flags is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.local_p2mp_id is not None:
                                return True

                            if self.local_ptree_type is not None:
                                return True

                            if self.local_tunnel_id is not None:
                                return True

                            if self.remote_available is not None:
                                return True

                            if self.remote_extended_tunnel_id is not None:
                                return True

                            if self.remote_flags is not None:
                                return True

                            if self.remote_label is not None:
                                return True

                            if self.remote_p2mp_id is not None:
                                return True

                            if self.remote_ptree_type is not None:
                                return True

                            if self.remote_tunnel_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire.P2MpPw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_remote_down is not None:
                            return True

                        if self.admited_bw is not None:
                            return True

                        if self.auto_discovery is not None:
                            return True

                        if self.backup_active is not None:
                            return True

                        if self.backup_force_active is not None:
                            return True

                        if self.backup_pw is not None:
                            return True

                        if self.bitrate_mismatched is not None:
                            return True

                        if self.bridge_pw_type_mismatch is not None:
                            return True

                        if self.cas_mismatched is not None:
                            return True

                        if self.diff_ts_mismatched is not None:
                            return True

                        if self.disable_delay is not None:
                            return True

                        if self.disable_never is not None:
                            return True

                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                            return True

                        if self.evpn_src_acid is not None:
                            return True

                        if self.fe_ctype is not None:
                            return True

                        if self.forward_class is not None:
                            return True

                        if self.freq_mismatched is not None:
                            return True

                        if self.illegal_control_word is not None:
                            return True

                        if self.imposed_vlan_id is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.ipv6_local_source_address is not None:
                            return True

                        if self.is_evpnvpws_type is not None:
                            return True

                        if self.is_flow_label_static is not None:
                            return True

                        if self.is_multi_segment_pseudowire is not None:
                            return True

                        if self.is_partially_programmed is not None:
                            return True

                        if self.is_pwr_type is not None:
                            return True

                        if self.is_vfi is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.last_time_status_down is not None:
                            return True

                        if self.ldp_label_advertise_failed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.local_control_word is not None:
                            return True

                        if self.local_interface is not None and self.local_interface._has_data():
                            return True

                        if self.local_label_failed is not None:
                            return True

                        if self.local_pseudo_wire_type is not None:
                            return True

                        if self.local_signalling is not None and self.local_signalling._has_data():
                            return True

                        if self.local_source_address is not None:
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.not_supported_qinq is not None:
                            return True

                        if self.num_ma_cwithdraw_msg_received is not None:
                            return True

                        if self.number_ma_cwithdraw_message_sent is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                            return True

                        if self.payload_bytes_mismatched is not None:
                            return True

                        if self.payload_type_mismatched is not None:
                            return True

                        if self.peer_id is not None and self.peer_id._has_data():
                            return True

                        if self.preferred_path is not None and self.preferred_path._has_data():
                            return True

                        if self.preferred_path_disable_fallback is not None:
                            return True

                        if self.primary_peer_id is not None:
                            return True

                        if self.primary_pseudo_wire_id is not None:
                            return True

                        if self.primary_pw is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.pseudo_wire_id is not None:
                            return True

                        if self.pseudo_wire_state is not None:
                            return True

                        if self.pseudo_wire_type_mismatched is not None:
                            return True

                        if self.pw_class_name is not None:
                            return True

                        if self.pw_flow_label_code17_disabled is not None:
                            return True

                        if self.pw_flow_label_type is not None:
                            return True

                        if self.pw_flow_label_type_cfg is not None:
                            return True

                        if self.pw_redundancy_initial_delay is not None:
                            return True

                        if self.pw_redundancy_one_way is not None:
                            return True

                        if self.pw_status_use is not None:
                            return True

                        if self.pwlsd_rewrite_failed is not None:
                            return True

                        if self.remote_control_word is not None:
                            return True

                        if self.remote_interface is not None and self.remote_interface._has_data():
                            return True

                        if self.remote_label_failed is not None:
                            return True

                        if self.remote_pseudo_wire_type is not None:
                            return True

                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                            return True

                        if self.required_bw is not None:
                            return True

                        if self.resync_enabled is not None:
                            return True

                        if self.resync_threshold is not None:
                            return True

                        if self.rtp_mismatched is not None:
                            return True

                        if self.sequencing_type is not None:
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.sig_pkts_mismatched is not None:
                            return True

                        if self.ssrc_mismatched is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.table_policy_name is not None:
                            return True

                        if self.tag_rewrite is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.time_elapsed_status_down is not None:
                            return True

                        if self.transport_lsp_down is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup.PseudoWire']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                        return True

                    if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                        return True

                    if self.segment_type is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Backup']['meta_info']


            class Segment1(object):
                """
                Segment 1
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire()
                    self.pseudo_wire.parent = self
                    self.segment_type = None


                class AttachmentCircuit(object):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bvi_mac_conflict = None
                        self.bvi_no_port_up = None
                        self.control_word_mismatched = None
                        self.encapsulation_error = None
                        self.encapsulation_mismatched = None
                        self.evpn_internal_label = None
                        self.interface = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self.interface_handle = None
                        self.internal_ms_ti = None
                        self.interworking = None
                        self.is_ac_partially_programmed = None
                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self.mac_limit_oper_down = None
                        self.ms_ti_mismatch = None
                        self.msti = None
                        self.msti_mismatch_down = None
                        self.mtu_mismatched = None
                        self.node_id = None
                        self.out_of_memory_state = None
                        self.redundancy_group_id = None
                        self.redundancy_group_state = None
                        self.redundancy_object_id = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self.tdm_media_mismatched = None
                        self.xconnect_id = None


                    class Interface(object):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics']['meta_info']


                    class L2VpnProtection(object):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active = None
                            self.protected_name = None
                            self.protection_configured = None
                            self.protection_name = None
                            self.protection_type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active is not None:
                                return True

                            if self.protected_name is not None:
                                return True

                            if self.protection_configured is not None:
                                return True

                            if self.protection_name is not None:
                                return True

                            if self.protection_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2VpnProtection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bvi_mac_conflict is not None:
                            return True

                        if self.bvi_no_port_up is not None:
                            return True

                        if self.control_word_mismatched is not None:
                            return True

                        if self.encapsulation_error is not None:
                            return True

                        if self.encapsulation_mismatched is not None:
                            return True

                        if self.evpn_internal_label is not None:
                            return True

                        if self.interface is not None and self.interface._has_data():
                            return True

                        if self.interface_handle is not None:
                            return True

                        if self.internal_ms_ti is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.is_ac_partially_programmed is not None:
                            return True

                        if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.ms_ti_mismatch is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.msti_mismatch_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.redundancy_group_id is not None:
                            return True

                        if self.redundancy_group_state is not None:
                            return True

                        if self.redundancy_object_id is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.tdm_media_mismatched is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.AttachmentCircuit']['meta_info']


                class PseudoWire(object):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_remote_down = None
                        self.admited_bw = None
                        self.auto_discovery = None
                        self.backup_active = None
                        self.backup_force_active = None
                        self.backup_pw = None
                        self.bitrate_mismatched = None
                        self.bridge_pw_type_mismatch = None
                        self.cas_mismatched = None
                        self.diff_ts_mismatched = None
                        self.disable_delay = None
                        self.disable_never = None
                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self.evpn_src_acid = None
                        self.fe_ctype = None
                        self.forward_class = None
                        self.freq_mismatched = None
                        self.illegal_control_word = None
                        self.imposed_vlan_id = None
                        self.interworking = None
                        self.ipv6_local_source_address = None
                        self.is_evpnvpws_type = None
                        self.is_flow_label_static = None
                        self.is_multi_segment_pseudowire = None
                        self.is_partially_programmed = None
                        self.is_pwr_type = None
                        self.is_vfi = None
                        self.last_time_status_changed = None
                        self.last_time_status_down = None
                        self.ldp_label_advertise_failed = None
                        self.load_balance = None
                        self.local_control_word = None
                        self.local_interface = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self.local_label_failed = None
                        self.local_pseudo_wire_type = None
                        self.local_signalling = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self.local_source_address = None
                        self.mac_limit_oper_down = None
                        self.mtu_mismatched = None
                        self.not_supported_qinq = None
                        self.num_ma_cwithdraw_msg_received = None
                        self.number_ma_cwithdraw_message_sent = None
                        self.out_of_memory_state = None
                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self.payload_bytes_mismatched = None
                        self.payload_type_mismatched = None
                        self.peer_id = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self.preferred_path = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self.preferred_path_disable_fallback = None
                        self.primary_peer_id = None
                        self.primary_pseudo_wire_id = None
                        self.primary_pw = None
                        self.protocol = None
                        self.pseudo_wire_id = None
                        self.pseudo_wire_state = None
                        self.pseudo_wire_type_mismatched = None
                        self.pw_class_name = None
                        self.pw_flow_label_code17_disabled = None
                        self.pw_flow_label_type = None
                        self.pw_flow_label_type_cfg = None
                        self.pw_redundancy_initial_delay = None
                        self.pw_redundancy_one_way = None
                        self.pw_status_use = None
                        self.pwlsd_rewrite_failed = None
                        self.remote_control_word = None
                        self.remote_interface = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self.remote_label_failed = None
                        self.remote_pseudo_wire_type = None
                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self.required_bw = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.rtp_mismatched = None
                        self.sequencing_type = None
                        self.shutdown = None
                        self.sig_pkts_mismatched = None
                        self.ssrc_mismatched = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self.table_policy_name = None
                        self.tag_rewrite = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.time_elapsed_status_down = None
                        self.transport_lsp_down = None
                        self.xconnect_id = None


                    class PeerId(object):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.internal_label = None
                            self.ipv4_peer_id = None
                            self.ipv6_peer_id = None
                            self.type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.internal_label is not None:
                                return True

                            if self.ipv4_peer_id is not None:
                                return True

                            if self.ipv6_peer_id is not None:
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PeerId']['meta_info']


                    class EncapsulationInfo(object):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.atom = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self.encapsulation = None
                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self


                        class Atom(object):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_pseudowire_headend = None
                                self.is_sai_itype2 = None
                                self.is_tai_itype2 = None
                                self.ldp_label_advertisment_failed = None
                                self.local_agi = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self.local_c_ctype = None
                                self.local_ceid = None
                                self.local_cv_type = None
                                self.local_group_id = None
                                self.local_label = None
                                self.local_ldp_id = None
                                self.local_saii_gbl_id = None
                                self.local_saiiac_id = None
                                self.local_taii_gbl_id = None
                                self.local_taiiac_id = None
                                self.local_veid = None
                                self.lsd_rewrite_failed = None
                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self.rem_saii = None
                                self.rem_saii_gbl_id = None
                                self.rem_saiiac_id = None
                                self.rem_taii = None
                                self.rem_taii_gbl_id = None
                                self.rem_taiiac_id = None
                                self.remote_agi = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self.remote_c_ctype = None
                                self.remote_ceid = None
                                self.remote_cv_type = None
                                self.remote_group_id = None
                                self.remote_label = None
                                self.remote_ldp_id = None
                                self.remote_source_address = None
                                self.remote_veid = None
                                self.saii = None
                                self.source_address = None
                                self.taii = None


                            class LocalAgi(object):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                            class RemoteAgi(object):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                            class MultiSegmentPseudowireStats(object):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.received_bytes = None
                                    self.received_packets = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.received_bytes is not None:
                                        return True

                                    if self.received_packets is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_pseudowire_headend is not None:
                                    return True

                                if self.is_sai_itype2 is not None:
                                    return True

                                if self.is_tai_itype2 is not None:
                                    return True

                                if self.ldp_label_advertisment_failed is not None:
                                    return True

                                if self.local_agi is not None and self.local_agi._has_data():
                                    return True

                                if self.local_c_ctype is not None:
                                    return True

                                if self.local_ceid is not None:
                                    return True

                                if self.local_cv_type is not None:
                                    return True

                                if self.local_group_id is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_ldp_id is not None:
                                    return True

                                if self.local_saii_gbl_id is not None:
                                    return True

                                if self.local_saiiac_id is not None:
                                    return True

                                if self.local_taii_gbl_id is not None:
                                    return True

                                if self.local_taiiac_id is not None:
                                    return True

                                if self.local_veid is not None:
                                    return True

                                if self.lsd_rewrite_failed is not None:
                                    return True

                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                    return True

                                if self.rem_saii is not None:
                                    return True

                                if self.rem_saii_gbl_id is not None:
                                    return True

                                if self.rem_saiiac_id is not None:
                                    return True

                                if self.rem_taii is not None:
                                    return True

                                if self.rem_taii_gbl_id is not None:
                                    return True

                                if self.rem_taiiac_id is not None:
                                    return True

                                if self.remote_agi is not None and self.remote_agi._has_data():
                                    return True

                                if self.remote_c_ctype is not None:
                                    return True

                                if self.remote_ceid is not None:
                                    return True

                                if self.remote_cv_type is not None:
                                    return True

                                if self.remote_group_id is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_ldp_id is not None:
                                    return True

                                if self.remote_source_address is not None:
                                    return True

                                if self.remote_veid is not None:
                                    return True

                                if self.saii is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.taii is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                        class L2Tpv3(object):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dont_fragment_bit = None
                                self.ipv4_source_address = None
                                self.ipv6_source_address = None
                                self.l2tp_class_name = None
                                self.local_cookie_high_value = None
                                self.local_cookie_low_value = None
                                self.local_cookie_size = None
                                self.local_secondary_cookie_high_value = None
                                self.local_secondary_cookie_low_value = None
                                self.local_secondary_cookie_size = None
                                self.local_session_id = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.remote_circuit_status_up = None
                                self.remote_cookie_high_value = None
                                self.remote_cookie_low_value = None
                                self.remote_cookie_size = None
                                self.remote_session_id = None
                                self.tos = None
                                self.tos_mode = None
                                self.ttl = None
                                self.tunnel_state = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dont_fragment_bit is not None:
                                    return True

                                if self.ipv4_source_address is not None:
                                    return True

                                if self.ipv6_source_address is not None:
                                    return True

                                if self.l2tp_class_name is not None:
                                    return True

                                if self.local_cookie_high_value is not None:
                                    return True

                                if self.local_cookie_low_value is not None:
                                    return True

                                if self.local_cookie_size is not None:
                                    return True

                                if self.local_secondary_cookie_high_value is not None:
                                    return True

                                if self.local_secondary_cookie_low_value is not None:
                                    return True

                                if self.local_secondary_cookie_size is not None:
                                    return True

                                if self.local_session_id is not None:
                                    return True

                                if self.path_mtu_enabled is not None:
                                    return True

                                if self.path_mtu_max_value is not None:
                                    return True

                                if self.remote_circuit_status_up is not None:
                                    return True

                                if self.remote_cookie_high_value is not None:
                                    return True

                                if self.remote_cookie_low_value is not None:
                                    return True

                                if self.remote_cookie_size is not None:
                                    return True

                                if self.remote_session_id is not None:
                                    return True

                                if self.tos is not None:
                                    return True

                                if self.tos_mode is not None:
                                    return True

                                if self.ttl is not None:
                                    return True

                                if self.tunnel_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.atom is not None and self.atom._has_data():
                                return True

                            if self.encapsulation is not None:
                                return True

                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo']['meta_info']


                    class LocalInterface(object):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface']['meta_info']


                    class RemoteInterface(object):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface']['meta_info']


                    class PreferredPath(object):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ip_tunnel_interface_number = None
                            self.next_hop_ip = None
                            self.option = None
                            self.te_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ip_tunnel_interface_number is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            if self.option is not None:
                                return True

                            if self.te_tunnel_interface_number is not None:
                                return True

                            if self.tp_tunnel_interface_number is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath']['meta_info']


                    class LocalSignalling(object):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling']['meta_info']


                    class RemoteSignalling(object):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.Statistics']['meta_info']


                    class P2MpPw(object):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_available = None
                            self.local_extended_tunnel_id = None
                            self.local_flags = None
                            self.local_label = None
                            self.local_p2mp_id = None
                            self.local_ptree_type = None
                            self.local_tunnel_id = None
                            self.remote_available = None
                            self.remote_extended_tunnel_id = None
                            self.remote_flags = None
                            self.remote_label = None
                            self.remote_p2mp_id = None
                            self.remote_ptree_type = None
                            self.remote_tunnel_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_available is not None:
                                return True

                            if self.local_extended_tunnel_id is not None:
                                return True

                            if self.local_flags is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.local_p2mp_id is not None:
                                return True

                            if self.local_ptree_type is not None:
                                return True

                            if self.local_tunnel_id is not None:
                                return True

                            if self.remote_available is not None:
                                return True

                            if self.remote_extended_tunnel_id is not None:
                                return True

                            if self.remote_flags is not None:
                                return True

                            if self.remote_label is not None:
                                return True

                            if self.remote_p2mp_id is not None:
                                return True

                            if self.remote_ptree_type is not None:
                                return True

                            if self.remote_tunnel_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire.P2MpPw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_remote_down is not None:
                            return True

                        if self.admited_bw is not None:
                            return True

                        if self.auto_discovery is not None:
                            return True

                        if self.backup_active is not None:
                            return True

                        if self.backup_force_active is not None:
                            return True

                        if self.backup_pw is not None:
                            return True

                        if self.bitrate_mismatched is not None:
                            return True

                        if self.bridge_pw_type_mismatch is not None:
                            return True

                        if self.cas_mismatched is not None:
                            return True

                        if self.diff_ts_mismatched is not None:
                            return True

                        if self.disable_delay is not None:
                            return True

                        if self.disable_never is not None:
                            return True

                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                            return True

                        if self.evpn_src_acid is not None:
                            return True

                        if self.fe_ctype is not None:
                            return True

                        if self.forward_class is not None:
                            return True

                        if self.freq_mismatched is not None:
                            return True

                        if self.illegal_control_word is not None:
                            return True

                        if self.imposed_vlan_id is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.ipv6_local_source_address is not None:
                            return True

                        if self.is_evpnvpws_type is not None:
                            return True

                        if self.is_flow_label_static is not None:
                            return True

                        if self.is_multi_segment_pseudowire is not None:
                            return True

                        if self.is_partially_programmed is not None:
                            return True

                        if self.is_pwr_type is not None:
                            return True

                        if self.is_vfi is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.last_time_status_down is not None:
                            return True

                        if self.ldp_label_advertise_failed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.local_control_word is not None:
                            return True

                        if self.local_interface is not None and self.local_interface._has_data():
                            return True

                        if self.local_label_failed is not None:
                            return True

                        if self.local_pseudo_wire_type is not None:
                            return True

                        if self.local_signalling is not None and self.local_signalling._has_data():
                            return True

                        if self.local_source_address is not None:
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.not_supported_qinq is not None:
                            return True

                        if self.num_ma_cwithdraw_msg_received is not None:
                            return True

                        if self.number_ma_cwithdraw_message_sent is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                            return True

                        if self.payload_bytes_mismatched is not None:
                            return True

                        if self.payload_type_mismatched is not None:
                            return True

                        if self.peer_id is not None and self.peer_id._has_data():
                            return True

                        if self.preferred_path is not None and self.preferred_path._has_data():
                            return True

                        if self.preferred_path_disable_fallback is not None:
                            return True

                        if self.primary_peer_id is not None:
                            return True

                        if self.primary_pseudo_wire_id is not None:
                            return True

                        if self.primary_pw is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.pseudo_wire_id is not None:
                            return True

                        if self.pseudo_wire_state is not None:
                            return True

                        if self.pseudo_wire_type_mismatched is not None:
                            return True

                        if self.pw_class_name is not None:
                            return True

                        if self.pw_flow_label_code17_disabled is not None:
                            return True

                        if self.pw_flow_label_type is not None:
                            return True

                        if self.pw_flow_label_type_cfg is not None:
                            return True

                        if self.pw_redundancy_initial_delay is not None:
                            return True

                        if self.pw_redundancy_one_way is not None:
                            return True

                        if self.pw_status_use is not None:
                            return True

                        if self.pwlsd_rewrite_failed is not None:
                            return True

                        if self.remote_control_word is not None:
                            return True

                        if self.remote_interface is not None and self.remote_interface._has_data():
                            return True

                        if self.remote_label_failed is not None:
                            return True

                        if self.remote_pseudo_wire_type is not None:
                            return True

                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                            return True

                        if self.required_bw is not None:
                            return True

                        if self.resync_enabled is not None:
                            return True

                        if self.resync_threshold is not None:
                            return True

                        if self.rtp_mismatched is not None:
                            return True

                        if self.sequencing_type is not None:
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.sig_pkts_mismatched is not None:
                            return True

                        if self.ssrc_mismatched is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.table_policy_name is not None:
                            return True

                        if self.tag_rewrite is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.time_elapsed_status_down is not None:
                            return True

                        if self.transport_lsp_down is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1.PseudoWire']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment1'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                        return True

                    if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                        return True

                    if self.segment_type is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment1']['meta_info']


            class Segment2(object):
                """
                Segment 2
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire()
                    self.pseudo_wire.parent = self
                    self.segment_type = None


                class AttachmentCircuit(object):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bvi_mac_conflict = None
                        self.bvi_no_port_up = None
                        self.control_word_mismatched = None
                        self.encapsulation_error = None
                        self.encapsulation_mismatched = None
                        self.evpn_internal_label = None
                        self.interface = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self.interface_handle = None
                        self.internal_ms_ti = None
                        self.interworking = None
                        self.is_ac_partially_programmed = None
                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self.mac_limit_oper_down = None
                        self.ms_ti_mismatch = None
                        self.msti = None
                        self.msti_mismatch_down = None
                        self.mtu_mismatched = None
                        self.node_id = None
                        self.out_of_memory_state = None
                        self.redundancy_group_id = None
                        self.redundancy_group_state = None
                        self.redundancy_object_id = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self.tdm_media_mismatched = None
                        self.xconnect_id = None


                    class Interface(object):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics']['meta_info']


                    class L2VpnProtection(object):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active = None
                            self.protected_name = None
                            self.protection_configured = None
                            self.protection_name = None
                            self.protection_type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active is not None:
                                return True

                            if self.protected_name is not None:
                                return True

                            if self.protection_configured is not None:
                                return True

                            if self.protection_name is not None:
                                return True

                            if self.protection_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2VpnProtection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bvi_mac_conflict is not None:
                            return True

                        if self.bvi_no_port_up is not None:
                            return True

                        if self.control_word_mismatched is not None:
                            return True

                        if self.encapsulation_error is not None:
                            return True

                        if self.encapsulation_mismatched is not None:
                            return True

                        if self.evpn_internal_label is not None:
                            return True

                        if self.interface is not None and self.interface._has_data():
                            return True

                        if self.interface_handle is not None:
                            return True

                        if self.internal_ms_ti is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.is_ac_partially_programmed is not None:
                            return True

                        if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.ms_ti_mismatch is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.msti_mismatch_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.redundancy_group_id is not None:
                            return True

                        if self.redundancy_group_state is not None:
                            return True

                        if self.redundancy_object_id is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.tdm_media_mismatched is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.AttachmentCircuit']['meta_info']


                class PseudoWire(object):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_remote_down = None
                        self.admited_bw = None
                        self.auto_discovery = None
                        self.backup_active = None
                        self.backup_force_active = None
                        self.backup_pw = None
                        self.bitrate_mismatched = None
                        self.bridge_pw_type_mismatch = None
                        self.cas_mismatched = None
                        self.diff_ts_mismatched = None
                        self.disable_delay = None
                        self.disable_never = None
                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self.evpn_src_acid = None
                        self.fe_ctype = None
                        self.forward_class = None
                        self.freq_mismatched = None
                        self.illegal_control_word = None
                        self.imposed_vlan_id = None
                        self.interworking = None
                        self.ipv6_local_source_address = None
                        self.is_evpnvpws_type = None
                        self.is_flow_label_static = None
                        self.is_multi_segment_pseudowire = None
                        self.is_partially_programmed = None
                        self.is_pwr_type = None
                        self.is_vfi = None
                        self.last_time_status_changed = None
                        self.last_time_status_down = None
                        self.ldp_label_advertise_failed = None
                        self.load_balance = None
                        self.local_control_word = None
                        self.local_interface = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self.local_label_failed = None
                        self.local_pseudo_wire_type = None
                        self.local_signalling = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self.local_source_address = None
                        self.mac_limit_oper_down = None
                        self.mtu_mismatched = None
                        self.not_supported_qinq = None
                        self.num_ma_cwithdraw_msg_received = None
                        self.number_ma_cwithdraw_message_sent = None
                        self.out_of_memory_state = None
                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self.payload_bytes_mismatched = None
                        self.payload_type_mismatched = None
                        self.peer_id = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self.preferred_path = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self.preferred_path_disable_fallback = None
                        self.primary_peer_id = None
                        self.primary_pseudo_wire_id = None
                        self.primary_pw = None
                        self.protocol = None
                        self.pseudo_wire_id = None
                        self.pseudo_wire_state = None
                        self.pseudo_wire_type_mismatched = None
                        self.pw_class_name = None
                        self.pw_flow_label_code17_disabled = None
                        self.pw_flow_label_type = None
                        self.pw_flow_label_type_cfg = None
                        self.pw_redundancy_initial_delay = None
                        self.pw_redundancy_one_way = None
                        self.pw_status_use = None
                        self.pwlsd_rewrite_failed = None
                        self.remote_control_word = None
                        self.remote_interface = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self.remote_label_failed = None
                        self.remote_pseudo_wire_type = None
                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self.required_bw = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.rtp_mismatched = None
                        self.sequencing_type = None
                        self.shutdown = None
                        self.sig_pkts_mismatched = None
                        self.ssrc_mismatched = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self.table_policy_name = None
                        self.tag_rewrite = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.time_elapsed_status_down = None
                        self.transport_lsp_down = None
                        self.xconnect_id = None


                    class PeerId(object):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.internal_label = None
                            self.ipv4_peer_id = None
                            self.ipv6_peer_id = None
                            self.type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.internal_label is not None:
                                return True

                            if self.ipv4_peer_id is not None:
                                return True

                            if self.ipv6_peer_id is not None:
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PeerId']['meta_info']


                    class EncapsulationInfo(object):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.atom = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self.encapsulation = None
                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self


                        class Atom(object):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_pseudowire_headend = None
                                self.is_sai_itype2 = None
                                self.is_tai_itype2 = None
                                self.ldp_label_advertisment_failed = None
                                self.local_agi = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self.local_c_ctype = None
                                self.local_ceid = None
                                self.local_cv_type = None
                                self.local_group_id = None
                                self.local_label = None
                                self.local_ldp_id = None
                                self.local_saii_gbl_id = None
                                self.local_saiiac_id = None
                                self.local_taii_gbl_id = None
                                self.local_taiiac_id = None
                                self.local_veid = None
                                self.lsd_rewrite_failed = None
                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self.rem_saii = None
                                self.rem_saii_gbl_id = None
                                self.rem_saiiac_id = None
                                self.rem_taii = None
                                self.rem_taii_gbl_id = None
                                self.rem_taiiac_id = None
                                self.remote_agi = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self.remote_c_ctype = None
                                self.remote_ceid = None
                                self.remote_cv_type = None
                                self.remote_group_id = None
                                self.remote_label = None
                                self.remote_ldp_id = None
                                self.remote_source_address = None
                                self.remote_veid = None
                                self.saii = None
                                self.source_address = None
                                self.taii = None


                            class LocalAgi(object):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                            class RemoteAgi(object):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                            class MultiSegmentPseudowireStats(object):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.received_bytes = None
                                    self.received_packets = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.received_bytes is not None:
                                        return True

                                    if self.received_packets is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_pseudowire_headend is not None:
                                    return True

                                if self.is_sai_itype2 is not None:
                                    return True

                                if self.is_tai_itype2 is not None:
                                    return True

                                if self.ldp_label_advertisment_failed is not None:
                                    return True

                                if self.local_agi is not None and self.local_agi._has_data():
                                    return True

                                if self.local_c_ctype is not None:
                                    return True

                                if self.local_ceid is not None:
                                    return True

                                if self.local_cv_type is not None:
                                    return True

                                if self.local_group_id is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_ldp_id is not None:
                                    return True

                                if self.local_saii_gbl_id is not None:
                                    return True

                                if self.local_saiiac_id is not None:
                                    return True

                                if self.local_taii_gbl_id is not None:
                                    return True

                                if self.local_taiiac_id is not None:
                                    return True

                                if self.local_veid is not None:
                                    return True

                                if self.lsd_rewrite_failed is not None:
                                    return True

                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                    return True

                                if self.rem_saii is not None:
                                    return True

                                if self.rem_saii_gbl_id is not None:
                                    return True

                                if self.rem_saiiac_id is not None:
                                    return True

                                if self.rem_taii is not None:
                                    return True

                                if self.rem_taii_gbl_id is not None:
                                    return True

                                if self.rem_taiiac_id is not None:
                                    return True

                                if self.remote_agi is not None and self.remote_agi._has_data():
                                    return True

                                if self.remote_c_ctype is not None:
                                    return True

                                if self.remote_ceid is not None:
                                    return True

                                if self.remote_cv_type is not None:
                                    return True

                                if self.remote_group_id is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_ldp_id is not None:
                                    return True

                                if self.remote_source_address is not None:
                                    return True

                                if self.remote_veid is not None:
                                    return True

                                if self.saii is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.taii is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                        class L2Tpv3(object):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dont_fragment_bit = None
                                self.ipv4_source_address = None
                                self.ipv6_source_address = None
                                self.l2tp_class_name = None
                                self.local_cookie_high_value = None
                                self.local_cookie_low_value = None
                                self.local_cookie_size = None
                                self.local_secondary_cookie_high_value = None
                                self.local_secondary_cookie_low_value = None
                                self.local_secondary_cookie_size = None
                                self.local_session_id = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.remote_circuit_status_up = None
                                self.remote_cookie_high_value = None
                                self.remote_cookie_low_value = None
                                self.remote_cookie_size = None
                                self.remote_session_id = None
                                self.tos = None
                                self.tos_mode = None
                                self.ttl = None
                                self.tunnel_state = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dont_fragment_bit is not None:
                                    return True

                                if self.ipv4_source_address is not None:
                                    return True

                                if self.ipv6_source_address is not None:
                                    return True

                                if self.l2tp_class_name is not None:
                                    return True

                                if self.local_cookie_high_value is not None:
                                    return True

                                if self.local_cookie_low_value is not None:
                                    return True

                                if self.local_cookie_size is not None:
                                    return True

                                if self.local_secondary_cookie_high_value is not None:
                                    return True

                                if self.local_secondary_cookie_low_value is not None:
                                    return True

                                if self.local_secondary_cookie_size is not None:
                                    return True

                                if self.local_session_id is not None:
                                    return True

                                if self.path_mtu_enabled is not None:
                                    return True

                                if self.path_mtu_max_value is not None:
                                    return True

                                if self.remote_circuit_status_up is not None:
                                    return True

                                if self.remote_cookie_high_value is not None:
                                    return True

                                if self.remote_cookie_low_value is not None:
                                    return True

                                if self.remote_cookie_size is not None:
                                    return True

                                if self.remote_session_id is not None:
                                    return True

                                if self.tos is not None:
                                    return True

                                if self.tos_mode is not None:
                                    return True

                                if self.ttl is not None:
                                    return True

                                if self.tunnel_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.atom is not None and self.atom._has_data():
                                return True

                            if self.encapsulation is not None:
                                return True

                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo']['meta_info']


                    class LocalInterface(object):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface']['meta_info']


                    class RemoteInterface(object):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface']['meta_info']


                    class PreferredPath(object):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ip_tunnel_interface_number = None
                            self.next_hop_ip = None
                            self.option = None
                            self.te_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ip_tunnel_interface_number is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            if self.option is not None:
                                return True

                            if self.te_tunnel_interface_number is not None:
                                return True

                            if self.tp_tunnel_interface_number is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath']['meta_info']


                    class LocalSignalling(object):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling']['meta_info']


                    class RemoteSignalling(object):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.Statistics']['meta_info']


                    class P2MpPw(object):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_available = None
                            self.local_extended_tunnel_id = None
                            self.local_flags = None
                            self.local_label = None
                            self.local_p2mp_id = None
                            self.local_ptree_type = None
                            self.local_tunnel_id = None
                            self.remote_available = None
                            self.remote_extended_tunnel_id = None
                            self.remote_flags = None
                            self.remote_label = None
                            self.remote_p2mp_id = None
                            self.remote_ptree_type = None
                            self.remote_tunnel_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_available is not None:
                                return True

                            if self.local_extended_tunnel_id is not None:
                                return True

                            if self.local_flags is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.local_p2mp_id is not None:
                                return True

                            if self.local_ptree_type is not None:
                                return True

                            if self.local_tunnel_id is not None:
                                return True

                            if self.remote_available is not None:
                                return True

                            if self.remote_extended_tunnel_id is not None:
                                return True

                            if self.remote_flags is not None:
                                return True

                            if self.remote_label is not None:
                                return True

                            if self.remote_p2mp_id is not None:
                                return True

                            if self.remote_ptree_type is not None:
                                return True

                            if self.remote_tunnel_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire.P2MpPw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_remote_down is not None:
                            return True

                        if self.admited_bw is not None:
                            return True

                        if self.auto_discovery is not None:
                            return True

                        if self.backup_active is not None:
                            return True

                        if self.backup_force_active is not None:
                            return True

                        if self.backup_pw is not None:
                            return True

                        if self.bitrate_mismatched is not None:
                            return True

                        if self.bridge_pw_type_mismatch is not None:
                            return True

                        if self.cas_mismatched is not None:
                            return True

                        if self.diff_ts_mismatched is not None:
                            return True

                        if self.disable_delay is not None:
                            return True

                        if self.disable_never is not None:
                            return True

                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                            return True

                        if self.evpn_src_acid is not None:
                            return True

                        if self.fe_ctype is not None:
                            return True

                        if self.forward_class is not None:
                            return True

                        if self.freq_mismatched is not None:
                            return True

                        if self.illegal_control_word is not None:
                            return True

                        if self.imposed_vlan_id is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.ipv6_local_source_address is not None:
                            return True

                        if self.is_evpnvpws_type is not None:
                            return True

                        if self.is_flow_label_static is not None:
                            return True

                        if self.is_multi_segment_pseudowire is not None:
                            return True

                        if self.is_partially_programmed is not None:
                            return True

                        if self.is_pwr_type is not None:
                            return True

                        if self.is_vfi is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.last_time_status_down is not None:
                            return True

                        if self.ldp_label_advertise_failed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.local_control_word is not None:
                            return True

                        if self.local_interface is not None and self.local_interface._has_data():
                            return True

                        if self.local_label_failed is not None:
                            return True

                        if self.local_pseudo_wire_type is not None:
                            return True

                        if self.local_signalling is not None and self.local_signalling._has_data():
                            return True

                        if self.local_source_address is not None:
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.not_supported_qinq is not None:
                            return True

                        if self.num_ma_cwithdraw_msg_received is not None:
                            return True

                        if self.number_ma_cwithdraw_message_sent is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                            return True

                        if self.payload_bytes_mismatched is not None:
                            return True

                        if self.payload_type_mismatched is not None:
                            return True

                        if self.peer_id is not None and self.peer_id._has_data():
                            return True

                        if self.preferred_path is not None and self.preferred_path._has_data():
                            return True

                        if self.preferred_path_disable_fallback is not None:
                            return True

                        if self.primary_peer_id is not None:
                            return True

                        if self.primary_pseudo_wire_id is not None:
                            return True

                        if self.primary_pw is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.pseudo_wire_id is not None:
                            return True

                        if self.pseudo_wire_state is not None:
                            return True

                        if self.pseudo_wire_type_mismatched is not None:
                            return True

                        if self.pw_class_name is not None:
                            return True

                        if self.pw_flow_label_code17_disabled is not None:
                            return True

                        if self.pw_flow_label_type is not None:
                            return True

                        if self.pw_flow_label_type_cfg is not None:
                            return True

                        if self.pw_redundancy_initial_delay is not None:
                            return True

                        if self.pw_redundancy_one_way is not None:
                            return True

                        if self.pw_status_use is not None:
                            return True

                        if self.pwlsd_rewrite_failed is not None:
                            return True

                        if self.remote_control_word is not None:
                            return True

                        if self.remote_interface is not None and self.remote_interface._has_data():
                            return True

                        if self.remote_label_failed is not None:
                            return True

                        if self.remote_pseudo_wire_type is not None:
                            return True

                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                            return True

                        if self.required_bw is not None:
                            return True

                        if self.resync_enabled is not None:
                            return True

                        if self.resync_threshold is not None:
                            return True

                        if self.rtp_mismatched is not None:
                            return True

                        if self.sequencing_type is not None:
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.sig_pkts_mismatched is not None:
                            return True

                        if self.ssrc_mismatched is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.table_policy_name is not None:
                            return True

                        if self.tag_rewrite is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.time_elapsed_status_down is not None:
                            return True

                        if self.transport_lsp_down is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2.PseudoWire']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:segment2'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                        return True

                    if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                        return True

                    if self.segment_type is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Segment2']['meta_info']


            class Ce2Ce(object):
                """
                CE2CE
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\:  bool
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ce_added = None
                    self.local_customer_edge_id = None
                    self.remote_customer_edge_id = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:ce2ce'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ce_added is not None:
                        return True

                    if self.local_customer_edge_id is not None:
                        return True

                    if self.remote_customer_edge_id is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.Ce2Ce']['meta_info']


            class BackupSegment(object):
                """
                Backup Segment
                
                .. attribute:: attachment_circuit
                
                	Attachment Circuit
                	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                
                .. attribute:: pseudo_wire
                
                	Pseudowire
                	**type**\:   :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                
                .. attribute:: segment_type
                
                	SegmentType
                	**type**\:   :py:class:`L2VpnSegmentEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.attachment_circuit = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                    self.attachment_circuit.parent = self
                    self.pseudo_wire = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire()
                    self.pseudo_wire.parent = self
                    self.segment_type = None


                class AttachmentCircuit(object):
                    """
                    Attachment Circuit
                    
                    .. attribute:: bvi_mac_conflict
                    
                    	BVI Mac Conflict
                    	**type**\:  bool
                    
                    .. attribute:: bvi_no_port_up
                    
                    	BVI no BP Up
                    	**type**\:  bool
                    
                    .. attribute:: control_word_mismatched
                    
                    	Control word mismatched
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_error
                    
                    	Encapsulation Error
                    	**type**\:  str
                    
                    .. attribute:: encapsulation_mismatched
                    
                    	Encapsulation mismatched
                    	**type**\:  bool
                    
                    .. attribute:: evpn_internal_label
                    
                    	EVPN Internal Label
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interface
                    	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                    
                    .. attribute:: interface_handle
                    
                    	Interface Handler
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: internal_ms_ti
                    
                    	Internal MSTi
                    	**type**\:  str
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: is_ac_partially_programmed
                    
                    	Is attachment\-circuit partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: l2vpn_protection
                    
                    	Protection object used for this segment
                    	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection>`
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: ms_ti_mismatch
                    
                    	MSTi mismatch
                    	**type**\:  bool
                    
                    .. attribute:: msti
                    
                    	MSTi
                    	**type**\:  str
                    
                    .. attribute:: msti_mismatch_down
                    
                    	Oper down due to MSTI mismatch
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: node_id
                    
                    	Node ID
                    	**type**\:  str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_id
                    
                    	Redundancy Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: redundancy_group_state
                    
                    	Redundancy Group State
                    	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                    
                    .. attribute:: redundancy_object_id
                    
                    	Redundancy Object ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                    
                    .. attribute:: tdm_media_mismatched
                    
                    	TDM media parms mismatched
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bvi_mac_conflict = None
                        self.bvi_no_port_up = None
                        self.control_word_mismatched = None
                        self.encapsulation_error = None
                        self.encapsulation_mismatched = None
                        self.evpn_internal_label = None
                        self.interface = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                        self.interface.parent = self
                        self.interface_handle = None
                        self.internal_ms_ti = None
                        self.interworking = None
                        self.is_ac_partially_programmed = None
                        self.l2vpn_protection = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection()
                        self.l2vpn_protection.parent = self
                        self.mac_limit_oper_down = None
                        self.ms_ti_mismatch = None
                        self.msti = None
                        self.msti_mismatch_down = None
                        self.mtu_mismatched = None
                        self.node_id = None
                        self.out_of_memory_state = None
                        self.redundancy_group_id = None
                        self.redundancy_group_state = None
                        self.redundancy_object_id = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                        self.statistics.parent = self
                        self.tdm_media_mismatched = None
                        self.xconnect_id = None


                    class Interface(object):
                        """
                        Interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface_(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics']['meta_info']


                    class L2VpnProtection(object):
                        """
                        Protection object used for this segment
                        
                        .. attribute:: active
                        
                        	Active
                        	**type**\:  bool
                        
                        .. attribute:: protected_name
                        
                        	Name of the protected segment
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_configured
                        
                        	Protection configured
                        	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                        
                        .. attribute:: protection_name
                        
                        	Name of the segment acting as backup
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: protection_type
                        
                        	Type of the protection
                        	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.active = None
                            self.protected_name = None
                            self.protection_configured = None
                            self.protection_name = None
                            self.protection_type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.active is not None:
                                return True

                            if self.protected_name is not None:
                                return True

                            if self.protection_configured is not None:
                                return True

                            if self.protection_name is not None:
                                return True

                            if self.protection_type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2VpnProtection']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bvi_mac_conflict is not None:
                            return True

                        if self.bvi_no_port_up is not None:
                            return True

                        if self.control_word_mismatched is not None:
                            return True

                        if self.encapsulation_error is not None:
                            return True

                        if self.encapsulation_mismatched is not None:
                            return True

                        if self.evpn_internal_label is not None:
                            return True

                        if self.interface is not None and self.interface._has_data():
                            return True

                        if self.interface_handle is not None:
                            return True

                        if self.internal_ms_ti is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.is_ac_partially_programmed is not None:
                            return True

                        if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.ms_ti_mismatch is not None:
                            return True

                        if self.msti is not None:
                            return True

                        if self.msti_mismatch_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.node_id is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.redundancy_group_id is not None:
                            return True

                        if self.redundancy_group_state is not None:
                            return True

                        if self.redundancy_object_id is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.tdm_media_mismatched is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.AttachmentCircuit']['meta_info']


                class PseudoWire(object):
                    """
                    Pseudowire
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_remote_down = None
                        self.admited_bw = None
                        self.auto_discovery = None
                        self.backup_active = None
                        self.backup_force_active = None
                        self.backup_pw = None
                        self.bitrate_mismatched = None
                        self.bridge_pw_type_mismatch = None
                        self.cas_mismatched = None
                        self.diff_ts_mismatched = None
                        self.disable_delay = None
                        self.disable_never = None
                        self.encapsulation_info = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self.evpn_src_acid = None
                        self.fe_ctype = None
                        self.forward_class = None
                        self.freq_mismatched = None
                        self.illegal_control_word = None
                        self.imposed_vlan_id = None
                        self.interworking = None
                        self.ipv6_local_source_address = None
                        self.is_evpnvpws_type = None
                        self.is_flow_label_static = None
                        self.is_multi_segment_pseudowire = None
                        self.is_partially_programmed = None
                        self.is_pwr_type = None
                        self.is_vfi = None
                        self.last_time_status_changed = None
                        self.last_time_status_down = None
                        self.ldp_label_advertise_failed = None
                        self.load_balance = None
                        self.local_control_word = None
                        self.local_interface = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                        self.local_interface.parent = self
                        self.local_label_failed = None
                        self.local_pseudo_wire_type = None
                        self.local_signalling = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                        self.local_signalling.parent = self
                        self.local_source_address = None
                        self.mac_limit_oper_down = None
                        self.mtu_mismatched = None
                        self.not_supported_qinq = None
                        self.num_ma_cwithdraw_msg_received = None
                        self.number_ma_cwithdraw_message_sent = None
                        self.out_of_memory_state = None
                        self.p2mp_pw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self.payload_bytes_mismatched = None
                        self.payload_type_mismatched = None
                        self.peer_id = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                        self.peer_id.parent = self
                        self.preferred_path = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                        self.preferred_path.parent = self
                        self.preferred_path_disable_fallback = None
                        self.primary_peer_id = None
                        self.primary_pseudo_wire_id = None
                        self.primary_pw = None
                        self.protocol = None
                        self.pseudo_wire_id = None
                        self.pseudo_wire_state = None
                        self.pseudo_wire_type_mismatched = None
                        self.pw_class_name = None
                        self.pw_flow_label_code17_disabled = None
                        self.pw_flow_label_type = None
                        self.pw_flow_label_type_cfg = None
                        self.pw_redundancy_initial_delay = None
                        self.pw_redundancy_one_way = None
                        self.pw_status_use = None
                        self.pwlsd_rewrite_failed = None
                        self.remote_control_word = None
                        self.remote_interface = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                        self.remote_interface.parent = self
                        self.remote_label_failed = None
                        self.remote_pseudo_wire_type = None
                        self.remote_signalling = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self.required_bw = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.rtp_mismatched = None
                        self.sequencing_type = None
                        self.shutdown = None
                        self.sig_pkts_mismatched = None
                        self.ssrc_mismatched = None
                        self.state = None
                        self.statistics = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                        self.statistics.parent = self
                        self.table_policy_name = None
                        self.tag_rewrite = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.time_elapsed_status_down = None
                        self.transport_lsp_down = None
                        self.xconnect_id = None


                    class PeerId(object):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.internal_label = None
                            self.ipv4_peer_id = None
                            self.ipv6_peer_id = None
                            self.type = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.internal_label is not None:
                                return True

                            if self.ipv4_peer_id is not None:
                                return True

                            if self.ipv6_peer_id is not None:
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId']['meta_info']


                    class EncapsulationInfo(object):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.atom = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self.encapsulation = None
                            self.l2tpv3 = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self


                        class Atom(object):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_pseudowire_headend = None
                                self.is_sai_itype2 = None
                                self.is_tai_itype2 = None
                                self.ldp_label_advertisment_failed = None
                                self.local_agi = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self.local_c_ctype = None
                                self.local_ceid = None
                                self.local_cv_type = None
                                self.local_group_id = None
                                self.local_label = None
                                self.local_ldp_id = None
                                self.local_saii_gbl_id = None
                                self.local_saiiac_id = None
                                self.local_taii_gbl_id = None
                                self.local_taiiac_id = None
                                self.local_veid = None
                                self.lsd_rewrite_failed = None
                                self.multi_segment_pseudowire_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self.rem_saii = None
                                self.rem_saii_gbl_id = None
                                self.rem_saiiac_id = None
                                self.rem_taii = None
                                self.rem_taii_gbl_id = None
                                self.rem_taiiac_id = None
                                self.remote_agi = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self.remote_c_ctype = None
                                self.remote_ceid = None
                                self.remote_cv_type = None
                                self.remote_group_id = None
                                self.remote_label = None
                                self.remote_ldp_id = None
                                self.remote_source_address = None
                                self.remote_veid = None
                                self.saii = None
                                self.source_address = None
                                self.taii = None


                            class LocalAgi(object):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                            class RemoteAgi(object):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                            class MultiSegmentPseudowireStats(object):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.received_bytes = None
                                    self.received_packets = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.received_bytes is not None:
                                        return True

                                    if self.received_packets is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_pseudowire_headend is not None:
                                    return True

                                if self.is_sai_itype2 is not None:
                                    return True

                                if self.is_tai_itype2 is not None:
                                    return True

                                if self.ldp_label_advertisment_failed is not None:
                                    return True

                                if self.local_agi is not None and self.local_agi._has_data():
                                    return True

                                if self.local_c_ctype is not None:
                                    return True

                                if self.local_ceid is not None:
                                    return True

                                if self.local_cv_type is not None:
                                    return True

                                if self.local_group_id is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_ldp_id is not None:
                                    return True

                                if self.local_saii_gbl_id is not None:
                                    return True

                                if self.local_saiiac_id is not None:
                                    return True

                                if self.local_taii_gbl_id is not None:
                                    return True

                                if self.local_taiiac_id is not None:
                                    return True

                                if self.local_veid is not None:
                                    return True

                                if self.lsd_rewrite_failed is not None:
                                    return True

                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                    return True

                                if self.rem_saii is not None:
                                    return True

                                if self.rem_saii_gbl_id is not None:
                                    return True

                                if self.rem_saiiac_id is not None:
                                    return True

                                if self.rem_taii is not None:
                                    return True

                                if self.rem_taii_gbl_id is not None:
                                    return True

                                if self.rem_taiiac_id is not None:
                                    return True

                                if self.remote_agi is not None and self.remote_agi._has_data():
                                    return True

                                if self.remote_c_ctype is not None:
                                    return True

                                if self.remote_ceid is not None:
                                    return True

                                if self.remote_cv_type is not None:
                                    return True

                                if self.remote_group_id is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_ldp_id is not None:
                                    return True

                                if self.remote_source_address is not None:
                                    return True

                                if self.remote_veid is not None:
                                    return True

                                if self.saii is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.taii is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom']['meta_info']


                        class L2Tpv3(object):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dont_fragment_bit = None
                                self.ipv4_source_address = None
                                self.ipv6_source_address = None
                                self.l2tp_class_name = None
                                self.local_cookie_high_value = None
                                self.local_cookie_low_value = None
                                self.local_cookie_size = None
                                self.local_secondary_cookie_high_value = None
                                self.local_secondary_cookie_low_value = None
                                self.local_secondary_cookie_size = None
                                self.local_session_id = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.remote_circuit_status_up = None
                                self.remote_cookie_high_value = None
                                self.remote_cookie_low_value = None
                                self.remote_cookie_size = None
                                self.remote_session_id = None
                                self.tos = None
                                self.tos_mode = None
                                self.ttl = None
                                self.tunnel_state = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dont_fragment_bit is not None:
                                    return True

                                if self.ipv4_source_address is not None:
                                    return True

                                if self.ipv6_source_address is not None:
                                    return True

                                if self.l2tp_class_name is not None:
                                    return True

                                if self.local_cookie_high_value is not None:
                                    return True

                                if self.local_cookie_low_value is not None:
                                    return True

                                if self.local_cookie_size is not None:
                                    return True

                                if self.local_secondary_cookie_high_value is not None:
                                    return True

                                if self.local_secondary_cookie_low_value is not None:
                                    return True

                                if self.local_secondary_cookie_size is not None:
                                    return True

                                if self.local_session_id is not None:
                                    return True

                                if self.path_mtu_enabled is not None:
                                    return True

                                if self.path_mtu_max_value is not None:
                                    return True

                                if self.remote_circuit_status_up is not None:
                                    return True

                                if self.remote_cookie_high_value is not None:
                                    return True

                                if self.remote_cookie_low_value is not None:
                                    return True

                                if self.remote_cookie_size is not None:
                                    return True

                                if self.remote_session_id is not None:
                                    return True

                                if self.tos is not None:
                                    return True

                                if self.tos_mode is not None:
                                    return True

                                if self.ttl is not None:
                                    return True

                                if self.tunnel_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2Tpv3']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.atom is not None and self.atom._has_data():
                                return True

                            if self.encapsulation is not None:
                                return True

                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo']['meta_info']


                    class LocalInterface(object):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface']['meta_info']


                    class RemoteInterface(object):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface']['meta_info']


                    class PreferredPath(object):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ip_tunnel_interface_number = None
                            self.next_hop_ip = None
                            self.option = None
                            self.te_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ip_tunnel_interface_number is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            if self.option is not None:
                                return True

                            if self.te_tunnel_interface_number is not None:
                                return True

                            if self.tp_tunnel_interface_number is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath']['meta_info']


                    class LocalSignalling(object):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling']['meta_info']


                    class RemoteSignalling(object):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics']['meta_info']


                    class P2MpPw(object):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_available = None
                            self.local_extended_tunnel_id = None
                            self.local_flags = None
                            self.local_label = None
                            self.local_p2mp_id = None
                            self.local_ptree_type = None
                            self.local_tunnel_id = None
                            self.remote_available = None
                            self.remote_extended_tunnel_id = None
                            self.remote_flags = None
                            self.remote_label = None
                            self.remote_p2mp_id = None
                            self.remote_ptree_type = None
                            self.remote_tunnel_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_available is not None:
                                return True

                            if self.local_extended_tunnel_id is not None:
                                return True

                            if self.local_flags is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.local_p2mp_id is not None:
                                return True

                            if self.local_ptree_type is not None:
                                return True

                            if self.local_tunnel_id is not None:
                                return True

                            if self.remote_available is not None:
                                return True

                            if self.remote_extended_tunnel_id is not None:
                                return True

                            if self.remote_flags is not None:
                                return True

                            if self.remote_label is not None:
                                return True

                            if self.remote_p2mp_id is not None:
                                return True

                            if self.remote_ptree_type is not None:
                                return True

                            if self.remote_tunnel_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire.P2MpPw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment/Cisco-IOS-XR-l2vpn-oper:pseudo-wire'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_remote_down is not None:
                            return True

                        if self.admited_bw is not None:
                            return True

                        if self.auto_discovery is not None:
                            return True

                        if self.backup_active is not None:
                            return True

                        if self.backup_force_active is not None:
                            return True

                        if self.backup_pw is not None:
                            return True

                        if self.bitrate_mismatched is not None:
                            return True

                        if self.bridge_pw_type_mismatch is not None:
                            return True

                        if self.cas_mismatched is not None:
                            return True

                        if self.diff_ts_mismatched is not None:
                            return True

                        if self.disable_delay is not None:
                            return True

                        if self.disable_never is not None:
                            return True

                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                            return True

                        if self.evpn_src_acid is not None:
                            return True

                        if self.fe_ctype is not None:
                            return True

                        if self.forward_class is not None:
                            return True

                        if self.freq_mismatched is not None:
                            return True

                        if self.illegal_control_word is not None:
                            return True

                        if self.imposed_vlan_id is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.ipv6_local_source_address is not None:
                            return True

                        if self.is_evpnvpws_type is not None:
                            return True

                        if self.is_flow_label_static is not None:
                            return True

                        if self.is_multi_segment_pseudowire is not None:
                            return True

                        if self.is_partially_programmed is not None:
                            return True

                        if self.is_pwr_type is not None:
                            return True

                        if self.is_vfi is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.last_time_status_down is not None:
                            return True

                        if self.ldp_label_advertise_failed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.local_control_word is not None:
                            return True

                        if self.local_interface is not None and self.local_interface._has_data():
                            return True

                        if self.local_label_failed is not None:
                            return True

                        if self.local_pseudo_wire_type is not None:
                            return True

                        if self.local_signalling is not None and self.local_signalling._has_data():
                            return True

                        if self.local_source_address is not None:
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.not_supported_qinq is not None:
                            return True

                        if self.num_ma_cwithdraw_msg_received is not None:
                            return True

                        if self.number_ma_cwithdraw_message_sent is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                            return True

                        if self.payload_bytes_mismatched is not None:
                            return True

                        if self.payload_type_mismatched is not None:
                            return True

                        if self.peer_id is not None and self.peer_id._has_data():
                            return True

                        if self.preferred_path is not None and self.preferred_path._has_data():
                            return True

                        if self.preferred_path_disable_fallback is not None:
                            return True

                        if self.primary_peer_id is not None:
                            return True

                        if self.primary_pseudo_wire_id is not None:
                            return True

                        if self.primary_pw is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.pseudo_wire_id is not None:
                            return True

                        if self.pseudo_wire_state is not None:
                            return True

                        if self.pseudo_wire_type_mismatched is not None:
                            return True

                        if self.pw_class_name is not None:
                            return True

                        if self.pw_flow_label_code17_disabled is not None:
                            return True

                        if self.pw_flow_label_type is not None:
                            return True

                        if self.pw_flow_label_type_cfg is not None:
                            return True

                        if self.pw_redundancy_initial_delay is not None:
                            return True

                        if self.pw_redundancy_one_way is not None:
                            return True

                        if self.pw_status_use is not None:
                            return True

                        if self.pwlsd_rewrite_failed is not None:
                            return True

                        if self.remote_control_word is not None:
                            return True

                        if self.remote_interface is not None and self.remote_interface._has_data():
                            return True

                        if self.remote_label_failed is not None:
                            return True

                        if self.remote_pseudo_wire_type is not None:
                            return True

                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                            return True

                        if self.required_bw is not None:
                            return True

                        if self.resync_enabled is not None:
                            return True

                        if self.resync_threshold is not None:
                            return True

                        if self.rtp_mismatched is not None:
                            return True

                        if self.sequencing_type is not None:
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.sig_pkts_mismatched is not None:
                            return True

                        if self.ssrc_mismatched is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.table_policy_name is not None:
                            return True

                        if self.tag_rewrite is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.time_elapsed_status_down is not None:
                            return True

                        if self.transport_lsp_down is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment.PseudoWire']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect/Cisco-IOS-XR-l2vpn-oper:backup-segment'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                        return True

                    if self.pseudo_wire is not None and self.pseudo_wire._has_data():
                        return True

                    if self.segment_type is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Xconnects.Xconnect.BackupSegment']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects/Cisco-IOS-XR-l2vpn-oper:xconnect'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.backup is not None and self.backup._has_data():
                    return True

                if self.backup_segment is not None:
                    for child_ref in self.backup_segment:
                        if child_ref._has_data():
                            return True

                if self.ce2ce is not None and self.ce2ce._has_data():
                    return True

                if self.description is not None:
                    return True

                if self.diag_mask is not None:
                    return True

                if self.group_name is not None:
                    return True

                if self.group_name_xr is not None:
                    return True

                if self.interworking is not None:
                    return True

                if self.is_mp2mp is not None:
                    return True

                if self.number_of_backup_p_ws is not None:
                    return True

                if self.segment1 is not None and self.segment1._has_data():
                    return True

                if self.segment2 is not None and self.segment2._has_data():
                    return True

                if self.state is not None:
                    return True

                if self.xconnect_name is not None:
                    return True

                if self.xconnect_name_xr is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Xconnects.Xconnect']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnects'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.xconnect is not None:
                for child_ref in self.xconnect:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.Xconnects']['meta_info']


    class XconnectGroups(object):
        """
        XConnect group Table
        
        .. attribute:: xconnect_group
        
        	XConnect group information
        	**type**\: list of    :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectGroups.XconnectGroup>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.xconnect_group = YList()
            self.xconnect_group.parent = self
            self.xconnect_group.name = 'xconnect_group'


        class XconnectGroup(object):
            """
            XConnect group information
            
            .. attribute:: group_name  <key>
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.group_name = None
                self.group_name_xr = None
                self.number_xconnects = None

            @property
            def _common_path(self):
                if self.group_name is None:
                    raise YPYModelError('Key property group_name is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-groups/Cisco-IOS-XR-l2vpn-oper:xconnect-group[Cisco-IOS-XR-l2vpn-oper:group-name = ' + str(self.group_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.group_name is not None:
                    return True

                if self.group_name_xr is not None:
                    return True

                if self.number_xconnects is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.XconnectGroups.XconnectGroup']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-groups'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.xconnect_group is not None:
                for child_ref in self.xconnect_group:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.XconnectGroups']['meta_info']


    class XconnectMp2Mps(object):
        """
        XConnect MP2MP Table
        
        .. attribute:: xconnect_mp2mp
        
        	XConnect MP2MP information
        	**type**\: list of    :py:class:`XconnectMp2Mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.xconnect_mp2mp = YList()
            self.xconnect_mp2mp.parent = self
            self.xconnect_mp2mp.name = 'xconnect_mp2mp'


        class XconnectMp2Mp(object):
            """
            XConnect MP2MP information
            
            .. attribute:: discovery
            
            	l2vpn xc auto discovery info
            	**type**\:   :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery>`
            
            .. attribute:: group_name
            
            	XConnect Group
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: group_name_xr
            
            	Group name
            	**type**\:  str
            
            .. attribute:: l2_encapsulation
            
            	L2 Encapsulation
            	**type**\:   :py:class:`L2VpnBagAdEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagAdEncapEnum>`
            
            .. attribute:: mp2_mp_name
            
            	Mp2Mp Name
            	**type**\:  str
            
            	**length:** 1..26
            
            .. attribute:: mp2mp_name
            
            	MP2MP name
            	**type**\:  str
            
            .. attribute:: mp2mpid
            
            	Identification Number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpn_id
            
            	Vpn ID
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: vpn_mtu
            
            	VPN MTU
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: xconnect_shutdown
            
            	Administratively disabled
            	**type**\:  bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.discovery = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery()
                self.discovery.parent = self
                self.group_name = None
                self.group_name_xr = None
                self.l2_encapsulation = None
                self.mp2_mp_name = None
                self.mp2mp_name = None
                self.mp2mpid = None
                self.vpn_id = None
                self.vpn_mtu = None
                self.xconnect_shutdown = None


            class Discovery(object):
                """
                l2vpn xc auto discovery info
                
                .. attribute:: ad_method
                
                	Autodiscovery Method
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ad_service_connected
                
                	Service Connected
                	**type**\:  bool
                
                .. attribute:: ad_signalling_method
                
                	Signaling Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ce_range
                
                	CE Range
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: export_route_policy
                
                	Export Route Policy
                	**type**\:  str
                
                .. attribute:: export_rt
                
                	Export Route Targets
                	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt>`
                
                .. attribute:: import_rt
                
                	Import Route Targets
                	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt>`
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2c_es
                
                	Number of ce2ce
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_advertised
                
                	Number of ce2ce Advertised
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rd_value
                
                	Route Distinguisher
                	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue>`
                
                .. attribute:: vpn_added
                
                	VPN Added
                	**type**\:  bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ad_method = None
                    self.ad_service_connected = None
                    self.ad_signalling_method = None
                    self.ce_range = None
                    self.export_route_policy = None
                    self.export_rt = YList()
                    self.export_rt.parent = self
                    self.export_rt.name = 'export_rt'
                    self.import_rt = YList()
                    self.import_rt.parent = self
                    self.import_rt.name = 'import_rt'
                    self.number_a_cs = None
                    self.number_a_cs_up = None
                    self.number_ce2c_es = None
                    self.number_ce2ce_advertised = None
                    self.number_p_ws_up = None
                    self.number_pseudowires = None
                    self.rd_value = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue()
                    self.rd_value.parent = self
                    self.vpn_added = None


                class RdValue(object):
                    """
                    Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto()
                        self.auto.parent = self
                        self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rd = None
                        self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr()
                        self.v4_addr.parent = self


                    class Auto(object):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto_index = None
                            self.router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto_index is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.Auto']['meta_info']


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue.V4Addr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:rd-value'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto is not None and self.auto._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rd is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.RdValue']['meta_info']


                class ImportRt(object):
                    """
                    Import Route Targets
                    
                    .. attribute:: es_import
                    
                    	es import
                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs>`
                    
                    .. attribute:: rt
                    
                    	RT
                    	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.es_import = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport()
                        self.es_import.parent = self
                        self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rt = None
                        self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr()
                        self.v4_addr.parent = self


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.V4Addr']['meta_info']


                    class EsImport(object):
                        """
                        es import
                        
                        .. attribute:: high_bytes
                        
                        	Top 4 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low_bytes
                        
                        	Low 2 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.high_bytes = None
                            self.low_bytes = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.high_bytes is not None:
                                return True

                            if self.low_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt.EsImport']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:import-rt'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.es_import is not None and self.es_import._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rt is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ImportRt']['meta_info']


                class ExportRt(object):
                    """
                    Export Route Targets
                    
                    .. attribute:: es_import
                    
                    	es import
                    	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs>`
                    
                    .. attribute:: rt
                    
                    	RT
                    	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.es_import = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport()
                        self.es_import.parent = self
                        self.four_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rt = None
                        self.two_byte_as = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr()
                        self.v4_addr.parent = self


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.V4Addr']['meta_info']


                    class EsImport(object):
                        """
                        es import
                        
                        .. attribute:: high_bytes
                        
                        	Top 4 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: low_bytes
                        
                        	Low 2 bytes of ES Import
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.high_bytes = None
                            self.low_bytes = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.high_bytes is not None:
                                return True

                            if self.low_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt.EsImport']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery/Cisco-IOS-XR-l2vpn-oper:export-rt'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.es_import is not None and self.es_import._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rt is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery.ExportRt']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp/Cisco-IOS-XR-l2vpn-oper:discovery'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ad_method is not None:
                        return True

                    if self.ad_service_connected is not None:
                        return True

                    if self.ad_signalling_method is not None:
                        return True

                    if self.ce_range is not None:
                        return True

                    if self.export_route_policy is not None:
                        return True

                    if self.export_rt is not None:
                        for child_ref in self.export_rt:
                            if child_ref._has_data():
                                return True

                    if self.import_rt is not None:
                        for child_ref in self.import_rt:
                            if child_ref._has_data():
                                return True

                    if self.number_a_cs is not None:
                        return True

                    if self.number_a_cs_up is not None:
                        return True

                    if self.number_ce2c_es is not None:
                        return True

                    if self.number_ce2ce_advertised is not None:
                        return True

                    if self.number_p_ws_up is not None:
                        return True

                    if self.number_pseudowires is not None:
                        return True

                    if self.rd_value is not None and self.rd_value._has_data():
                        return True

                    if self.vpn_added is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp.Discovery']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mp'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.discovery is not None and self.discovery._has_data():
                    return True

                if self.group_name is not None:
                    return True

                if self.group_name_xr is not None:
                    return True

                if self.l2_encapsulation is not None:
                    return True

                if self.mp2_mp_name is not None:
                    return True

                if self.mp2mp_name is not None:
                    return True

                if self.mp2mpid is not None:
                    return True

                if self.vpn_id is not None:
                    return True

                if self.vpn_mtu is not None:
                    return True

                if self.xconnect_shutdown is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.XconnectMp2Mps.XconnectMp2Mp']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-mp2mps'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.xconnect_mp2mp is not None:
                for child_ref in self.xconnect_mp2mp:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.XconnectMp2Mps']['meta_info']


    class Indexes(object):
        """
        ID Manager Index Table
        
        .. attribute:: index
        
        	ID Manager Index Pool
        	**type**\: list of    :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Indexes.Index>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.index = YList()
            self.index.parent = self
            self.index.name = 'index'


        class Index(object):
            """
            ID Manager Index Pool
            
            .. attribute:: pool_id  <key>
            
            	Pool ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: allocated_ids
            
            	Number of IDs allocated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: application_type
            
            	Application Type
            	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
            
            .. attribute:: max_num_id_mgr
            
            	Maximum number of pool extensions
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_id_mgr_in_use
            
            	ID mgr instances in use
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pool_id_xr
            
            	Pool Id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pool_size
            
            	Pool size
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: zombied_ids
            
            	Number of IDs allocated
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.pool_id = None
                self.allocated_ids = None
                self.application_type = None
                self.max_num_id_mgr = None
                self.num_id_mgr_in_use = None
                self.pool_id_xr = None
                self.pool_size = None
                self.zombied_ids = None

            @property
            def _common_path(self):
                if self.pool_id is None:
                    raise YPYModelError('Key property pool_id is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:indexes/Cisco-IOS-XR-l2vpn-oper:index[Cisco-IOS-XR-l2vpn-oper:pool-id = ' + str(self.pool_id) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.pool_id is not None:
                    return True

                if self.allocated_ids is not None:
                    return True

                if self.application_type is not None:
                    return True

                if self.max_num_id_mgr is not None:
                    return True

                if self.num_id_mgr_in_use is not None:
                    return True

                if self.pool_id_xr is not None:
                    return True

                if self.pool_size is not None:
                    return True

                if self.zombied_ids is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Indexes.Index']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:indexes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.index is not None:
                for child_ref in self.index:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.Indexes']['meta_info']


    class XconnectSummary(object):
        """
        XConnect summary information
        
        .. attribute:: admin_down_backup_interface_xconnects
        
        	Number of XCs with backup interface in admin down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: admin_down_backup_xconnects
        
        	Number of XCs with backup PW in admin down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: down_backup_interface_xconnects
        
        	Number of XCs with backup interface in down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: down_backup_xconnects
        
        	Number of XCs with backup PW in down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_ce2_ceconnections
        
        	Number of Ce2Ce connections
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_ce2ce_advertized
        
        	Number of CE2CE connections that have been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_ce2ce_not_advertized
        
        	Number of CE2CE connections that have not been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_groups
        
        	Number of groups
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects
        
        	Number of mp2mp xconnects
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects_advertised
        
        	Number of Mp2mp XCs that have been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects_down
        
        	Number of Mp2mp XCs that have ben admined down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnects_up
        
        	Number of Mp2mp XCs that have been admined up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2mp_xconnectss_not_advertised
        
        	Number of Mp2mp XCs that have not been advertized
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects
        
        	Number of xconnects
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_administratively_down
        
        	Number of xconnects with segments in admin down state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_currently_using_backup
        
        	Number of XCs currently using backup PW (UP state)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_currently_using_backup_interface
        
        	Number of XCs currently using backup interface (UP state)
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_down
        
        	Number of xconnects whose state is down
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_locally_switched
        
        	Number of locally switched xconnects
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
        
        	Number of xconnects of type attachment circuit to pseudowire
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
        
        	Number of xconnects of type monitor session to pseudowire
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
        
        	Number of xconnects of type PseudoWire To PseudoWire
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_unresolved
        
        	Number of xconnects whose state is unresolved
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_up
        
        	Numxber of xconnects whose state is up
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_with_backup_interface
        
        	Number of XCs configured with backup interface
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_xconnects_with_backup_pw
        
        	Number of XCs configured with backup PW
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: out_of_memory_state
        
        	L2VPN Out of memory state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: partially_programmed_xconnects
        
        	Number of cross\-connects partially programmed
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_backup_interface_xconnects
        
        	Number of XCs with backup interface in standby state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_backup_xconnects
        
        	Number of XCs with backup PW in standby state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: standby_ready_backup_xconnects
        
        	Number of XCs with backup PW in standby ready state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: unresolved_backup_interface_xconnects
        
        	Number of XCs with backup interface in unresolved state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: unresolved_backup_xconnects
        
        	Number of XCs with backup PW in unresolved state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.admin_down_backup_interface_xconnects = None
            self.admin_down_backup_xconnects = None
            self.down_backup_interface_xconnects = None
            self.down_backup_xconnects = None
            self.number_ce2_ceconnections = None
            self.number_ce2ce_advertized = None
            self.number_ce2ce_not_advertized = None
            self.number_groups = None
            self.number_mp2mp_xconnects = None
            self.number_mp2mp_xconnects_advertised = None
            self.number_mp2mp_xconnects_down = None
            self.number_mp2mp_xconnects_up = None
            self.number_mp2mp_xconnectss_not_advertised = None
            self.number_xconnects = None
            self.number_xconnects_administratively_down = None
            self.number_xconnects_currently_using_backup = None
            self.number_xconnects_currently_using_backup_interface = None
            self.number_xconnects_down = None
            self.number_xconnects_locally_switched = None
            self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
            self.number_xconnects_type_monitor_session_to_pseudo_wire = None
            self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
            self.number_xconnects_unresolved = None
            self.number_xconnects_up = None
            self.number_xconnects_with_backup_interface = None
            self.number_xconnects_with_backup_pw = None
            self.out_of_memory_state = None
            self.partially_programmed_xconnects = None
            self.standby_backup_interface_xconnects = None
            self.standby_backup_xconnects = None
            self.standby_ready_backup_xconnects = None
            self.unresolved_backup_interface_xconnects = None
            self.unresolved_backup_xconnects = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-summary'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.admin_down_backup_interface_xconnects is not None:
                return True

            if self.admin_down_backup_xconnects is not None:
                return True

            if self.down_backup_interface_xconnects is not None:
                return True

            if self.down_backup_xconnects is not None:
                return True

            if self.number_ce2_ceconnections is not None:
                return True

            if self.number_ce2ce_advertized is not None:
                return True

            if self.number_ce2ce_not_advertized is not None:
                return True

            if self.number_groups is not None:
                return True

            if self.number_mp2mp_xconnects is not None:
                return True

            if self.number_mp2mp_xconnects_advertised is not None:
                return True

            if self.number_mp2mp_xconnects_down is not None:
                return True

            if self.number_mp2mp_xconnects_up is not None:
                return True

            if self.number_mp2mp_xconnectss_not_advertised is not None:
                return True

            if self.number_xconnects is not None:
                return True

            if self.number_xconnects_administratively_down is not None:
                return True

            if self.number_xconnects_currently_using_backup is not None:
                return True

            if self.number_xconnects_currently_using_backup_interface is not None:
                return True

            if self.number_xconnects_down is not None:
                return True

            if self.number_xconnects_locally_switched is not None:
                return True

            if self.number_xconnects_type_attachment_circuit_to_pseudo_wire is not None:
                return True

            if self.number_xconnects_type_monitor_session_to_pseudo_wire is not None:
                return True

            if self.number_xconnects_type_pseudo_wire_to_pseudo_wire is not None:
                return True

            if self.number_xconnects_unresolved is not None:
                return True

            if self.number_xconnects_up is not None:
                return True

            if self.number_xconnects_with_backup_interface is not None:
                return True

            if self.number_xconnects_with_backup_pw is not None:
                return True

            if self.out_of_memory_state is not None:
                return True

            if self.partially_programmed_xconnects is not None:
                return True

            if self.standby_backup_interface_xconnects is not None:
                return True

            if self.standby_backup_xconnects is not None:
                return True

            if self.standby_ready_backup_xconnects is not None:
                return True

            if self.unresolved_backup_interface_xconnects is not None:
                return True

            if self.unresolved_backup_xconnects is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.XconnectSummary']['meta_info']


    class ProcFsm(object):
        """
        L2VPN Process FSM information
        
        .. attribute:: event_history
        
        	L2VPN Process event history
        	**type**\: list of    :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.EventHistory>`
        
        .. attribute:: failover_status
        
        	L2VPN failover status
        	**type**\:   :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.FailoverStatus>`
        
        .. attribute:: issu_status
        
        	L2VPN ISSU Status and timestamp
        	**type**\:   :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.IssuStatus>`
        
        .. attribute:: nsr_status
        
        	L2VPN NSR status and timestamp
        	**type**\:   :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.NsrStatus>`
        
        .. attribute:: process_role
        
        	Current Process Role
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: process_state
        
        	Current Process State
        	**type**\:  int
        
        	**range:** 0..255
        
        .. attribute:: report_card
        
        	L2VPN Collaborator report card
        	**type**\: list of    :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.ReportCard>`
        
        .. attribute:: state_transition_time
        
        	Transition time for all states
        	**type**\:  list of int
        
        	**range:** 0..4294967295
        
        .. attribute:: sw_install_in_progress
        
        	Is s/w install currently in progress?
        	**type**\:  bool
        
        .. attribute:: sync_flags
        
        	Sync complete flags
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: xid_info
        
        	XID information
        	**type**\: list of    :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.XidInfo>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.event_history = YList()
            self.event_history.parent = self
            self.event_history.name = 'event_history'
            self.failover_status = L2Vpn.ProcFsm.FailoverStatus()
            self.failover_status.parent = self
            self.issu_status = L2Vpn.ProcFsm.IssuStatus()
            self.issu_status.parent = self
            self.nsr_status = L2Vpn.ProcFsm.NsrStatus()
            self.nsr_status.parent = self
            self.process_role = None
            self.process_state = None
            self.report_card = YList()
            self.report_card.parent = self
            self.report_card.name = 'report_card'
            self.state_transition_time = YLeafList()
            self.state_transition_time.parent = self
            self.state_transition_time.name = 'state_transition_time'
            self.sw_install_in_progress = None
            self.sync_flags = None
            self.xid_info = YList()
            self.xid_info.parent = self
            self.xid_info.name = 'xid_info'


        class FailoverStatus(object):
            """
            L2VPN failover status
            
            .. attribute:: master_time
            
            	Master time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: start_time
            
            	Start time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: triggered_time
            
            	Triggered time
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.master_time = None
                self.start_time = None
                self.triggered_time = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:failover-status'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.master_time is not None:
                    return True

                if self.start_time is not None:
                    return True

                if self.triggered_time is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.ProcFsm.FailoverStatus']['meta_info']


        class NsrStatus(object):
            """
            L2VPN NSR status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.NsrStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.idt_status = L2Vpn.ProcFsm.NsrStatus.IdtStatus()
                self.idt_status.parent = self
                self.previ_ous_idt_status = L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self.role = None


            class IdtStatus(object):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.ProcFsm.NsrStatus.IdtStatus']['meta_info']


            class PreviOusIdtStatus(object):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.ProcFsm.NsrStatus.PreviOusIdtStatus']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:nsr-status'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.idt_status is not None and self.idt_status._has_data():
                    return True

                if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                    return True

                if self.role is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.ProcFsm.NsrStatus']['meta_info']


        class IssuStatus(object):
            """
            L2VPN ISSU Status and timestamp
            
            .. attribute:: idt_status
            
            	IDT status
            	**type**\:   :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.IssuStatus.IdtStatus>`
            
            .. attribute:: previ_ous_idt_status
            
            	Previous IDT status
            	**type**\:   :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus>`
            
            .. attribute:: role
            
            	Process role
            	**type**\:   :py:class:`L2VpnProcRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcRoleEnum>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.idt_status = L2Vpn.ProcFsm.IssuStatus.IdtStatus()
                self.idt_status.parent = self
                self.previ_ous_idt_status = L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus()
                self.previ_ous_idt_status.parent = self
                self.role = None


            class IdtStatus(object):
                """
                IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.ProcFsm.IssuStatus.IdtStatus']['meta_info']


            class PreviOusIdtStatus(object):
                """
                Previous IDT status
                
                .. attribute:: declare_time
                
                	Declare ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_end_time
                
                	IDT end timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: idt_start_time
                
                	IDT start timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: not_ready_reason
                
                	Not ready reason
                	**type**\:   :py:class:`L2VpnProcNsrNotReadyReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProcNsrNotReadyReasonEnum>`
                
                .. attribute:: sync_status
                
                	Sync status
                	**type**\:   :py:class:`L2VpnSyncStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSyncStatusEnum>`
                
                .. attribute:: withdraw_time
                
                	Withdraw ready timestamp in seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.declare_time = None
                    self.idt_end_time = None
                    self.idt_start_time = None
                    self.not_ready_reason = None
                    self.sync_status = None
                    self.withdraw_time = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status/Cisco-IOS-XR-l2vpn-oper:previ-ous-idt-status'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.declare_time is not None:
                        return True

                    if self.idt_end_time is not None:
                        return True

                    if self.idt_start_time is not None:
                        return True

                    if self.not_ready_reason is not None:
                        return True

                    if self.sync_status is not None:
                        return True

                    if self.withdraw_time is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.ProcFsm.IssuStatus.PreviOusIdtStatus']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:issu-status'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.idt_status is not None and self.idt_status._has_data():
                    return True

                if self.previ_ous_idt_status is not None and self.previ_ous_idt_status._has_data():
                    return True

                if self.role is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.ProcFsm.IssuStatus']['meta_info']


        class XidInfo(object):
            """
            XID information
            
            .. attribute:: app_type
            
            	App type
            	**type**\:   :py:class:`L2VpnIdMgrAppEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIdMgrAppEnum>`
            
            .. attribute:: sent_ids
            
            	Number of XIDs transferred
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.app_type = None
                self.sent_ids = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:xid-info'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.app_type is not None:
                    return True

                if self.sent_ids is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.ProcFsm.XidInfo']['meta_info']


        class ReportCard(object):
            """
            L2VPN Collaborator report card
            
            .. attribute:: collaborator_idt_done
            
            	Is IDT done for this collaborator
            	**type**\:  bool
            
            .. attribute:: collaborator_is_connected
            
            	Is the collaborator connected
            	**type**\:  bool
            
            .. attribute:: collaborator_skipped
            
            	Was this collaborator skipped for not connecting in time
            	**type**\:  bool
            
            .. attribute:: connection_change_time
            
            	Time when connection state (UP/DOWN) changed
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: idt_time
            
            	Time when IDT was done
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.collaborator_idt_done = None
                self.collaborator_is_connected = None
                self.collaborator_skipped = None
                self.connection_change_time = None
                self.idt_time = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:report-card'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.collaborator_idt_done is not None:
                    return True

                if self.collaborator_is_connected is not None:
                    return True

                if self.collaborator_skipped is not None:
                    return True

                if self.connection_change_time is not None:
                    return True

                if self.idt_time is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.ProcFsm.ReportCard']['meta_info']


        class EventHistory(object):
            """
            L2VPN Process event history
            
            .. attribute:: event_timestamp
            
            	Event timestamp
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: new_state
            
            	New state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: previous_state
            
            	Previous state
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: process_collaborator
            
            	Process collaborator
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: process_event
            
            	Process event
            	**type**\:  int
            
            	**range:** 0..65535
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.event_timestamp = None
                self.new_state = None
                self.previous_state = None
                self.process_collaborator = None
                self.process_event = None

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm/Cisco-IOS-XR-l2vpn-oper:event-history'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.event_timestamp is not None:
                    return True

                if self.new_state is not None:
                    return True

                if self.previous_state is not None:
                    return True

                if self.process_collaborator is not None:
                    return True

                if self.process_event is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.ProcFsm.EventHistory']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:proc-fsm'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.event_history is not None:
                for child_ref in self.event_history:
                    if child_ref._has_data():
                        return True

            if self.failover_status is not None and self.failover_status._has_data():
                return True

            if self.issu_status is not None and self.issu_status._has_data():
                return True

            if self.nsr_status is not None and self.nsr_status._has_data():
                return True

            if self.process_role is not None:
                return True

            if self.process_state is not None:
                return True

            if self.report_card is not None:
                for child_ref in self.report_card:
                    if child_ref._has_data():
                        return True

            if self.state_transition_time is not None:
                for child in self.state_transition_time:
                    if child is not None:
                        return True

            if self.sw_install_in_progress is not None:
                return True

            if self.sync_flags is not None:
                return True

            if self.xid_info is not None:
                for child_ref in self.xid_info:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.ProcFsm']['meta_info']


    class MstpPorts(object):
        """
        L2VPN MSTP Port Table
        
        .. attribute:: mstp_port
        
        	MSTP Port information
        	**type**\: list of    :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts.MstpPort>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.mstp_port = YList()
            self.mstp_port.parent = self
            self.mstp_port.name = 'mstp_port'


        class MstpPort(object):
            """
            MSTP Port information
            
            .. attribute:: interface  <key>
            
            	Interface
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: interface_name
            
            	Interface name
            	**type**\:  str
            
            .. attribute:: msti_entry
            
            	MSTI
            	**type**\: list of    :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts.MstpPort.MstiEntry>`
            
            .. attribute:: mstp_interface_handle
            
            	Interface handle
            	**type**\:  str
            
            	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
            
            .. attribute:: protected
            
            	Protected
            	**type**\:  bool
            
            .. attribute:: reference_count
            
            	Reference Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface = None
                self.interface_name = None
                self.msti_entry = YList()
                self.msti_entry.parent = self
                self.msti_entry.name = 'msti_entry'
                self.mstp_interface_handle = None
                self.protected = None
                self.reference_count = None


            class MstiEntry(object):
                """
                MSTI
                
                .. attribute:: ack_count
                
                	Ack count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bd_count
                
                	BD count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bd_entry
                
                	BD entries
                	**type**\: list of    :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                
                .. attribute:: cfg_ms_ti
                
                	 Configured MSTi
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: flush_count
                
                	Flush count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_flags
                
                	Msti Flags
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_state
                
                	Msti State
                	**type**\:   :py:class:`L2VpnMstiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMstiStateEnum>`
                
                .. attribute:: nack_count
                
                	Nack count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rcv_count
                
                	Receive count 
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ack_count = None
                    self.bd_count = None
                    self.bd_entry = YList()
                    self.bd_entry.parent = self
                    self.bd_entry.name = 'bd_entry'
                    self.cfg_ms_ti = None
                    self.flush_count = None
                    self.interface_count = None
                    self.msti_flags = None
                    self.msti_state = None
                    self.nack_count = None
                    self.rcv_count = None


                class BdEntry(object):
                    """
                    BD entries
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bdif_count
                    
                    	BD Intf Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bdid = None
                        self.bdif_count = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bd-entry'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bdid is not None:
                            return True

                        if self.bdif_count is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.MstpPorts.MstpPort.MstiEntry.BdEntry']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:msti-entry'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ack_count is not None:
                        return True

                    if self.bd_count is not None:
                        return True

                    if self.bd_entry is not None:
                        for child_ref in self.bd_entry:
                            if child_ref._has_data():
                                return True

                    if self.cfg_ms_ti is not None:
                        return True

                    if self.flush_count is not None:
                        return True

                    if self.interface_count is not None:
                        return True

                    if self.msti_flags is not None:
                        return True

                    if self.msti_state is not None:
                        return True

                    if self.nack_count is not None:
                        return True

                    if self.rcv_count is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.MstpPorts.MstpPort.MstiEntry']['meta_info']

            @property
            def _common_path(self):
                if self.interface is None:
                    raise YPYModelError('Key property interface is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mstp-ports/Cisco-IOS-XR-l2vpn-oper:mstp-port[Cisco-IOS-XR-l2vpn-oper:interface = ' + str(self.interface) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface is not None:
                    return True

                if self.interface_name is not None:
                    return True

                if self.msti_entry is not None:
                    for child_ref in self.msti_entry:
                        if child_ref._has_data():
                            return True

                if self.mstp_interface_handle is not None:
                    return True

                if self.protected is not None:
                    return True

                if self.reference_count is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.MstpPorts.MstpPort']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mstp-ports'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.mstp_port is not None:
                for child_ref in self.mstp_port:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.MstpPorts']['meta_info']


    class GenericInterfaceListDetails(object):
        """
        L2VPN generic interface list Detail Table
        
        .. attribute:: generic_interface_list_detail
        
        	Generic Interface List detail information
        	**type**\: list of    :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.generic_interface_list_detail = YList()
            self.generic_interface_list_detail.parent = self
            self.generic_interface_list_detail.name = 'generic_interface_list_detail'


        class GenericInterfaceListDetail(object):
            """
            Generic Interface List detail information
            
            .. attribute:: interface_list_name  <key>
            
            	Generic Interface List Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: interface
            
            	Interfaces
            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
            
            .. attribute:: is_provisioned
            
            	Is Provisioned
            	**type**\:  bool
            
            .. attribute:: items
            
            	Number of items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: psedowire_ether_items
            
            	Number PW Ether Items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pseudowire_ether_range
            
            	PW\-Ether ranges
            	**type**\: list of    :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
            
            .. attribute:: pseudowire_iw_items
            
            	Number PW IW Items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pseudowire_iw_range
            
            	PW\-IW ranges
            	**type**\: list of    :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
            
            .. attribute:: summary
            
            	Summary information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_list_name = None
                self.interface = YList()
                self.interface.parent = self
                self.interface.name = 'interface'
                self.is_provisioned = None
                self.items = None
                self.psedowire_ether_items = None
                self.pseudowire_ether_range = YList()
                self.pseudowire_ether_range.parent = self
                self.pseudowire_ether_range.name = 'pseudowire_ether_range'
                self.pseudowire_iw_items = None
                self.pseudowire_iw_range = YList()
                self.pseudowire_iw_range.parent = self
                self.pseudowire_iw_range.name = 'pseudowire_iw_range'
                self.summary = L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                self.summary.parent = self


            class Summary(object):
                """
                Summary information
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: items
                
                	Number of items
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.interface_list_id = None
                    self.interface_list_name_xr = None
                    self.items = None
                    self.number_of_interfaces = None


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:summary'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.interface_list_id is not None:
                        return True

                    if self.interface_list_name_xr is not None:
                        return True

                    if self.items is not None:
                        return True

                    if self.number_of_interfaces is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary']['meta_info']


            class Interface(object):
                """
                Interfaces
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: is_fib_downloaded
                
                	Is interface downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: not_supported_replications
                
                	Number of replications failed because unsupported
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pending_replications
                
                	Number of pending replications
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_name = None
                    self.is_fib_downloaded = None
                    self.not_supported_replications = None
                    self.pending_replications = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_name is not None:
                        return True

                    if self.is_fib_downloaded is not None:
                        return True

                    if self.not_supported_replications is not None:
                        return True

                    if self.pending_replications is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface']['meta_info']


            class PseudowireEtherRange(object):
                """
                PW\-Ether ranges
                
                .. attribute:: lower
                
                	lower range
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: upper
                
                	upper range
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.lower = None
                    self.upper = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether-range'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.lower is not None:
                        return True

                    if self.upper is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange']['meta_info']


            class PseudowireIwRange(object):
                """
                PW\-IW ranges
                
                .. attribute:: lower
                
                	lower range
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: upper
                
                	upper range
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.lower = None
                    self.upper = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw-range'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.lower is not None:
                        return True

                    if self.upper is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange']['meta_info']

            @property
            def _common_path(self):
                if self.interface_list_name is None:
                    raise YPYModelError('Key property interface_list_name is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-detail[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_list_name is not None:
                    return True

                if self.interface is not None:
                    for child_ref in self.interface:
                        if child_ref._has_data():
                            return True

                if self.is_provisioned is not None:
                    return True

                if self.items is not None:
                    return True

                if self.psedowire_ether_items is not None:
                    return True

                if self.pseudowire_ether_range is not None:
                    for child_ref in self.pseudowire_ether_range:
                        if child_ref._has_data():
                            return True

                if self.pseudowire_iw_items is not None:
                    return True

                if self.pseudowire_iw_range is not None:
                    for child_ref in self.pseudowire_iw_range:
                        if child_ref._has_data():
                            return True

                if self.summary is not None and self.summary._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.GenericInterfaceListDetails.GenericInterfaceListDetail']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-details'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.generic_interface_list_detail is not None:
                for child_ref in self.generic_interface_list_detail:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.GenericInterfaceListDetails']['meta_info']


    class L2VpnResourceState(object):
        """
        L2VPN resource state information
        
        .. attribute:: resource_out_of_memory_state
        
        	L2VPN Out of memory state
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.resource_out_of_memory_state = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:l2vpn-resource-state'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.resource_out_of_memory_state is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.L2VpnResourceState']['meta_info']


    class BridgeDomains(object):
        """
        VPLS Bridge Domain Information
        
        .. attribute:: bridge_domain
        
        	VPLS Bridge Domain Information
        	**type**\: list of    :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.bridge_domain = YList()
            self.bridge_domain.parent = self
            self.bridge_domain.name = 'bridge_domain'


        class BridgeDomain(object):
            """
            VPLS Bridge Domain Information
            
            .. attribute:: bridge_access_pws
            
            	VPLS Bridge Domain Access Pseudowire Table
            	**type**\:   :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws>`
            
            .. attribute:: bridge_access_vfi_table
            
            	Bridge Domain Access VFI Table
            	**type**\:   :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
            
            .. attribute:: bridge_acs
            
            	VPLS Bridge Domain Attachment Circuit Table
            	**type**\:   :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs>`
            
            .. attribute:: bridge_core_vfi_table
            
            	Bridge Domain Core VFI Table
            	**type**\:   :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
            
            .. attribute:: bridge_domain_group_name
            
            	Bridge Domain Group Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: bridge_domain_info
            
            	VPLS Bridge Domain Information
            	**type**\:   :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
            
            .. attribute:: bridge_domain_name
            
            	Bridge Domain Name
            	**type**\:  str
            
            	**length:** 1..27
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.bridge_access_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws()
                self.bridge_access_pws.parent = self
                self.bridge_access_vfi_table = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                self.bridge_access_vfi_table.parent = self
                self.bridge_acs = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs()
                self.bridge_acs.parent = self
                self.bridge_core_vfi_table = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                self.bridge_core_vfi_table.parent = self
                self.bridge_domain_group_name = None
                self.bridge_domain_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                self.bridge_domain_info.parent = self
                self.bridge_domain_name = None


            class BridgeAccessVfiTable(object):
                """
                Bridge Domain Access VFI Table
                
                .. attribute:: bridge_pws
                
                	Bridge Domain Access/Core Pseudowire Table
                	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                    self.bridge_pws.parent = self


                class BridgePws(object):
                    """
                    Bridge Domain Access/Core Pseudowire Table
                    
                    .. attribute:: bridge_pw
                    
                    	VPLS Bridge Domain Pseudowire
                    	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_pw = YList()
                        self.bridge_pw.parent = self
                        self.bridge_pw.name = 'bridge_pw'


                    class BridgePw(object):
                        """
                        VPLS Bridge Domain Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_type
                        
                        	PW Type
                        	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                        
                        .. attribute:: ve_id_vpls_id_0_3
                        
                        	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpls_id_4_7
                        
                        	Zero or Last 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.is_access = None
                            self.neighbor = None
                            self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                            self.pseudowire.parent = self
                            self.pseudowire_id = None
                            self.pw_type = None
                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                            self.security_parameters.parent = self
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'
                            self.ve_id_vpls_id_0_3 = None
                            self.vpls_id_4_7 = None


                        class Pseudowire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.is_access is not None:
                                return True

                            if self.neighbor is not None:
                                return True

                            if self.pseudowire is not None and self.pseudowire._has_data():
                                return True

                            if self.pseudowire_id is not None:
                                return True

                            if self.pw_type is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            if self.ve_id_vpls_id_0_3 is not None:
                                return True

                            if self.vpls_id_4_7 is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_pw is not None:
                            for child_ref in self.bridge_pw:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi-table'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_pws is not None and self.bridge_pws._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessVfiTable']['meta_info']


            class BridgeCoreVfiTable(object):
                """
                Bridge Domain Core VFI Table
                
                .. attribute:: bridge_pws
                
                	Bridge Domain Access/Core Pseudowire Table
                	**type**\:   :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_pws = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                    self.bridge_pws.parent = self


                class BridgePws(object):
                    """
                    Bridge Domain Access/Core Pseudowire Table
                    
                    .. attribute:: bridge_pw
                    
                    	VPLS Bridge Domain Pseudowire
                    	**type**\: list of    :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.bridge_pw = YList()
                        self.bridge_pw.parent = self
                        self.bridge_pw.name = 'bridge_pw'


                    class BridgePw(object):
                        """
                        VPLS Bridge Domain Pseudowire
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\:  bool
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: pw_type
                        
                        	PW Type
                        	**type**\:   :py:class:`L2VpnpwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnpwEnum>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                        
                        .. attribute:: ve_id_vpls_id_0_3
                        
                        	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpls_id_4_7
                        
                        	Zero or Last 4 bytes of VPLS\-ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.is_access = None
                            self.neighbor = None
                            self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                            self.pseudowire.parent = self
                            self.pseudowire_id = None
                            self.pw_type = None
                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                            self.security_parameters.parent = self
                            self.static_mac = YList()
                            self.static_mac.parent = self
                            self.static_mac.name = 'static_mac'
                            self.ve_id_vpls_id_0_3 = None
                            self.vpls_id_4_7 = None


                        class Pseudowire(object):
                            """
                            Pseudowire
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\:  bool
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\:  bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\:  bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\:  bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\:  bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\:  bool
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\:  bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\:  bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\:  bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\:  bool
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\:  bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\:  bool
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: is_evpnvpws_type
                            
                            	is EVPN VPWS
                            	**type**\:  bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\:  bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\:  bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\:  bool
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\:  bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\:  bool
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\:  bool
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\:  bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\:  bool
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw>`
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\:  bool
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\:  bool
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\:  bool
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\:  bool
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\:  str
                            
                            	**length:** 0..33
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\:  bool
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\:  bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\:  bool
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\:  bool
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\:  bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\:  bool
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\:  bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\:  bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\:  bool
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\:  str
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\:  str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ad_method = None
                                self.ad_remote_down = None
                                self.admited_bw = None
                                self.auto_discovery = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.backup_pw = None
                                self.bitrate_mismatched = None
                                self.bridge_pw_type_mismatch = None
                                self.cas_mismatched = None
                                self.diff_ts_mismatched = None
                                self.disable_delay = None
                                self.disable_never = None
                                self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self.evpn_src_acid = None
                                self.fe_ctype = None
                                self.forward_class = None
                                self.freq_mismatched = None
                                self.illegal_control_word = None
                                self.imposed_vlan_id = None
                                self.interworking = None
                                self.ipv6_local_source_address = None
                                self.is_evpnvpws_type = None
                                self.is_flow_label_static = None
                                self.is_multi_segment_pseudowire = None
                                self.is_partially_programmed = None
                                self.is_pwr_type = None
                                self.is_vfi = None
                                self.last_time_status_changed = None
                                self.last_time_status_down = None
                                self.ldp_label_advertise_failed = None
                                self.load_balance = None
                                self.local_control_word = None
                                self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self.local_label_failed = None
                                self.local_pseudo_wire_type = None
                                self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self.local_source_address = None
                                self.mac_limit_oper_down = None
                                self.mtu_mismatched = None
                                self.not_supported_qinq = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.out_of_memory_state = None
                                self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw()
                                self.p2mp_pw.parent = self
                                self.payload_bytes_mismatched = None
                                self.payload_type_mismatched = None
                                self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self.preferred_path_disable_fallback = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.primary_pw = None
                                self.protocol = None
                                self.pseudo_wire_id = None
                                self.pseudo_wire_state = None
                                self.pseudo_wire_type_mismatched = None
                                self.pw_class_name = None
                                self.pw_flow_label_code17_disabled = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_redundancy_initial_delay = None
                                self.pw_redundancy_one_way = None
                                self.pw_status_use = None
                                self.pwlsd_rewrite_failed = None
                                self.remote_control_word = None
                                self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self.remote_label_failed = None
                                self.remote_pseudo_wire_type = None
                                self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self.required_bw = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.rtp_mismatched = None
                                self.sequencing_type = None
                                self.shutdown = None
                                self.sig_pkts_mismatched = None
                                self.ssrc_mismatched = None
                                self.state = None
                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self.table_policy_name = None
                                self.tag_rewrite = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.time_elapsed_status_changed = None
                                self.time_elapsed_status_down = None
                                self.transport_lsp_down = None
                                self.xconnect_id = None


                            class PeerId(object):
                                """
                                Peer
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.internal_label = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.type = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.internal_label is not None:
                                        return True

                                    if self.ipv4_peer_id is not None:
                                        return True

                                    if self.ipv6_peer_id is not None:
                                        return True

                                    if self.type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId']['meta_info']


                            class EncapsulationInfo(object):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self.encapsulation = None
                                    self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                    self.l2tpv3.parent = self


                                class Atom(object):
                                    """
                                    atom
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\:  bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\:  bool
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.is_pseudowire_headend = None
                                        self.is_sai_itype2 = None
                                        self.is_tai_itype2 = None
                                        self.ldp_label_advertisment_failed = None
                                        self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self.local_c_ctype = None
                                        self.local_ceid = None
                                        self.local_cv_type = None
                                        self.local_group_id = None
                                        self.local_label = None
                                        self.local_ldp_id = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.local_veid = None
                                        self.lsd_rewrite_failed = None
                                        self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self.rem_saii = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self.remote_c_ctype = None
                                        self.remote_ceid = None
                                        self.remote_cv_type = None
                                        self.remote_group_id = None
                                        self.remote_label = None
                                        self.remote_ldp_id = None
                                        self.remote_source_address = None
                                        self.remote_veid = None
                                        self.saii = None
                                        self.source_address = None
                                        self.taii = None


                                    class LocalAgi(object):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                    class RemoteAgi(object):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self.vpls_id_type = None


                                        class Auto(object):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.asn = None
                                                self.vpn_id = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.asn is not None:
                                                    return True

                                                if self.vpn_id is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                        class TwoByteAs(object):
                                            """
                                            two byte as
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.four_byte_index = None
                                                self.two_byte_as = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.four_byte_index is not None:
                                                    return True

                                                if self.two_byte_as is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                        class V4Addr(object):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.ipv4_address = None
                                                self.two_byte_index = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.ipv4_address is not None:
                                                    return True

                                                if self.two_byte_index is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.auto is not None and self.auto._has_data():
                                                return True

                                            if self.two_byte_as is not None and self.two_byte_as._has_data():
                                                return True

                                            if self.v4_addr is not None and self.v4_addr._has_data():
                                                return True

                                            if self.vpls_id_type is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                    class MultiSegmentPseudowireStats(object):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.received_bytes = None
                                            self.received_packets = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.received_bytes is not None:
                                                return True

                                            if self.received_packets is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.is_pseudowire_headend is not None:
                                            return True

                                        if self.is_sai_itype2 is not None:
                                            return True

                                        if self.is_tai_itype2 is not None:
                                            return True

                                        if self.ldp_label_advertisment_failed is not None:
                                            return True

                                        if self.local_agi is not None and self.local_agi._has_data():
                                            return True

                                        if self.local_c_ctype is not None:
                                            return True

                                        if self.local_ceid is not None:
                                            return True

                                        if self.local_cv_type is not None:
                                            return True

                                        if self.local_group_id is not None:
                                            return True

                                        if self.local_label is not None:
                                            return True

                                        if self.local_ldp_id is not None:
                                            return True

                                        if self.local_saii_gbl_id is not None:
                                            return True

                                        if self.local_saiiac_id is not None:
                                            return True

                                        if self.local_taii_gbl_id is not None:
                                            return True

                                        if self.local_taiiac_id is not None:
                                            return True

                                        if self.local_veid is not None:
                                            return True

                                        if self.lsd_rewrite_failed is not None:
                                            return True

                                        if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                            return True

                                        if self.rem_saii is not None:
                                            return True

                                        if self.rem_saii_gbl_id is not None:
                                            return True

                                        if self.rem_saiiac_id is not None:
                                            return True

                                        if self.rem_taii is not None:
                                            return True

                                        if self.rem_taii_gbl_id is not None:
                                            return True

                                        if self.rem_taiiac_id is not None:
                                            return True

                                        if self.remote_agi is not None and self.remote_agi._has_data():
                                            return True

                                        if self.remote_c_ctype is not None:
                                            return True

                                        if self.remote_ceid is not None:
                                            return True

                                        if self.remote_cv_type is not None:
                                            return True

                                        if self.remote_group_id is not None:
                                            return True

                                        if self.remote_label is not None:
                                            return True

                                        if self.remote_ldp_id is not None:
                                            return True

                                        if self.remote_source_address is not None:
                                            return True

                                        if self.remote_veid is not None:
                                            return True

                                        if self.saii is not None:
                                            return True

                                        if self.source_address is not None:
                                            return True

                                        if self.taii is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                                class L2Tpv3(object):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\:  bool
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\:  str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\:  bool
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dont_fragment_bit = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.l2tp_class_name = None
                                        self.local_cookie_high_value = None
                                        self.local_cookie_low_value = None
                                        self.local_cookie_size = None
                                        self.local_secondary_cookie_high_value = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_size = None
                                        self.local_session_id = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.remote_circuit_status_up = None
                                        self.remote_cookie_high_value = None
                                        self.remote_cookie_low_value = None
                                        self.remote_cookie_size = None
                                        self.remote_session_id = None
                                        self.tos = None
                                        self.tos_mode = None
                                        self.ttl = None
                                        self.tunnel_state = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dont_fragment_bit is not None:
                                            return True

                                        if self.ipv4_source_address is not None:
                                            return True

                                        if self.ipv6_source_address is not None:
                                            return True

                                        if self.l2tp_class_name is not None:
                                            return True

                                        if self.local_cookie_high_value is not None:
                                            return True

                                        if self.local_cookie_low_value is not None:
                                            return True

                                        if self.local_cookie_size is not None:
                                            return True

                                        if self.local_secondary_cookie_high_value is not None:
                                            return True

                                        if self.local_secondary_cookie_low_value is not None:
                                            return True

                                        if self.local_secondary_cookie_size is not None:
                                            return True

                                        if self.local_session_id is not None:
                                            return True

                                        if self.path_mtu_enabled is not None:
                                            return True

                                        if self.path_mtu_max_value is not None:
                                            return True

                                        if self.remote_circuit_status_up is not None:
                                            return True

                                        if self.remote_cookie_high_value is not None:
                                            return True

                                        if self.remote_cookie_low_value is not None:
                                            return True

                                        if self.remote_cookie_size is not None:
                                            return True

                                        if self.remote_session_id is not None:
                                            return True

                                        if self.tos is not None:
                                            return True

                                        if self.tos_mode is not None:
                                            return True

                                        if self.ttl is not None:
                                            return True

                                        if self.tunnel_state is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atom is not None and self.atom._has_data():
                                        return True

                                    if self.encapsulation is not None:
                                        return True

                                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo']['meta_info']


                            class LocalInterface(object):
                                """
                                Local interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface']['meta_info']


                            class RemoteInterface(object):
                                """
                                Remote interface
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\:  str
                                
                                	**length:** 0..81
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.mtu = None
                                    self.name = None
                                    self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self.payload_bytes = None


                                class Parameters(object):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self.type = None
                                        self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self


                                    class Ethernet(object):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.xconnect_tags = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                    class Vlan(object):
                                        """
                                        VLAN
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\:  list of int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None
                                            self.rewrite_tag = YLeafList()
                                            self.rewrite_tag.parent = self
                                            self.rewrite_tag.name = 'rewrite_tag'
                                            self.simple_efp = None
                                            self.vlan_range = YList()
                                            self.vlan_range.parent = self
                                            self.vlan_range.name = 'vlan_range'
                                            self.vlan_rewrite_tag = None
                                            self.xconnect_tags = None


                                        class VlanRange(object):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.lower = None
                                                self.upper = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.lower is not None:
                                                    return True

                                                if self.upper is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.encapsulation_type is not None:
                                                return True

                                            if self.outer_tag is not None:
                                                return True

                                            if self.rewrite_tag is not None:
                                                for child in self.rewrite_tag:
                                                    if child is not None:
                                                        return True

                                            if self.simple_efp is not None:
                                                return True

                                            if self.vlan_range is not None:
                                                for child_ref in self.vlan_range:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.vlan_rewrite_tag is not None:
                                                return True

                                            if self.xconnect_tags is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                    class Tdm(object):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\:  str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.tdm_mode = None
                                            self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self.timeslot_group = None
                                            self.timeslot_rate = None


                                        class TdmOptions(object):
                                            """
                                            TDM options
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.bit_rate = None
                                                self.cas = None
                                                self.payload_bytes = None
                                                self.rtp = None
                                                self.rtp_header_payload_type = None
                                                self.signalling_packets = None
                                                self.ssrc = None
                                                self.timestamp_clock_freq = None
                                                self.timestamp_mode = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.bit_rate is not None:
                                                    return True

                                                if self.cas is not None:
                                                    return True

                                                if self.payload_bytes is not None:
                                                    return True

                                                if self.rtp is not None:
                                                    return True

                                                if self.rtp_header_payload_type is not None:
                                                    return True

                                                if self.signalling_packets is not None:
                                                    return True

                                                if self.ssrc is not None:
                                                    return True

                                                if self.timestamp_clock_freq is not None:
                                                    return True

                                                if self.timestamp_mode is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.tdm_mode is not None:
                                                return True

                                            if self.tdm_options is not None and self.tdm_options._has_data():
                                                return True

                                            if self.timeslot_group is not None:
                                                return True

                                            if self.timeslot_rate is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                    class Atm(object):
                                        """
                                        ATM
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.atm_mode = None
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.vci = None
                                            self.vpi = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.atm_mode is not None:
                                                return True

                                            if self.maximum_number_cells_packed is not None:
                                                return True

                                            if self.maximum_number_cells_un_packed is not None:
                                                return True

                                            if self.vci is not None:
                                                return True

                                            if self.vpi is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                    class Fr(object):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.dlci = None
                                            self.fr_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.dlci is not None:
                                                return True

                                            if self.fr_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                    class PseudowireEther(object):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                    class PseudowireIw(object):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self.internal_label = None
                                            self.is_valid = None


                                        class InterfaceList(object):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\:  str
                                            
                                            	**length:** 0..33
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface = YList()
                                                self.interface.parent = self
                                                self.interface.name = 'interface'
                                                self.interface_list_id = None
                                                self.interface_list_name = None


                                            class Interface(object):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\:  str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    self.parent = None
                                                    self.interface_name = None
                                                    self.replicate_status = None

                                                @property
                                                def _common_path(self):

                                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                                def is_config(self):
                                                    ''' Returns True if this instance represents config data else returns False '''
                                                    return False

                                                def _has_data(self):
                                                    if not self.is_config():
                                                        return False
                                                    if self.interface_name is not None:
                                                        return True

                                                    if self.replicate_status is not None:
                                                        return True

                                                    return False

                                                @staticmethod
                                                def _meta_info():
                                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface is not None:
                                                    for child_ref in self.interface:
                                                        if child_ref._has_data():
                                                            return True

                                                if self.interface_list_id is not None:
                                                    return True

                                                if self.interface_list_name is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_list is not None and self.interface_list._has_data():
                                                return True

                                            if self.internal_label is not None:
                                                return True

                                            if self.is_valid is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm is not None and self.atm._has_data():
                                            return True

                                        if self.ethernet is not None and self.ethernet._has_data():
                                            return True

                                        if self.fr is not None and self.fr._has_data():
                                            return True

                                        if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                            return True

                                        if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                            return True

                                        if self.tdm is not None and self.tdm._has_data():
                                            return True

                                        if self.type is not None:
                                            return True

                                        if self.vlan is not None and self.vlan._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.mtu is not None:
                                        return True

                                    if self.name is not None:
                                        return True

                                    if self.parameters is not None and self.parameters._has_data():
                                        return True

                                    if self.payload_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface']['meta_info']


                            class PreferredPath(object):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ip_tunnel_interface_number = None
                                    self.next_hop_ip = None
                                    self.option = None
                                    self.te_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ip_tunnel_interface_number is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    if self.option is not None:
                                        return True

                                    if self.te_tunnel_interface_number is not None:
                                        return True

                                    if self.tp_tunnel_interface_number is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath']['meta_info']


                            class LocalSignalling(object):
                                """
                                Local signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling']['meta_info']


                            class RemoteSignalling(object):
                                """
                                Remote signalling
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.pw_status = None
                                    self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self.tlv = YList()
                                    self.tlv.parent = self
                                    self.tlv.name = 'tlv'


                                class StatusTlv(object):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                                class Tlv(object):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\:  str
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.description = None
                                        self.local_address = None
                                        self.pw_id = None
                                        self.remote_address = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.description is not None:
                                            return True

                                        if self.local_address is not None:
                                            return True

                                        if self.pw_id is not None:
                                            return True

                                        if self.remote_address is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.pw_status is not None:
                                        return True

                                    if self.status_tlv is not None and self.status_tlv._has_data():
                                        return True

                                    if self.tlv is not None:
                                        for child_ref in self.tlv:
                                            if child_ref._has_data():
                                                return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics']['meta_info']


                            class P2MpPw(object):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\:  bool
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.local_available = None
                                    self.local_extended_tunnel_id = None
                                    self.local_flags = None
                                    self.local_label = None
                                    self.local_p2mp_id = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.remote_available = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_flags = None
                                    self.remote_label = None
                                    self.remote_p2mp_id = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.local_available is not None:
                                        return True

                                    if self.local_extended_tunnel_id is not None:
                                        return True

                                    if self.local_flags is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_p2mp_id is not None:
                                        return True

                                    if self.local_ptree_type is not None:
                                        return True

                                    if self.local_tunnel_id is not None:
                                        return True

                                    if self.remote_available is not None:
                                        return True

                                    if self.remote_extended_tunnel_id is not None:
                                        return True

                                    if self.remote_flags is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_p2mp_id is not None:
                                        return True

                                    if self.remote_ptree_type is not None:
                                        return True

                                    if self.remote_tunnel_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2MpPw']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ad_method is not None:
                                    return True

                                if self.ad_remote_down is not None:
                                    return True

                                if self.admited_bw is not None:
                                    return True

                                if self.auto_discovery is not None:
                                    return True

                                if self.backup_active is not None:
                                    return True

                                if self.backup_force_active is not None:
                                    return True

                                if self.backup_pw is not None:
                                    return True

                                if self.bitrate_mismatched is not None:
                                    return True

                                if self.bridge_pw_type_mismatch is not None:
                                    return True

                                if self.cas_mismatched is not None:
                                    return True

                                if self.diff_ts_mismatched is not None:
                                    return True

                                if self.disable_delay is not None:
                                    return True

                                if self.disable_never is not None:
                                    return True

                                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                    return True

                                if self.evpn_src_acid is not None:
                                    return True

                                if self.fe_ctype is not None:
                                    return True

                                if self.forward_class is not None:
                                    return True

                                if self.freq_mismatched is not None:
                                    return True

                                if self.illegal_control_word is not None:
                                    return True

                                if self.imposed_vlan_id is not None:
                                    return True

                                if self.interworking is not None:
                                    return True

                                if self.ipv6_local_source_address is not None:
                                    return True

                                if self.is_evpnvpws_type is not None:
                                    return True

                                if self.is_flow_label_static is not None:
                                    return True

                                if self.is_multi_segment_pseudowire is not None:
                                    return True

                                if self.is_partially_programmed is not None:
                                    return True

                                if self.is_pwr_type is not None:
                                    return True

                                if self.is_vfi is not None:
                                    return True

                                if self.last_time_status_changed is not None:
                                    return True

                                if self.last_time_status_down is not None:
                                    return True

                                if self.ldp_label_advertise_failed is not None:
                                    return True

                                if self.load_balance is not None:
                                    return True

                                if self.local_control_word is not None:
                                    return True

                                if self.local_interface is not None and self.local_interface._has_data():
                                    return True

                                if self.local_label_failed is not None:
                                    return True

                                if self.local_pseudo_wire_type is not None:
                                    return True

                                if self.local_signalling is not None and self.local_signalling._has_data():
                                    return True

                                if self.local_source_address is not None:
                                    return True

                                if self.mac_limit_oper_down is not None:
                                    return True

                                if self.mtu_mismatched is not None:
                                    return True

                                if self.not_supported_qinq is not None:
                                    return True

                                if self.num_ma_cwithdraw_msg_received is not None:
                                    return True

                                if self.number_ma_cwithdraw_message_sent is not None:
                                    return True

                                if self.out_of_memory_state is not None:
                                    return True

                                if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                    return True

                                if self.payload_bytes_mismatched is not None:
                                    return True

                                if self.payload_type_mismatched is not None:
                                    return True

                                if self.peer_id is not None and self.peer_id._has_data():
                                    return True

                                if self.preferred_path is not None and self.preferred_path._has_data():
                                    return True

                                if self.preferred_path_disable_fallback is not None:
                                    return True

                                if self.primary_peer_id is not None:
                                    return True

                                if self.primary_pseudo_wire_id is not None:
                                    return True

                                if self.primary_pw is not None:
                                    return True

                                if self.protocol is not None:
                                    return True

                                if self.pseudo_wire_id is not None:
                                    return True

                                if self.pseudo_wire_state is not None:
                                    return True

                                if self.pseudo_wire_type_mismatched is not None:
                                    return True

                                if self.pw_class_name is not None:
                                    return True

                                if self.pw_flow_label_code17_disabled is not None:
                                    return True

                                if self.pw_flow_label_type is not None:
                                    return True

                                if self.pw_flow_label_type_cfg is not None:
                                    return True

                                if self.pw_redundancy_initial_delay is not None:
                                    return True

                                if self.pw_redundancy_one_way is not None:
                                    return True

                                if self.pw_status_use is not None:
                                    return True

                                if self.pwlsd_rewrite_failed is not None:
                                    return True

                                if self.remote_control_word is not None:
                                    return True

                                if self.remote_interface is not None and self.remote_interface._has_data():
                                    return True

                                if self.remote_label_failed is not None:
                                    return True

                                if self.remote_pseudo_wire_type is not None:
                                    return True

                                if self.remote_signalling is not None and self.remote_signalling._has_data():
                                    return True

                                if self.required_bw is not None:
                                    return True

                                if self.resync_enabled is not None:
                                    return True

                                if self.resync_threshold is not None:
                                    return True

                                if self.rtp_mismatched is not None:
                                    return True

                                if self.sequencing_type is not None:
                                    return True

                                if self.shutdown is not None:
                                    return True

                                if self.sig_pkts_mismatched is not None:
                                    return True

                                if self.ssrc_mismatched is not None:
                                    return True

                                if self.state is not None:
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.table_policy_name is not None:
                                    return True

                                if self.tag_rewrite is not None:
                                    return True

                                if self.time_created is not None:
                                    return True

                                if self.time_elapsed_creation is not None:
                                    return True

                                if self.time_elapsed_status_changed is not None:
                                    return True

                                if self.time_elapsed_status_down is not None:
                                    return True

                                if self.transport_lsp_down is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire']['meta_info']


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters']['meta_info']


                        class StaticMac(object):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.address is not None:
                                    return True

                                if self.bmac is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws/Cisco-IOS-XR-l2vpn-oper:bridge-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.is_access is not None:
                                return True

                            if self.neighbor is not None:
                                return True

                            if self.pseudowire is not None and self.pseudowire._has_data():
                                return True

                            if self.pseudowire_id is not None:
                                return True

                            if self.pw_type is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.static_mac is not None:
                                for child_ref in self.static_mac:
                                    if child_ref._has_data():
                                        return True

                            if self.ve_id_vpls_id_0_3 is not None:
                                return True

                            if self.vpls_id_4_7 is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table/Cisco-IOS-XR-l2vpn-oper:bridge-pws'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.bridge_pw is not None:
                            for child_ref in self.bridge_pw:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-core-vfi-table'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_pws is not None and self.bridge_pws._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeCoreVfiTable']['meta_info']


            class BridgeAcs(object):
                """
                VPLS Bridge Domain Attachment Circuit Table
                
                .. attribute:: bridge_ac
                
                	VPLS Bridge Domain Attachment Circuit
                	**type**\: list of    :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_ac = YList()
                    self.bridge_ac.parent = self
                    self.bridge_ac.name = 'bridge_ac'


                class BridgeAc(object):
                    """
                    VPLS Bridge Domain Attachment Circuit
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                    
                    .. attribute:: bvi_mac_index
                    
                    	MyMac Index
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: bvimac
                    
                    	BVI MAC addresses
                    	**type**\: list of    :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                    
                    .. attribute:: security_parameters
                    
                    	Security Parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                    
                    .. attribute:: static_mac
                    
                    	Static MAC addresses
                    	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.attachment_circuit = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self.bvi_mac_index = None
                        self.bvimac = YList()
                        self.bvimac.parent = self
                        self.bvimac.name = 'bvimac'
                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                        self.security_parameters.parent = self
                        self.static_mac = YList()
                        self.static_mac.parent = self
                        self.static_mac.name = 'static_mac'


                    class AttachmentCircuit(object):
                        """
                        Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit']['meta_info']


                    class SecurityParameters(object):
                        """
                        Security Parameters
                        
                        .. attribute:: base
                        
                        	Basic Security Parameters
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: dhcpv4_trust
                        
                        	DHCPv4 Trust Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                            self.base.parent = self
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.dhcpv4_trust = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_rate_unit = None
                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_rate_unit = None


                        class Base(object):
                            """
                            Basic Security Parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dai_address_validation_mask = None
                                self.dhcpv4_profile_name = None
                                self.dhcpv4_snoop = None
                                self.flood_unknown_unicast_enabled = None
                                self.flood_uu_disabled_mac_limit_action = None
                                self.igm_pv4_disabled = None
                                self.igm_pv4_profile_name = None
                                self.is_dai_addr_validate_destination_mac_enabled = None
                                self.is_dai_addr_validate_ipv4_enabled = None
                                self.is_dai_addr_validate_source_mac_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_ip_source_guard_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_mac_secure_accept_shutdown_enabled = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.learn_disabled_mac_limit_action = None
                                self.mac_aging_mode = None
                                self.mac_aging_time = None
                                self.mac_flooding = None
                                self.mac_learning = None
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification = None
                                self.mac_limit_reached = None
                                self.mac_port_down_flush_enabled = None
                                self.mac_secure_action = None
                                self.mld_profile_name = None
                                self.mmrp_flood_optimization = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.split_horizon_group_id = None
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dai_address_validation_mask is not None:
                                    return True

                                if self.dhcpv4_profile_name is not None:
                                    return True

                                if self.dhcpv4_snoop is not None:
                                    return True

                                if self.flood_unknown_unicast_enabled is not None:
                                    return True

                                if self.flood_uu_disabled_mac_limit_action is not None:
                                    return True

                                if self.igm_pv4_disabled is not None:
                                    return True

                                if self.igm_pv4_profile_name is not None:
                                    return True

                                if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_ipv4_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_source_mac_enabled is not None:
                                    return True

                                if self.is_dai_enabled is not None:
                                    return True

                                if self.is_dai_logging_enabled is not None:
                                    return True

                                if self.is_ip_source_guard_enabled is not None:
                                    return True

                                if self.is_ipsg_logging_enabled is not None:
                                    return True

                                if self.is_mac_secure_accept_shutdown_enabled is not None:
                                    return True

                                if self.is_mac_secure_enabled is not None:
                                    return True

                                if self.is_mac_secure_logging_enabled is not None:
                                    return True

                                if self.learn_disabled_mac_limit_action is not None:
                                    return True

                                if self.mac_aging_mode is not None:
                                    return True

                                if self.mac_aging_time is not None:
                                    return True

                                if self.mac_flooding is not None:
                                    return True

                                if self.mac_learning is not None:
                                    return True

                                if self.mac_limit is not None:
                                    return True

                                if self.mac_limit_action is not None:
                                    return True

                                if self.mac_limit_notification is not None:
                                    return True

                                if self.mac_limit_reached is not None:
                                    return True

                                if self.mac_port_down_flush_enabled is not None:
                                    return True

                                if self.mac_secure_action is not None:
                                    return True

                                if self.mld_profile_name is not None:
                                    return True

                                if self.mmrp_flood_optimization is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.split_horizon_group_id is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base']['meta_info']


                        class StormControl(object):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bd_policer = None
                                self.broadcast = None
                                self.multicast = None
                                self.unicast = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:storm-control'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bd_policer is not None:
                                    return True

                                if self.broadcast is not None:
                                    return True

                                if self.multicast is not None:
                                    return True

                                if self.unicast is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.broadcast_storm_control_rate_unit is not None:
                                return True

                            if self.dhcpv4_trust is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_rate_unit is not None:
                                return True

                            if self.storm_control is not None and self.storm_control._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            if self.unicast_storm_control_rate_unit is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters']['meta_info']


                    class StaticMac(object):
                        """
                        Static MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:static-mac'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.bmac is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac']['meta_info']


                    class Bvimac(object):
                        """
                        BVI MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:bvimac'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.bmac is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac']['meta_info']

                    @property
                    def _common_path(self):
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-acs/Cisco-IOS-XR-l2vpn-oper:bridge-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        if self.bvi_mac_index is not None:
                            return True

                        if self.bvimac is not None:
                            for child_ref in self.bvimac:
                                if child_ref._has_data():
                                    return True

                        if self.security_parameters is not None and self.security_parameters._has_data():
                            return True

                        if self.static_mac is not None:
                            for child_ref in self.static_mac:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-acs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_ac is not None:
                        for child_ref in self.bridge_ac:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAcs']['meta_info']


            class BridgeAccessPws(object):
                """
                VPLS Bridge Domain Access Pseudowire Table
                
                .. attribute:: bridge_access_pw
                
                	VPLS Bridge Domain Access Pseudowire
                	**type**\: list of    :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.bridge_access_pw = YList()
                    self.bridge_access_pw.parent = self
                    self.bridge_access_pw.name = 'bridge_access_pw'


                class BridgeAccessPw(object):
                    """
                    VPLS Bridge Domain Access Pseudowire
                    
                    .. attribute:: is_access
                    
                    	Is Access PW
                    	**type**\:  bool
                    
                    .. attribute:: neighbor
                    
                    	Neighbor IPv4 address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pseudowire
                    
                    	Pseudowire
                    	**type**\:   :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                    
                    .. attribute:: pseudowire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: security_parameters
                    
                    	Security Parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                    
                    .. attribute:: static_mac
                    
                    	Static MAC addresses
                    	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.is_access = None
                        self.neighbor = None
                        self.pseudowire = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                        self.pseudowire.parent = self
                        self.pseudowire_id = None
                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                        self.security_parameters.parent = self
                        self.static_mac = YList()
                        self.static_mac.parent = self
                        self.static_mac.name = 'static_mac'


                    class Pseudowire(object):
                        """
                        Pseudowire
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\:  bool
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\:  bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\:  bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\:  bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\:  bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\:  bool
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\:  bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\:  bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\:  bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\:  bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\:  bool
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: is_evpnvpws_type
                        
                        	is EVPN VPWS
                        	**type**\:  bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\:  bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\:  bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\:  bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\:  bool
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\:  bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\:  bool
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\:  bool
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw>`
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\:  bool
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\:  bool
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\:  bool
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\:  bool
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\:  str
                        
                        	**length:** 0..33
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\:  bool
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\:  bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\:  bool
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\:  bool
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\:  bool
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\:  bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\:  bool
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\:  bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\:  bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\:  bool
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\:  str
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\:  str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_remote_down = None
                            self.admited_bw = None
                            self.auto_discovery = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.backup_pw = None
                            self.bitrate_mismatched = None
                            self.bridge_pw_type_mismatch = None
                            self.cas_mismatched = None
                            self.diff_ts_mismatched = None
                            self.disable_delay = None
                            self.disable_never = None
                            self.encapsulation_info = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self.evpn_src_acid = None
                            self.fe_ctype = None
                            self.forward_class = None
                            self.freq_mismatched = None
                            self.illegal_control_word = None
                            self.imposed_vlan_id = None
                            self.interworking = None
                            self.ipv6_local_source_address = None
                            self.is_evpnvpws_type = None
                            self.is_flow_label_static = None
                            self.is_multi_segment_pseudowire = None
                            self.is_partially_programmed = None
                            self.is_pwr_type = None
                            self.is_vfi = None
                            self.last_time_status_changed = None
                            self.last_time_status_down = None
                            self.ldp_label_advertise_failed = None
                            self.load_balance = None
                            self.local_control_word = None
                            self.local_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self.local_label_failed = None
                            self.local_pseudo_wire_type = None
                            self.local_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self.local_source_address = None
                            self.mac_limit_oper_down = None
                            self.mtu_mismatched = None
                            self.not_supported_qinq = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.out_of_memory_state = None
                            self.p2mp_pw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw()
                            self.p2mp_pw.parent = self
                            self.payload_bytes_mismatched = None
                            self.payload_type_mismatched = None
                            self.peer_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self.preferred_path = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self.preferred_path_disable_fallback = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.primary_pw = None
                            self.protocol = None
                            self.pseudo_wire_id = None
                            self.pseudo_wire_state = None
                            self.pseudo_wire_type_mismatched = None
                            self.pw_class_name = None
                            self.pw_flow_label_code17_disabled = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_redundancy_initial_delay = None
                            self.pw_redundancy_one_way = None
                            self.pw_status_use = None
                            self.pwlsd_rewrite_failed = None
                            self.remote_control_word = None
                            self.remote_interface = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self.remote_label_failed = None
                            self.remote_pseudo_wire_type = None
                            self.remote_signalling = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self.required_bw = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.rtp_mismatched = None
                            self.sequencing_type = None
                            self.shutdown = None
                            self.sig_pkts_mismatched = None
                            self.ssrc_mismatched = None
                            self.state = None
                            self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self.table_policy_name = None
                            self.tag_rewrite = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.time_elapsed_status_changed = None
                            self.time_elapsed_status_down = None
                            self.transport_lsp_down = None
                            self.xconnect_id = None


                        class PeerId(object):
                            """
                            Peer
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.internal_label = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.type = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:peer-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.internal_label is not None:
                                    return True

                                if self.ipv4_peer_id is not None:
                                    return True

                                if self.ipv6_peer_id is not None:
                                    return True

                                if self.type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId']['meta_info']


                        class EncapsulationInfo(object):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atom = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self.encapsulation = None
                                self.l2tpv3 = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3()
                                self.l2tpv3.parent = self


                            class Atom(object):
                                """
                                atom
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\:  bool
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\:  bool
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\:  bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\:  bool
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\:  bool
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.is_pseudowire_headend = None
                                    self.is_sai_itype2 = None
                                    self.is_tai_itype2 = None
                                    self.ldp_label_advertisment_failed = None
                                    self.local_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self.local_c_ctype = None
                                    self.local_ceid = None
                                    self.local_cv_type = None
                                    self.local_group_id = None
                                    self.local_label = None
                                    self.local_ldp_id = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.local_veid = None
                                    self.lsd_rewrite_failed = None
                                    self.multi_segment_pseudowire_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self.rem_saii = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.remote_agi = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self.remote_c_ctype = None
                                    self.remote_ceid = None
                                    self.remote_cv_type = None
                                    self.remote_group_id = None
                                    self.remote_label = None
                                    self.remote_ldp_id = None
                                    self.remote_source_address = None
                                    self.remote_veid = None
                                    self.saii = None
                                    self.source_address = None
                                    self.taii = None


                                class LocalAgi(object):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                                class RemoteAgi(object):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self.vpls_id_type = None


                                    class Auto(object):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.asn = None
                                            self.vpn_id = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:auto'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.asn is not None:
                                                return True

                                            if self.vpn_id is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                    class TwoByteAs(object):
                                        """
                                        two byte as
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.four_byte_index = None
                                            self.two_byte_as = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.four_byte_index is not None:
                                                return True

                                            if self.two_byte_as is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                    class V4Addr(object):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.ipv4_address = None
                                            self.two_byte_index = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.ipv4_address is not None:
                                                return True

                                            if self.two_byte_index is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.auto is not None and self.auto._has_data():
                                            return True

                                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                                            return True

                                        if self.v4_addr is not None and self.v4_addr._has_data():
                                            return True

                                        if self.vpls_id_type is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                                class MultiSegmentPseudowireStats(object):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.received_bytes = None
                                        self.received_packets = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.received_bytes is not None:
                                            return True

                                        if self.received_packets is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:atom'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.is_pseudowire_headend is not None:
                                        return True

                                    if self.is_sai_itype2 is not None:
                                        return True

                                    if self.is_tai_itype2 is not None:
                                        return True

                                    if self.ldp_label_advertisment_failed is not None:
                                        return True

                                    if self.local_agi is not None and self.local_agi._has_data():
                                        return True

                                    if self.local_c_ctype is not None:
                                        return True

                                    if self.local_ceid is not None:
                                        return True

                                    if self.local_cv_type is not None:
                                        return True

                                    if self.local_group_id is not None:
                                        return True

                                    if self.local_label is not None:
                                        return True

                                    if self.local_ldp_id is not None:
                                        return True

                                    if self.local_saii_gbl_id is not None:
                                        return True

                                    if self.local_saiiac_id is not None:
                                        return True

                                    if self.local_taii_gbl_id is not None:
                                        return True

                                    if self.local_taiiac_id is not None:
                                        return True

                                    if self.local_veid is not None:
                                        return True

                                    if self.lsd_rewrite_failed is not None:
                                        return True

                                    if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                        return True

                                    if self.rem_saii is not None:
                                        return True

                                    if self.rem_saii_gbl_id is not None:
                                        return True

                                    if self.rem_saiiac_id is not None:
                                        return True

                                    if self.rem_taii is not None:
                                        return True

                                    if self.rem_taii_gbl_id is not None:
                                        return True

                                    if self.rem_taiiac_id is not None:
                                        return True

                                    if self.remote_agi is not None and self.remote_agi._has_data():
                                        return True

                                    if self.remote_c_ctype is not None:
                                        return True

                                    if self.remote_ceid is not None:
                                        return True

                                    if self.remote_cv_type is not None:
                                        return True

                                    if self.remote_group_id is not None:
                                        return True

                                    if self.remote_label is not None:
                                        return True

                                    if self.remote_ldp_id is not None:
                                        return True

                                    if self.remote_source_address is not None:
                                        return True

                                    if self.remote_veid is not None:
                                        return True

                                    if self.saii is not None:
                                        return True

                                    if self.source_address is not None:
                                        return True

                                    if self.taii is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                            class L2Tpv3(object):
                                """
                                l2tpv3
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\:  bool
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\:  str
                                
                                	**length:** 0..32
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\:  bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\:  bool
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dont_fragment_bit = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.l2tp_class_name = None
                                    self.local_cookie_high_value = None
                                    self.local_cookie_low_value = None
                                    self.local_cookie_size = None
                                    self.local_secondary_cookie_high_value = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_size = None
                                    self.local_session_id = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.remote_circuit_status_up = None
                                    self.remote_cookie_high_value = None
                                    self.remote_cookie_low_value = None
                                    self.remote_cookie_size = None
                                    self.remote_session_id = None
                                    self.tos = None
                                    self.tos_mode = None
                                    self.ttl = None
                                    self.tunnel_state = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dont_fragment_bit is not None:
                                        return True

                                    if self.ipv4_source_address is not None:
                                        return True

                                    if self.ipv6_source_address is not None:
                                        return True

                                    if self.l2tp_class_name is not None:
                                        return True

                                    if self.local_cookie_high_value is not None:
                                        return True

                                    if self.local_cookie_low_value is not None:
                                        return True

                                    if self.local_cookie_size is not None:
                                        return True

                                    if self.local_secondary_cookie_high_value is not None:
                                        return True

                                    if self.local_secondary_cookie_low_value is not None:
                                        return True

                                    if self.local_secondary_cookie_size is not None:
                                        return True

                                    if self.local_session_id is not None:
                                        return True

                                    if self.path_mtu_enabled is not None:
                                        return True

                                    if self.path_mtu_max_value is not None:
                                        return True

                                    if self.remote_circuit_status_up is not None:
                                        return True

                                    if self.remote_cookie_high_value is not None:
                                        return True

                                    if self.remote_cookie_low_value is not None:
                                        return True

                                    if self.remote_cookie_size is not None:
                                        return True

                                    if self.remote_session_id is not None:
                                        return True

                                    if self.tos is not None:
                                        return True

                                    if self.tos_mode is not None:
                                        return True

                                    if self.ttl is not None:
                                        return True

                                    if self.tunnel_state is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atom is not None and self.atom._has_data():
                                    return True

                                if self.encapsulation is not None:
                                    return True

                                if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo']['meta_info']


                        class LocalInterface(object):
                            """
                            Local interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface']['meta_info']


                        class RemoteInterface(object):
                            """
                            Remote interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):

                                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface']['meta_info']


                        class PreferredPath(object):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.ip_tunnel_interface_number = None
                                self.next_hop_ip = None
                                self.option = None
                                self.te_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.ip_tunnel_interface_number is not None:
                                    return True

                                if self.next_hop_ip is not None:
                                    return True

                                if self.option is not None:
                                    return True

                                if self.te_tunnel_interface_number is not None:
                                    return True

                                if self.tp_tunnel_interface_number is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath']['meta_info']


                        class LocalSignalling(object):
                            """
                            Local signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling']['meta_info']


                        class RemoteSignalling(object):
                            """
                            Remote signalling
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.pw_status = None
                                self.status_tlv = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self.tlv = YList()
                                self.tlv.parent = self
                                self.tlv.name = 'tlv'


                            class StatusTlv(object):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                            class Tlv(object):
                                """
                                Switching TLV info
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\:  str
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.description = None
                                    self.local_address = None
                                    self.pw_id = None
                                    self.remote_address = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling/Cisco-IOS-XR-l2vpn-oper:tlv'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.description is not None:
                                        return True

                                    if self.local_address is not None:
                                        return True

                                    if self.pw_id is not None:
                                        return True

                                    if self.remote_address is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.pw_status is not None:
                                    return True

                                if self.status_tlv is not None and self.status_tlv._has_data():
                                    return True

                                if self.tlv is not None:
                                    for child_ref in self.tlv:
                                        if child_ref._has_data():
                                            return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics']['meta_info']


                        class P2MpPw(object):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\:  bool
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.local_available = None
                                self.local_extended_tunnel_id = None
                                self.local_flags = None
                                self.local_label = None
                                self.local_p2mp_id = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.remote_available = None
                                self.remote_extended_tunnel_id = None
                                self.remote_flags = None
                                self.remote_label = None
                                self.remote_p2mp_id = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.local_available is not None:
                                    return True

                                if self.local_extended_tunnel_id is not None:
                                    return True

                                if self.local_flags is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_p2mp_id is not None:
                                    return True

                                if self.local_ptree_type is not None:
                                    return True

                                if self.local_tunnel_id is not None:
                                    return True

                                if self.remote_available is not None:
                                    return True

                                if self.remote_extended_tunnel_id is not None:
                                    return True

                                if self.remote_flags is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_p2mp_id is not None:
                                    return True

                                if self.remote_ptree_type is not None:
                                    return True

                                if self.remote_tunnel_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2MpPw']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_remote_down is not None:
                                return True

                            if self.admited_bw is not None:
                                return True

                            if self.auto_discovery is not None:
                                return True

                            if self.backup_active is not None:
                                return True

                            if self.backup_force_active is not None:
                                return True

                            if self.backup_pw is not None:
                                return True

                            if self.bitrate_mismatched is not None:
                                return True

                            if self.bridge_pw_type_mismatch is not None:
                                return True

                            if self.cas_mismatched is not None:
                                return True

                            if self.diff_ts_mismatched is not None:
                                return True

                            if self.disable_delay is not None:
                                return True

                            if self.disable_never is not None:
                                return True

                            if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                                return True

                            if self.evpn_src_acid is not None:
                                return True

                            if self.fe_ctype is not None:
                                return True

                            if self.forward_class is not None:
                                return True

                            if self.freq_mismatched is not None:
                                return True

                            if self.illegal_control_word is not None:
                                return True

                            if self.imposed_vlan_id is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.ipv6_local_source_address is not None:
                                return True

                            if self.is_evpnvpws_type is not None:
                                return True

                            if self.is_flow_label_static is not None:
                                return True

                            if self.is_multi_segment_pseudowire is not None:
                                return True

                            if self.is_partially_programmed is not None:
                                return True

                            if self.is_pwr_type is not None:
                                return True

                            if self.is_vfi is not None:
                                return True

                            if self.last_time_status_changed is not None:
                                return True

                            if self.last_time_status_down is not None:
                                return True

                            if self.ldp_label_advertise_failed is not None:
                                return True

                            if self.load_balance is not None:
                                return True

                            if self.local_control_word is not None:
                                return True

                            if self.local_interface is not None and self.local_interface._has_data():
                                return True

                            if self.local_label_failed is not None:
                                return True

                            if self.local_pseudo_wire_type is not None:
                                return True

                            if self.local_signalling is not None and self.local_signalling._has_data():
                                return True

                            if self.local_source_address is not None:
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.not_supported_qinq is not None:
                                return True

                            if self.num_ma_cwithdraw_msg_received is not None:
                                return True

                            if self.number_ma_cwithdraw_message_sent is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                                return True

                            if self.payload_bytes_mismatched is not None:
                                return True

                            if self.payload_type_mismatched is not None:
                                return True

                            if self.peer_id is not None and self.peer_id._has_data():
                                return True

                            if self.preferred_path is not None and self.preferred_path._has_data():
                                return True

                            if self.preferred_path_disable_fallback is not None:
                                return True

                            if self.primary_peer_id is not None:
                                return True

                            if self.primary_pseudo_wire_id is not None:
                                return True

                            if self.primary_pw is not None:
                                return True

                            if self.protocol is not None:
                                return True

                            if self.pseudo_wire_id is not None:
                                return True

                            if self.pseudo_wire_state is not None:
                                return True

                            if self.pseudo_wire_type_mismatched is not None:
                                return True

                            if self.pw_class_name is not None:
                                return True

                            if self.pw_flow_label_code17_disabled is not None:
                                return True

                            if self.pw_flow_label_type is not None:
                                return True

                            if self.pw_flow_label_type_cfg is not None:
                                return True

                            if self.pw_redundancy_initial_delay is not None:
                                return True

                            if self.pw_redundancy_one_way is not None:
                                return True

                            if self.pw_status_use is not None:
                                return True

                            if self.pwlsd_rewrite_failed is not None:
                                return True

                            if self.remote_control_word is not None:
                                return True

                            if self.remote_interface is not None and self.remote_interface._has_data():
                                return True

                            if self.remote_label_failed is not None:
                                return True

                            if self.remote_pseudo_wire_type is not None:
                                return True

                            if self.remote_signalling is not None and self.remote_signalling._has_data():
                                return True

                            if self.required_bw is not None:
                                return True

                            if self.resync_enabled is not None:
                                return True

                            if self.resync_threshold is not None:
                                return True

                            if self.rtp_mismatched is not None:
                                return True

                            if self.sequencing_type is not None:
                                return True

                            if self.shutdown is not None:
                                return True

                            if self.sig_pkts_mismatched is not None:
                                return True

                            if self.ssrc_mismatched is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.table_policy_name is not None:
                                return True

                            if self.tag_rewrite is not None:
                                return True

                            if self.time_created is not None:
                                return True

                            if self.time_elapsed_creation is not None:
                                return True

                            if self.time_elapsed_status_changed is not None:
                                return True

                            if self.time_elapsed_status_down is not None:
                                return True

                            if self.transport_lsp_down is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire']['meta_info']


                    class SecurityParameters(object):
                        """
                        Security Parameters
                        
                        .. attribute:: base
                        
                        	Basic Security Parameters
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: dhcpv4_trust
                        
                        	DHCPv4 Trust Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                            self.base.parent = self
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.dhcpv4_trust = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_rate_unit = None
                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_rate_unit = None


                        class Base(object):
                            """
                            Basic Security Parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dai_address_validation_mask = None
                                self.dhcpv4_profile_name = None
                                self.dhcpv4_snoop = None
                                self.flood_unknown_unicast_enabled = None
                                self.flood_uu_disabled_mac_limit_action = None
                                self.igm_pv4_disabled = None
                                self.igm_pv4_profile_name = None
                                self.is_dai_addr_validate_destination_mac_enabled = None
                                self.is_dai_addr_validate_ipv4_enabled = None
                                self.is_dai_addr_validate_source_mac_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_ip_source_guard_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_mac_secure_accept_shutdown_enabled = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.learn_disabled_mac_limit_action = None
                                self.mac_aging_mode = None
                                self.mac_aging_time = None
                                self.mac_flooding = None
                                self.mac_learning = None
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification = None
                                self.mac_limit_reached = None
                                self.mac_port_down_flush_enabled = None
                                self.mac_secure_action = None
                                self.mld_profile_name = None
                                self.mmrp_flood_optimization = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.split_horizon_group_id = None
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dai_address_validation_mask is not None:
                                    return True

                                if self.dhcpv4_profile_name is not None:
                                    return True

                                if self.dhcpv4_snoop is not None:
                                    return True

                                if self.flood_unknown_unicast_enabled is not None:
                                    return True

                                if self.flood_uu_disabled_mac_limit_action is not None:
                                    return True

                                if self.igm_pv4_disabled is not None:
                                    return True

                                if self.igm_pv4_profile_name is not None:
                                    return True

                                if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_ipv4_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_source_mac_enabled is not None:
                                    return True

                                if self.is_dai_enabled is not None:
                                    return True

                                if self.is_dai_logging_enabled is not None:
                                    return True

                                if self.is_ip_source_guard_enabled is not None:
                                    return True

                                if self.is_ipsg_logging_enabled is not None:
                                    return True

                                if self.is_mac_secure_accept_shutdown_enabled is not None:
                                    return True

                                if self.is_mac_secure_enabled is not None:
                                    return True

                                if self.is_mac_secure_logging_enabled is not None:
                                    return True

                                if self.learn_disabled_mac_limit_action is not None:
                                    return True

                                if self.mac_aging_mode is not None:
                                    return True

                                if self.mac_aging_time is not None:
                                    return True

                                if self.mac_flooding is not None:
                                    return True

                                if self.mac_learning is not None:
                                    return True

                                if self.mac_limit is not None:
                                    return True

                                if self.mac_limit_action is not None:
                                    return True

                                if self.mac_limit_notification is not None:
                                    return True

                                if self.mac_limit_reached is not None:
                                    return True

                                if self.mac_port_down_flush_enabled is not None:
                                    return True

                                if self.mac_secure_action is not None:
                                    return True

                                if self.mld_profile_name is not None:
                                    return True

                                if self.mmrp_flood_optimization is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.split_horizon_group_id is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base']['meta_info']


                        class StormControl(object):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bd_policer = None
                                self.broadcast = None
                                self.multicast = None
                                self.unicast = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bd_policer is not None:
                                    return True

                                if self.broadcast is not None:
                                    return True

                                if self.multicast is not None:
                                    return True

                                if self.unicast is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.broadcast_storm_control_rate_unit is not None:
                                return True

                            if self.dhcpv4_trust is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_rate_unit is not None:
                                return True

                            if self.storm_control is not None and self.storm_control._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            if self.unicast_storm_control_rate_unit is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters']['meta_info']


                    class StaticMac(object):
                        """
                        Static MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw/Cisco-IOS-XR-l2vpn-oper:static-mac'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.bmac is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws/Cisco-IOS-XR-l2vpn-oper:bridge-access-pw'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.is_access is not None:
                            return True

                        if self.neighbor is not None:
                            return True

                        if self.pseudowire is not None and self.pseudowire._has_data():
                            return True

                        if self.pseudowire_id is not None:
                            return True

                        if self.security_parameters is not None and self.security_parameters._has_data():
                            return True

                        if self.static_mac is not None:
                            for child_ref in self.static_mac:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-access-pws'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.bridge_access_pw is not None:
                        for child_ref in self.bridge_access_pw:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeAccessPws']['meta_info']


            class BridgeDomainInfo(object):
                """
                VPLS Bridge Domain Information
                
                .. attribute:: acpwup
                
                	Number of bridge ports (AC,PW) which are up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: as_
                
                	BGP AS number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_access_vfi
                
                	Access Virtual Forwarding Interfaces
                	**type**\: list of    :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                
                .. attribute:: bridge_coupled_state
                
                	Bridge\-domain coupled state
                	**type**\:   :py:class:`L2VpnBridgeCoupledStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeCoupledStateEnum>`
                
                .. attribute:: bridge_description
                
                	Human\-readable bridge\-domain description
                	**type**\:  str
                
                .. attribute:: bridge_domain_id
                
                	Identification number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_internal_msti
                
                	Bridge\-domain internal msti
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_msti
                
                	Bridge\-domain msti
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_mtu
                
                	Maximum transmission unit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_name
                
                	Bridge\-domain name
                	**type**\:  str
                
                .. attribute:: bridge_shg_id
                
                	Bridge\-domain shgid
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bridge_state
                
                	Bridge\-domain state
                	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                
                .. attribute:: bridge_type
                
                	Bridge\-domain type
                	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                
                .. attribute:: bridge_vfi
                
                	Virtual Forwarding Interfaces
                	**type**\: list of    :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                
                .. attribute:: configured
                
                	Bridge\-domain is configured
                	**type**\:  bool
                
                .. attribute:: disposition_bytecount
                
                	EVPN Disposition Byte Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: disposition_pkt_count
                
                	EVPN Disposition Packet Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: evi
                
                	E\-VPN id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: evpn_parameters
                
                	EVPN parameters
                	**type**\:   :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                
                .. attribute:: flodd_group_id_down
                
                	Oper down because no FGID
                	**type**\:  bool
                
                .. attribute:: group_name
                
                	Group name
                	**type**\:  str
                
                .. attribute:: imposition_byte_count
                
                	EVPN Imposition Byte Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: imposition_pkt_count
                
                	EVPN Imposition Packet Count
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: is_bridge_partially_programmed
                
                	Bridge is partially programmed
                	**type**\:  bool
                
                .. attribute:: is_rd_configured
                
                	Config or Auto
                	**type**\:  bool
                
                .. attribute:: last_time_status_changed
                
                	Last time the bridge domain status changed
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                
                .. attribute:: mac_filter
                
                	MAC addresses for filtering
                	**type**\: list of    :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                
                .. attribute:: mac_limit_down
                
                	Oper down because MAC limit reached
                	**type**\:  bool
                
                .. attribute:: mac_withdraw
                
                	MAC withdraw enabled
                	**type**\:  bool
                
                .. attribute:: mac_withdraw_access
                
                	MAC Access PW withdraw enabled
                	**type**\:  bool
                
                .. attribute:: mac_withdraw_option
                
                	Event on which MAC withdraw is sent
                	**type**\:   :py:class:`L2VpnBagMacWithdrawOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacWithdrawOptionEnum>`
                
                .. attribute:: mac_withdraw_relay
                
                	MAC Access PW withdraw relaying from access to access enabled
                	**type**\:  bool
                
                .. attribute:: num_vn_is
                
                	Number of VNIs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_up
                
                	Number of VNIs up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_access_vf_is
                
                	Number of Access VFIs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pb_bs
                
                	Number of pbbs
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: number_pb_bs_up
                
                	Number of pbbs up
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_vf_is
                
                	Number of virtual forwarding interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                
                	nV Satellite Offload IPv4 Multicast Disabled
                	**type**\:  bool
                
                .. attribute:: p2mp_enabled
                
                	P2MP Enabled on this Bridge Domain
                	**type**\:  bool
                
                .. attribute:: partially_programmed_a_cs
                
                	Number of attachment circuits partially programmed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_pseudowires
                
                	Number of pseudowires partially programmed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pbb_parameters
                
                	PBB parameters
                	**type**\:   :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                
                .. attribute:: rd
                
                	Route Distinguisher
                	**type**\:   :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                
                .. attribute:: security_parameters
                
                	Security parameters
                	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                
                .. attribute:: shutdown
                
                	Administratively disabled
                	**type**\:  bool
                
                .. attribute:: standby_pseudowires
                
                	Number of pseudowires standby
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: time_created
                
                	Time when the bridge domain was created
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: time_elapsed_creation
                
                	Time elapsed since creation
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: time_elapsed_status_changed
                
                	Time elapsed since status changed
                	**type**\:  str
                
                	**length:** 0..50
                
                .. attribute:: vine_fsm_state
                
                	VNI, IRB, Native\-Evpn state
                	**type**\:  str
                
                .. attribute:: vni_parameters
                
                	VNI parameters
                	**type**\:   :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.acpwup = None
                    self.as_ = None
                    self.bridge_access_vfi = YList()
                    self.bridge_access_vfi.parent = self
                    self.bridge_access_vfi.name = 'bridge_access_vfi'
                    self.bridge_coupled_state = None
                    self.bridge_description = None
                    self.bridge_domain_id = None
                    self.bridge_internal_msti = None
                    self.bridge_msti = None
                    self.bridge_mtu = None
                    self.bridge_name = None
                    self.bridge_shg_id = None
                    self.bridge_state = None
                    self.bridge_type = None
                    self.bridge_vfi = YList()
                    self.bridge_vfi.parent = self
                    self.bridge_vfi.name = 'bridge_vfi'
                    self.configured = None
                    self.disposition_bytecount = None
                    self.disposition_pkt_count = None
                    self.evi = None
                    self.evpn_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                    self.evpn_parameters.parent = self
                    self.flodd_group_id_down = None
                    self.group_name = None
                    self.imposition_byte_count = None
                    self.imposition_pkt_count = None
                    self.is_bridge_partially_programmed = None
                    self.is_rd_configured = None
                    self.last_time_status_changed = None
                    self.load_balance = None
                    self.mac_filter = YList()
                    self.mac_filter.parent = self
                    self.mac_filter.name = 'mac_filter'
                    self.mac_limit_down = None
                    self.mac_withdraw = None
                    self.mac_withdraw_access = None
                    self.mac_withdraw_option = None
                    self.mac_withdraw_relay = None
                    self.num_vn_is = None
                    self.num_vn_is_up = None
                    self.number_a_cs = None
                    self.number_a_cs_up = None
                    self.number_access_vf_is = None
                    self.number_p_ws_up = None
                    self.number_pb_bs = None
                    self.number_pb_bs_up = None
                    self.number_pseudowires = None
                    self.number_vf_is = None
                    self.nv_satellite_offload_ipv4_multicast_disabled = None
                    self.p2mp_enabled = None
                    self.partially_programmed_a_cs = None
                    self.partially_programmed_pseudowires = None
                    self.pbb_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                    self.pbb_parameters.parent = self
                    self.rd = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                    self.rd.parent = self
                    self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                    self.security_parameters.parent = self
                    self.shutdown = None
                    self.standby_pseudowires = None
                    self.time_created = None
                    self.time_elapsed_creation = None
                    self.time_elapsed_status_changed = None
                    self.vine_fsm_state = None
                    self.vni_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                    self.vni_parameters.parent = self


                class SecurityParameters(object):
                    """
                    Security parameters
                    
                    .. attribute:: broadcast_storm_control_kb_ps
                    
                    	Broadcast Storm Control KbPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: broadcast_storm_control_pps
                    
                    	Broadcast Storm Control PPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: broadcast_storm_control_rate_unit
                    
                    	Broadcast Storm Control Rate Unit
                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                    
                    .. attribute:: dai_address_validation_mask
                    
                    	DAI Address Validation mask
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dhcpv4_profile_name
                    
                    	DHCPv4 Profile Name
                    	**type**\:  str
                    
                    .. attribute:: dhcpv4_snoop
                    
                    	DHCPv4 Snoop Status
                    	**type**\:  bool
                    
                    .. attribute:: flood_unknown_unicast_enabled
                    
                    	Flooding unknown unicast enabled
                    	**type**\:  bool
                    
                    .. attribute:: flood_uu_disabled_mac_limit_action
                    
                    	Flooding of unknown\-unicast disabled due to MAC limit action
                    	**type**\:  bool
                    
                    .. attribute:: igm_pv4_disabled
                    
                    	IGMPv4 Disabled
                    	**type**\:  bool
                    
                    .. attribute:: igm_pv4_profile_name
                    
                    	IGMPv4 Profile Name
                    	**type**\:  str
                    
                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                    
                    	Is DAI Dstination MAC Address Validation Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                    
                    	Is DAI IPv4 Addr Validation Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                    
                    	Is DAI Source MAC Address Validation Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_enabled
                    
                    	Is Dynamic ARP Inspection Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_dai_logging_enabled
                    
                    	Is DAI Logging Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_source_guard_enabled
                    
                    	Is IP Source Guard Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_ipsg_logging_enabled
                    
                    	Is IP Source Guard Logging Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                    
                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                    	**type**\:  bool
                    
                    .. attribute:: is_mac_secure_enabled
                    
                    	Is MAC Secure Enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_mac_secure_logging_enabled
                    
                    	Is MAC Secure Logging Enabled
                    	**type**\:  bool
                    
                    .. attribute:: learn_disabled_mac_limit_action
                    
                    	Learning disabled due to MAC limit action
                    	**type**\:  bool
                    
                    .. attribute:: mac_aging_mode
                    
                    	MAC Aging Mode
                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                    
                    .. attribute:: mac_aging_time
                    
                    	MAC aging time in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: mac_flooding
                    
                    	MAC flooding enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_learning
                    
                    	MAC learning enabled
                    	**type**\:  bool
                    
                    .. attribute:: mac_limit
                    
                    	MAC address limit
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                    
                    .. attribute:: mac_limit_notification
                    
                    	MAC limit notification
                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                    
                    .. attribute:: mac_limit_reached
                    
                    	MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mac_port_down_flush_enabled
                    
                    	MAC Flush when port goes down
                    	**type**\:  bool
                    
                    .. attribute:: mac_secure_action
                    
                    	MAC Secure Action
                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                    
                    .. attribute:: mld_profile_name
                    
                    	MLD Profile Name
                    	**type**\:  str
                    
                    .. attribute:: mmrp_flood_optimization
                    
                    	MMRP Flood Optimization Status
                    	**type**\:  bool
                    
                    .. attribute:: multicast_storm_control_kb_ps
                    
                    	Multicast Storm Control KbPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: multicast_storm_control_pps
                    
                    	Multicast Storm Control PPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: multicast_storm_control_rate_unit
                    
                    	Multicast Storm Control Rate Unit
                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                    
                    .. attribute:: split_horizon_group_id
                    
                    	Split Horizon Group ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: storm_control
                    
                    	Storm Control Configuration
                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                    
                    .. attribute:: unicast_storm_control_kb_ps
                    
                    	Unicast Storm Control KbPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: unicast_storm_control_pps
                    
                    	Unicast Storm Control PPS
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: unicast_storm_control_rate_unit
                    
                    	Unicast Storm Control Rate Unit
                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.broadcast_storm_control_kb_ps = None
                        self.broadcast_storm_control_pps = None
                        self.broadcast_storm_control_rate_unit = None
                        self.dai_address_validation_mask = None
                        self.dhcpv4_profile_name = None
                        self.dhcpv4_snoop = None
                        self.flood_unknown_unicast_enabled = None
                        self.flood_uu_disabled_mac_limit_action = None
                        self.igm_pv4_disabled = None
                        self.igm_pv4_profile_name = None
                        self.is_dai_addr_validate_destination_mac_enabled = None
                        self.is_dai_addr_validate_ipv4_enabled = None
                        self.is_dai_addr_validate_source_mac_enabled = None
                        self.is_dai_enabled = None
                        self.is_dai_logging_enabled = None
                        self.is_ip_source_guard_enabled = None
                        self.is_ipsg_logging_enabled = None
                        self.is_mac_secure_accept_shutdown_enabled = None
                        self.is_mac_secure_enabled = None
                        self.is_mac_secure_logging_enabled = None
                        self.learn_disabled_mac_limit_action = None
                        self.mac_aging_mode = None
                        self.mac_aging_time = None
                        self.mac_flooding = None
                        self.mac_learning = None
                        self.mac_limit = None
                        self.mac_limit_action = None
                        self.mac_limit_notification = None
                        self.mac_limit_reached = None
                        self.mac_port_down_flush_enabled = None
                        self.mac_secure_action = None
                        self.mld_profile_name = None
                        self.mmrp_flood_optimization = None
                        self.multicast_storm_control_kb_ps = None
                        self.multicast_storm_control_pps = None
                        self.multicast_storm_control_rate_unit = None
                        self.split_horizon_group_id = None
                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                        self.storm_control.parent = self
                        self.unicast_storm_control_kb_ps = None
                        self.unicast_storm_control_pps = None
                        self.unicast_storm_control_rate_unit = None


                    class StormControl(object):
                        """
                        Storm Control Configuration
                        
                        .. attribute:: bd_policer
                        
                        	Bridge Domain Policer
                        	**type**\:  bool
                        
                        .. attribute:: broadcast
                        
                        	Broadcast Storm Control
                        	**type**\:  bool
                        
                        .. attribute:: multicast
                        
                        	Multicast Storm Control
                        	**type**\:  bool
                        
                        .. attribute:: unicast
                        
                        	Unknown\-unicast Storm Control
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bd_policer = None
                            self.broadcast = None
                            self.multicast = None
                            self.unicast = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bd_policer is not None:
                                return True

                            if self.broadcast is not None:
                                return True

                            if self.multicast is not None:
                                return True

                            if self.unicast is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.broadcast_storm_control_kb_ps is not None:
                            return True

                        if self.broadcast_storm_control_pps is not None:
                            return True

                        if self.broadcast_storm_control_rate_unit is not None:
                            return True

                        if self.dai_address_validation_mask is not None:
                            return True

                        if self.dhcpv4_profile_name is not None:
                            return True

                        if self.dhcpv4_snoop is not None:
                            return True

                        if self.flood_unknown_unicast_enabled is not None:
                            return True

                        if self.flood_uu_disabled_mac_limit_action is not None:
                            return True

                        if self.igm_pv4_disabled is not None:
                            return True

                        if self.igm_pv4_profile_name is not None:
                            return True

                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                            return True

                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                            return True

                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                            return True

                        if self.is_dai_enabled is not None:
                            return True

                        if self.is_dai_logging_enabled is not None:
                            return True

                        if self.is_ip_source_guard_enabled is not None:
                            return True

                        if self.is_ipsg_logging_enabled is not None:
                            return True

                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                            return True

                        if self.is_mac_secure_enabled is not None:
                            return True

                        if self.is_mac_secure_logging_enabled is not None:
                            return True

                        if self.learn_disabled_mac_limit_action is not None:
                            return True

                        if self.mac_aging_mode is not None:
                            return True

                        if self.mac_aging_time is not None:
                            return True

                        if self.mac_flooding is not None:
                            return True

                        if self.mac_learning is not None:
                            return True

                        if self.mac_limit is not None:
                            return True

                        if self.mac_limit_action is not None:
                            return True

                        if self.mac_limit_notification is not None:
                            return True

                        if self.mac_limit_reached is not None:
                            return True

                        if self.mac_port_down_flush_enabled is not None:
                            return True

                        if self.mac_secure_action is not None:
                            return True

                        if self.mld_profile_name is not None:
                            return True

                        if self.mmrp_flood_optimization is not None:
                            return True

                        if self.multicast_storm_control_kb_ps is not None:
                            return True

                        if self.multicast_storm_control_pps is not None:
                            return True

                        if self.multicast_storm_control_rate_unit is not None:
                            return True

                        if self.split_horizon_group_id is not None:
                            return True

                        if self.storm_control is not None and self.storm_control._has_data():
                            return True

                        if self.unicast_storm_control_kb_ps is not None:
                            return True

                        if self.unicast_storm_control_pps is not None:
                            return True

                        if self.unicast_storm_control_rate_unit is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters']['meta_info']


                class PbbParameters(object):
                    """
                    PBB parameters
                    
                    .. attribute:: pbb_core
                    
                    	PBB Core
                    	**type**\:   :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                    
                    .. attribute:: pbb_edge
                    
                    	PBB Edge
                    	**type**\:   :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                    
                    .. attribute:: type
                    
                    	Type
                    	**type**\:   :py:class:`L2VpnBridgeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.pbb_core = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                        self.pbb_core.parent = self
                        self.pbb_edge = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                        self.pbb_edge.parent = self
                        self.type = None


                    class PbbEdge(object):
                        """
                        PBB Edge
                        
                        .. attribute:: core_bridge_name
                        
                        	Core Bridge Domain Name
                        	**type**\:  str
                        
                        .. attribute:: core_bridge_state
                        
                        	Core Bridge State
                        	**type**\:   :py:class:`L2VpnBridgeStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBridgeStateEnum>`
                        
                        .. attribute:: edge_port
                        
                        	PBB Edge Port
                        	**type**\:   :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                        
                        .. attribute:: i_sid
                        
                        	SID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mirp_lite_protocol
                        
                        	MIRP\-lite protocol info
                        	**type**\:   :py:class:`L2VpnMirpLiteProtocolInfoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteProtocolInfoEnum>`
                        
                        .. attribute:: mirp_lite_status
                        
                        	MIRP\-lite Status
                        	**type**\:   :py:class:`L2VpnMirpLiteStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMirpLiteStatusEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.core_bridge_name = None
                            self.core_bridge_state = None
                            self.edge_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                            self.edge_port.parent = self
                            self.i_sid = None
                            self.mirp_lite_protocol = None
                            self.mirp_lite_status = None


                        class EdgePort(object):
                            """
                            PBB Edge Port
                            
                            .. attribute:: bmac_mapping
                            
                            	CMAC to BMAC Mapping
                            	**type**\: list of    :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                            
                            .. attribute:: edge_port_state
                            
                            	PBB Edge Port State
                            	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                            
                            .. attribute:: unknown_unicast_mac
                            
                            	Unknown Unicast MAC
                            	**type**\:  str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: unknown_unicast_mac_set
                            
                            	Unknown Unicast MAC Configured
                            	**type**\:  bool
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bmac_mapping = YList()
                                self.bmac_mapping.parent = self
                                self.bmac_mapping.name = 'bmac_mapping'
                                self.edge_port_state = None
                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                self.security_parameters.parent = self
                                self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                self.statistics.parent = self
                                self.unknown_unicast_mac = None
                                self.unknown_unicast_mac_set = None
                                self.xconnect_id = None


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters']['meta_info']


                            class Statistics(object):
                                """
                                Statistics
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self


                                class ImpostionStats(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self


                                    class ImpositionStat(object):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                    class ImpositionMtuDrop(object):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                    class ImpostionTailDrop(object):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                    class L2FsbiDrop(object):
                                        """
                                        rx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                    class Multicast(object):
                                        """
                                        Multicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast']['meta_info']


                                    class Broadcast(object):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                    class UnknownUnicast(object):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast is not None and self.broadcast._has_data():
                                            return True

                                        if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                            return True

                                        if self.imposition_stat is not None and self.imposition_stat._has_data():
                                            return True

                                        if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                            return True

                                        if self.multicast is not None and self.multicast._has_data():
                                            return True

                                        if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats']['meta_info']


                                class DispostionStats(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats>`
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self


                                    class DispositionStat(object):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                    class DispositionMtuDrop(object):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                    class DispositionTailDrop(object):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                    class MulticastDrop(object):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                    class UnicastDrop(object):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                    class BroadcastDrop(object):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                    class ReceivedDrops(object):
                                        """
                                        tx discards
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                    class DaiDrop(object):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                    class IpsgDrop(object):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                    class DispositionOoODrops(object):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                    class DispositionP2MpStats(object):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                    class KnownUnicast(object):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                    class MacMove(object):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\:  int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.byte_counts = None
                                            self.packet_counts = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.byte_counts is not None:
                                                return True

                                            if self.packet_counts is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                            return True

                                        if self.dai_drop is not None and self.dai_drop._has_data():
                                            return True

                                        if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                            return True

                                        if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                            return True

                                        if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                            return True

                                        if self.disposition_stat is not None and self.disposition_stat._has_data():
                                            return True

                                        if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                            return True

                                        if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                            return True

                                        if self.known_unicast is not None and self.known_unicast._has_data():
                                            return True

                                        if self.mac_move is not None and self.mac_move._has_data():
                                            return True

                                        if self.multicast_drop is not None and self.multicast_drop._has_data():
                                            return True

                                        if self.received_drops is not None and self.received_drops._has_data():
                                            return True

                                        if self.unicast_drop is not None and self.unicast_drop._has_data():
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats']['meta_info']


                                class SequenceNumber(object):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self.sequence_number_expected = None
                                        self.sequence_number_sent = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bypassed_inbound_sequence_packet is not None:
                                            return True

                                        if self.bypassed_out_sequence_packet is not None:
                                            return True

                                        if self.sequence_number_expected is not None:
                                            return True

                                        if self.sequence_number_sent is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:statistics'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                        return True

                                    if self.impostion_stats is not None and self.impostion_stats._has_data():
                                        return True

                                    if self.sequence_number is not None and self.sequence_number._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics']['meta_info']


                            class BmacMapping(object):
                                """
                                CMAC to BMAC Mapping
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\:  str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port/Cisco-IOS-XR-l2vpn-oper:bmac-mapping'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.address is not None:
                                        return True

                                    if self.bmac is not None:
                                        return True

                                    if self.next_hop_ip is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge/Cisco-IOS-XR-l2vpn-oper:edge-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bmac_mapping is not None:
                                    for child_ref in self.bmac_mapping:
                                        if child_ref._has_data():
                                            return True

                                if self.edge_port_state is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.statistics is not None and self.statistics._has_data():
                                    return True

                                if self.unknown_unicast_mac is not None:
                                    return True

                                if self.unknown_unicast_mac_set is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-edge'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.core_bridge_name is not None:
                                return True

                            if self.core_bridge_state is not None:
                                return True

                            if self.edge_port is not None and self.edge_port._has_data():
                                return True

                            if self.i_sid is not None:
                                return True

                            if self.mirp_lite_protocol is not None:
                                return True

                            if self.mirp_lite_status is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge']['meta_info']


                    class PbbCore(object):
                        """
                        PBB Core
                        
                        .. attribute:: core_port
                        
                        	PBB Core Port
                        	**type**\:   :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                        
                        .. attribute:: num_ass_edge
                        
                        	Number of Associated PBB Edges
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.core_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                            self.core_port.parent = self
                            self.num_ass_edge = None


                        class CorePort(object):
                            """
                            PBB Core Port
                            
                            .. attribute:: core_port_state
                            
                            	PBB Core Port State
                            	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                            
                            .. attribute:: vlan_id
                            
                            	Vlan ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.core_port_state = None
                                self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                self.security_parameters.parent = self
                                self.vlan_id = None
                                self.xconnect_id = None


                            class SecurityParameters(object):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dhcpv4_trust = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class Base(object):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\:  bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\:  str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_profile_name = None
                                        self.dhcpv4_snoop = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.mac_aging_mode = None
                                        self.mac_aging_time = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_limit_reached = None
                                        self.mac_port_down_flush_enabled = None
                                        self.mac_secure_action = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.split_horizon_group_id = None
                                        self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self.unicast_storm_control_kb_ps = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_rate_unit = None


                                    class StormControl(object):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\:  bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\:  bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bd_policer = None
                                            self.broadcast = None
                                            self.multicast = None
                                            self.unicast = None

                                        @property
                                        def _common_path(self):

                                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bd_policer is not None:
                                                return True

                                            if self.broadcast is not None:
                                                return True

                                            if self.multicast is not None:
                                                return True

                                            if self.unicast is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl']['meta_info']

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.broadcast_storm_control_kb_ps is not None:
                                            return True

                                        if self.broadcast_storm_control_pps is not None:
                                            return True

                                        if self.broadcast_storm_control_rate_unit is not None:
                                            return True

                                        if self.dai_address_validation_mask is not None:
                                            return True

                                        if self.dhcpv4_profile_name is not None:
                                            return True

                                        if self.dhcpv4_snoop is not None:
                                            return True

                                        if self.flood_unknown_unicast_enabled is not None:
                                            return True

                                        if self.flood_uu_disabled_mac_limit_action is not None:
                                            return True

                                        if self.igm_pv4_disabled is not None:
                                            return True

                                        if self.igm_pv4_profile_name is not None:
                                            return True

                                        if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_ipv4_enabled is not None:
                                            return True

                                        if self.is_dai_addr_validate_source_mac_enabled is not None:
                                            return True

                                        if self.is_dai_enabled is not None:
                                            return True

                                        if self.is_dai_logging_enabled is not None:
                                            return True

                                        if self.is_ip_source_guard_enabled is not None:
                                            return True

                                        if self.is_ipsg_logging_enabled is not None:
                                            return True

                                        if self.is_mac_secure_accept_shutdown_enabled is not None:
                                            return True

                                        if self.is_mac_secure_enabled is not None:
                                            return True

                                        if self.is_mac_secure_logging_enabled is not None:
                                            return True

                                        if self.learn_disabled_mac_limit_action is not None:
                                            return True

                                        if self.mac_aging_mode is not None:
                                            return True

                                        if self.mac_aging_time is not None:
                                            return True

                                        if self.mac_flooding is not None:
                                            return True

                                        if self.mac_learning is not None:
                                            return True

                                        if self.mac_limit is not None:
                                            return True

                                        if self.mac_limit_action is not None:
                                            return True

                                        if self.mac_limit_notification is not None:
                                            return True

                                        if self.mac_limit_reached is not None:
                                            return True

                                        if self.mac_port_down_flush_enabled is not None:
                                            return True

                                        if self.mac_secure_action is not None:
                                            return True

                                        if self.mld_profile_name is not None:
                                            return True

                                        if self.mmrp_flood_optimization is not None:
                                            return True

                                        if self.multicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.multicast_storm_control_pps is not None:
                                            return True

                                        if self.multicast_storm_control_rate_unit is not None:
                                            return True

                                        if self.split_horizon_group_id is not None:
                                            return True

                                        if self.storm_control is not None and self.storm_control._has_data():
                                            return True

                                        if self.unicast_storm_control_kb_ps is not None:
                                            return True

                                        if self.unicast_storm_control_pps is not None:
                                            return True

                                        if self.unicast_storm_control_rate_unit is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base']['meta_info']


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.base is not None and self.base._has_data():
                                        return True

                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dhcpv4_trust is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core/Cisco-IOS-XR-l2vpn-oper:core-port'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.core_port_state is not None:
                                    return True

                                if self.security_parameters is not None and self.security_parameters._has_data():
                                    return True

                                if self.vlan_id is not None:
                                    return True

                                if self.xconnect_id is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters/Cisco-IOS-XR-l2vpn-oper:pbb-core'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.core_port is not None and self.core_port._has_data():
                                return True

                            if self.num_ass_edge is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:pbb-parameters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.pbb_core is not None and self.pbb_core._has_data():
                            return True

                        if self.pbb_edge is not None and self.pbb_edge._has_data():
                            return True

                        if self.type is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters']['meta_info']


                class EvpnParameters(object):
                    """
                    EVPN parameters
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_port
                    
                    	EVPN Port
                    	**type**\:   :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.evi = None
                        self.evpn_port = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                        self.evpn_port.parent = self


                    class EvpnPort(object):
                        """
                        EVPN Port
                        
                        .. attribute:: evpn_port_state
                        
                        	EVPN Port State
                        	**type**\:   :py:class:`L2VpnVirtualportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVirtualportStateEnum>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.evpn_port_state = None
                            self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                            self.security_parameters.parent = self
                            self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                            self.statistics.parent = self
                            self.xconnect_id = None


                        class SecurityParameters(object):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                self.base.parent = self
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dhcpv4_trust = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class Base(object):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\:  bool
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\:  bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\:  bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\:  str
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\:  bool
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\:  bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\:  bool
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\:  bool
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\:  bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\:  bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\:  str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\:  bool
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_profile_name = None
                                    self.dhcpv4_snoop = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.mac_aging_mode = None
                                    self.mac_aging_time = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_limit_reached = None
                                    self.mac_port_down_flush_enabled = None
                                    self.mac_secure_action = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.split_horizon_group_id = None
                                    self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self.unicast_storm_control_kb_ps = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_rate_unit = None


                                class StormControl(object):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\:  bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\:  bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bd_policer = None
                                        self.broadcast = None
                                        self.multicast = None
                                        self.unicast = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bd_policer is not None:
                                            return True

                                        if self.broadcast is not None:
                                            return True

                                        if self.multicast is not None:
                                            return True

                                        if self.unicast is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_storm_control_kb_ps is not None:
                                        return True

                                    if self.broadcast_storm_control_pps is not None:
                                        return True

                                    if self.broadcast_storm_control_rate_unit is not None:
                                        return True

                                    if self.dai_address_validation_mask is not None:
                                        return True

                                    if self.dhcpv4_profile_name is not None:
                                        return True

                                    if self.dhcpv4_snoop is not None:
                                        return True

                                    if self.flood_unknown_unicast_enabled is not None:
                                        return True

                                    if self.flood_uu_disabled_mac_limit_action is not None:
                                        return True

                                    if self.igm_pv4_disabled is not None:
                                        return True

                                    if self.igm_pv4_profile_name is not None:
                                        return True

                                    if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_ipv4_enabled is not None:
                                        return True

                                    if self.is_dai_addr_validate_source_mac_enabled is not None:
                                        return True

                                    if self.is_dai_enabled is not None:
                                        return True

                                    if self.is_dai_logging_enabled is not None:
                                        return True

                                    if self.is_ip_source_guard_enabled is not None:
                                        return True

                                    if self.is_ipsg_logging_enabled is not None:
                                        return True

                                    if self.is_mac_secure_accept_shutdown_enabled is not None:
                                        return True

                                    if self.is_mac_secure_enabled is not None:
                                        return True

                                    if self.is_mac_secure_logging_enabled is not None:
                                        return True

                                    if self.learn_disabled_mac_limit_action is not None:
                                        return True

                                    if self.mac_aging_mode is not None:
                                        return True

                                    if self.mac_aging_time is not None:
                                        return True

                                    if self.mac_flooding is not None:
                                        return True

                                    if self.mac_learning is not None:
                                        return True

                                    if self.mac_limit is not None:
                                        return True

                                    if self.mac_limit_action is not None:
                                        return True

                                    if self.mac_limit_notification is not None:
                                        return True

                                    if self.mac_limit_reached is not None:
                                        return True

                                    if self.mac_port_down_flush_enabled is not None:
                                        return True

                                    if self.mac_secure_action is not None:
                                        return True

                                    if self.mld_profile_name is not None:
                                        return True

                                    if self.mmrp_flood_optimization is not None:
                                        return True

                                    if self.multicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.multicast_storm_control_pps is not None:
                                        return True

                                    if self.multicast_storm_control_rate_unit is not None:
                                        return True

                                    if self.split_horizon_group_id is not None:
                                        return True

                                    if self.storm_control is not None and self.storm_control._has_data():
                                        return True

                                    if self.unicast_storm_control_kb_ps is not None:
                                        return True

                                    if self.unicast_storm_control_pps is not None:
                                        return True

                                    if self.unicast_storm_control_rate_unit is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base']['meta_info']


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.base is not None and self.base._has_data():
                                    return True

                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dhcpv4_trust is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):

                                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters/Cisco-IOS-XR-l2vpn-oper:evpn-port'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.evpn_port_state is not None:
                                return True

                            if self.security_parameters is not None and self.security_parameters._has_data():
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:evpn-parameters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.evi is not None:
                            return True

                        if self.evpn_port is not None and self.evpn_port._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters']['meta_info']


                class VniParameters(object):
                    """
                    VNI parameters
                    
                    .. attribute:: anycast_mcast_group_addr
                    
                    	Anycast Multicast Group Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: anycast_vtep_ip_addr
                    
                    	Anycast VTEP IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: multicast_group_addr
                    
                    	Multicast Group Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: overlay
                    
                    	NVE Overlay
                    	**type**\:  str
                    
                    .. attribute:: security_parameters
                    
                    	Security Parameters
                    	**type**\:   :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                    
                    .. attribute:: source_ip_addr
                    
                    	Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: static_mac
                    
                    	Static MAC addresses
                    	**type**\: list of    :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                    
                    .. attribute:: udp_port
                    
                    	UDP Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni
                    
                    	VNI
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_encap_type
                    
                    	VNI Encapsulation Type
                    	**type**\:   :py:class:`L2VpnVniEncapsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniEncapsEnum>`
                    
                    .. attribute:: vni_mode
                    
                    	VNI Mode
                    	**type**\:   :py:class:`L2VpnVniModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVniModeEnum>`
                    
                    .. attribute:: vni_port_state
                    
                    	VNI Port State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: xconnect_id
                    
                    	Xconnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.anycast_mcast_group_addr = None
                        self.anycast_vtep_ip_addr = None
                        self.multicast_group_addr = None
                        self.overlay = None
                        self.security_parameters = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                        self.security_parameters.parent = self
                        self.source_ip_addr = None
                        self.static_mac = YList()
                        self.static_mac.parent = self
                        self.static_mac.name = 'static_mac'
                        self.statistics = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                        self.statistics.parent = self
                        self.udp_port = None
                        self.vni = None
                        self.vni_encap_type = None
                        self.vni_mode = None
                        self.vni_port_state = None
                        self.xconnect_id = None


                    class SecurityParameters(object):
                        """
                        Security Parameters
                        
                        .. attribute:: base
                        
                        	Basic Security Parameters
                        	**type**\:   :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: dhcpv4_trust
                        
                        	DHCPv4 Trust Status
                        	**type**\:  bool
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.base = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                            self.base.parent = self
                            self.broadcast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.dhcpv4_trust = None
                            self.multicast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_rate_unit = None
                            self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self.unicast_storm_control_kb_ps = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_rate_unit = None


                        class Base(object):
                            """
                            Basic Security Parameters
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\:  bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\:  bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\:  bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\:  str
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\:  bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\:  bool
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:   :py:class:`L2VpnBagMacAgingModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacAgingModeEnum>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\:  bool
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:   :py:class:`L2VpnBagMacLimitActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitActionEnum>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:   :py:class:`L2VpnBagMacLimitNotifyEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacLimitNotifyEnum>`
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\:  bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\:  bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:   :py:class:`L2VpnBagMacSecureActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagMacSecureActionEnum>`
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\:  str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\:  bool
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:   :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:   :py:class:`L2VpnBagStormControlRateUnitEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnBagStormControlRateUnitEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_storm_control_kb_ps = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.dai_address_validation_mask = None
                                self.dhcpv4_profile_name = None
                                self.dhcpv4_snoop = None
                                self.flood_unknown_unicast_enabled = None
                                self.flood_uu_disabled_mac_limit_action = None
                                self.igm_pv4_disabled = None
                                self.igm_pv4_profile_name = None
                                self.is_dai_addr_validate_destination_mac_enabled = None
                                self.is_dai_addr_validate_ipv4_enabled = None
                                self.is_dai_addr_validate_source_mac_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_ip_source_guard_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_mac_secure_accept_shutdown_enabled = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.learn_disabled_mac_limit_action = None
                                self.mac_aging_mode = None
                                self.mac_aging_time = None
                                self.mac_flooding = None
                                self.mac_learning = None
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification = None
                                self.mac_limit_reached = None
                                self.mac_port_down_flush_enabled = None
                                self.mac_secure_action = None
                                self.mld_profile_name = None
                                self.mmrp_flood_optimization = None
                                self.multicast_storm_control_kb_ps = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_rate_unit = None
                                self.split_horizon_group_id = None
                                self.storm_control = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                self.storm_control.parent = self
                                self.unicast_storm_control_kb_ps = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_rate_unit = None


                            class StormControl(object):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\:  bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\:  bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bd_policer = None
                                    self.broadcast = None
                                    self.multicast = None
                                    self.unicast = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base/Cisco-IOS-XR-l2vpn-oper:storm-control'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bd_policer is not None:
                                        return True

                                    if self.broadcast is not None:
                                        return True

                                    if self.multicast is not None:
                                        return True

                                    if self.unicast is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:base'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_storm_control_kb_ps is not None:
                                    return True

                                if self.broadcast_storm_control_pps is not None:
                                    return True

                                if self.broadcast_storm_control_rate_unit is not None:
                                    return True

                                if self.dai_address_validation_mask is not None:
                                    return True

                                if self.dhcpv4_profile_name is not None:
                                    return True

                                if self.dhcpv4_snoop is not None:
                                    return True

                                if self.flood_unknown_unicast_enabled is not None:
                                    return True

                                if self.flood_uu_disabled_mac_limit_action is not None:
                                    return True

                                if self.igm_pv4_disabled is not None:
                                    return True

                                if self.igm_pv4_profile_name is not None:
                                    return True

                                if self.is_dai_addr_validate_destination_mac_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_ipv4_enabled is not None:
                                    return True

                                if self.is_dai_addr_validate_source_mac_enabled is not None:
                                    return True

                                if self.is_dai_enabled is not None:
                                    return True

                                if self.is_dai_logging_enabled is not None:
                                    return True

                                if self.is_ip_source_guard_enabled is not None:
                                    return True

                                if self.is_ipsg_logging_enabled is not None:
                                    return True

                                if self.is_mac_secure_accept_shutdown_enabled is not None:
                                    return True

                                if self.is_mac_secure_enabled is not None:
                                    return True

                                if self.is_mac_secure_logging_enabled is not None:
                                    return True

                                if self.learn_disabled_mac_limit_action is not None:
                                    return True

                                if self.mac_aging_mode is not None:
                                    return True

                                if self.mac_aging_time is not None:
                                    return True

                                if self.mac_flooding is not None:
                                    return True

                                if self.mac_learning is not None:
                                    return True

                                if self.mac_limit is not None:
                                    return True

                                if self.mac_limit_action is not None:
                                    return True

                                if self.mac_limit_notification is not None:
                                    return True

                                if self.mac_limit_reached is not None:
                                    return True

                                if self.mac_port_down_flush_enabled is not None:
                                    return True

                                if self.mac_secure_action is not None:
                                    return True

                                if self.mld_profile_name is not None:
                                    return True

                                if self.mmrp_flood_optimization is not None:
                                    return True

                                if self.multicast_storm_control_kb_ps is not None:
                                    return True

                                if self.multicast_storm_control_pps is not None:
                                    return True

                                if self.multicast_storm_control_rate_unit is not None:
                                    return True

                                if self.split_horizon_group_id is not None:
                                    return True

                                if self.storm_control is not None and self.storm_control._has_data():
                                    return True

                                if self.unicast_storm_control_kb_ps is not None:
                                    return True

                                if self.unicast_storm_control_pps is not None:
                                    return True

                                if self.unicast_storm_control_rate_unit is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base']['meta_info']


                        class StormControl(object):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\:  bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\:  bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bd_policer = None
                                self.broadcast = None
                                self.multicast = None
                                self.unicast = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters/Cisco-IOS-XR-l2vpn-oper:storm-control'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bd_policer is not None:
                                    return True

                                if self.broadcast is not None:
                                    return True

                                if self.multicast is not None:
                                    return True

                                if self.unicast is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:security-parameters'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.base is not None and self.base._has_data():
                                return True

                            if self.broadcast_storm_control_kb_ps is not None:
                                return True

                            if self.broadcast_storm_control_pps is not None:
                                return True

                            if self.broadcast_storm_control_rate_unit is not None:
                                return True

                            if self.dhcpv4_trust is not None:
                                return True

                            if self.multicast_storm_control_kb_ps is not None:
                                return True

                            if self.multicast_storm_control_pps is not None:
                                return True

                            if self.multicast_storm_control_rate_unit is not None:
                                return True

                            if self.storm_control is not None and self.storm_control._has_data():
                                return True

                            if self.unicast_storm_control_kb_ps is not None:
                                return True

                            if self.unicast_storm_control_pps is not None:
                                return True

                            if self.unicast_storm_control_rate_unit is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics']['meta_info']


                    class StaticMac(object):
                        """
                        Static MAC addresses
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters/Cisco-IOS-XR-l2vpn-oper:static-mac'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.address is not None:
                                return True

                            if self.bmac is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:vni-parameters'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.anycast_mcast_group_addr is not None:
                            return True

                        if self.anycast_vtep_ip_addr is not None:
                            return True

                        if self.multicast_group_addr is not None:
                            return True

                        if self.overlay is not None:
                            return True

                        if self.security_parameters is not None and self.security_parameters._has_data():
                            return True

                        if self.source_ip_addr is not None:
                            return True

                        if self.static_mac is not None:
                            for child_ref in self.static_mac:
                                if child_ref._has_data():
                                    return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.udp_port is not None:
                            return True

                        if self.vni is not None:
                            return True

                        if self.vni_encap_type is not None:
                            return True

                        if self.vni_mode is not None:
                            return True

                        if self.vni_port_state is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters']['meta_info']


                class Rd(object):
                    """
                    Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                        self.auto.parent = self
                        self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                        self.four_byte_as.parent = self
                        self.rd = None
                        self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                        self.two_byte_as.parent = self
                        self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                        self.v4_addr.parent = self


                    class Auto(object):
                        """
                        auto
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.auto_index = None
                            self.router_id = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:auto'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.auto_index is not None:
                                return True

                            if self.router_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto']['meta_info']


                    class TwoByteAs(object):
                        """
                        two byte as
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_index = None
                            self.two_byte_as = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_index is not None:
                                return True

                            if self.two_byte_as is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs']['meta_info']


                    class FourByteAs(object):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.four_byte_as = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.four_byte_as is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs']['meta_info']


                    class V4Addr(object):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ipv4_address = None
                            self.two_byte_index = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ipv4_address is not None:
                                return True

                            if self.two_byte_index is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:rd'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.auto is not None and self.auto._has_data():
                            return True

                        if self.four_byte_as is not None and self.four_byte_as._has_data():
                            return True

                        if self.rd is not None:
                            return True

                        if self.two_byte_as is not None and self.two_byte_as._has_data():
                            return True

                        if self.v4_addr is not None and self.v4_addr._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd']['meta_info']


                class MacFilter(object):
                    """
                    MAC addresses for filtering
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: bmac
                    
                    	Backbone MAC address
                    	**type**\:  str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: next_hop_ip
                    
                    	Next Hop IP
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.address = None
                        self.bmac = None
                        self.next_hop_ip = None

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:mac-filter'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.address is not None:
                            return True

                        if self.bmac is not None:
                            return True

                        if self.next_hop_ip is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter']['meta_info']


                class BridgeVfi(object):
                    """
                    Virtual Forwarding Interfaces
                    
                    .. attribute:: access
                    
                    	VFI is an Access VFI
                    	**type**\:  bool
                    
                    .. attribute:: discovery_information
                    
                    	Auto Discovery information
                    	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of Pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_information
                    
                    	Multicast P2MP information
                    	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: vfi_name
                    
                    	Virtual forwarding instance name
                    	**type**\:  str
                    
                    .. attribute:: vfi_state
                    
                    	VFI state
                    	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.access = None
                        self.discovery_information = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                        self.discovery_information.parent = self
                        self.number_pseudowires = None
                        self.p2mp_information = YList()
                        self.p2mp_information.parent = self
                        self.p2mp_information.name = 'p2mp_information'
                        self.shutdown = None
                        self.vfi_name = None
                        self.vfi_state = None


                    class DiscoveryInformation(object):
                        """
                        Auto Discovery information
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling protocol
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_number
                        
                        	Autonomous System Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\:  str
                        
                        .. attribute:: export_rt
                        
                        	List of export route targets
                        	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                        
                        .. attribute:: import_rt
                        
                        	List of import route targets
                        	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                        
                        .. attribute:: l2vpn_router_id
                        
                        	L2PVN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: provisioned_ve_id
                        
                        	Provisioned VPLS edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                        
                        .. attribute:: service_connected
                        
                        	Is the BGP service connected?
                        	**type**\:  bool
                        
                        .. attribute:: ve_id
                        
                        	VPLS Edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ve_range
                        
                        	VE range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vpls_id
                        
                        	VPLS ID
                        	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                        
                        .. attribute:: vpls_id_conflict
                        
                        	VPLS\-ID Conflict
                        	**type**\:  bool
                        
                        .. attribute:: vpn_added
                        
                        	Is VPN id configured
                        	**type**\:  bool
                        
                        .. attribute:: vpn_id
                        
                        	Vpn ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_signalling_method = None
                            self.as_number = None
                            self.export_route_policy = None
                            self.export_rt = YList()
                            self.export_rt.parent = self
                            self.export_rt.name = 'export_rt'
                            self.import_rt = YList()
                            self.import_rt.parent = self
                            self.import_rt.name = 'import_rt'
                            self.l2vpn_router_id = None
                            self.provisioned_ve_id = None
                            self.rd_value = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                            self.rd_value.parent = self
                            self.service_connected = None
                            self.ve_id = None
                            self.ve_range = None
                            self.vpls_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                            self.vpls_id.parent = self
                            self.vpls_id_conflict = None
                            self.vpn_added = None
                            self.vpn_id = None


                        class RdValue(object):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                self.auto.parent = self
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rd = None
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                self.v4_addr.parent = self


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto_index = None
                                    self.router_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto_index is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rd is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue']['meta_info']


                        class VplsId(object):
                            """
                            VPLS ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                self.auto.parent = self
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                self.v4_addr.parent = self
                                self.vpls_id_type = None


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asn = None
                                    self.vpn_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asn is not None:
                                        return True

                                    if self.vpn_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                if self.vpls_id_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId']['meta_info']


                        class ImportRt(object):
                            """
                            List of import route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                self.es_import.parent = self
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rt = None
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                self.v4_addr.parent = self


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                            class EsImport(object):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.high_bytes = None
                                    self.low_bytes = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.high_bytes is not None:
                                        return True

                                    if self.low_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.es_import is not None and self.es_import._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rt is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt']['meta_info']


                        class ExportRt(object):
                            """
                            List of export route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                self.es_import.parent = self
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rt = None
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                self.v4_addr.parent = self


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                            class EsImport(object):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.high_bytes = None
                                    self.low_bytes = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.high_bytes is not None:
                                        return True

                                    if self.low_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.es_import is not None and self.es_import._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rt is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_signalling_method is not None:
                                return True

                            if self.as_number is not None:
                                return True

                            if self.export_route_policy is not None:
                                return True

                            if self.export_rt is not None:
                                for child_ref in self.export_rt:
                                    if child_ref._has_data():
                                        return True

                            if self.import_rt is not None:
                                for child_ref in self.import_rt:
                                    if child_ref._has_data():
                                        return True

                            if self.l2vpn_router_id is not None:
                                return True

                            if self.provisioned_ve_id is not None:
                                return True

                            if self.rd_value is not None and self.rd_value._has_data():
                                return True

                            if self.service_connected is not None:
                                return True

                            if self.ve_id is not None:
                                return True

                            if self.ve_range is not None:
                                return True

                            if self.vpls_id is not None and self.vpls_id._has_data():
                                return True

                            if self.vpls_id_conflict is not None:
                                return True

                            if self.vpn_added is not None:
                                return True

                            if self.vpn_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation']['meta_info']


                    class P2MpInformation(object):
                        """
                        Multicast P2MP information
                        
                        .. attribute:: attribute_set_name
                        
                        	TE Attribute Set Name
                        	**type**\:  str
                        
                        .. attribute:: local_label
                        
                        	P2MP Tunnel Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ptree_id
                        
                        	PTree ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: signaling
                        
                        	P2MP signaling
                        	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                        
                        .. attribute:: transport
                        
                        	P2MP transport
                        	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                        
                        .. attribute:: transport_status
                        
                        	Transport Status
                        	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                        
                        .. attribute:: tunnel_interface
                        
                        	P2MP Tunnel Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.attribute_set_name = None
                            self.local_label = None
                            self.ptree_id = None
                            self.signaling = None
                            self.transport = None
                            self.transport_status = None
                            self.tunnel_interface = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attribute_set_name is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.ptree_id is not None:
                                return True

                            if self.signaling is not None:
                                return True

                            if self.transport is not None:
                                return True

                            if self.transport_status is not None:
                                return True

                            if self.tunnel_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2MpInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-vfi'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.access is not None:
                            return True

                        if self.discovery_information is not None and self.discovery_information._has_data():
                            return True

                        if self.number_pseudowires is not None:
                            return True

                        if self.p2mp_information is not None:
                            for child_ref in self.p2mp_information:
                                if child_ref._has_data():
                                    return True

                        if self.shutdown is not None:
                            return True

                        if self.vfi_name is not None:
                            return True

                        if self.vfi_state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi']['meta_info']


                class BridgeAccessVfi(object):
                    """
                    Access Virtual Forwarding Interfaces
                    
                    .. attribute:: access
                    
                    	VFI is an Access VFI
                    	**type**\:  bool
                    
                    .. attribute:: discovery_information
                    
                    	Auto Discovery information
                    	**type**\:   :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of Pseudowires
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_information
                    
                    	Multicast P2MP information
                    	**type**\: list of    :py:class:`P2MpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: vfi_name
                    
                    	Virtual forwarding instance name
                    	**type**\:  str
                    
                    .. attribute:: vfi_state
                    
                    	VFI state
                    	**type**\:   :py:class:`L2VpnVfiStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiStateEnum>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.access = None
                        self.discovery_information = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                        self.discovery_information.parent = self
                        self.number_pseudowires = None
                        self.p2mp_information = YList()
                        self.p2mp_information.parent = self
                        self.p2mp_information.name = 'p2mp_information'
                        self.shutdown = None
                        self.vfi_name = None
                        self.vfi_state = None


                    class DiscoveryInformation(object):
                        """
                        Auto Discovery information
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling protocol
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: as_number
                        
                        	Autonomous System Number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\:  str
                        
                        .. attribute:: export_rt
                        
                        	List of export route targets
                        	**type**\: list of    :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                        
                        .. attribute:: import_rt
                        
                        	List of import route targets
                        	**type**\: list of    :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                        
                        .. attribute:: l2vpn_router_id
                        
                        	L2PVN Router ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: provisioned_ve_id
                        
                        	Provisioned VPLS edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:   :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                        
                        .. attribute:: service_connected
                        
                        	Is the BGP service connected?
                        	**type**\:  bool
                        
                        .. attribute:: ve_id
                        
                        	VPLS Edge ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ve_range
                        
                        	VE range
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vpls_id
                        
                        	VPLS ID
                        	**type**\:   :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                        
                        .. attribute:: vpls_id_conflict
                        
                        	VPLS\-ID Conflict
                        	**type**\:  bool
                        
                        .. attribute:: vpn_added
                        
                        	Is VPN id configured
                        	**type**\:  bool
                        
                        .. attribute:: vpn_id
                        
                        	Vpn ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ad_method = None
                            self.ad_signalling_method = None
                            self.as_number = None
                            self.export_route_policy = None
                            self.export_rt = YList()
                            self.export_rt.parent = self
                            self.export_rt.name = 'export_rt'
                            self.import_rt = YList()
                            self.import_rt.parent = self
                            self.import_rt.name = 'import_rt'
                            self.l2vpn_router_id = None
                            self.provisioned_ve_id = None
                            self.rd_value = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                            self.rd_value.parent = self
                            self.service_connected = None
                            self.ve_id = None
                            self.ve_range = None
                            self.vpls_id = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                            self.vpls_id.parent = self
                            self.vpls_id_conflict = None
                            self.vpn_added = None
                            self.vpn_id = None


                        class RdValue(object):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:   :py:class:`L2VpnAdRdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRdEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                self.auto.parent = self
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rd = None
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                self.v4_addr.parent = self


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto_index = None
                                    self.router_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto_index is not None:
                                        return True

                                    if self.router_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:rd-value'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rd is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue']['meta_info']


                        class VplsId(object):
                            """
                            VPLS ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.auto = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                self.auto.parent = self
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                self.v4_addr.parent = self
                                self.vpls_id_type = None


                            class Auto(object):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.asn = None
                                    self.vpn_id = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:auto'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.asn is not None:
                                        return True

                                    if self.vpn_id is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto']['meta_info']


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:vpls-id'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.auto is not None and self.auto._has_data():
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                if self.vpls_id_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId']['meta_info']


                        class ImportRt(object):
                            """
                            List of import route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                self.es_import.parent = self
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rt = None
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                self.v4_addr.parent = self


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr']['meta_info']


                            class EsImport(object):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.high_bytes = None
                                    self.low_bytes = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.high_bytes is not None:
                                        return True

                                    if self.low_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:import-rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.es_import is not None and self.es_import._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rt is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt']['meta_info']


                        class ExportRt(object):
                            """
                            List of export route targets
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:   :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:   :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:   :py:class:`L2VpnAdRtEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdRtEnum>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.es_import = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                self.es_import.parent = self
                                self.four_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self.rt = None
                                self.two_byte_as = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self.v4_addr = L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                self.v4_addr.parent = self


                            class TwoByteAs(object):
                                """
                                two byte as
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_index = None
                                    self.two_byte_as = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_index is not None:
                                        return True

                                    if self.two_byte_as is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs']['meta_info']


                            class FourByteAs(object):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.four_byte_as = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:four-byte-as'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.four_byte_as is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs']['meta_info']


                            class V4Addr(object):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.ipv4_address = None
                                    self.two_byte_index = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.ipv4_address is not None:
                                        return True

                                    if self.two_byte_index is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr']['meta_info']


                            class EsImport(object):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.high_bytes = None
                                    self.low_bytes = None

                                @property
                                def _common_path(self):

                                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt/Cisco-IOS-XR-l2vpn-oper:es-import'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.high_bytes is not None:
                                        return True

                                    if self.low_bytes is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport']['meta_info']

                            @property
                            def _common_path(self):

                                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information/Cisco-IOS-XR-l2vpn-oper:export-rt'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.es_import is not None and self.es_import._has_data():
                                    return True

                                if self.four_byte_as is not None and self.four_byte_as._has_data():
                                    return True

                                if self.rt is not None:
                                    return True

                                if self.two_byte_as is not None and self.two_byte_as._has_data():
                                    return True

                                if self.v4_addr is not None and self.v4_addr._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt']['meta_info']

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:discovery-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ad_method is not None:
                                return True

                            if self.ad_signalling_method is not None:
                                return True

                            if self.as_number is not None:
                                return True

                            if self.export_route_policy is not None:
                                return True

                            if self.export_rt is not None:
                                for child_ref in self.export_rt:
                                    if child_ref._has_data():
                                        return True

                            if self.import_rt is not None:
                                for child_ref in self.import_rt:
                                    if child_ref._has_data():
                                        return True

                            if self.l2vpn_router_id is not None:
                                return True

                            if self.provisioned_ve_id is not None:
                                return True

                            if self.rd_value is not None and self.rd_value._has_data():
                                return True

                            if self.service_connected is not None:
                                return True

                            if self.ve_id is not None:
                                return True

                            if self.ve_range is not None:
                                return True

                            if self.vpls_id is not None and self.vpls_id._has_data():
                                return True

                            if self.vpls_id_conflict is not None:
                                return True

                            if self.vpn_added is not None:
                                return True

                            if self.vpn_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation']['meta_info']


                    class P2MpInformation(object):
                        """
                        Multicast P2MP information
                        
                        .. attribute:: attribute_set_name
                        
                        	TE Attribute Set Name
                        	**type**\:  str
                        
                        .. attribute:: local_label
                        
                        	P2MP Tunnel Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ptree_id
                        
                        	PTree ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: signaling
                        
                        	P2MP signaling
                        	**type**\:   :py:class:`L2VpnVfiP2MpSignalingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpSignalingEnum>`
                        
                        .. attribute:: transport
                        
                        	P2MP transport
                        	**type**\:   :py:class:`L2VpnVfiP2MpTransportEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnVfiP2MpTransportEnum>`
                        
                        .. attribute:: transport_status
                        
                        	Transport Status
                        	**type**\:   :py:class:`P2MpTransportStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2MpTransportStateEnum>`
                        
                        .. attribute:: tunnel_interface
                        
                        	P2MP Tunnel Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.attribute_set_name = None
                            self.local_label = None
                            self.ptree_id = None
                            self.signaling = None
                            self.transport = None
                            self.transport_status = None
                            self.tunnel_interface = None

                        @property
                        def _common_path(self):

                            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi/Cisco-IOS-XR-l2vpn-oper:p2mp-information'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.attribute_set_name is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.ptree_id is not None:
                                return True

                            if self.signaling is not None:
                                return True

                            if self.transport is not None:
                                return True

                            if self.transport_status is not None:
                                return True

                            if self.tunnel_interface is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2MpInformation']['meta_info']

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info/Cisco-IOS-XR-l2vpn-oper:bridge-access-vfi'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.access is not None:
                            return True

                        if self.discovery_information is not None and self.discovery_information._has_data():
                            return True

                        if self.number_pseudowires is not None:
                            return True

                        if self.p2mp_information is not None:
                            for child_ref in self.p2mp_information:
                                if child_ref._has_data():
                                    return True

                        if self.shutdown is not None:
                            return True

                        if self.vfi_name is not None:
                            return True

                        if self.vfi_state is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain/Cisco-IOS-XR-l2vpn-oper:bridge-domain-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.acpwup is not None:
                        return True

                    if self.as_ is not None:
                        return True

                    if self.bridge_access_vfi is not None:
                        for child_ref in self.bridge_access_vfi:
                            if child_ref._has_data():
                                return True

                    if self.bridge_coupled_state is not None:
                        return True

                    if self.bridge_description is not None:
                        return True

                    if self.bridge_domain_id is not None:
                        return True

                    if self.bridge_internal_msti is not None:
                        return True

                    if self.bridge_msti is not None:
                        return True

                    if self.bridge_mtu is not None:
                        return True

                    if self.bridge_name is not None:
                        return True

                    if self.bridge_shg_id is not None:
                        return True

                    if self.bridge_state is not None:
                        return True

                    if self.bridge_type is not None:
                        return True

                    if self.bridge_vfi is not None:
                        for child_ref in self.bridge_vfi:
                            if child_ref._has_data():
                                return True

                    if self.configured is not None:
                        return True

                    if self.disposition_bytecount is not None:
                        return True

                    if self.disposition_pkt_count is not None:
                        return True

                    if self.evi is not None:
                        return True

                    if self.evpn_parameters is not None and self.evpn_parameters._has_data():
                        return True

                    if self.flodd_group_id_down is not None:
                        return True

                    if self.group_name is not None:
                        return True

                    if self.imposition_byte_count is not None:
                        return True

                    if self.imposition_pkt_count is not None:
                        return True

                    if self.is_bridge_partially_programmed is not None:
                        return True

                    if self.is_rd_configured is not None:
                        return True

                    if self.last_time_status_changed is not None:
                        return True

                    if self.load_balance is not None:
                        return True

                    if self.mac_filter is not None:
                        for child_ref in self.mac_filter:
                            if child_ref._has_data():
                                return True

                    if self.mac_limit_down is not None:
                        return True

                    if self.mac_withdraw is not None:
                        return True

                    if self.mac_withdraw_access is not None:
                        return True

                    if self.mac_withdraw_option is not None:
                        return True

                    if self.mac_withdraw_relay is not None:
                        return True

                    if self.num_vn_is is not None:
                        return True

                    if self.num_vn_is_up is not None:
                        return True

                    if self.number_a_cs is not None:
                        return True

                    if self.number_a_cs_up is not None:
                        return True

                    if self.number_access_vf_is is not None:
                        return True

                    if self.number_p_ws_up is not None:
                        return True

                    if self.number_pb_bs is not None:
                        return True

                    if self.number_pb_bs_up is not None:
                        return True

                    if self.number_pseudowires is not None:
                        return True

                    if self.number_vf_is is not None:
                        return True

                    if self.nv_satellite_offload_ipv4_multicast_disabled is not None:
                        return True

                    if self.p2mp_enabled is not None:
                        return True

                    if self.partially_programmed_a_cs is not None:
                        return True

                    if self.partially_programmed_pseudowires is not None:
                        return True

                    if self.pbb_parameters is not None and self.pbb_parameters._has_data():
                        return True

                    if self.rd is not None and self.rd._has_data():
                        return True

                    if self.security_parameters is not None and self.security_parameters._has_data():
                        return True

                    if self.shutdown is not None:
                        return True

                    if self.standby_pseudowires is not None:
                        return True

                    if self.time_created is not None:
                        return True

                    if self.time_elapsed_creation is not None:
                        return True

                    if self.time_elapsed_status_changed is not None:
                        return True

                    if self.vine_fsm_state is not None:
                        return True

                    if self.vni_parameters is not None and self.vni_parameters._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain.BridgeDomainInfo']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains/Cisco-IOS-XR-l2vpn-oper:bridge-domain'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.bridge_access_pws is not None and self.bridge_access_pws._has_data():
                    return True

                if self.bridge_access_vfi_table is not None and self.bridge_access_vfi_table._has_data():
                    return True

                if self.bridge_acs is not None and self.bridge_acs._has_data():
                    return True

                if self.bridge_core_vfi_table is not None and self.bridge_core_vfi_table._has_data():
                    return True

                if self.bridge_domain_group_name is not None:
                    return True

                if self.bridge_domain_info is not None and self.bridge_domain_info._has_data():
                    return True

                if self.bridge_domain_name is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.BridgeDomains.BridgeDomain']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:bridge-domains'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.bridge_domain is not None:
                for child_ref in self.bridge_domain:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.BridgeDomains']['meta_info']


    class DiscoverySummary(object):
        """
        Discovery summary information
        
        .. attribute:: bgp_current_node_id
        
        	BGP current node id
        	**type**\:  str
        
        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
        
        .. attribute:: bgp_ipc_transport_mode
        
        	IPC Transport mode with BGP
        	**type**\:   :py:class:`L2VpnIpcTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnIpcTransportModeEnum>`
        
        .. attribute:: bgp_stateon_active_rp
        
        	BGP state on the active RP
        	**type**\:  bool
        
        .. attribute:: bgp_stateon_standby_rp
        
        	BGP state on standby RP
        	**type**\:  bool
        
        .. attribute:: number_bridge_domainvpns
        
        	Number of BDs registered
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_local_edges_bridge_domain
        
        	Number of local Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_local_edges_xconnect
        
        	Number of local Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_mp2m_pxconnect_vpns
        
        	Number of XCs registered
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_nlri_bridge_domain
        
        	Number of NLRI
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_nlri_xconnect
        
        	Number of NLRI
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_remote_edges_bridge_domain
        
        	Number of Remote Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: number_remote_edges_xconnect
        
        	Number of Remote Edges
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: vpls_registered
        
        	Is the VPLS service registered
        	**type**\:  bool
        
        .. attribute:: vpws_registered
        
        	Is the VPWS service registered
        	**type**\:  bool
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.bgp_current_node_id = None
            self.bgp_ipc_transport_mode = None
            self.bgp_stateon_active_rp = None
            self.bgp_stateon_standby_rp = None
            self.number_bridge_domainvpns = None
            self.number_local_edges_bridge_domain = None
            self.number_local_edges_xconnect = None
            self.number_mp2m_pxconnect_vpns = None
            self.number_nlri_bridge_domain = None
            self.number_nlri_xconnect = None
            self.number_remote_edges_bridge_domain = None
            self.number_remote_edges_xconnect = None
            self.vpls_registered = None
            self.vpws_registered = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:discovery-summary'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.bgp_current_node_id is not None:
                return True

            if self.bgp_ipc_transport_mode is not None:
                return True

            if self.bgp_stateon_active_rp is not None:
                return True

            if self.bgp_stateon_standby_rp is not None:
                return True

            if self.number_bridge_domainvpns is not None:
                return True

            if self.number_local_edges_bridge_domain is not None:
                return True

            if self.number_local_edges_xconnect is not None:
                return True

            if self.number_mp2m_pxconnect_vpns is not None:
                return True

            if self.number_nlri_bridge_domain is not None:
                return True

            if self.number_nlri_xconnect is not None:
                return True

            if self.number_remote_edges_bridge_domain is not None:
                return True

            if self.number_remote_edges_xconnect is not None:
                return True

            if self.vpls_registered is not None:
                return True

            if self.vpws_registered is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.DiscoverySummary']['meta_info']


    class G8032(object):
        """
        G8032 information
        
        .. attribute:: g8032_rings
        
        	G8032 Ring table
        	**type**\:   :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.g8032_rings = L2Vpn.G8032.G8032Rings()
            self.g8032_rings.parent = self


        class G8032Rings(object):
            """
            G8032 Ring table
            
            .. attribute:: g8032_ring
            
            	G8032 Ring
            	**type**\: list of    :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.g8032_ring = YList()
                self.g8032_ring.parent = self
                self.g8032_ring.name = 'g8032_ring'


            class G8032Ring(object):
                """
                G8032 Ring
                
                .. attribute:: ring_name  <key>
                
                	Ring Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: g8032_ring_detail
                
                	G8032 Ring detailed information
                	**type**\:   :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                
                .. attribute:: g8032_ring_instance_details
                
                	G8032 Ring Instance detail table
                	**type**\:   :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                
                .. attribute:: g8032_ring_instance_summaries
                
                	G8032 Ring Instance summary table
                	**type**\:   :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                
                .. attribute:: g8032_ring_summary
                
                	G8032 Ring summary information
                	**type**\:   :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ring_name = None
                    self.g8032_ring_detail = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                    self.g8032_ring_detail.parent = self
                    self.g8032_ring_instance_details = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                    self.g8032_ring_instance_details.parent = self
                    self.g8032_ring_instance_summaries = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                    self.g8032_ring_instance_summaries.parent = self
                    self.g8032_ring_summary = L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                    self.g8032_ring_summary.parent = self


                class G8032RingDetail(object):
                    """
                    G8032 Ring detailed information
                    
                    .. attribute:: excluded_vlan_id
                    
                    	Exclusion Vlan ids list 
                    	**type**\:  list of int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: is_open_ring
                    
                    	Flag open ring
                    	**type**\:  bool
                    
                    .. attribute:: is_provider_bridge
                    
                    	Operating mode Customer/Provider 
                    	**type**\:  bool
                    
                    .. attribute:: monitor0
                    
                    	Monitor port 0
                    	**type**\:  str
                    
                    .. attribute:: monitor1
                    
                    	Monitor port 1
                    	**type**\:  str
                    
                    .. attribute:: port0
                    
                    	Port 0
                    	**type**\:  str
                    
                    .. attribute:: port1
                    
                    	Port 1
                    	**type**\:  str
                    
                    .. attribute:: ring_name
                    
                    	Name of the ring
                    	**type**\:  str
                    
                    .. attribute:: tcn_propagation
                    
                    	Global TCN propagation
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.excluded_vlan_id = YLeafList()
                        self.excluded_vlan_id.parent = self
                        self.excluded_vlan_id.name = 'excluded_vlan_id'
                        self.is_open_ring = None
                        self.is_provider_bridge = None
                        self.monitor0 = None
                        self.monitor1 = None
                        self.port0 = None
                        self.port1 = None
                        self.ring_name = None
                        self.tcn_propagation = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-detail'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.excluded_vlan_id is not None:
                            for child in self.excluded_vlan_id:
                                if child is not None:
                                    return True

                        if self.is_open_ring is not None:
                            return True

                        if self.is_provider_bridge is not None:
                            return True

                        if self.monitor0 is not None:
                            return True

                        if self.monitor1 is not None:
                            return True

                        if self.port0 is not None:
                            return True

                        if self.port1 is not None:
                            return True

                        if self.ring_name is not None:
                            return True

                        if self.tcn_propagation is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingDetail']['meta_info']


                class G8032RingInstanceSummaries(object):
                    """
                    G8032 Ring Instance summary table
                    
                    .. attribute:: g8032_ring_instance_summary
                    
                    	G8032 Ring Instance summary information
                    	**type**\: list of    :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.g8032_ring_instance_summary = YList()
                        self.g8032_ring_instance_summary.parent = self
                        self.g8032_ring_instance_summary.name = 'g8032_ring_instance_summary'


                    class G8032RingInstanceSummary(object):
                        """
                        G8032 Ring Instance summary information
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: aps_port0
                        
                        	Port 0 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: aps_port1
                        
                        	Port 1 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: config_state
                        
                        	State of the instance
                        	**type**\:  bool
                        
                        .. attribute:: included_vlan_id
                        
                        	Inclusion list Vlan Ids
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ring_instance
                        
                        	Ring instance number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance = None
                            self.aps_port0 = None
                            self.aps_port1 = None
                            self.config_state = None
                            self.included_vlan_id = YLeafList()
                            self.included_vlan_id.parent = self
                            self.included_vlan_id.name = 'included_vlan_id'
                            self.ring_instance = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.instance is None:
                                raise YPYModelError('Key property instance is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summary[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance is not None:
                                return True

                            if self.aps_port0 is not None:
                                return True

                            if self.aps_port1 is not None:
                                return True

                            if self.config_state is not None:
                                return True

                            if self.included_vlan_id is not None:
                                for child in self.included_vlan_id:
                                    if child is not None:
                                        return True

                            if self.ring_instance is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-summaries'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.g8032_ring_instance_summary is not None:
                            for child_ref in self.g8032_ring_instance_summary:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries']['meta_info']


                class G8032RingSummary(object):
                    """
                    G8032 Ring summary information
                    
                    .. attribute:: port0
                    
                    	Port 0
                    	**type**\:  str
                    
                    .. attribute:: port1
                    
                    	Port 1
                    	**type**\:  str
                    
                    .. attribute:: ring_name
                    
                    	Name of the ring
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.port0 = None
                        self.port1 = None
                        self.ring_name = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-summary'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.port0 is not None:
                            return True

                        if self.port1 is not None:
                            return True

                        if self.ring_name is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingSummary']['meta_info']


                class G8032RingInstanceDetails(object):
                    """
                    G8032 Ring Instance detail table
                    
                    .. attribute:: g8032_ring_instance_detail
                    
                    	G8032 Ring Instance detailed information
                    	**type**\: list of    :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.g8032_ring_instance_detail = YList()
                        self.g8032_ring_instance_detail.parent = self
                        self.g8032_ring_instance_detail.name = 'g8032_ring_instance_detail'


                    class G8032RingInstanceDetail(object):
                        """
                        G8032 Ring Instance detailed information
                        
                        .. attribute:: instance  <key>
                        
                        	Instance
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: aps_channel_level
                        
                        	APS channel level
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: aps_port0
                        
                        	Port 0 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: aps_port1
                        
                        	Port 1 of aps\-channel
                        	**type**\:  str
                        
                        .. attribute:: config_state
                        
                        	State of the instance
                        	**type**\:  bool
                        
                        .. attribute:: included_vlan_id
                        
                        	Inclusion list Vlan Ids
                        	**type**\:  list of int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ring_description
                        
                        	Ring description
                        	**type**\:  str
                        
                        .. attribute:: ring_instance
                        
                        	Ring instance number
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ring_profile
                        
                        	Ring Profile
                        	**type**\:  str
                        
                        .. attribute:: rpl
                        
                        	RPL
                        	**type**\:   :py:class:`L2VpnG8032RplEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032RplEnum>`
                        
                        .. attribute:: unresolved_reason
                        
                        	Reason of unresolved state state
                        	**type**\:   :py:class:`L2VpnG8032UncfgReasonEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnG8032UncfgReasonEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.instance = None
                            self.aps_channel_level = None
                            self.aps_port0 = None
                            self.aps_port1 = None
                            self.config_state = None
                            self.included_vlan_id = YLeafList()
                            self.included_vlan_id.parent = self
                            self.included_vlan_id.name = 'included_vlan_id'
                            self.ring_description = None
                            self.ring_instance = None
                            self.ring_profile = None
                            self.rpl = None
                            self.unresolved_reason = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.instance is None:
                                raise YPYModelError('Key property instance is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-detail[Cisco-IOS-XR-l2vpn-oper:instance = ' + str(self.instance) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.instance is not None:
                                return True

                            if self.aps_channel_level is not None:
                                return True

                            if self.aps_port0 is not None:
                                return True

                            if self.aps_port1 is not None:
                                return True

                            if self.config_state is not None:
                                return True

                            if self.included_vlan_id is not None:
                                for child in self.included_vlan_id:
                                    if child is not None:
                                        return True

                            if self.ring_description is not None:
                                return True

                            if self.ring_instance is not None:
                                return True

                            if self.ring_profile is not None:
                                return True

                            if self.rpl is not None:
                                return True

                            if self.unresolved_reason is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:g8032-ring-instance-details'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.g8032_ring_instance_detail is not None:
                            for child_ref in self.g8032_ring_instance_detail:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails']['meta_info']

                @property
                def _common_path(self):
                    if self.ring_name is None:
                        raise YPYModelError('Key property ring_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:g8032/Cisco-IOS-XR-l2vpn-oper:g8032-rings/Cisco-IOS-XR-l2vpn-oper:g8032-ring[Cisco-IOS-XR-l2vpn-oper:ring-name = ' + str(self.ring_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ring_name is not None:
                        return True

                    if self.g8032_ring_detail is not None and self.g8032_ring_detail._has_data():
                        return True

                    if self.g8032_ring_instance_details is not None and self.g8032_ring_instance_details._has_data():
                        return True

                    if self.g8032_ring_instance_summaries is not None and self.g8032_ring_instance_summaries._has_data():
                        return True

                    if self.g8032_ring_summary is not None and self.g8032_ring_summary._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.G8032.G8032Rings.G8032Ring']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:g8032/Cisco-IOS-XR-l2vpn-oper:g8032-rings'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.g8032_ring is not None:
                    for child_ref in self.g8032_ring:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.G8032.G8032Rings']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:g8032'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.g8032_rings is not None and self.g8032_rings._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.G8032']['meta_info']


    class PseudowireClasses(object):
        """
        List of pseudowire classes
        
        .. attribute:: pseudowire_class
        
        	Pseudowire class information
        	**type**\: list of    :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.pseudowire_class = YList()
            self.pseudowire_class.parent = self
            self.pseudowire_class.name = 'pseudowire_class'


        class PseudowireClass(object):
            """
            Pseudowire class information
            
            .. attribute:: pseudowire_class_name  <key>
            
            	Pseudowire Class Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: backup_mac_withdraw
            
            	TRUE if MAC withdraw message is sent
            	**type**\:  bool
            
            .. attribute:: control_word
            
            	Control word
            	**type**\:   :py:class:`L2VpnPwClassControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwClassControlWordEnum>`
            
            .. attribute:: disable_delay
            
            	Disable Deley
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: disable_never
            
            	TRUE if backup is not automatically disabled
            	**type**\:  bool
            
            .. attribute:: encapsulation_info
            
            	Encapsulation specific pseudowire information
            	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
            
            .. attribute:: is_flow_label_static
            
            	is flow label static
            	**type**\:  bool
            
            .. attribute:: load_balance
            
            	Load Balance Type
            	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
            
            .. attribute:: local_source_address
            
            	Local source address
            	**type**\:   :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
            
            .. attribute:: preferred_path
            
            	MPLS Preferred Path
            	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath>`
            
            .. attribute:: preferred_path_disable_fallback
            
            	PreferredPathDisableFallback
            	**type**\:  bool
            
            .. attribute:: protocol
            
            	Protocol
            	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
            
            .. attribute:: pw_class_name
            
            	Pseudowire class name
            	**type**\:  str
            
            	**length:** 0..33
            
            .. attribute:: pw_flow_label_code17_disabled
            
            	Disable sending Code 17 TLV
            	**type**\:  bool
            
            .. attribute:: pw_flow_label_type_cfg
            
            	Configured pseudowire flow label type
            	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
            
            .. attribute:: resync_enabled
            
            	Resync if packets out of sequence
            	**type**\:  bool
            
            .. attribute:: resync_threshold
            
            	Number of Packets Out of Seqence to trigger resync
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sequencing_type
            
            	Sequencing Type
            	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
            
            .. attribute:: tag_rewrite
            
            	Static tag rewrite
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: transport_mode
            
            	Transport mode
            	**type**\:   :py:class:`L2VpnTransportModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTransportModeEnum>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.pseudowire_class_name = None
                self.backup_mac_withdraw = None
                self.control_word = None
                self.disable_delay = None
                self.disable_never = None
                self.encapsulation_info = L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                self.encapsulation_info.parent = self
                self.is_flow_label_static = None
                self.load_balance = None
                self.local_source_address = L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                self.local_source_address.parent = self
                self.preferred_path = L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath()
                self.preferred_path.parent = self
                self.preferred_path_disable_fallback = None
                self.protocol = None
                self.pw_class_name = None
                self.pw_flow_label_code17_disabled = None
                self.pw_flow_label_type_cfg = None
                self.resync_enabled = None
                self.resync_threshold = None
                self.sequencing_type = None
                self.tag_rewrite = None
                self.transport_mode = None


            class EncapsulationInfo(object):
                """
                Encapsulation specific pseudowire information
                
                .. attribute:: encapsulation
                
                	Encapsulation
                	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                
                .. attribute:: l2tpv3
                
                	l2tpv3
                	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.encapsulation = None
                    self.l2tpv3 = L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3()
                    self.l2tpv3.parent = self


                class L2Tpv3(object):
                    """
                    l2tpv3
                    
                    .. attribute:: cookie_size
                    
                    	Cookie size\: 0, 4, or 8 bytes
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dont_fragment_bit
                    
                    	Don't Fragment Bit
                    	**type**\:  bool
                    
                    .. attribute:: ipv4_source_address
                    
                    	IPv4 source address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: l2tp_class_name
                    
                    	L2TPClassName
                    	**type**\:  str
                    
                    	**length:** 0..32
                    
                    .. attribute:: path_mtu_enabled
                    
                    	Path MTU enabled
                    	**type**\:  bool
                    
                    .. attribute:: path_mtu_max_value
                    
                    	Path MTU Maximum allowable session MTU
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: tos
                    
                    	Type Of Service Value
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: tos_mode
                    
                    	Type Of Service Mode
                    	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                    
                    .. attribute:: ttl
                    
                    	Time To Live value
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.cookie_size = None
                        self.dont_fragment_bit = None
                        self.ipv4_source_address = None
                        self.l2tp_class_name = None
                        self.path_mtu_enabled = None
                        self.path_mtu_max_value = None
                        self.tos = None
                        self.tos_mode = None
                        self.ttl = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.cookie_size is not None:
                            return True

                        if self.dont_fragment_bit is not None:
                            return True

                        if self.ipv4_source_address is not None:
                            return True

                        if self.l2tp_class_name is not None:
                            return True

                        if self.path_mtu_enabled is not None:
                            return True

                        if self.path_mtu_max_value is not None:
                            return True

                        if self.tos is not None:
                            return True

                        if self.tos_mode is not None:
                            return True

                        if self.ttl is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2Tpv3']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.encapsulation is not None:
                        return True

                    if self.l2tpv3 is not None and self.l2tpv3._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.PseudowireClasses.PseudowireClass.EncapsulationInfo']['meta_info']


            class PreferredPath(object):
                """
                MPLS Preferred Path
                
                .. attribute:: ip_tunnel_interface_number
                
                	IPTunnelInterfaceNumber
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: next_hop_ip
                
                	NextHopIP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: option
                
                	Option
                	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                
                .. attribute:: te_tunnel_interface_number
                
                	TETunnelInterfaceNumber
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tp_tunnel_interface_number
                
                	TPTunnelInterfaceNumber
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ip_tunnel_interface_number = None
                    self.next_hop_ip = None
                    self.option = None
                    self.te_tunnel_interface_number = None
                    self.tp_tunnel_interface_number = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ip_tunnel_interface_number is not None:
                        return True

                    if self.next_hop_ip is not None:
                        return True

                    if self.option is not None:
                        return True

                    if self.te_tunnel_interface_number is not None:
                        return True

                    if self.tp_tunnel_interface_number is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.PseudowireClasses.PseudowireClass.PreferredPath']['meta_info']


            class LocalSourceAddress(object):
                """
                Local source address
                
                .. attribute:: address
                
                	Local source address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: configuration
                
                	Configuration
                	**type**\:   :py:class:`L2VpnSrcAddressSetEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSrcAddressSetEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.address = None
                    self.configuration = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-source-address'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.address is not None:
                        return True

                    if self.configuration is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.PseudowireClasses.PseudowireClass.LocalSourceAddress']['meta_info']

            @property
            def _common_path(self):
                if self.pseudowire_class_name is None:
                    raise YPYModelError('Key property pseudowire_class_name is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes/Cisco-IOS-XR-l2vpn-oper:pseudowire-class[Cisco-IOS-XR-l2vpn-oper:pseudowire-class-name = ' + str(self.pseudowire_class_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.pseudowire_class_name is not None:
                    return True

                if self.backup_mac_withdraw is not None:
                    return True

                if self.control_word is not None:
                    return True

                if self.disable_delay is not None:
                    return True

                if self.disable_never is not None:
                    return True

                if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                    return True

                if self.is_flow_label_static is not None:
                    return True

                if self.load_balance is not None:
                    return True

                if self.local_source_address is not None and self.local_source_address._has_data():
                    return True

                if self.preferred_path is not None and self.preferred_path._has_data():
                    return True

                if self.preferred_path_disable_fallback is not None:
                    return True

                if self.protocol is not None:
                    return True

                if self.pw_class_name is not None:
                    return True

                if self.pw_flow_label_code17_disabled is not None:
                    return True

                if self.pw_flow_label_type_cfg is not None:
                    return True

                if self.resync_enabled is not None:
                    return True

                if self.resync_threshold is not None:
                    return True

                if self.sequencing_type is not None:
                    return True

                if self.tag_rewrite is not None:
                    return True

                if self.transport_mode is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.PseudowireClasses.PseudowireClass']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:pseudowire-classes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.pseudowire_class is not None:
                for child_ref in self.pseudowire_class:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.PseudowireClasses']['meta_info']


    class L2VpnCollaborators(object):
        """
        L2VPN collaborator information
        
        .. attribute:: collaborator_statistics
        
        	Collaborator Statistics
        	**type**\:   :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnCollaborators.CollaboratorStatistics>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.collaborator_statistics = L2Vpn.L2VpnCollaborators.CollaboratorStatistics()
            self.collaborator_statistics.parent = self


        class CollaboratorStatistics(object):
            """
            Collaborator Statistics
            
            .. attribute:: count
            
            	count
            	**type**\: list of    :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.count = YList()
                self.count.parent = self
                self.count.name = 'count'


            class Count(object):
                """
                count
                
                .. attribute:: collaborator_name
                
                	Collaborator Name
                	**type**\:  str
                
                .. attribute:: down
                
                	Down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_up
                
                	Is up
                	**type**\:  bool
                
                .. attribute:: up
                
                	Up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.collaborator_name = None
                    self.down = None
                    self.is_up = None
                    self.up = None

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics/Cisco-IOS-XR-l2vpn-oper:count'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.collaborator_name is not None:
                        return True

                    if self.down is not None:
                        return True

                    if self.is_up is not None:
                        return True

                    if self.up is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.L2VpnCollaborators.CollaboratorStatistics.Count']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators/Cisco-IOS-XR-l2vpn-oper:collaborator-statistics'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.count is not None:
                    for child_ref in self.count:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.L2VpnCollaborators.CollaboratorStatistics']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:l2vpn-collaborators'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.collaborator_statistics is not None and self.collaborator_statistics._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.L2VpnCollaborators']['meta_info']


    class Mvrp(object):
        """
        MVRP
        
        .. attribute:: mvrp_main_ports
        
        	MVRP Main Port Table
        	**type**\:   :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.mvrp_main_ports = L2Vpn.Mvrp.MvrpMainPorts()
            self.mvrp_main_ports.parent = self


        class MvrpMainPorts(object):
            """
            MVRP Main Port Table
            
            .. attribute:: mvrp_main_port
            
            	MVRP Main Port
            	**type**\: list of    :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.mvrp_main_port = YList()
                self.mvrp_main_port.parent = self
                self.mvrp_main_port.name = 'mvrp_main_port'


            class MvrpMainPort(object):
                """
                MVRP Main Port
                
                .. attribute:: main_port_interface_name  <key>
                
                	Main Port interface
                	**type**\:  str
                
                	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                
                .. attribute:: mvrp_bridge_ports
                
                	MVRP Bridge Port Table
                	**type**\:   :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                
                .. attribute:: mvrp_main_port_info
                
                	MVRP Main Port Information
                	**type**\:   :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.main_port_interface_name = None
                    self.mvrp_bridge_ports = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                    self.mvrp_bridge_ports.parent = self
                    self.mvrp_main_port_info = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                    self.mvrp_main_port_info.parent = self


                class MvrpMainPortInfo(object):
                    """
                    MVRP Main Port Information
                    
                    .. attribute:: default_bridge_port
                    
                    	Trunk or default Bridge Port
                    	**type**\:   :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                    
                    .. attribute:: is_default_encap
                    
                    	Is default encap set
                    	**type**\:  bool
                    
                    .. attribute:: is_trunk
                    
                    	Is main port a trunk
                    	**type**\:  bool
                    
                    .. attribute:: main_port_interface_name
                    
                    	Main Port Interface name
                    	**type**\:  str
                    
                    .. attribute:: number_of_bridge_ports
                    
                    	Number of Bridge Ports
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.default_bridge_port = L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                        self.default_bridge_port.parent = self
                        self.is_default_encap = None
                        self.is_trunk = None
                        self.main_port_interface_name = None
                        self.number_of_bridge_ports = None


                    class DefaultBridgePort(object):
                        """
                        Trunk or default Bridge Port
                        
                        .. attribute:: bridge_port_interface_name
                        
                        	Bridge port Interface name
                        	**type**\:  str
                        
                        .. attribute:: bridge_port_xconnect_id
                        
                        	Bridge port XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mvrp_sequence_number
                        
                        	MVRP Sequence Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan_range
                        
                        	VLAN IDs
                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bridge_port_interface_name = None
                            self.bridge_port_xconnect_id = None
                            self.mvrp_sequence_number = None
                            self.vlan_range = YList()
                            self.vlan_range.parent = self
                            self.vlan_range.name = 'vlan_range'


                        class VlanRange(object):
                            """
                            VLAN IDs
                            
                            .. attribute:: lower
                            
                            	Lower
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: upper
                            
                            	Upper
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lower = None
                                self.upper = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lower is not None:
                                    return True

                                if self.upper is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:default-bridge-port'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bridge_port_interface_name is not None:
                                return True

                            if self.bridge_port_xconnect_id is not None:
                                return True

                            if self.mvrp_sequence_number is not None:
                                return True

                            if self.vlan_range is not None:
                                for child_ref in self.vlan_range:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port-info'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.default_bridge_port is not None and self.default_bridge_port._has_data():
                            return True

                        if self.is_default_encap is not None:
                            return True

                        if self.is_trunk is not None:
                            return True

                        if self.main_port_interface_name is not None:
                            return True

                        if self.number_of_bridge_ports is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo']['meta_info']


                class MvrpBridgePorts(object):
                    """
                    MVRP Bridge Port Table
                    
                    .. attribute:: mvrp_bridge_port
                    
                    	MVRP Bridge Port Information
                    	**type**\: list of    :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.mvrp_bridge_port = YList()
                        self.mvrp_bridge_port.parent = self
                        self.mvrp_bridge_port.name = 'mvrp_bridge_port'


                    class MvrpBridgePort(object):
                        """
                        MVRP Bridge Port Information
                        
                        .. attribute:: interface_name  <key>
                        
                        	Bridge Port Interface Name
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: bridge_port_interface_name
                        
                        	Bridge port Interface name
                        	**type**\:  str
                        
                        .. attribute:: bridge_port_xconnect_id
                        
                        	Bridge port XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mvrp_sequence_number
                        
                        	MVRP Sequence Number
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: vlan_range
                        
                        	VLAN IDs
                        	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.bridge_port_interface_name = None
                            self.bridge_port_xconnect_id = None
                            self.mvrp_sequence_number = None
                            self.vlan_range = YList()
                            self.vlan_range.parent = self
                            self.vlan_range.name = 'vlan_range'


                        class VlanRange(object):
                            """
                            VLAN IDs
                            
                            .. attribute:: lower
                            
                            	Lower
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: upper
                            
                            	Upper
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.lower = None
                                self.upper = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.lower is not None:
                                    return True

                                if self.upper is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')
                            if self.interface_name is None:
                                raise YPYModelError('Key property interface_name is None')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-port[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.bridge_port_interface_name is not None:
                                return True

                            if self.bridge_port_xconnect_id is not None:
                                return True

                            if self.mvrp_sequence_number is not None:
                                return True

                            if self.vlan_range is not None:
                                for child_ref in self.vlan_range:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mvrp-bridge-ports'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.mvrp_bridge_port is not None:
                            for child_ref in self.mvrp_bridge_port:
                                if child_ref._has_data():
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts']['meta_info']

                @property
                def _common_path(self):
                    if self.main_port_interface_name is None:
                        raise YPYModelError('Key property main_port_interface_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mvrp/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports/Cisco-IOS-XR-l2vpn-oper:mvrp-main-port[Cisco-IOS-XR-l2vpn-oper:main-port-interface-name = ' + str(self.main_port_interface_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.main_port_interface_name is not None:
                        return True

                    if self.mvrp_bridge_ports is not None and self.mvrp_bridge_ports._has_data():
                        return True

                    if self.mvrp_main_port_info is not None and self.mvrp_main_port_info._has_data():
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts.MvrpMainPort']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mvrp/Cisco-IOS-XR-l2vpn-oper:mvrp-main-ports'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.mvrp_main_port is not None:
                    for child_ref in self.mvrp_main_port:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.Mvrp.MvrpMainPorts']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mvrp'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.mvrp_main_ports is not None and self.mvrp_main_ports._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.Mvrp']['meta_info']


    class GenericInterfaces(object):
        """
        L2VPN generic interface list Table
        
        .. attribute:: generic_interface
        
        	Generic Interface List information
        	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaces.GenericInterface>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.generic_interface = YList()
            self.generic_interface.parent = self
            self.generic_interface.name = 'generic_interface'


        class GenericInterface(object):
            """
            Generic Interface List information
            
            .. attribute:: interface_list_name  <key>
            
            	Generic Interface List Name
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: interface
            
            	Interfaces
            	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.GenericInterfaces.GenericInterface.Interface>`
            
            .. attribute:: interface_list_id
            
            	Interface internal ID
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_list_name_xr
            
            	Interface\-list name
            	**type**\:  str
            
            	**length:** 0..33
            
            .. attribute:: items
            
            	Number of items
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_of_interfaces
            
            	Number of interfaces
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.interface_list_name = None
                self.interface = YList()
                self.interface.parent = self
                self.interface.name = 'interface'
                self.interface_list_id = None
                self.interface_list_name_xr = None
                self.items = None
                self.number_of_interfaces = None


            class Interface(object):
                """
                Interfaces
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                .. attribute:: is_fib_downloaded
                
                	Is interface downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: not_supported_replications
                
                	Number of replications failed because unsupported
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: pending_replications
                
                	Number of pending replications
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_name = None
                    self.is_fib_downloaded = None
                    self.not_supported_replications = None
                    self.pending_replications = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_name is not None:
                        return True

                    if self.is_fib_downloaded is not None:
                        return True

                    if self.not_supported_replications is not None:
                        return True

                    if self.pending_replications is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.GenericInterfaces.GenericInterface.Interface']['meta_info']

            @property
            def _common_path(self):
                if self.interface_list_name is None:
                    raise YPYModelError('Key property interface_list_name is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:generic-interfaces/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:interface-list-name = ' + str(self.interface_list_name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.interface_list_name is not None:
                    return True

                if self.interface is not None:
                    for child_ref in self.interface:
                        if child_ref._has_data():
                            return True

                if self.interface_list_id is not None:
                    return True

                if self.interface_list_name_xr is not None:
                    return True

                if self.items is not None:
                    return True

                if self.number_of_interfaces is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.GenericInterfaces.GenericInterface']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.generic_interface is not None:
                for child_ref in self.generic_interface:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.GenericInterfaces']['meta_info']


    class MstpVlans(object):
        """
        L2VPN MSTP VLAN Table
        
        .. attribute:: mstp_vlan
        
        	L2VPN MSTP VLAN information
        	**type**\: list of    :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpVlans.MstpVlan>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.mstp_vlan = YList()
            self.mstp_vlan.parent = self
            self.mstp_vlan.name = 'mstp_vlan'


        class MstpVlan(object):
            """
            L2VPN MSTP VLAN information
            
            .. attribute:: vlan_id  <key>
            
            	vlan id
            	**type**\:  int
            
            	**range:** 0..4098
            
            .. attribute:: msti_id
            
            	MSTI id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: port_count
            
            	Port Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sub_interface
            
            	Sub interfaces
            	**type**\: list of    :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.MstpVlans.MstpVlan.SubInterface>`
            
            .. attribute:: vlan_id_xr
            
            	Vlan id
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.vlan_id = None
                self.msti_id = None
                self.port_count = None
                self.sub_interface = YList()
                self.sub_interface.parent = self
                self.sub_interface.name = 'sub_interface'
                self.vlan_id_xr = None


            class SubInterface(object):
                """
                Sub interfaces
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\:  str
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.interface_name = None

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sub-interface'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.interface_name is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.MstpVlans.MstpVlan.SubInterface']['meta_info']

            @property
            def _common_path(self):
                if self.vlan_id is None:
                    raise YPYModelError('Key property vlan_id is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mstp-vlans/Cisco-IOS-XR-l2vpn-oper:mstp-vlan[Cisco-IOS-XR-l2vpn-oper:vlan-id = ' + str(self.vlan_id) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.vlan_id is not None:
                    return True

                if self.msti_id is not None:
                    return True

                if self.port_count is not None:
                    return True

                if self.sub_interface is not None:
                    for child_ref in self.sub_interface:
                        if child_ref._has_data():
                            return True

                if self.vlan_id_xr is not None:
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.MstpVlans.MstpVlan']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:mstp-vlans'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.mstp_vlan is not None:
                for child_ref in self.mstp_vlan:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.MstpVlans']['meta_info']


    class L2VpnPbbBsa(object):
        """
        L2VPN PBB Backbone Source MAC information
        
        .. attribute:: bmac_sa
        
        	BMAC SA
        	**type**\:  str
        
        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
        
        .. attribute:: chassis_is_provisioned
        
        	Chassis MAC is configured
        	**type**\:  bool
        
        .. attribute:: chassis_mac
        
        	Chassis MAC
        	**type**\:  str
        
        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
        
        .. attribute:: provisioned
        
        	BMAC SA configured
        	**type**\:  bool
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.bmac_sa = None
            self.chassis_is_provisioned = None
            self.chassis_mac = None
            self.provisioned = None

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:l2vpn-pbb-bsa'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.bmac_sa is not None:
                return True

            if self.chassis_is_provisioned is not None:
                return True

            if self.chassis_mac is not None:
                return True

            if self.provisioned is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.L2VpnPbbBsa']['meta_info']


    class FlexibleXconnectServices(object):
        """
        Flexible XConnect Service Table
        
        .. attribute:: flexible_xconnect_service
        
        	Flexible XConnect Service Information
        	**type**\: list of    :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.flexible_xconnect_service = YList()
            self.flexible_xconnect_service.parent = self
            self.flexible_xconnect_service.name = 'flexible_xconnect_service'


        class FlexibleXconnectService(object):
            """
            Flexible XConnect Service Information
            
            .. attribute:: name  <key>
            
            	Flexible XConnect Service Name
            	**type**\:  str
            
            	**length:** 1..23
            
            .. attribute:: flexible_xconnect_service_acs
            
            	Flexible XConnect Service Attachment Circuit Table
            	**type**\:   :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
            
            .. attribute:: flexible_xconnect_service_info
            
            	Flexible XConnect Service Information
            	**type**\:   :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.name = None
                self.flexible_xconnect_service_acs = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                self.flexible_xconnect_service_acs.parent = self
                self.flexible_xconnect_service_info = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                self.flexible_xconnect_service_info.parent = self


            class FlexibleXconnectServiceAcs(object):
                """
                Flexible XConnect Service Attachment Circuit
                Table
                
                .. attribute:: flexible_xconnect_service_ac
                
                	Flexible XConnect Service Attachment Circuit
                	**type**\: list of    :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.flexible_xconnect_service_ac = YList()
                    self.flexible_xconnect_service_ac.parent = self
                    self.flexible_xconnect_service_ac.name = 'flexible_xconnect_service_ac'


                class FlexibleXconnectServiceAc(object):
                    """
                    Flexible XConnect Service Attachment Circuit
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                    
                    .. attribute:: attachment_circuit
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\:   :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.attachment_circuit = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                        self.attachment_circuit.parent = self


                    class AttachmentCircuit(object):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\:  bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\:  bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\:  bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\:  str
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\:  bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:   :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\:  str
                        
                        	**pattern:** (([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){3,4}\\d+\\.\\d+)\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]\*\\d+))\|(([a\-zA\-Z0\-9\_]\*\\d+/){2}([a\-zA\-Z0\-9\_]+))\|([a\-zA\-Z0\-9\_\-]\*\\d+)\|([a\-zA\-Z0\-9\_\-]\*\\d+\\.\\d+)\|(mpls)\|(dwdm)
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\:  str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\:  bool
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:   :py:class:`L2VpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection>`
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\:  bool
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\:  bool
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\:  str
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\:  bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\:  bool
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\:  str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:   :py:class:`L2VpnRgStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnRgStateEnum>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\:  bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_error = None
                            self.encapsulation_mismatched = None
                            self.evpn_internal_label = None
                            self.interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self.interface_handle = None
                            self.internal_ms_ti = None
                            self.interworking = None
                            self.is_ac_partially_programmed = None
                            self.l2vpn_protection = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection()
                            self.l2vpn_protection.parent = self
                            self.mac_limit_oper_down = None
                            self.ms_ti_mismatch = None
                            self.msti = None
                            self.msti_mismatch_down = None
                            self.mtu_mismatched = None
                            self.node_id = None
                            self.out_of_memory_state = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.state = None
                            self.statistics = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self.tdm_media_mismatched = None
                            self.xconnect_id = None


                        class Interface(object):
                            """
                            Interface
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\:  str
                            
                            	**length:** 0..81
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.mtu = None
                                self.name = None
                                self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self.payload_bytes = None


                            class Parameters(object):
                                """
                                Interface parameters
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self.type = None
                                    self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self


                                class Ethernet(object):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.xconnect_tags = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet']['meta_info']


                                class Vlan(object):
                                    """
                                    VLAN
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\:  list of int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None
                                        self.rewrite_tag = YLeafList()
                                        self.rewrite_tag.parent = self
                                        self.rewrite_tag.name = 'rewrite_tag'
                                        self.simple_efp = None
                                        self.vlan_range = YList()
                                        self.vlan_range.parent = self
                                        self.vlan_range.name = 'vlan_range'
                                        self.vlan_rewrite_tag = None
                                        self.xconnect_tags = None


                                    class VlanRange(object):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.lower = None
                                            self.upper = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.lower is not None:
                                                return True

                                            if self.upper is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.encapsulation_type is not None:
                                            return True

                                        if self.outer_tag is not None:
                                            return True

                                        if self.rewrite_tag is not None:
                                            for child in self.rewrite_tag:
                                                if child is not None:
                                                    return True

                                        if self.simple_efp is not None:
                                            return True

                                        if self.vlan_range is not None:
                                            for child_ref in self.vlan_range:
                                                if child_ref._has_data():
                                                    return True

                                        if self.vlan_rewrite_tag is not None:
                                            return True

                                        if self.xconnect_tags is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan']['meta_info']


                                class Tdm(object):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\:  str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.tdm_mode = None
                                        self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self.timeslot_group = None
                                        self.timeslot_rate = None


                                    class TdmOptions(object):
                                        """
                                        TDM options
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\:  int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.bit_rate = None
                                            self.cas = None
                                            self.payload_bytes = None
                                            self.rtp = None
                                            self.rtp_header_payload_type = None
                                            self.signalling_packets = None
                                            self.ssrc = None
                                            self.timestamp_clock_freq = None
                                            self.timestamp_mode = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.bit_rate is not None:
                                                return True

                                            if self.cas is not None:
                                                return True

                                            if self.payload_bytes is not None:
                                                return True

                                            if self.rtp is not None:
                                                return True

                                            if self.rtp_header_payload_type is not None:
                                                return True

                                            if self.signalling_packets is not None:
                                                return True

                                            if self.ssrc is not None:
                                                return True

                                            if self.timestamp_clock_freq is not None:
                                                return True

                                            if self.timestamp_mode is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.tdm_mode is not None:
                                            return True

                                        if self.tdm_options is not None and self.tdm_options._has_data():
                                            return True

                                        if self.timeslot_group is not None:
                                            return True

                                        if self.timeslot_rate is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm']['meta_info']


                                class Atm(object):
                                    """
                                    ATM
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.atm_mode = None
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.vci = None
                                        self.vpi = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.atm_mode is not None:
                                            return True

                                        if self.maximum_number_cells_packed is not None:
                                            return True

                                        if self.maximum_number_cells_un_packed is not None:
                                            return True

                                        if self.vci is not None:
                                            return True

                                        if self.vpi is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm']['meta_info']


                                class Fr(object):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.dlci = None
                                        self.fr_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.dlci is not None:
                                            return True

                                        if self.fr_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr']['meta_info']


                                class PseudowireEther(object):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther']['meta_info']


                                class PseudowireIw(object):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self.internal_label = None
                                        self.is_valid = None


                                    class InterfaceList(object):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of    :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\:  str
                                        
                                        	**length:** 0..33
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface = YList()
                                            self.interface.parent = self
                                            self.interface.name = 'interface'
                                            self.interface_list_id = None
                                            self.interface_list_name = None


                                        class Interface_(object):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\:  str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                self.parent = None
                                                self.interface_name = None
                                                self.replicate_status = None

                                            @property
                                            def _common_path(self):
                                                if self.parent is None:
                                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                            def is_config(self):
                                                ''' Returns True if this instance represents config data else returns False '''
                                                return False

                                            def _has_data(self):
                                                if not self.is_config():
                                                    return False
                                                if self.interface_name is not None:
                                                    return True

                                                if self.replicate_status is not None:
                                                    return True

                                                return False

                                            @staticmethod
                                            def _meta_info():
                                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_']['meta_info']

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface is not None:
                                                for child_ref in self.interface:
                                                    if child_ref._has_data():
                                                        return True

                                            if self.interface_list_id is not None:
                                                return True

                                            if self.interface_list_name is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface_list is not None and self.interface_list._has_data():
                                            return True

                                        if self.internal_label is not None:
                                            return True

                                        if self.is_valid is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm is not None and self.atm._has_data():
                                        return True

                                    if self.ethernet is not None and self.ethernet._has_data():
                                        return True

                                    if self.fr is not None and self.fr._has_data():
                                        return True

                                    if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                        return True

                                    if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                        return True

                                    if self.tdm is not None and self.tdm._has_data():
                                        return True

                                    if self.type is not None:
                                        return True

                                    if self.vlan is not None and self.vlan._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.mtu is not None:
                                    return True

                                if self.name is not None:
                                    return True

                                if self.parameters is not None and self.parameters._has_data():
                                    return True

                                if self.payload_bytes is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface']['meta_info']


                        class Statistics(object):
                            """
                            Statistics
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dispostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self.impostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self.sequence_number = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self


                            class ImpostionStats(object):
                                """
                                imposition stats
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self.imposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self.imposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self.impostion_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.l2fsbi_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self.multicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self.unknown_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self


                                class ImpositionStat(object):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                                class ImpositionMtuDrop(object):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                                class ImpostionTailDrop(object):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                                class L2FsbiDrop(object):
                                    """
                                    rx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                                class Multicast(object):
                                    """
                                    Multicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast']['meta_info']


                                class Broadcast(object):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                                class UnknownUnicast(object):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast is not None and self.broadcast._has_data():
                                        return True

                                    if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                        return True

                                    if self.imposition_stat is not None and self.imposition_stat._has_data():
                                        return True

                                    if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                        return True

                                    if self.multicast is not None and self.multicast._has_data():
                                        return True

                                    if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats']['meta_info']


                            class DispostionStats(object):
                                """
                                disposition stats
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats>`
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.broadcast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self.dai_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self.disposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self.disposition_oo_o_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self.disposition_p2mp_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self.disposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self.disposition_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self.ipsg_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self.mac_move = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self.multicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self.received_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self.unicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self


                                class DispositionStat(object):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat']['meta_info']


                                class DispositionMtuDrop(object):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                                class DispositionTailDrop(object):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                                class MulticastDrop(object):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop']['meta_info']


                                class UnicastDrop(object):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop']['meta_info']


                                class BroadcastDrop(object):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                                class ReceivedDrops(object):
                                    """
                                    tx discards
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                                class DaiDrop(object):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop']['meta_info']


                                class IpsgDrop(object):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop']['meta_info']


                                class DispositionOoODrops(object):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                                class DispositionP2MpStats(object):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                                class KnownUnicast(object):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast']['meta_info']


                                class MacMove(object):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\:  int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.byte_counts = None
                                        self.packet_counts = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.byte_counts is not None:
                                            return True

                                        if self.packet_counts is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                        return True

                                    if self.dai_drop is not None and self.dai_drop._has_data():
                                        return True

                                    if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                        return True

                                    if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                        return True

                                    if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                        return True

                                    if self.disposition_stat is not None and self.disposition_stat._has_data():
                                        return True

                                    if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                        return True

                                    if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                        return True

                                    if self.known_unicast is not None and self.known_unicast._has_data():
                                        return True

                                    if self.mac_move is not None and self.mac_move._has_data():
                                        return True

                                    if self.multicast_drop is not None and self.multicast_drop._has_data():
                                        return True

                                    if self.received_drops is not None and self.received_drops._has_data():
                                        return True

                                    if self.unicast_drop is not None and self.unicast_drop._has_data():
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats']['meta_info']


                            class SequenceNumber(object):
                                """
                                sequence numbers
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self.sequence_number_expected = None
                                    self.sequence_number_sent = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.bypassed_inbound_sequence_packet is not None:
                                        return True

                                    if self.bypassed_out_sequence_packet is not None:
                                        return True

                                    if self.sequence_number_expected is not None:
                                        return True

                                    if self.sequence_number_sent is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                    return True

                                if self.impostion_stats is not None and self.impostion_stats._has_data():
                                    return True

                                if self.sequence_number is not None and self.sequence_number._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics']['meta_info']


                        class L2VpnProtection(object):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\:  bool
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:   :py:class:`L2VpnProtectionRoleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionRoleEnum>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\:  str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:   :py:class:`L2VpnProtectionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnProtectionEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.active = None
                                self.protected_name = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protection_type = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2vpn-protection'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.active is not None:
                                    return True

                                if self.protected_name is not None:
                                    return True

                                if self.protection_configured is not None:
                                    return True

                                if self.protection_name is not None:
                                    return True

                                if self.protection_type is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2VpnProtection']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:attachment-circuit'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.bvi_mac_conflict is not None:
                                return True

                            if self.bvi_no_port_up is not None:
                                return True

                            if self.control_word_mismatched is not None:
                                return True

                            if self.encapsulation_error is not None:
                                return True

                            if self.encapsulation_mismatched is not None:
                                return True

                            if self.evpn_internal_label is not None:
                                return True

                            if self.interface is not None and self.interface._has_data():
                                return True

                            if self.interface_handle is not None:
                                return True

                            if self.internal_ms_ti is not None:
                                return True

                            if self.interworking is not None:
                                return True

                            if self.is_ac_partially_programmed is not None:
                                return True

                            if self.l2vpn_protection is not None and self.l2vpn_protection._has_data():
                                return True

                            if self.mac_limit_oper_down is not None:
                                return True

                            if self.ms_ti_mismatch is not None:
                                return True

                            if self.msti is not None:
                                return True

                            if self.msti_mismatch_down is not None:
                                return True

                            if self.mtu_mismatched is not None:
                                return True

                            if self.node_id is not None:
                                return True

                            if self.out_of_memory_state is not None:
                                return True

                            if self.redundancy_group_id is not None:
                                return True

                            if self.redundancy_group_state is not None:
                                return True

                            if self.redundancy_object_id is not None:
                                return True

                            if self.state is not None:
                                return True

                            if self.statistics is not None and self.statistics._has_data():
                                return True

                            if self.tdm_media_mismatched is not None:
                                return True

                            if self.xconnect_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.interface_name is None:
                            raise YPYModelError('Key property interface_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-ac[Cisco-IOS-XR-l2vpn-oper:interface-name = ' + str(self.interface_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.attachment_circuit is not None and self.attachment_circuit._has_data():
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-acs'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.flexible_xconnect_service_ac is not None:
                        for child_ref in self.flexible_xconnect_service_ac:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs']['meta_info']


            class FlexibleXconnectServiceInfo(object):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name
                
                	Flexible XConnect Service Name
                	**type**\:  str
                
                .. attribute:: num_p_ws
                
                	Number of Pseudowires in Pseudowire List
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: pseudowire
                
                	Flexible XConnect Service Pseudowire List
                	**type**\: list of    :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                
                .. attribute:: state
                
                	State of the Flexible XConnect Service
                	**type**\:   :py:class:`L2VpnXcStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnXcStateEnum>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.name = None
                    self.num_p_ws = None
                    self.pseudowire = YList()
                    self.pseudowire.parent = self
                    self.pseudowire.name = 'pseudowire'
                    self.state = None


                class Pseudowire(object):
                    """
                    Flexible XConnect Service Pseudowire List
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery method
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ad_remote_down
                    
                    	Auto\-Discovered PW remote state down
                    	**type**\:  bool
                    
                    .. attribute:: admited_bw
                    
                    	Admited Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: auto_discovery
                    
                    	Is autodiscovery
                    	**type**\:  bool
                    
                    .. attribute:: backup_active
                    
                    	TRUE if backup is active
                    	**type**\:  bool
                    
                    .. attribute:: backup_force_active
                    
                    	TRUE if backup is active due to switchover
                    	**type**\:  bool
                    
                    .. attribute:: backup_pw
                    
                    	TRUE if PW is a backup PW
                    	**type**\:  bool
                    
                    .. attribute:: bitrate_mismatched
                    
                    	Bitrate mismatched
                    	**type**\:  bool
                    
                    .. attribute:: bridge_pw_type_mismatch
                    
                    	Oper down because Bridge has mismatched PW Types
                    	**type**\:  bool
                    
                    .. attribute:: cas_mismatched
                    
                    	CAS mismatched
                    	**type**\:  bool
                    
                    .. attribute:: diff_ts_mismatched
                    
                    	Differential timestamp mismatched
                    	**type**\:  bool
                    
                    .. attribute:: disable_delay
                    
                    	Backup disable delay
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\:  bool
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:   :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                    
                    .. attribute:: evpn_src_acid
                    
                    	EVPN VPWS Source AC ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fe_ctype
                    
                    	Pseudowire FEC type
                    	**type**\:   :py:class:`L2VpnPwFecEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFecEnum>`
                    
                    .. attribute:: forward_class
                    
                    	Forward Class attribute
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: freq_mismatched
                    
                    	Frequency mismatched
                    	**type**\:  bool
                    
                    .. attribute:: illegal_control_word
                    
                    	Illegal control word
                    	**type**\:  bool
                    
                    .. attribute:: imposed_vlan_id
                    
                    	Imposed vlan id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:   :py:class:`L2VpnInterworkingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterworkingEnum>`
                    
                    .. attribute:: ipv6_local_source_address
                    
                    	Local IPv6 Source Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_evpnvpws_type
                    
                    	is EVPN VPWS
                    	**type**\:  bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\:  bool
                    
                    .. attribute:: is_multi_segment_pseudowire
                    
                    	Is Multi\-Segment Pseudowire
                    	**type**\:  bool
                    
                    .. attribute:: is_partially_programmed
                    
                    	Is Pseudowire partially programmed
                    	**type**\:  bool
                    
                    .. attribute:: is_pwr_type
                    
                    	is Pseudowire\-routed
                    	**type**\:  bool
                    
                    .. attribute:: is_vfi
                    
                    	Is VFI interface
                    	**type**\:  bool
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the pseudowire status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_down
                    
                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: ldp_label_advertise_failed
                    
                    	LDP label advertisment failed
                    	**type**\:  bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:   :py:class:`L2VpnLoadBalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnLoadBalEnum>`
                    
                    .. attribute:: local_control_word
                    
                    	Local control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\:   :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                    
                    .. attribute:: local_label_failed
                    
                    	Failed to set BGP advertised local label
                    	**type**\:  bool
                    
                    .. attribute:: local_pseudo_wire_type
                    
                    	Local pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: local_signalling
                    
                    	Local signalling
                    	**type**\:   :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                    
                    .. attribute:: local_source_address
                    
                    	Local Source Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: mac_limit_oper_down
                    
                    	Oper down because MAC limit reached
                    	**type**\:  bool
                    
                    .. attribute:: mtu_mismatched
                    
                    	MTU mismatched
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_qinq
                    
                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                    	**type**\:  bool
                    
                    .. attribute:: num_ma_cwithdraw_msg_received
                    
                    	Num MW messages received over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ma_cwithdraw_message_sent
                    
                    	Num MW messages sent over PW
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: out_of_memory_state
                    
                    	L2VPN Out of memory state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2mp_pw
                    
                    	P2MP Pseudowire Information
                    	**type**\:   :py:class:`P2MpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw>`
                    
                    .. attribute:: payload_bytes_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: payload_type_mismatched
                    
                    	Payload bytes mismatched
                    	**type**\:  bool
                    
                    .. attribute:: peer_id
                    
                    	Peer
                    	**type**\:   :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:   :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	Prefpath fallback enable/disable
                    	**type**\:  bool
                    
                    .. attribute:: primary_peer_id
                    
                    	Primary Peer IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: primary_pseudo_wire_id
                    
                    	Primary Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: primary_pw
                    
                    	TRUE if PW is a primary PW
                    	**type**\:  bool
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`L2VpnSignallingProtoEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSignallingProtoEnum>`
                    
                    .. attribute:: pseudo_wire_id
                    
                    	Pseudowire ID
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: pseudo_wire_state
                    
                    	Pseudowire state
                    	**type**\:   :py:class:`L2VpnPwStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwStateEnum>`
                    
                    .. attribute:: pseudo_wire_type_mismatched
                    
                    	Pseudowire type mismatched
                    	**type**\:  bool
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\:  bool
                    
                    .. attribute:: pw_flow_label_type
                    
                    	Negotiated pseudowire flow label type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label Type
                    	**type**\:   :py:class:`L2VpnPwFlowLabelEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwFlowLabelEnum>`
                    
                    .. attribute:: pw_redundancy_initial_delay
                    
                    	Initial delay for redundant PW in seconds
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    .. attribute:: pw_redundancy_one_way
                    
                    	Force one\-way PW redundancy behaviour in Redundancy Group
                    	**type**\:  bool
                    
                    .. attribute:: pw_status_use
                    
                    	PW status in use
                    	**type**\:  bool
                    
                    .. attribute:: pwlsd_rewrite_failed
                    
                    	LSD rewrite failed
                    	**type**\:  bool
                    
                    .. attribute:: remote_control_word
                    
                    	Remote control word
                    	**type**\:   :py:class:`L2VpnPwControlWordEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwControlWordEnum>`
                    
                    .. attribute:: remote_interface
                    
                    	Remote interface
                    	**type**\:   :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                    
                    .. attribute:: remote_label_failed
                    
                    	Failed to set BGP advertised remote label
                    	**type**\:  bool
                    
                    .. attribute:: remote_pseudo_wire_type
                    
                    	Remote pseudowire type
                    	**type**\:   :py:class:`L2VpnPwEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwEnum>`
                    
                    .. attribute:: remote_signalling
                    
                    	Remote signalling
                    	**type**\:   :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                    
                    .. attribute:: required_bw
                    
                    	Required Bandwidth
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\:  bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rtp_mismatched
                    
                    	RTP mismatched
                    	**type**\:  bool
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:   :py:class:`L2VpnPwSequenceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPwSequenceEnum>`
                    
                    .. attribute:: shutdown
                    
                    	Shutdown
                    	**type**\:  bool
                    
                    .. attribute:: sig_pkts_mismatched
                    
                    	Signalling packets mismatched
                    	**type**\:  bool
                    
                    .. attribute:: ssrc_mismatched
                    
                    	SSRC mismatched
                    	**type**\:  bool
                    
                    .. attribute:: state
                    
                    	State
                    	**type**\:   :py:class:`L2VpnSegmentStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnSegmentStateEnum>`
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                    
                    .. attribute:: table_policy_name
                    
                    	Table\-policy Name
                    	**type**\:  str
                    
                    .. attribute:: tag_rewrite
                    
                    	StaticTagRewrite
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: time_created
                    
                    	Time when the pseudowire was created
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\:  str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_down
                    
                    	Time elapsed since last status down in seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: transport_lsp_down
                    
                    	Oper down due to Transport LSP down
                    	**type**\:  bool
                    
                    .. attribute:: xconnect_id
                    
                    	XConnect ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ad_method = None
                        self.ad_remote_down = None
                        self.admited_bw = None
                        self.auto_discovery = None
                        self.backup_active = None
                        self.backup_force_active = None
                        self.backup_pw = None
                        self.bitrate_mismatched = None
                        self.bridge_pw_type_mismatch = None
                        self.cas_mismatched = None
                        self.diff_ts_mismatched = None
                        self.disable_delay = None
                        self.disable_never = None
                        self.encapsulation_info = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self.evpn_src_acid = None
                        self.fe_ctype = None
                        self.forward_class = None
                        self.freq_mismatched = None
                        self.illegal_control_word = None
                        self.imposed_vlan_id = None
                        self.interworking = None
                        self.ipv6_local_source_address = None
                        self.is_evpnvpws_type = None
                        self.is_flow_label_static = None
                        self.is_multi_segment_pseudowire = None
                        self.is_partially_programmed = None
                        self.is_pwr_type = None
                        self.is_vfi = None
                        self.last_time_status_changed = None
                        self.last_time_status_down = None
                        self.ldp_label_advertise_failed = None
                        self.load_balance = None
                        self.local_control_word = None
                        self.local_interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                        self.local_interface.parent = self
                        self.local_label_failed = None
                        self.local_pseudo_wire_type = None
                        self.local_signalling = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                        self.local_signalling.parent = self
                        self.local_source_address = None
                        self.mac_limit_oper_down = None
                        self.mtu_mismatched = None
                        self.not_supported_qinq = None
                        self.num_ma_cwithdraw_msg_received = None
                        self.number_ma_cwithdraw_message_sent = None
                        self.out_of_memory_state = None
                        self.p2mp_pw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw()
                        self.p2mp_pw.parent = self
                        self.payload_bytes_mismatched = None
                        self.payload_type_mismatched = None
                        self.peer_id = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                        self.peer_id.parent = self
                        self.preferred_path = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                        self.preferred_path.parent = self
                        self.preferred_path_disable_fallback = None
                        self.primary_peer_id = None
                        self.primary_pseudo_wire_id = None
                        self.primary_pw = None
                        self.protocol = None
                        self.pseudo_wire_id = None
                        self.pseudo_wire_state = None
                        self.pseudo_wire_type_mismatched = None
                        self.pw_class_name = None
                        self.pw_flow_label_code17_disabled = None
                        self.pw_flow_label_type = None
                        self.pw_flow_label_type_cfg = None
                        self.pw_redundancy_initial_delay = None
                        self.pw_redundancy_one_way = None
                        self.pw_status_use = None
                        self.pwlsd_rewrite_failed = None
                        self.remote_control_word = None
                        self.remote_interface = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                        self.remote_interface.parent = self
                        self.remote_label_failed = None
                        self.remote_pseudo_wire_type = None
                        self.remote_signalling = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                        self.remote_signalling.parent = self
                        self.required_bw = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.rtp_mismatched = None
                        self.sequencing_type = None
                        self.shutdown = None
                        self.sig_pkts_mismatched = None
                        self.ssrc_mismatched = None
                        self.state = None
                        self.statistics = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                        self.statistics.parent = self
                        self.table_policy_name = None
                        self.tag_rewrite = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.time_elapsed_status_changed = None
                        self.time_elapsed_status_down = None
                        self.transport_lsp_down = None
                        self.xconnect_id = None


                    class PeerId(object):
                        """
                        Peer
                        
                        .. attribute:: internal_label
                        
                        	Internal Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_peer_id
                        
                        	Peer IPv4 address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_peer_id
                        
                        	Peer IPv6 address
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: type
                        
                        	type
                        	**type**\:   :py:class:`L2VpnPeerEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPeerEnum>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.internal_label = None
                            self.ipv4_peer_id = None
                            self.ipv6_peer_id = None
                            self.type = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:peer-id'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.internal_label is not None:
                                return True

                            if self.ipv4_peer_id is not None:
                                return True

                            if self.ipv6_peer_id is not None:
                                return True

                            if self.type is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId']['meta_info']


                    class EncapsulationInfo(object):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: atom
                        
                        	atom
                        	**type**\:   :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:   :py:class:`L2VpnEncapMethodEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnEncapMethodEnum>`
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:   :py:class:`L2Tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.atom = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                            self.atom.parent = self
                            self.encapsulation = None
                            self.l2tpv3 = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3()
                            self.l2tpv3.parent = self


                        class Atom(object):
                            """
                            atom
                            
                            .. attribute:: is_pseudowire_headend
                            
                            	Is this connected to a PW\-HE AC
                            	**type**\:  bool
                            
                            .. attribute:: is_sai_itype2
                            
                            	Is SAII FEC129 Type 2
                            	**type**\:  bool
                            
                            .. attribute:: is_tai_itype2
                            
                            	Is TAII type 2
                            	**type**\:  bool
                            
                            .. attribute:: ldp_label_advertisment_failed
                            
                            	LDP label advertisment failed
                            	**type**\:  bool
                            
                            .. attribute:: local_agi
                            
                            	Local Attachment Group Identifier
                            	**type**\:   :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                            
                            .. attribute:: local_c_ctype
                            
                            	Local VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_ceid
                            
                            	Local CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cv_type
                            
                            	Local VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_group_id
                            
                            	Local group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_label
                            
                            	Local label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ldp_id
                            
                            	Local LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_saii_gbl_id
                            
                            	Local SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_saiiac_id
                            
                            	Local SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taii_gbl_id
                            
                            	Local TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_taiiac_id
                            
                            	Local TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_veid
                            
                            	Local VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\:  bool
                            
                            .. attribute:: multi_segment_pseudowire_stats
                            
                            	Multisegment pseudowire statistics
                            	**type**\:   :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                            
                            .. attribute:: rem_saii
                            
                            	Remote Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_saii_gbl_id
                            
                            	Remote SAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_saiiac_id
                            
                            	Remote SAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taii
                            
                            	Remote Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: rem_taii_gbl_id
                            
                            	Remote TAII Global ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: rem_taiiac_id
                            
                            	Remote TAII AC ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_agi
                            
                            	Remote Attachment Group Identifier
                            	**type**\:   :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                            
                            .. attribute:: remote_c_ctype
                            
                            	Remote VCCV CC type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_ceid
                            
                            	Remote CE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cv_type
                            
                            	Remote VCCV CV type
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_group_id
                            
                            	Remote group ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_label
                            
                            	Remote label
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ldp_id
                            
                            	Remote LDP ID
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_source_address
                            
                            	Remote BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_veid
                            
                            	Remote VE ID
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: saii
                            
                            	Source Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: source_address
                            
                            	Local BGP source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: taii
                            
                            	Target Attachment Individual Identifer
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.is_pseudowire_headend = None
                                self.is_sai_itype2 = None
                                self.is_tai_itype2 = None
                                self.ldp_label_advertisment_failed = None
                                self.local_agi = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                self.local_agi.parent = self
                                self.local_c_ctype = None
                                self.local_ceid = None
                                self.local_cv_type = None
                                self.local_group_id = None
                                self.local_label = None
                                self.local_ldp_id = None
                                self.local_saii_gbl_id = None
                                self.local_saiiac_id = None
                                self.local_taii_gbl_id = None
                                self.local_taiiac_id = None
                                self.local_veid = None
                                self.lsd_rewrite_failed = None
                                self.multi_segment_pseudowire_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                self.multi_segment_pseudowire_stats.parent = self
                                self.rem_saii = None
                                self.rem_saii_gbl_id = None
                                self.rem_saiiac_id = None
                                self.rem_taii = None
                                self.rem_taii_gbl_id = None
                                self.rem_taiiac_id = None
                                self.remote_agi = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                self.remote_agi.parent = self
                                self.remote_c_ctype = None
                                self.remote_ceid = None
                                self.remote_cv_type = None
                                self.remote_group_id = None
                                self.remote_label = None
                                self.remote_ldp_id = None
                                self.remote_source_address = None
                                self.remote_veid = None
                                self.saii = None
                                self.source_address = None
                                self.taii = None


                            class LocalAgi(object):
                                """
                                Local Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi']['meta_info']


                            class RemoteAgi(object):
                                """
                                Remote Attachment Group Identifier
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:   :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:   :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:   :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:   :py:class:`L2VpnAdVplsIdEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAdVplsIdEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.auto = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                    self.auto.parent = self
                                    self.two_byte_as = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self.v4_addr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                    self.v4_addr.parent = self
                                    self.vpls_id_type = None


                                class Auto(object):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.asn = None
                                        self.vpn_id = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:auto'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.asn is not None:
                                            return True

                                        if self.vpn_id is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto']['meta_info']


                                class TwoByteAs(object):
                                    """
                                    two byte as
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.four_byte_index = None
                                        self.two_byte_as = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:two-byte-as'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.four_byte_index is not None:
                                            return True

                                        if self.two_byte_as is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs']['meta_info']


                                class V4Addr(object):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.ipv4_address = None
                                        self.two_byte_index = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:v4-addr'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.ipv4_address is not None:
                                            return True

                                        if self.two_byte_index is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-agi'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.auto is not None and self.auto._has_data():
                                        return True

                                    if self.two_byte_as is not None and self.two_byte_as._has_data():
                                        return True

                                    if self.v4_addr is not None and self.v4_addr._has_data():
                                        return True

                                    if self.vpls_id_type is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi']['meta_info']


                            class MultiSegmentPseudowireStats(object):
                                """
                                Multisegment pseudowire statistics
                                
                                .. attribute:: received_bytes
                                
                                	Bytes received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: received_packets
                                
                                	Packets received
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.received_bytes = None
                                    self.received_packets = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multi-segment-pseudowire-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.received_bytes is not None:
                                        return True

                                    if self.received_packets is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atom'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.is_pseudowire_headend is not None:
                                    return True

                                if self.is_sai_itype2 is not None:
                                    return True

                                if self.is_tai_itype2 is not None:
                                    return True

                                if self.ldp_label_advertisment_failed is not None:
                                    return True

                                if self.local_agi is not None and self.local_agi._has_data():
                                    return True

                                if self.local_c_ctype is not None:
                                    return True

                                if self.local_ceid is not None:
                                    return True

                                if self.local_cv_type is not None:
                                    return True

                                if self.local_group_id is not None:
                                    return True

                                if self.local_label is not None:
                                    return True

                                if self.local_ldp_id is not None:
                                    return True

                                if self.local_saii_gbl_id is not None:
                                    return True

                                if self.local_saiiac_id is not None:
                                    return True

                                if self.local_taii_gbl_id is not None:
                                    return True

                                if self.local_taiiac_id is not None:
                                    return True

                                if self.local_veid is not None:
                                    return True

                                if self.lsd_rewrite_failed is not None:
                                    return True

                                if self.multi_segment_pseudowire_stats is not None and self.multi_segment_pseudowire_stats._has_data():
                                    return True

                                if self.rem_saii is not None:
                                    return True

                                if self.rem_saii_gbl_id is not None:
                                    return True

                                if self.rem_saiiac_id is not None:
                                    return True

                                if self.rem_taii is not None:
                                    return True

                                if self.rem_taii_gbl_id is not None:
                                    return True

                                if self.rem_taiiac_id is not None:
                                    return True

                                if self.remote_agi is not None and self.remote_agi._has_data():
                                    return True

                                if self.remote_c_ctype is not None:
                                    return True

                                if self.remote_ceid is not None:
                                    return True

                                if self.remote_cv_type is not None:
                                    return True

                                if self.remote_group_id is not None:
                                    return True

                                if self.remote_label is not None:
                                    return True

                                if self.remote_ldp_id is not None:
                                    return True

                                if self.remote_source_address is not None:
                                    return True

                                if self.remote_veid is not None:
                                    return True

                                if self.saii is not None:
                                    return True

                                if self.source_address is not None:
                                    return True

                                if self.taii is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom']['meta_info']


                        class L2Tpv3(object):
                            """
                            l2tpv3
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\:  bool
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_source_address
                            
                            	IPv6 source address
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\:  str
                            
                            	**length:** 0..32
                            
                            .. attribute:: local_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_cookie_size
                            
                            	Local cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_secondary_cookie_high_value
                            
                            	Upper 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_low_value
                            
                            	Lower 4 bytes of the value of the local secondary cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_secondary_cookie_size
                            
                            	Local secondary cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_session_id
                            
                            	Local session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\:  bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: remote_circuit_status_up
                            
                            	RemoteCircuitStatusUp
                            	**type**\:  bool
                            
                            .. attribute:: remote_cookie_high_value
                            
                            	Upper 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_low_value
                            
                            	Lower 4 bytes of the value of the remote cookie
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_cookie_size
                            
                            	Remote cookie size\: 0, 4, or 8 bytes
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_session_id
                            
                            	Remote session id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:   :py:class:`L2VpnTosModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTosModeEnum>`
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: tunnel_state
                            
                            	L2TP tunnel state
                            	**type**\:   :py:class:`L2VpnL2TpTunnelStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnL2TpTunnelStateEnum>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.dont_fragment_bit = None
                                self.ipv4_source_address = None
                                self.ipv6_source_address = None
                                self.l2tp_class_name = None
                                self.local_cookie_high_value = None
                                self.local_cookie_low_value = None
                                self.local_cookie_size = None
                                self.local_secondary_cookie_high_value = None
                                self.local_secondary_cookie_low_value = None
                                self.local_secondary_cookie_size = None
                                self.local_session_id = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.remote_circuit_status_up = None
                                self.remote_cookie_high_value = None
                                self.remote_cookie_low_value = None
                                self.remote_cookie_size = None
                                self.remote_session_id = None
                                self.tos = None
                                self.tos_mode = None
                                self.ttl = None
                                self.tunnel_state = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2tpv3'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.dont_fragment_bit is not None:
                                    return True

                                if self.ipv4_source_address is not None:
                                    return True

                                if self.ipv6_source_address is not None:
                                    return True

                                if self.l2tp_class_name is not None:
                                    return True

                                if self.local_cookie_high_value is not None:
                                    return True

                                if self.local_cookie_low_value is not None:
                                    return True

                                if self.local_cookie_size is not None:
                                    return True

                                if self.local_secondary_cookie_high_value is not None:
                                    return True

                                if self.local_secondary_cookie_low_value is not None:
                                    return True

                                if self.local_secondary_cookie_size is not None:
                                    return True

                                if self.local_session_id is not None:
                                    return True

                                if self.path_mtu_enabled is not None:
                                    return True

                                if self.path_mtu_max_value is not None:
                                    return True

                                if self.remote_circuit_status_up is not None:
                                    return True

                                if self.remote_cookie_high_value is not None:
                                    return True

                                if self.remote_cookie_low_value is not None:
                                    return True

                                if self.remote_cookie_size is not None:
                                    return True

                                if self.remote_session_id is not None:
                                    return True

                                if self.tos is not None:
                                    return True

                                if self.tos_mode is not None:
                                    return True

                                if self.ttl is not None:
                                    return True

                                if self.tunnel_state is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2Tpv3']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:encapsulation-info'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.atom is not None and self.atom._has_data():
                                return True

                            if self.encapsulation is not None:
                                return True

                            if self.l2tpv3 is not None and self.l2tpv3._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo']['meta_info']


                    class LocalInterface(object):
                        """
                        Local interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface']['meta_info']


                    class RemoteInterface(object):
                        """
                        Remote interface
                        
                        .. attribute:: mtu
                        
                        	Interface MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Interface name
                        	**type**\:  str
                        
                        	**length:** 0..81
                        
                        .. attribute:: parameters
                        
                        	Interface parameters
                        	**type**\:   :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                        
                        .. attribute:: payload_bytes
                        
                        	Payload bytes
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.mtu = None
                            self.name = None
                            self.parameters = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                            self.parameters.parent = self
                            self.payload_bytes = None


                        class Parameters(object):
                            """
                            Interface parameters
                            
                            .. attribute:: atm
                            
                            	ATM
                            	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                            
                            .. attribute:: ethernet
                            
                            	Ethernet
                            	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                            
                            .. attribute:: fr
                            
                            	Frame Relay
                            	**type**\:   :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                            
                            .. attribute:: pseudowire_ether
                            
                            	PW Ether
                            	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                            
                            .. attribute:: pseudowire_iw
                            
                            	PW IW
                            	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                            
                            .. attribute:: tdm
                            
                            	TDM
                            	**type**\:   :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:   :py:class:`L2VpnInterfaceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnInterfaceEnum>`
                            
                            .. attribute:: vlan
                            
                            	VLAN
                            	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.atm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                self.atm.parent = self
                                self.ethernet = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                self.ethernet.parent = self
                                self.fr = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                self.fr.parent = self
                                self.pseudowire_ether = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                self.pseudowire_ether.parent = self
                                self.pseudowire_iw = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                self.pseudowire_iw.parent = self
                                self.tdm = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                self.tdm.parent = self
                                self.type = None
                                self.vlan = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                self.vlan.parent = self


                            class Ethernet(object):
                                """
                                Ethernet
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.xconnect_tags = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ethernet'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet']['meta_info']


                            class Vlan(object):
                                """
                                VLAN
                                
                                .. attribute:: encapsulation_type
                                
                                	Encapsulation Type
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: outer_tag
                                
                                	Outer Tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: rewrite_tag
                                
                                	Rewrite Tags
                                	**type**\:  list of int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: simple_efp
                                
                                	Simple EFP
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_range
                                
                                	vlan range
                                	**type**\: list of    :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                
                                .. attribute:: vlan_rewrite_tag
                                
                                	VLAN rewrite tag
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: xconnect_tags
                                
                                	XConnect tags
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.encapsulation_type = None
                                    self.outer_tag = None
                                    self.rewrite_tag = YLeafList()
                                    self.rewrite_tag.parent = self
                                    self.rewrite_tag.name = 'rewrite_tag'
                                    self.simple_efp = None
                                    self.vlan_range = YList()
                                    self.vlan_range.parent = self
                                    self.vlan_range.name = 'vlan_range'
                                    self.vlan_rewrite_tag = None
                                    self.xconnect_tags = None


                                class VlanRange(object):
                                    """
                                    vlan range
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.lower = None
                                        self.upper = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan-range'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.lower is not None:
                                            return True

                                        if self.upper is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:vlan'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.encapsulation_type is not None:
                                        return True

                                    if self.outer_tag is not None:
                                        return True

                                    if self.rewrite_tag is not None:
                                        for child in self.rewrite_tag:
                                            if child is not None:
                                                return True

                                    if self.simple_efp is not None:
                                        return True

                                    if self.vlan_range is not None:
                                        for child_ref in self.vlan_range:
                                            if child_ref._has_data():
                                                return True

                                    if self.vlan_rewrite_tag is not None:
                                        return True

                                    if self.xconnect_tags is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan']['meta_info']


                            class Tdm(object):
                                """
                                TDM
                                
                                .. attribute:: tdm_mode
                                
                                	TDM mode
                                	**type**\:   :py:class:`L2VpnTdmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmModeEnum>`
                                
                                .. attribute:: tdm_options
                                
                                	TDM options
                                	**type**\:   :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                
                                .. attribute:: timeslot_group
                                
                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                	**type**\:  str
                                
                                .. attribute:: timeslot_rate
                                
                                	Timeslot rate in units of Kbps
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.tdm_mode = None
                                    self.tdm_options = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                    self.tdm_options.parent = self
                                    self.timeslot_group = None
                                    self.timeslot_rate = None


                                class TdmOptions(object):
                                    """
                                    TDM options
                                    
                                    .. attribute:: bit_rate
                                    
                                    	TDM bit rate in units of Kbps
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: cas
                                    
                                    	CAS
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	TDM payload bytes
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: rtp
                                    
                                    	RTP header
                                    	**type**\:   :py:class:`L2VpnTdmRtpOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTdmRtpOptionEnum>`
                                    
                                    .. attribute:: rtp_header_payload_type
                                    
                                    	RTP header payload type
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: signalling_packets
                                    
                                    	Signalling packets
                                    	**type**\:  int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ssrc
                                    
                                    	Synchronization Source identifier
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: timestamp_clock_freq
                                    
                                    	Timestamping clock frequency in units of 8Khz
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: timestamp_mode
                                    
                                    	TDM Timestamping mode
                                    	**type**\:   :py:class:`L2VpnTimeStampModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnTimeStampModeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.bit_rate = None
                                        self.cas = None
                                        self.payload_bytes = None
                                        self.rtp = None
                                        self.rtp_header_payload_type = None
                                        self.signalling_packets = None
                                        self.ssrc = None
                                        self.timestamp_clock_freq = None
                                        self.timestamp_mode = None

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm-options'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.bit_rate is not None:
                                            return True

                                        if self.cas is not None:
                                            return True

                                        if self.payload_bytes is not None:
                                            return True

                                        if self.rtp is not None:
                                            return True

                                        if self.rtp_header_payload_type is not None:
                                            return True

                                        if self.signalling_packets is not None:
                                            return True

                                        if self.ssrc is not None:
                                            return True

                                        if self.timestamp_clock_freq is not None:
                                            return True

                                        if self.timestamp_mode is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tdm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.tdm_mode is not None:
                                        return True

                                    if self.tdm_options is not None and self.tdm_options._has_data():
                                        return True

                                    if self.timeslot_group is not None:
                                        return True

                                    if self.timeslot_rate is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm']['meta_info']


                            class Atm(object):
                                """
                                ATM
                                
                                .. attribute:: atm_mode
                                
                                	ATM mode
                                	**type**\:   :py:class:`L2VpnAtmModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAtmModeEnum>`
                                
                                .. attribute:: maximum_number_cells_packed
                                
                                	Max number of cells packed
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: maximum_number_cells_un_packed
                                
                                	Max number of cells unpacked
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vci
                                
                                	Virtual channel identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpi
                                
                                	Virtual path identifier
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.atm_mode = None
                                    self.maximum_number_cells_packed = None
                                    self.maximum_number_cells_un_packed = None
                                    self.vci = None
                                    self.vpi = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:atm'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.atm_mode is not None:
                                        return True

                                    if self.maximum_number_cells_packed is not None:
                                        return True

                                    if self.maximum_number_cells_un_packed is not None:
                                        return True

                                    if self.vci is not None:
                                        return True

                                    if self.vpi is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm']['meta_info']


                            class Fr(object):
                                """
                                Frame Relay
                                
                                .. attribute:: dlci
                                
                                	Data\-link connection identifier
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: fr_mode
                                
                                	Frame Relay mode
                                	**type**\:   :py:class:`L2VpnFrModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnFrModeEnum>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.dlci = None
                                    self.fr_mode = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:fr'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.dlci is not None:
                                        return True

                                    if self.fr_mode is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr']['meta_info']


                            class PseudowireEther(object):
                                """
                                PW Ether
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-ether'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther']['meta_info']


                            class PseudowireIw(object):
                                """
                                PW IW
                                
                                .. attribute:: interface_list
                                
                                	Interface list data
                                	**type**\:   :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_valid
                                
                                	Is this Interface list valid
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.interface_list = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                    self.interface_list.parent = self
                                    self.internal_label = None
                                    self.is_valid = None


                                class InterfaceList(object):
                                    """
                                    Interface list data
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                    
                                    .. attribute:: interface_list_id
                                    
                                    	Interface internal ID
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_list_name
                                    
                                    	Interface\-list name
                                    	**type**\:  str
                                    
                                    	**length:** 0..33
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        self.parent = None
                                        self.interface = YList()
                                        self.interface.parent = self
                                        self.interface.name = 'interface'
                                        self.interface_list_id = None
                                        self.interface_list_name = None


                                    class Interface(object):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\:  str
                                        
                                        .. attribute:: replicate_status
                                        
                                        	Replicate status
                                        	**type**\:   :py:class:`IflistRepStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatusEnum>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            self.parent = None
                                            self.interface_name = None
                                            self.replicate_status = None

                                        @property
                                        def _common_path(self):
                                            if self.parent is None:
                                                raise YPYModelError('parent is not set . Cannot derive path.')

                                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                                        def is_config(self):
                                            ''' Returns True if this instance represents config data else returns False '''
                                            return False

                                        def _has_data(self):
                                            if not self.is_config():
                                                return False
                                            if self.interface_name is not None:
                                                return True

                                            if self.replicate_status is not None:
                                                return True

                                            return False

                                        @staticmethod
                                        def _meta_info():
                                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface']['meta_info']

                                    @property
                                    def _common_path(self):
                                        if self.parent is None:
                                            raise YPYModelError('parent is not set . Cannot derive path.')

                                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface-list'

                                    def is_config(self):
                                        ''' Returns True if this instance represents config data else returns False '''
                                        return False

                                    def _has_data(self):
                                        if not self.is_config():
                                            return False
                                        if self.interface is not None:
                                            for child_ref in self.interface:
                                                if child_ref._has_data():
                                                    return True

                                        if self.interface_list_id is not None:
                                            return True

                                        if self.interface_list_name is not None:
                                            return True

                                        return False

                                    @staticmethod
                                    def _meta_info():
                                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList']['meta_info']

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire-iw'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.interface_list is not None and self.interface_list._has_data():
                                        return True

                                    if self.internal_label is not None:
                                        return True

                                    if self.is_valid is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:parameters'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.atm is not None and self.atm._has_data():
                                    return True

                                if self.ethernet is not None and self.ethernet._has_data():
                                    return True

                                if self.fr is not None and self.fr._has_data():
                                    return True

                                if self.pseudowire_ether is not None and self.pseudowire_ether._has_data():
                                    return True

                                if self.pseudowire_iw is not None and self.pseudowire_iw._has_data():
                                    return True

                                if self.tdm is not None and self.tdm._has_data():
                                    return True

                                if self.type is not None:
                                    return True

                                if self.vlan is not None and self.vlan._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.mtu is not None:
                                return True

                            if self.name is not None:
                                return True

                            if self.parameters is not None and self.parameters._has_data():
                                return True

                            if self.payload_bytes is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface']['meta_info']


                    class PreferredPath(object):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:   :py:class:`L2VpnPrefpathOptionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnPrefpathOptionEnum>`
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.ip_tunnel_interface_number = None
                            self.next_hop_ip = None
                            self.option = None
                            self.te_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:preferred-path'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.ip_tunnel_interface_number is not None:
                                return True

                            if self.next_hop_ip is not None:
                                return True

                            if self.option is not None:
                                return True

                            if self.te_tunnel_interface_number is not None:
                                return True

                            if self.tp_tunnel_interface_number is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath']['meta_info']


                    class LocalSignalling(object):
                        """
                        Local signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:local-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling']['meta_info']


                    class RemoteSignalling(object):
                        """
                        Remote signalling
                        
                        .. attribute:: pw_status
                        
                        	PW Status
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: status_tlv
                        
                        	PW Status Switching TLV
                        	**type**\:   :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                        
                        .. attribute:: tlv
                        
                        	Switching TLV info
                        	**type**\: list of    :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.pw_status = None
                            self.status_tlv = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                            self.status_tlv.parent = self
                            self.tlv = YList()
                            self.tlv.parent = self
                            self.tlv.name = 'tlv'


                        class StatusTlv(object):
                            """
                            PW Status Switching TLV
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:status-tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv']['meta_info']


                        class Tlv(object):
                            """
                            Switching TLV info
                            
                            .. attribute:: description
                            
                            	PW Switching Point description
                            	**type**\:  str
                            
                            .. attribute:: local_address
                            
                            	Local IP Address of PW Switching Point
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_id
                            
                            	PW ID of last PW segment traversed
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_address
                            
                            	Remote IP Address of Last PW Switching Point traversed
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.description = None
                                self.local_address = None
                                self.pw_id = None
                                self.remote_address = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:tlv'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.description is not None:
                                    return True

                                if self.local_address is not None:
                                    return True

                                if self.pw_id is not None:
                                    return True

                                if self.remote_address is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:remote-signalling'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.pw_status is not None:
                                return True

                            if self.status_tlv is not None and self.status_tlv._has_data():
                                return True

                            if self.tlv is not None:
                                for child_ref in self.tlv:
                                    if child_ref._has_data():
                                        return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling']['meta_info']


                    class Statistics(object):
                        """
                        Statistics
                        
                        .. attribute:: dispostion_stats
                        
                        	disposition stats
                        	**type**\:   :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                        
                        .. attribute:: impostion_stats
                        
                        	imposition stats
                        	**type**\:   :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                        
                        .. attribute:: sequence_number
                        
                        	sequence numbers
                        	**type**\:   :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.dispostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                            self.dispostion_stats.parent = self
                            self.impostion_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                            self.impostion_stats.parent = self
                            self.sequence_number = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                            self.sequence_number.parent = self


                        class ImpostionStats(object):
                            """
                            imposition stats
                            
                            .. attribute:: broadcast
                            
                            	Broadcast
                            	**type**\:   :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                            
                            .. attribute:: imposition_mtu_drop
                            
                            	imposition mtu drop stats
                            	**type**\:   :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                            
                            .. attribute:: imposition_stat
                            
                            	imposition stats
                            	**type**\:   :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                            
                            .. attribute:: impostion_tail_drop
                            
                            	imposition tail drop stats
                            	**type**\:   :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                            
                            .. attribute:: l2fsbi_drop
                            
                            	rx discards
                            	**type**\:   :py:class:`L2FsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop>`
                            
                            .. attribute:: multicast
                            
                            	Multicast
                            	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                            
                            .. attribute:: unknown_unicast
                            
                            	Unknown Unicast
                            	**type**\:   :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                self.broadcast.parent = self
                                self.imposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                self.imposition_mtu_drop.parent = self
                                self.imposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                self.imposition_stat.parent = self
                                self.impostion_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                self.impostion_tail_drop.parent = self
                                self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.l2fsbi_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop()
                                self.l2fsbi_drop.parent = self
                                self.multicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                self.multicast.parent = self
                                self.unknown_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                self.unknown_unicast.parent = self


                            class ImpositionStat(object):
                                """
                                imposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat']['meta_info']


                            class ImpositionMtuDrop(object):
                                """
                                imposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:imposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop']['meta_info']


                            class ImpostionTailDrop(object):
                                """
                                imposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop']['meta_info']


                            class L2FsbiDrop(object):
                                """
                                rx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:l2fsbi-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2FsbiDrop']['meta_info']


                            class Multicast(object):
                                """
                                Multicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast']['meta_info']


                            class Broadcast(object):
                                """
                                Broadcast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast']['meta_info']


                            class UnknownUnicast(object):
                                """
                                Unknown Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unknown-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:impostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast is not None and self.broadcast._has_data():
                                    return True

                                if self.imposition_mtu_drop is not None and self.imposition_mtu_drop._has_data():
                                    return True

                                if self.imposition_stat is not None and self.imposition_stat._has_data():
                                    return True

                                if self.impostion_tail_drop is not None and self.impostion_tail_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.l2fsbi_drop is not None and self.l2fsbi_drop._has_data():
                                    return True

                                if self.multicast is not None and self.multicast._has_data():
                                    return True

                                if self.unknown_unicast is not None and self.unknown_unicast._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats']['meta_info']


                        class DispostionStats(object):
                            """
                            disposition stats
                            
                            .. attribute:: broadcast_drop
                            
                            	disposition storm control broadcast drop stats
                            	**type**\:   :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                            
                            .. attribute:: dai_drop
                            
                            	Disposition dynamic ARP inspection drop statistics
                            	**type**\:   :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                            
                            .. attribute:: disposition_mtu_drop
                            
                            	disposition mtu drop stats
                            	**type**\:   :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                            
                            .. attribute:: disposition_oo_o_drops
                            
                            	Disposition Out\-of\-Order Drops
                            	**type**\:   :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                            
                            .. attribute:: disposition_p2mp_stats
                            
                            	Disposition P2MP Stats
                            	**type**\:   :py:class:`DispositionP2MpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats>`
                            
                            .. attribute:: disposition_stat
                            
                            	disposition stats
                            	**type**\:   :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                            
                            .. attribute:: disposition_tail_drop
                            
                            	disposition tail drop stats
                            	**type**\:   :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                            
                            .. attribute:: ipsg_drop
                            
                            	disposition IP source guard drop statistics
                            	**type**\:   :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                            
                            .. attribute:: known_unicast
                            
                            	Known Unicast
                            	**type**\:   :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                            
                            .. attribute:: mac_move
                            
                            	MAC Move
                            	**type**\:   :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                            
                            .. attribute:: multicast_drop
                            
                            	disposition storm control multicast drop stats
                            	**type**\:   :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                            
                            .. attribute:: received_drops
                            
                            	tx discards
                            	**type**\:   :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                            
                            .. attribute:: unicast_drop
                            
                            	disposition storm control unknown unicast drop stats
                            	**type**\:   :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.broadcast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                self.broadcast_drop.parent = self
                                self.dai_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                self.dai_drop.parent = self
                                self.disposition_mtu_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                self.disposition_mtu_drop.parent = self
                                self.disposition_oo_o_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                self.disposition_oo_o_drops.parent = self
                                self.disposition_p2mp_stats = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats()
                                self.disposition_p2mp_stats.parent = self
                                self.disposition_stat = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                self.disposition_stat.parent = self
                                self.disposition_tail_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                self.disposition_tail_drop.parent = self
                                self.ipsg_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                self.ipsg_drop.parent = self
                                self.known_unicast = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                self.known_unicast.parent = self
                                self.mac_move = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                self.mac_move.parent = self
                                self.multicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                self.multicast_drop.parent = self
                                self.received_drops = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                self.received_drops.parent = self
                                self.unicast_drop = L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                self.unicast_drop.parent = self


                            class DispositionStat(object):
                                """
                                disposition stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-stat'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat']['meta_info']


                            class DispositionMtuDrop(object):
                                """
                                disposition mtu drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-mtu-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop']['meta_info']


                            class DispositionTailDrop(object):
                                """
                                disposition tail drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-tail-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop']['meta_info']


                            class MulticastDrop(object):
                                """
                                disposition storm control multicast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:multicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop']['meta_info']


                            class UnicastDrop(object):
                                """
                                disposition storm control unknown unicast drop
                                stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:unicast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop']['meta_info']


                            class BroadcastDrop(object):
                                """
                                disposition storm control broadcast drop stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:broadcast-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop']['meta_info']


                            class ReceivedDrops(object):
                                """
                                tx discards
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:received-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops']['meta_info']


                            class DaiDrop(object):
                                """
                                Disposition dynamic ARP inspection drop
                                statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dai-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop']['meta_info']


                            class IpsgDrop(object):
                                """
                                disposition IP source guard drop statistics
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:ipsg-drop'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop']['meta_info']


                            class DispositionOoODrops(object):
                                """
                                Disposition Out\-of\-Order Drops
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-oo-o-drops'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops']['meta_info']


                            class DispositionP2MpStats(object):
                                """
                                Disposition P2MP Stats
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:disposition-p2mp-stats'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2MpStats']['meta_info']


                            class KnownUnicast(object):
                                """
                                Known Unicast
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:known-unicast'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast']['meta_info']


                            class MacMove(object):
                                """
                                MAC Move
                                
                                .. attribute:: byte_counts
                                
                                	bytes counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: byte
                                
                                .. attribute:: packet_counts
                                
                                	packets counters
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    self.parent = None
                                    self.byte_counts = None
                                    self.packet_counts = None

                                @property
                                def _common_path(self):
                                    if self.parent is None:
                                        raise YPYModelError('parent is not set . Cannot derive path.')

                                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:mac-move'

                                def is_config(self):
                                    ''' Returns True if this instance represents config data else returns False '''
                                    return False

                                def _has_data(self):
                                    if not self.is_config():
                                        return False
                                    if self.byte_counts is not None:
                                        return True

                                    if self.packet_counts is not None:
                                        return True

                                    return False

                                @staticmethod
                                def _meta_info():
                                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove']['meta_info']

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:dispostion-stats'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.broadcast_drop is not None and self.broadcast_drop._has_data():
                                    return True

                                if self.dai_drop is not None and self.dai_drop._has_data():
                                    return True

                                if self.disposition_mtu_drop is not None and self.disposition_mtu_drop._has_data():
                                    return True

                                if self.disposition_oo_o_drops is not None and self.disposition_oo_o_drops._has_data():
                                    return True

                                if self.disposition_p2mp_stats is not None and self.disposition_p2mp_stats._has_data():
                                    return True

                                if self.disposition_stat is not None and self.disposition_stat._has_data():
                                    return True

                                if self.disposition_tail_drop is not None and self.disposition_tail_drop._has_data():
                                    return True

                                if self.ipsg_drop is not None and self.ipsg_drop._has_data():
                                    return True

                                if self.known_unicast is not None and self.known_unicast._has_data():
                                    return True

                                if self.mac_move is not None and self.mac_move._has_data():
                                    return True

                                if self.multicast_drop is not None and self.multicast_drop._has_data():
                                    return True

                                if self.received_drops is not None and self.received_drops._has_data():
                                    return True

                                if self.unicast_drop is not None and self.unicast_drop._has_data():
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats']['meta_info']


                        class SequenceNumber(object):
                            """
                            sequence numbers
                            
                            .. attribute:: bypassed_inbound_sequence_packet
                            
                            	Bypassed inbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: bypassed_out_sequence_packet
                            
                            	Bypassed outbound sequence packets
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: sequence_number_expected
                            
                            	sequence number expected
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequence_number_sent
                            
                            	sequence number sent
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                self.parent = None
                                self.bypassed_inbound_sequence_packet = None
                                self.bypassed_out_sequence_packet = None
                                self.sequence_number_expected = None
                                self.sequence_number_sent = None

                            @property
                            def _common_path(self):
                                if self.parent is None:
                                    raise YPYModelError('parent is not set . Cannot derive path.')

                                return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:sequence-number'

                            def is_config(self):
                                ''' Returns True if this instance represents config data else returns False '''
                                return False

                            def _has_data(self):
                                if not self.is_config():
                                    return False
                                if self.bypassed_inbound_sequence_packet is not None:
                                    return True

                                if self.bypassed_out_sequence_packet is not None:
                                    return True

                                if self.sequence_number_expected is not None:
                                    return True

                                if self.sequence_number_sent is not None:
                                    return True

                                return False

                            @staticmethod
                            def _meta_info():
                                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber']['meta_info']

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:statistics'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.dispostion_stats is not None and self.dispostion_stats._has_data():
                                return True

                            if self.impostion_stats is not None and self.impostion_stats._has_data():
                                return True

                            if self.sequence_number is not None and self.sequence_number._has_data():
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics']['meta_info']


                    class P2MpPw(object):
                        """
                        P2MP Pseudowire Information
                        
                        .. attribute:: local_available
                        
                        	Local LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: local_extended_tunnel_id
                        
                        	Local Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: local_flags
                        
                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: local_label
                        
                        	Local Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_p2mp_id
                        
                        	Local P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_ptree_type
                        
                        	Local P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: local_tunnel_id
                        
                        	Local Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_available
                        
                        	Remote LSM info available
                        	**type**\:  bool
                        
                        .. attribute:: remote_extended_tunnel_id
                        
                        	Remote Extended Tunnel ID
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: remote_flags
                        
                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_label
                        
                        	Remote Label
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_p2mp_id
                        
                        	Remote P2MP ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_ptree_type
                        
                        	Remote P\-Tree Type
                        	**type**\:   :py:class:`L2VpnP2MpPwPtreeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnP2MpPwPtreeEnum>`
                        
                        .. attribute:: remote_tunnel_id
                        
                        	Remote Tunnel ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.local_available = None
                            self.local_extended_tunnel_id = None
                            self.local_flags = None
                            self.local_label = None
                            self.local_p2mp_id = None
                            self.local_ptree_type = None
                            self.local_tunnel_id = None
                            self.remote_available = None
                            self.remote_extended_tunnel_id = None
                            self.remote_flags = None
                            self.remote_label = None
                            self.remote_p2mp_id = None
                            self.remote_ptree_type = None
                            self.remote_tunnel_id = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:p2mp-pw'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.local_available is not None:
                                return True

                            if self.local_extended_tunnel_id is not None:
                                return True

                            if self.local_flags is not None:
                                return True

                            if self.local_label is not None:
                                return True

                            if self.local_p2mp_id is not None:
                                return True

                            if self.local_ptree_type is not None:
                                return True

                            if self.local_tunnel_id is not None:
                                return True

                            if self.remote_available is not None:
                                return True

                            if self.remote_extended_tunnel_id is not None:
                                return True

                            if self.remote_flags is not None:
                                return True

                            if self.remote_label is not None:
                                return True

                            if self.remote_p2mp_id is not None:
                                return True

                            if self.remote_ptree_type is not None:
                                return True

                            if self.remote_tunnel_id is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2MpPw']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:pseudowire'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ad_method is not None:
                            return True

                        if self.ad_remote_down is not None:
                            return True

                        if self.admited_bw is not None:
                            return True

                        if self.auto_discovery is not None:
                            return True

                        if self.backup_active is not None:
                            return True

                        if self.backup_force_active is not None:
                            return True

                        if self.backup_pw is not None:
                            return True

                        if self.bitrate_mismatched is not None:
                            return True

                        if self.bridge_pw_type_mismatch is not None:
                            return True

                        if self.cas_mismatched is not None:
                            return True

                        if self.diff_ts_mismatched is not None:
                            return True

                        if self.disable_delay is not None:
                            return True

                        if self.disable_never is not None:
                            return True

                        if self.encapsulation_info is not None and self.encapsulation_info._has_data():
                            return True

                        if self.evpn_src_acid is not None:
                            return True

                        if self.fe_ctype is not None:
                            return True

                        if self.forward_class is not None:
                            return True

                        if self.freq_mismatched is not None:
                            return True

                        if self.illegal_control_word is not None:
                            return True

                        if self.imposed_vlan_id is not None:
                            return True

                        if self.interworking is not None:
                            return True

                        if self.ipv6_local_source_address is not None:
                            return True

                        if self.is_evpnvpws_type is not None:
                            return True

                        if self.is_flow_label_static is not None:
                            return True

                        if self.is_multi_segment_pseudowire is not None:
                            return True

                        if self.is_partially_programmed is not None:
                            return True

                        if self.is_pwr_type is not None:
                            return True

                        if self.is_vfi is not None:
                            return True

                        if self.last_time_status_changed is not None:
                            return True

                        if self.last_time_status_down is not None:
                            return True

                        if self.ldp_label_advertise_failed is not None:
                            return True

                        if self.load_balance is not None:
                            return True

                        if self.local_control_word is not None:
                            return True

                        if self.local_interface is not None and self.local_interface._has_data():
                            return True

                        if self.local_label_failed is not None:
                            return True

                        if self.local_pseudo_wire_type is not None:
                            return True

                        if self.local_signalling is not None and self.local_signalling._has_data():
                            return True

                        if self.local_source_address is not None:
                            return True

                        if self.mac_limit_oper_down is not None:
                            return True

                        if self.mtu_mismatched is not None:
                            return True

                        if self.not_supported_qinq is not None:
                            return True

                        if self.num_ma_cwithdraw_msg_received is not None:
                            return True

                        if self.number_ma_cwithdraw_message_sent is not None:
                            return True

                        if self.out_of_memory_state is not None:
                            return True

                        if self.p2mp_pw is not None and self.p2mp_pw._has_data():
                            return True

                        if self.payload_bytes_mismatched is not None:
                            return True

                        if self.payload_type_mismatched is not None:
                            return True

                        if self.peer_id is not None and self.peer_id._has_data():
                            return True

                        if self.preferred_path is not None and self.preferred_path._has_data():
                            return True

                        if self.preferred_path_disable_fallback is not None:
                            return True

                        if self.primary_peer_id is not None:
                            return True

                        if self.primary_pseudo_wire_id is not None:
                            return True

                        if self.primary_pw is not None:
                            return True

                        if self.protocol is not None:
                            return True

                        if self.pseudo_wire_id is not None:
                            return True

                        if self.pseudo_wire_state is not None:
                            return True

                        if self.pseudo_wire_type_mismatched is not None:
                            return True

                        if self.pw_class_name is not None:
                            return True

                        if self.pw_flow_label_code17_disabled is not None:
                            return True

                        if self.pw_flow_label_type is not None:
                            return True

                        if self.pw_flow_label_type_cfg is not None:
                            return True

                        if self.pw_redundancy_initial_delay is not None:
                            return True

                        if self.pw_redundancy_one_way is not None:
                            return True

                        if self.pw_status_use is not None:
                            return True

                        if self.pwlsd_rewrite_failed is not None:
                            return True

                        if self.remote_control_word is not None:
                            return True

                        if self.remote_interface is not None and self.remote_interface._has_data():
                            return True

                        if self.remote_label_failed is not None:
                            return True

                        if self.remote_pseudo_wire_type is not None:
                            return True

                        if self.remote_signalling is not None and self.remote_signalling._has_data():
                            return True

                        if self.required_bw is not None:
                            return True

                        if self.resync_enabled is not None:
                            return True

                        if self.resync_threshold is not None:
                            return True

                        if self.rtp_mismatched is not None:
                            return True

                        if self.sequencing_type is not None:
                            return True

                        if self.shutdown is not None:
                            return True

                        if self.sig_pkts_mismatched is not None:
                            return True

                        if self.ssrc_mismatched is not None:
                            return True

                        if self.state is not None:
                            return True

                        if self.statistics is not None and self.statistics._has_data():
                            return True

                        if self.table_policy_name is not None:
                            return True

                        if self.tag_rewrite is not None:
                            return True

                        if self.time_created is not None:
                            return True

                        if self.time_elapsed_creation is not None:
                            return True

                        if self.time_elapsed_status_changed is not None:
                            return True

                        if self.time_elapsed_status_down is not None:
                            return True

                        if self.transport_lsp_down is not None:
                            return True

                        if self.xconnect_id is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service-info'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.name is not None:
                        return True

                    if self.num_p_ws is not None:
                        return True

                    if self.pseudowire is not None:
                        for child_ref in self.pseudowire:
                            if child_ref._has_data():
                                return True

                    if self.state is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo']['meta_info']

            @property
            def _common_path(self):
                if self.name is None:
                    raise YPYModelError('Key property name is None')

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-service[Cisco-IOS-XR-l2vpn-oper:name = ' + str(self.name) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.name is not None:
                    return True

                if self.flexible_xconnect_service_acs is not None and self.flexible_xconnect_service_acs._has_data():
                    return True

                if self.flexible_xconnect_service_info is not None and self.flexible_xconnect_service_info._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.FlexibleXconnectServices.FlexibleXconnectService']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:flexible-xconnect-services'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.flexible_xconnect_service is not None:
                for child_ref in self.flexible_xconnect_service:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.FlexibleXconnectServices']['meta_info']


    class XconnectBrief(object):
        """
        XConnect brief information
        
        .. attribute:: encapsulation_report_matrix
        
        	Encapsulation report counters matrix
        	**type**\: list of    :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationReportMatrix>`
        
        .. attribute:: encapsulation_total
        
        	Total summary
        	**type**\: list of    :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationTotal>`
        
        .. attribute:: main_total_down
        
        	Total Number of non\-active Cross\-Conections with valid encaps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: main_total_unresolved
        
        	Total Number of unresolved Cross\-Conections with valid encaps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: main_total_up
        
        	Total Number of active Cross\-Conections with valid encaps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        .. attribute:: memory_state
        
        	L2VPN memory state
        	**type**\:   :py:class:`L2VpnMemoryStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnMemoryStateEnum>`
        
        .. attribute:: undefined_xc
        
        	Undefined xc including PW\-PW
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.encapsulation_report_matrix = YList()
            self.encapsulation_report_matrix.parent = self
            self.encapsulation_report_matrix.name = 'encapsulation_report_matrix'
            self.encapsulation_total = YList()
            self.encapsulation_total.parent = self
            self.encapsulation_total.name = 'encapsulation_total'
            self.main_total_down = None
            self.main_total_unresolved = None
            self.main_total_up = None
            self.memory_state = None
            self.undefined_xc = None


        class EncapsulationReportMatrix(object):
            """
            Encapsulation report counters matrix
            
            .. attribute:: ac1
            
            	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
            	**type**\: list of    :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.ac1 = YList()
                self.ac1.parent = self
                self.ac1.name = 'ac1'


            class Ac1(object):
                """
                Array of l2vpn\_xc\_brief\_first layer indexed by
                the AC1 encapsulation type
                
                .. attribute:: ac2
                
                	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                	**type**\: list of    :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.ac2 = YList()
                    self.ac2.parent = self
                    self.ac2.name = 'ac2'


                class Ac2(object):
                    """
                    Array of l2vpn\_xc\_brief\_line indexed by the AC2
                    encapsulation type plus one type for PW
                    
                    .. attribute:: ac1_encapsulation
                    
                    	AC1 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                    
                    .. attribute:: ac2_encapsulation
                    
                    	AC2 encapsulation
                    	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
                    
                    .. attribute:: down_count
                    
                    	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unresolved_count
                    
                    	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: up_count
                    
                    	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
                    	**type**\:  list of int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.ac1_encapsulation = None
                        self.ac2_encapsulation = None
                        self.down_count = YLeafList()
                        self.down_count.parent = self
                        self.down_count.name = 'down_count'
                        self.unresolved_count = YLeafList()
                        self.unresolved_count.parent = self
                        self.unresolved_count.name = 'unresolved_count'
                        self.up_count = YLeafList()
                        self.up_count.parent = self
                        self.up_count.name = 'up_count'

                    @property
                    def _common_path(self):

                        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix/Cisco-IOS-XR-l2vpn-oper:ac1/Cisco-IOS-XR-l2vpn-oper:ac2'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.ac1_encapsulation is not None:
                            return True

                        if self.ac2_encapsulation is not None:
                            return True

                        if self.down_count is not None:
                            for child in self.down_count:
                                if child is not None:
                                    return True

                        if self.unresolved_count is not None:
                            for child in self.unresolved_count:
                                if child is not None:
                                    return True

                        if self.up_count is not None:
                            for child in self.up_count:
                                if child is not None:
                                    return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2']['meta_info']

                @property
                def _common_path(self):

                    return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix/Cisco-IOS-XR-l2vpn-oper:ac1'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.ac2 is not None:
                        for child_ref in self.ac2:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['L2Vpn.XconnectBrief.EncapsulationReportMatrix.Ac1']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-report-matrix'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.ac1 is not None:
                    for child_ref in self.ac1:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.XconnectBrief.EncapsulationReportMatrix']['meta_info']


        class EncapsulationTotal(object):
            """
            Total summary
            
            .. attribute:: ac1_encapsulation
            
            	AC1 encapsulation
            	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
            
            .. attribute:: ac2_encapsulation
            
            	AC2 encapsulation
            	**type**\:   :py:class:`L2VpnAcEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2VpnAcEncapEnum>`
            
            .. attribute:: down_count
            
            	Number of non\-active cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_count
            
            	Number of unresolved cross\-connections array \- Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is EthernetInterworking, 3 is Total
            	**type**\:  list of int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.ac1_encapsulation = None
                self.ac2_encapsulation = None
                self.down_count = YLeafList()
                self.down_count.parent = self
                self.down_count.name = 'down_count'
                self.unresolved_count = YLeafList()
                self.unresolved_count.parent = self
                self.unresolved_count.name = 'unresolved_count'
                self.up_count = YLeafList()
                self.up_count.parent = self
                self.up_count.name = 'up_count'

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-brief/Cisco-IOS-XR-l2vpn-oper:encapsulation-total'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.ac1_encapsulation is not None:
                    return True

                if self.ac2_encapsulation is not None:
                    return True

                if self.down_count is not None:
                    for child in self.down_count:
                        if child is not None:
                            return True

                if self.unresolved_count is not None:
                    for child in self.unresolved_count:
                        if child is not None:
                            return True

                if self.up_count is not None:
                    for child in self.up_count:
                        if child is not None:
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['L2Vpn.XconnectBrief.EncapsulationTotal']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:l2vpn/Cisco-IOS-XR-l2vpn-oper:xconnect-brief'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.encapsulation_report_matrix is not None:
                for child_ref in self.encapsulation_report_matrix:
                    if child_ref._has_data():
                        return True

            if self.encapsulation_total is not None:
                for child_ref in self.encapsulation_total:
                    if child_ref._has_data():
                        return True

            if self.main_total_down is not None:
                return True

            if self.main_total_unresolved is not None:
                return True

            if self.main_total_up is not None:
                return True

            if self.memory_state is not None:
                return True

            if self.undefined_xc is not None:
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['L2Vpn.XconnectBrief']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-l2vpn-oper:l2vpn'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.bridge_domains is not None and self.bridge_domains._has_data():
            return True

        if self.bridge_summary is not None and self.bridge_summary._has_data():
            return True

        if self.discoveries is not None and self.discoveries._has_data():
            return True

        if self.discovery_summary is not None and self.discovery_summary._has_data():
            return True

        if self.flexible_xconnect_service_summary is not None and self.flexible_xconnect_service_summary._has_data():
            return True

        if self.flexible_xconnect_services is not None and self.flexible_xconnect_services._has_data():
            return True

        if self.g8032 is not None and self.g8032._has_data():
            return True

        if self.generic_interface_list_details is not None and self.generic_interface_list_details._has_data():
            return True

        if self.generic_interfaces is not None and self.generic_interfaces._has_data():
            return True

        if self.global_settings is not None and self.global_settings._has_data():
            return True

        if self.iccp_sm is not None and self.iccp_sm._has_data():
            return True

        if self.indexes is not None and self.indexes._has_data():
            return True

        if self.l2vpn_collaborators is not None and self.l2vpn_collaborators._has_data():
            return True

        if self.l2vpn_pbb_bsa is not None and self.l2vpn_pbb_bsa._has_data():
            return True

        if self.l2vpn_resource_state is not None and self.l2vpn_resource_state._has_data():
            return True

        if self.main_interfaces is not None and self.main_interfaces._has_data():
            return True

        if self.mstp_ports is not None and self.mstp_ports._has_data():
            return True

        if self.mstp_vlans is not None and self.mstp_vlans._has_data():
            return True

        if self.mvrp is not None and self.mvrp._has_data():
            return True

        if self.nsr is not None and self.nsr._has_data():
            return True

        if self.proc_fsm is not None and self.proc_fsm._has_data():
            return True

        if self.pseudowire_classes is not None and self.pseudowire_classes._has_data():
            return True

        if self.pseudowire_headend is not None and self.pseudowire_headend._has_data():
            return True

        if self.pwr is not None and self.pwr._has_data():
            return True

        if self.xconnect_brief is not None and self.xconnect_brief._has_data():
            return True

        if self.xconnect_groups is not None and self.xconnect_groups._has_data():
            return True

        if self.xconnect_mp2mp_ce2ces is not None and self.xconnect_mp2mp_ce2ces._has_data():
            return True

        if self.xconnect_mp2mps is not None and self.xconnect_mp2mps._has_data():
            return True

        if self.xconnect_summary is not None and self.xconnect_summary._has_data():
            return True

        if self.xconnects is not None and self.xconnects._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['L2Vpn']['meta_info']


class GenericInterfaceListV2(object):
    """
    generic interface list v2
    
    .. attribute:: active
    
    	Active generic interface list operational data
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active>`
    
    .. attribute:: nodes
    
    	Table of generic interface list operational data for a particular node
    	**type**\:   :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes>`
    
    .. attribute:: standby
    
    	Standby generic interface list operational data
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2015-11-09'

    def __init__(self):
        self.active = GenericInterfaceListV2.Active()
        self.active.parent = self
        self.nodes = GenericInterfaceListV2.Nodes()
        self.nodes.parent = self
        self.standby = GenericInterfaceListV2.Standby()
        self.standby.parent = self


    class Nodes(object):
        """
        Table of generic interface list operational data
        for a particular node
        
        .. attribute:: node
        
        	Generic interface list operational data for a particular node
        	**type**\: list of    :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.node = YList()
            self.node.parent = self
            self.node.name = 'node'


        class Node(object):
            """
            Generic interface list operational data for a
            particular node
            
            .. attribute:: node_id  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: generic_interfaces
            
            	Generic interface list table
            	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaces>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.node_id = None
                self.generic_interfaces = GenericInterfaceListV2.Nodes.Node.GenericInterfaces()
                self.generic_interfaces.parent = self


            class GenericInterfaces(object):
                """
                Generic interface list table
                
                .. attribute:: generic_interface
                
                	Generic Interface List
                	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.generic_interface = YList()
                    self.generic_interface.parent = self
                    self.generic_interface.name = 'generic_interface'


                class GenericInterface(object):
                    """
                    Generic Interface List
                    
                    .. attribute:: generic_interface_list_name  <key>
                    
                    	Generic Interface List Name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface>`
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_list_name
                    
                    	Interface\-list name
                    	**type**\:  str
                    
                    	**length:** 0..33
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is Interface list downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: is_provisioned
                    
                    	Is Provisioned
                    	**type**\:  bool
                    
                    .. attribute:: items
                    
                    	Number of items on which interface list is replicated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.generic_interface_list_name = None
                        self.interface = YList()
                        self.interface.parent = self
                        self.interface.name = 'interface'
                        self.interface_list_id = None
                        self.interface_list_name = None
                        self.is_fib_downloaded = None
                        self.is_provisioned = None
                        self.items = None


                    class Interface(object):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\:  str
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\:  bool
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            self.parent = None
                            self.interface_name = None
                            self.is_fib_downloaded = None
                            self.not_supported_replications = None
                            self.pending_replications = None

                        @property
                        def _common_path(self):
                            if self.parent is None:
                                raise YPYModelError('parent is not set . Cannot derive path.')

                            return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                        def is_config(self):
                            ''' Returns True if this instance represents config data else returns False '''
                            return False

                        def _has_data(self):
                            if not self.is_config():
                                return False
                            if self.interface_name is not None:
                                return True

                            if self.is_fib_downloaded is not None:
                                return True

                            if self.not_supported_replications is not None:
                                return True

                            if self.pending_replications is not None:
                                return True

                            return False

                        @staticmethod
                        def _meta_info():
                            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                            return meta._meta_table['GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface.Interface']['meta_info']

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')
                        if self.generic_interface_list_name is None:
                            raise YPYModelError('Key property generic_interface_list_name is None')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:generic-interface-list-name = ' + str(self.generic_interface_list_name) + ']'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.generic_interface_list_name is not None:
                            return True

                        if self.interface is not None:
                            for child_ref in self.interface:
                                if child_ref._has_data():
                                    return True

                        if self.interface_list_id is not None:
                            return True

                        if self.interface_list_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.is_provisioned is not None:
                            return True

                        if self.items is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['GenericInterfaceListV2.Nodes.Node.GenericInterfaces.GenericInterface']['meta_info']

                @property
                def _common_path(self):
                    if self.parent is None:
                        raise YPYModelError('parent is not set . Cannot derive path.')

                    return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.generic_interface is not None:
                        for child_ref in self.generic_interface:
                            if child_ref._has_data():
                                return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['GenericInterfaceListV2.Nodes.Node.GenericInterfaces']['meta_info']

            @property
            def _common_path(self):
                if self.node_id is None:
                    raise YPYModelError('Key property node_id is None')

                return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:nodes/Cisco-IOS-XR-l2vpn-oper:node[Cisco-IOS-XR-l2vpn-oper:node-id = ' + str(self.node_id) + ']'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.node_id is not None:
                    return True

                if self.generic_interfaces is not None and self.generic_interfaces._has_data():
                    return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['GenericInterfaceListV2.Nodes.Node']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:nodes'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.node is not None:
                for child_ref in self.node:
                    if child_ref._has_data():
                        return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['GenericInterfaceListV2.Nodes']['meta_info']


    class Standby(object):
        """
        Standby generic interface list operational data
        
        .. attribute:: generic_interfaces
        
        	Generic interface list table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaces>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.generic_interfaces = GenericInterfaceListV2.Standby.GenericInterfaces()
            self.generic_interfaces.parent = self


        class GenericInterfaces(object):
            """
            Generic interface list table
            
            .. attribute:: generic_interface
            
            	Generic Interface List
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.generic_interface = YList()
                self.generic_interface.parent = self
                self.generic_interface.name = 'generic_interface'


            class GenericInterface(object):
                """
                Generic Interface List
                
                .. attribute:: generic_interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: is_fib_downloaded
                
                	Is Interface list downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items on which interface list is replicated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.generic_interface_list_name = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.interface_list_id = None
                    self.interface_list_name = None
                    self.is_fib_downloaded = None
                    self.is_provisioned = None
                    self.items = None


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface.Interface']['meta_info']

                @property
                def _common_path(self):
                    if self.generic_interface_list_name is None:
                        raise YPYModelError('Key property generic_interface_list_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:generic-interfaces/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:generic-interface-list-name = ' + str(self.generic_interface_list_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.generic_interface_list_name is not None:
                        return True

                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.interface_list_id is not None:
                        return True

                    if self.interface_list_name is not None:
                        return True

                    if self.is_fib_downloaded is not None:
                        return True

                    if self.is_provisioned is not None:
                        return True

                    if self.items is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['GenericInterfaceListV2.Standby.GenericInterfaces.GenericInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:standby/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.generic_interface is not None:
                    for child_ref in self.generic_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['GenericInterfaceListV2.Standby.GenericInterfaces']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:standby'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.generic_interfaces is not None and self.generic_interfaces._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['GenericInterfaceListV2.Standby']['meta_info']


    class Active(object):
        """
        Active generic interface list operational data
        
        .. attribute:: generic_interfaces
        
        	Generic interface list table
        	**type**\:   :py:class:`GenericInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaces>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2015-11-09'

        def __init__(self):
            self.parent = None
            self.generic_interfaces = GenericInterfaceListV2.Active.GenericInterfaces()
            self.generic_interfaces.parent = self


        class GenericInterfaces(object):
            """
            Generic interface list table
            
            .. attribute:: generic_interface
            
            	Generic Interface List
            	**type**\: list of    :py:class:`GenericInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2015-11-09'

            def __init__(self):
                self.parent = None
                self.generic_interface = YList()
                self.generic_interface.parent = self
                self.generic_interface.name = 'generic_interface'


            class GenericInterface(object):
                """
                Generic Interface List
                
                .. attribute:: generic_interface_list_name  <key>
                
                	Generic Interface List Name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface>`
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_list_name
                
                	Interface\-list name
                	**type**\:  str
                
                	**length:** 0..33
                
                .. attribute:: is_fib_downloaded
                
                	Is Interface list downloaded to FIB
                	**type**\:  bool
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\:  bool
                
                .. attribute:: items
                
                	Number of items on which interface list is replicated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    self.parent = None
                    self.generic_interface_list_name = None
                    self.interface = YList()
                    self.interface.parent = self
                    self.interface.name = 'interface'
                    self.interface_list_id = None
                    self.interface_list_name = None
                    self.is_fib_downloaded = None
                    self.is_provisioned = None
                    self.items = None


                class Interface(object):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\:  str
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\:  bool
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        self.parent = None
                        self.interface_name = None
                        self.is_fib_downloaded = None
                        self.not_supported_replications = None
                        self.pending_replications = None

                    @property
                    def _common_path(self):
                        if self.parent is None:
                            raise YPYModelError('parent is not set . Cannot derive path.')

                        return self.parent._common_path +'/Cisco-IOS-XR-l2vpn-oper:interface'

                    def is_config(self):
                        ''' Returns True if this instance represents config data else returns False '''
                        return False

                    def _has_data(self):
                        if not self.is_config():
                            return False
                        if self.interface_name is not None:
                            return True

                        if self.is_fib_downloaded is not None:
                            return True

                        if self.not_supported_replications is not None:
                            return True

                        if self.pending_replications is not None:
                            return True

                        return False

                    @staticmethod
                    def _meta_info():
                        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                        return meta._meta_table['GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface.Interface']['meta_info']

                @property
                def _common_path(self):
                    if self.generic_interface_list_name is None:
                        raise YPYModelError('Key property generic_interface_list_name is None')

                    return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:generic-interfaces/Cisco-IOS-XR-l2vpn-oper:generic-interface[Cisco-IOS-XR-l2vpn-oper:generic-interface-list-name = ' + str(self.generic_interface_list_name) + ']'

                def is_config(self):
                    ''' Returns True if this instance represents config data else returns False '''
                    return False

                def _has_data(self):
                    if not self.is_config():
                        return False
                    if self.generic_interface_list_name is not None:
                        return True

                    if self.interface is not None:
                        for child_ref in self.interface:
                            if child_ref._has_data():
                                return True

                    if self.interface_list_id is not None:
                        return True

                    if self.interface_list_name is not None:
                        return True

                    if self.is_fib_downloaded is not None:
                        return True

                    if self.is_provisioned is not None:
                        return True

                    if self.items is not None:
                        return True

                    return False

                @staticmethod
                def _meta_info():
                    from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                    return meta._meta_table['GenericInterfaceListV2.Active.GenericInterfaces.GenericInterface']['meta_info']

            @property
            def _common_path(self):

                return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:active/Cisco-IOS-XR-l2vpn-oper:generic-interfaces'

            def is_config(self):
                ''' Returns True if this instance represents config data else returns False '''
                return False

            def _has_data(self):
                if not self.is_config():
                    return False
                if self.generic_interface is not None:
                    for child_ref in self.generic_interface:
                        if child_ref._has_data():
                            return True

                return False

            @staticmethod
            def _meta_info():
                from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
                return meta._meta_table['GenericInterfaceListV2.Active.GenericInterfaces']['meta_info']

        @property
        def _common_path(self):

            return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/Cisco-IOS-XR-l2vpn-oper:active'

        def is_config(self):
            ''' Returns True if this instance represents config data else returns False '''
            return False

        def _has_data(self):
            if not self.is_config():
                return False
            if self.generic_interfaces is not None and self.generic_interfaces._has_data():
                return True

            return False

        @staticmethod
        def _meta_info():
            from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
            return meta._meta_table['GenericInterfaceListV2.Active']['meta_info']

    @property
    def _common_path(self):

        return '/Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2'

    def is_config(self):
        ''' Returns True if this instance represents config data else returns False '''
        return False

    def _has_data(self):
        if not self.is_config():
            return False
        if self.active is not None and self.active._has_data():
            return True

        if self.nodes is not None and self.nodes._has_data():
            return True

        if self.standby is not None and self.standby._has_data():
            return True

        return False

    @staticmethod
    def _meta_info():
        from ydk.models.cisco_ios_xr._meta import _Cisco_IOS_XR_l2vpn_oper as meta
        return meta._meta_table['GenericInterfaceListV2']['meta_info']


